#!/usr/bin/env bash
#Title........: language_strings.sh
#Description..: All the translated strings that airgeddon uses are located here.
#Author.......: v1s1t0r
#Date.........: 20180815
#Bash Version.: 4.2 or later

#Set language_strings file version
#shellcheck disable=SC2034
function set_language_strings_version() {

	debug_print

	language_strings_version="8.11-1"
}

#Set different language text strings
#shellcheck disable=SC2154
#shellcheck disable=SC2034
function language_strings() {

	debug_print

	if [[ "$(declare -p wps_data_array 2> /dev/null)" != "declare -A"* ]]; then
		declare -gA wps_data_array
	fi

	declare -A unknown_chipset
	unknown_chipset["ENGLISH"]="Unknown"
	unknown_chipset["SPANISH"]="Desconocido"
	unknown_chipset["FRENCH"]="Inconnu"
	unknown_chipset["CATALAN"]="Desconegut"
	unknown_chipset["PORTUGUESE"]="Desconhecido"
	unknown_chipset["RUSSIAN"]="Неизвестно"
	unknown_chipset["GREEK"]="Άγνωστο"
	unknown_chipset["ITALIAN"]="Sconosciuto"
	unknown_chipset["POLISH"]="Nieznany"
	unknown_chipset["GERMAN"]="Unbekannt"
	unknown_chipset["TURKISH"]="Bilinmeyen"
	unknown_chipsetvar="${unknown_chipset[${language}]}"

	declare -A hintprefix
	hintprefix["ENGLISH"]="Hint"
	hintprefix["SPANISH"]="Consejo"
	hintprefix["FRENCH"]="Conseil"
	hintprefix["CATALAN"]="Consell"
	hintprefix["PORTUGUESE"]="Conselho"
	hintprefix["RUSSIAN"]="Подсказка"
	hintprefix["GREEK"]="Συμβουλή"
	hintprefix["ITALIAN"]="Consiglio"
	hintprefix["POLISH"]="Wskazówka"
	hintprefix["GERMAN"]="Rat"
	hintprefix["TURKISH"]="İpucu"
	hintvar="*${hintprefix[${language}]}*"
	escaped_hintvar="\*${hintprefix[${language}]}\*"

	declare -A optionaltool_needed
	optionaltool_needed["ENGLISH"]="Locked option, it needs: "
	optionaltool_needed["SPANISH"]="Opción bloqueada, requiere: "
	optionaltool_needed["FRENCH"]="Option bloquée parce qu’il manque: "
	optionaltool_needed["CATALAN"]="Opció bloquejada, necessita: "
	optionaltool_needed["PORTUGUESE"]="Opção bloqueada requer: "
	optionaltool_needed["RUSSIAN"]="Опция заблокирована, требуется: "
	optionaltool_needed["GREEK"]="Κλειδωμένη επιλογή, χρειάζεται: "
	optionaltool_needed["ITALIAN"]="Opzione bloccata, richiede: "
	optionaltool_needed["POLISH"]="Opcja zablokowana, wymaga: "
	optionaltool_needed["GERMAN"]="Option gesperrt, folgendes ist erfordert: "
	optionaltool_needed["TURKISH"]="Engellenen seçenek şunları gerektirir: "

	declare -A under_construction
	under_construction["ENGLISH"]="under construction"
	under_construction["SPANISH"]="en construcción"
	under_construction["FRENCH"]="en construction"
	under_construction["CATALAN"]="en construcció"
	under_construction["PORTUGUESE"]="em construção"
	under_construction["RUSSIAN"]="на ремонте"
	under_construction["GREEK"]="υπό κατασκευή"
	under_construction["ITALIAN"]="in costruzione"
	under_construction["POLISH"]="w budowie"
	under_construction["GERMAN"]="im Aufbau"
	under_construction["TURKISH"]="yapım aşamasında"
	under_constructionvar="${under_construction[${language}]}"

	declare -gA possible_package_names_text
	possible_package_names_text["ENGLISH"]="Possible package name"
	possible_package_names_text["SPANISH"]="Posible nombre del paquete"
	possible_package_names_text["FRENCH"]="Possible nom du paquet"
	possible_package_names_text["CATALAN"]="Possible nom del paquet"
	possible_package_names_text["PORTUGUESE"]="Possível nome do pacote"
	possible_package_names_text["RUSSIAN"]="Возможное имя пакета"
	possible_package_names_text["GREEK"]="Πιθανό όνομα πακέτου"
	possible_package_names_text["ITALIAN"]="Possibile nome del pacchetto"
	possible_package_names_text["POLISH"]="Możliwa nazwa pakietu"
	possible_package_names_text["GERMAN"]="Möglicher Paketname"
	possible_package_names_text["TURKISH"]="Olası paket adı"

	declare -gA et_misc_texts
	et_misc_texts["ENGLISH",0]="Evil Twin AP Info"
	et_misc_texts["SPANISH",0]="Info Evil Twin AP"
	et_misc_texts["FRENCH",0]="Info Evil Twin AP"
	et_misc_texts["CATALAN",0]="Info Evil Twin AP"
	et_misc_texts["PORTUGUESE",0]="Info Evil Twin AP"
	et_misc_texts["RUSSIAN",0]="Информация о Злом Двойнике ТД"
	et_misc_texts["GREEK",0]="Πληροφορίες Evil Twin AP"
	et_misc_texts["ITALIAN",0]="Info Evil Twin AP"
	et_misc_texts["POLISH",0]="Informacja Evil Twin AP"
	et_misc_texts["GERMAN",0]="Information über Evil Twin AP"
	et_misc_texts["TURKISH",0]="Şeytani İkiz"

	et_misc_texts["ENGLISH",1]="Channel"
	et_misc_texts["SPANISH",1]="Canal"
	et_misc_texts["FRENCH",1]="Canal"
	et_misc_texts["CATALAN",1]="Canal"
	et_misc_texts["PORTUGUESE",1]="Canal"
	et_misc_texts["RUSSIAN",1]="Канал"
	et_misc_texts["GREEK",1]="Κανάλι"
	et_misc_texts["ITALIAN",1]="Canale"
	et_misc_texts["POLISH",1]="Kanał"
	et_misc_texts["GERMAN",1]="Kanal"
	et_misc_texts["TURKISH",1]="Kanal"

	et_misc_texts["ENGLISH",2]="Online time"
	et_misc_texts["SPANISH",2]="Tiempo online"
	et_misc_texts["FRENCH",2]="Temps en ligne"
	et_misc_texts["CATALAN",2]="Temps online"
	et_misc_texts["PORTUGUESE",2]="Tempo online"
	et_misc_texts["RUSSIAN",2]="Время онлайн"
	et_misc_texts["GREEK",2]="Χρόνος σε σύνδεση"
	et_misc_texts["ITALIAN",2]="Tempo online"
	et_misc_texts["POLISH",2]="Czas online"
	et_misc_texts["GERMAN",2]="Zeit online"
	et_misc_texts["TURKISH",2]="Çevrimiçi zaman"

	et_misc_texts["ENGLISH",3]="DHCP ips given to possible connected clients"
	et_misc_texts["SPANISH",3]="Ips entregadas por DHCP a posibles clientes conectados"
	et_misc_texts["FRENCH",3]="Ips attribuées à d'éventuels clients DHCP"
	et_misc_texts["CATALAN",3]="Ips lliurades per DHCP a possibles clients connectats"
	et_misc_texts["PORTUGUESE",3]="Ips entregues pelo DHCP aos possíveis clientes conectados"
	et_misc_texts["RUSSIAN",3]="IP, которые DHCP будет давать возможным подключённым клиентам"
	et_misc_texts["GREEK",3]="DHCP IP διευθύνσεις που έχουν δωθεί σε πιθανούς συνδεδεμένους χρήστες"
	et_misc_texts["ITALIAN",3]="Ips forniti dal DHCP a possibili clienti collegati"
	et_misc_texts["POLISH",3]="Adresy IP przydzielane przez DHCP do połączonych potencjalnych klientów"
	et_misc_texts["GERMAN",3]="Ips durch DHCP an mögliche verbundene Clients geliefert"
	et_misc_texts["TURKISH",3]="Olası bağlanmış istemcilere verilen DHCP ipler"

	et_misc_texts["ENGLISH",4]="With this attack you have to use an external sniffer to try to obtain client passwords connected to the network"
	et_misc_texts["SPANISH",4]="Con este ataque has de usar un sniffer externo para intentar obtener contraseñas de los clientes conectados a la red"
	et_misc_texts["FRENCH",4]="Avec cette attaque, vous devez utiliser un sniffeur pour tenter d'obtenir les mots de passe des clients connectés au réseau"
	et_misc_texts["CATALAN",4]="Amb aquest atac has d'utilitzar un sniffer extern per intentar obtenir contrasenyes dels clients connectats a la xarxa"
	et_misc_texts["PORTUGUESE",4]="Com este ataque você tem que usar um sniffer externo para tentar obter as senhas dos clientes conectados à rede"
	et_misc_texts["RUSSIAN",4]="С этой атакой вам нужно использовать внешний сниффер для попытки получить пароли клиентов, подключённых к сети"
	et_misc_texts["GREEK",4]="Με αυτή την επίθεση θα πρέπει να χρησιμοποιήσετε έναν εξωτερικό sniffer για να μπορέσετε να υποκλέψετε κωδικούς πρόσβασης από τους χρήστες που είναι συνδεδεμένοι στο δίκτυο"
	et_misc_texts["ITALIAN",4]="Con questo attacco è necessario utilizzare uno sniffer esterno per cercare di ottenere le password dei clienti connessi alla rete"
	et_misc_texts["POLISH",4]="W tym ataku musisz użyć zewnętrznego sniffera, aby spróbować uzyskać hasła od klientów podłączonych do sieci"
	et_misc_texts["GERMAN",4]="Mit diesem Angriff ist ein externer Sniffer erforderlich um Passwörter von am Netzwerk verbundene clients zu stehlen"
	et_misc_texts["TURKISH",4]="Bu saldırı sonucunda ağa bağlı müşteri şifrelerini edinmek için harici bir algılayıcı kullanmanız gerekir"

	et_misc_texts["ENGLISH",5]="With this attack, watch the sniffer's screen to see if a password appears"
	et_misc_texts["SPANISH",5]="Con este ataque, estate atento a la pantalla del sniffer para ver si aparece alguna contraseña"
	et_misc_texts["FRENCH",5]="Vérifiez pendant l'attaque dans la console du sniffeur si un mot de passe a été capturé"
	et_misc_texts["CATALAN",5]="Amb aquest atac, estigues atent a la pantalla de l'sniffer per veure si apareix alguna contrasenya"
	et_misc_texts["PORTUGUESE",5]="Com este ataque, fique atento na tela do sniffer para ver se aparece alguma senha"
	et_misc_texts["RUSSIAN",5]="С этой атакой смотрите на окно сниффера, чтобы следить за появлением пароля"
	et_misc_texts["GREEK",5]="Με αυτή την επίθεση, παρακολουθήστε την οθόνη του sniffer για να δείτε αν εχει εμφανιστεί κάποιος κωδικός πρόσβασης"
	et_misc_texts["ITALIAN",5]="Con questo attacco, presta attenzione alla schermata dello sniffer per vedere se compare una password"
	et_misc_texts["POLISH",5]="Podczas tego ataku obserwuj ekran sniffera, aby zobaczyć, czy pojawia się hasło"
	et_misc_texts["GERMAN",5]="Schau mit diesem Angriff ans Bildschirm ob ein Passwort erscheint"
	et_misc_texts["TURKISH",5]="Bu saldırı ile algılayıcının ekranını görebilir ve şifre çıktığında şifreyi görebilirsiniz"

	et_misc_texts["ENGLISH",6]="With this attack, we'll wait for a network client to provide us with the password for the wifi network in our captive portal"
	et_misc_texts["SPANISH",6]="Con este ataque, esperaremos a que un cliente de la red nos provea de la contraseña de la red wifi en nuestro portal cautivo"
	et_misc_texts["FRENCH",6]="Avec cette attaque nous allons attendre qu'un client rentre le mot de passe du réseau cible dans notre portail captif"
	et_misc_texts["CATALAN",6]="Amb aquest atac, esperarem que un client de la xarxa ens proveeixi de la contrasenya de la xarxa wifi al nostre portal captiu"
	et_misc_texts["PORTUGUESE",6]="Com este ataque, vamos esperar que um cliente nos forneça a senha da rede wifi em nosso portal cativo"
	et_misc_texts["RUSSIAN",6]="С этой атакой вы будете ожидать, чтобы сетевые клиенты ввели пароль для wifi сети на нашем перехватывающем портале"
	et_misc_texts["GREEK",6]="Με αυτή την επίθεση, θα περιμένουμε για έναν χρήστη του δικτύου να μας παρέχει με τον κωδικό πρόσβασης του wifi στο captive portal μας"
	et_misc_texts["ITALIAN",6]="Con questo attacco, aspettaremo che un cliente della rete ci fornisca la password per la rete wireless attraverso il nostro captive portal"
	et_misc_texts["POLISH",6]="W tym ataku poczekamy na klienta sieci aż poda nam hasło do sieci wifi na naszej stronie captive portal"
	et_misc_texts["GERMAN",6]="Mit diesem Angriff warten wir bis ein client im Netzwerk uns das Passwort des WLANs in unserer Vorschaltseite übergibt"
	et_misc_texts["TURKISH",6]="Bu saldırı ile, şifrenin doğru bir şekilde esaret portalımıza giriş yapılmasını bekleyeceğiz"

	et_misc_texts["ENGLISH",7]="No clients connected yet"
	et_misc_texts["SPANISH",7]="No hay clientes conectados aún"
	et_misc_texts["FRENCH",7]="Toujours pas de clients connectés"
	et_misc_texts["CATALAN",7]="Encara no hi han clients connectats"
	et_misc_texts["PORTUGUESE",7]="Ainda não há clientes conectados"
	et_misc_texts["RUSSIAN",7]="Клиенты ещё не подключены"
	et_misc_texts["GREEK",7]="Ακόμα κανένας συνδεδεμένος χρήστης"
	et_misc_texts["ITALIAN",7]="Non ci sono ancora clienti collegati"
	et_misc_texts["POLISH",7]="Nie ma jeszcze żadnych podłączonych klientów"
	et_misc_texts["GERMAN",7]="Keine clients bisher verbunden"
	et_misc_texts["TURKISH",7]="Henüz hiçbir alıcı bağlanmadı"

	et_misc_texts["ENGLISH",8]="airgeddon. Evil Twin attack captured passwords"
	et_misc_texts["SPANISH",8]="airgeddon. Contraseñas capturadas en ataque Evil Twin"
	et_misc_texts["FRENCH",8]="airgeddon. Mots de passe capturés par attaque Evil Twin"
	et_misc_texts["CATALAN",8]="airgeddon. Contrasenyes capturades amb atac Evil Twin"
	et_misc_texts["PORTUGUESE",8]="airgeddon. Senhas capturadas no ataque ataque Evil Twin"
	et_misc_texts["RUSSIAN",8]="airgeddon. Атака Злой Двойник захватила пароли"
	et_misc_texts["GREEK",8]="airgeddon. Η επίθεση Evil Twin κατέγραψε κωδικούς πρόσβασης"
	et_misc_texts["ITALIAN",8]="airgeddon. Password catturate con l'attacco Evil Twin"
	et_misc_texts["POLISH",8]="airgeddon. Hasła przechwycone podczas ataku Evil Twin"
	et_misc_texts["GERMAN",8]="airgeddon. Passwörter im Evil Twin-Angriff erfassen"
	et_misc_texts["TURKISH",8]="airgeddon. Şeytani İkiz şifreleri yakaladı"

	et_misc_texts["ENGLISH",9]="Wireless network, ESSID:"
	et_misc_texts["SPANISH",9]="Red inalámbrica, ESSID:"
	et_misc_texts["FRENCH",9]="Réseau sans fil, ESSID:"
	et_misc_texts["CATALAN",9]="Xarxa sense fils, ESSID:"
	et_misc_texts["PORTUGUESE",9]="ESSID da rede sem fio:"
	et_misc_texts["RUSSIAN",9]="Беспроводная сеть, ESSID:"
	et_misc_texts["GREEK",9]="Ασύρματο Δίκτυο, ESSID:"
	et_misc_texts["ITALIAN",9]="Rete wireless, ESSID:"
	et_misc_texts["POLISH",9]="Sieć bezprzewodowa, ESSID:"
	et_misc_texts["GERMAN",9]="WLAN, ESSID:"
	et_misc_texts["TURKISH",9]="Kablosuz ağ, ESSID:"

	et_misc_texts["ENGLISH",10]="Enter your wireless network password to get internet access"
	et_misc_texts["SPANISH",10]="Introduzca su contraseña de acceso a la red inalámbrica para poder acceder a internet"
	et_misc_texts["FRENCH",10]="Veuillez saisir la clé de sécurité du réseau wifi pour obtenir accès à internet"
	et_misc_texts["CATALAN",10]="Introduïu la contrasenya d&#39;accés a la xarxa sense fils per poder accedir a internet"
	et_misc_texts["PORTUGUESE",10]="Digite a senha da rede wifi para ter acesso a internet"
	et_misc_texts["RUSSIAN",10]="Введите пароль Вашей беспроводной сети для подключения к Интернету"
	et_misc_texts["GREEK",10]="Εισάγετε τον κωδικό πρόσβασης του wifi δικτύου σας για να υπάρξει σύνδεση στο διαδίκτυο"
	et_misc_texts["ITALIAN",10]="Introdurre la password della rete wireless per poter accedere a internet"
	et_misc_texts["POLISH",10]="Wprowadź hasło do sieci bezprzewodowej, aby uzyskać dostęp do internetu"
	et_misc_texts["GERMAN",10]="Schreiben Sie ihr WLAN-Passwort für Internetzugang"
	et_misc_texts["TURKISH",10]="İnternete bağlanabilmek için kablosuz ağ şifrenizi girmelisiniz"

	et_misc_texts["ENGLISH",11]="Password"
	et_misc_texts["SPANISH",11]="Contraseña"
	et_misc_texts["FRENCH",11]="Clé de sécurité"
	et_misc_texts["CATALAN",11]="Contrasenya"
	et_misc_texts["PORTUGUESE",11]="Senha"
	et_misc_texts["RUSSIAN",11]="Пароль"
	et_misc_texts["GREEK",11]="Κωδικός πρόσβασης"
	et_misc_texts["ITALIAN",11]="Password"
	et_misc_texts["POLISH",11]="Hasło"
	et_misc_texts["GERMAN",11]="Passwort"
	et_misc_texts["TURKISH",11]="Şifre"

	et_misc_texts["ENGLISH",12]="Show password"
	et_misc_texts["SPANISH",12]="Mostrar contraseña"
	et_misc_texts["FRENCH",12]="Afficher les caractères"
	et_misc_texts["CATALAN",12]="Mostra la contrasenya"
	et_misc_texts["PORTUGUESE",12]="Mostrar senha"
	et_misc_texts["RUSSIAN",12]="Показать пароль"
	et_misc_texts["GREEK",12]="Εμφάνιση κωδικού πρόσβασης"
	et_misc_texts["ITALIAN",12]="Mostrare password"
	et_misc_texts["POLISH",12]="Pokaż hasło"
	et_misc_texts["GERMAN",12]="Passwort zeigen"
	et_misc_texts["TURKISH",12]="Şifreyi göster"

	et_misc_texts["ENGLISH",13]="Submit"
	et_misc_texts["SPANISH",13]="Enviar"
	et_misc_texts["FRENCH",13]="Enregistrer"
	et_misc_texts["CATALAN",13]="Enviar"
	et_misc_texts["PORTUGUESE",13]="Enviar"
	et_misc_texts["RUSSIAN",13]="Отправить"
	et_misc_texts["GREEK",13]="Υποβολή"
	et_misc_texts["ITALIAN",13]="Inviare"
	et_misc_texts["POLISH",13]="Wyślij"
	et_misc_texts["GERMAN",13]="Schicken"
	et_misc_texts["TURKISH",13]="Tamam"

	et_misc_texts["ENGLISH",14]="An unexpected error occurred, redirecting to the main screen"
	et_misc_texts["SPANISH",14]="Ha ocurrido un error inesperado, redirigiendo a la pantalla principal"
	et_misc_texts["FRENCH",14]="Une erreur inattendue s&#39;est produite, retour à l&#39;écran principal"
	et_misc_texts["CATALAN",14]="Hi ha hagut un error inesperat, redirigint a la pantalla principal"
	et_misc_texts["PORTUGUESE",14]="Ocorreu um erro inesperado, redirecionando para a pagina principal"
	et_misc_texts["RUSSIAN",14]="Непредвиденная ошибка, перенаправление на главную страницу"
	et_misc_texts["GREEK",14]="Παρουσιάστηκε μη αναμενόμενο σφάλμα, Θα καθοδηγηθείτε στην κύρια οθόνη"
	et_misc_texts["ITALIAN",14]="Si è verificato un errore imprevisto, reindirizzando alla schermata principale"
	et_misc_texts["POLISH",14]="Wystąpił nieoczekiwany błąd, zostaniesz przekierowany do ekranu głównego"
	et_misc_texts["GERMAN",14]="Ein Fehler ist aufgetreten, Sie werden zur Homepage weitergeleitet"
	et_misc_texts["TURKISH",14]="Beklenmeyen bir hata oluştu, anasayfaya yönlendiriliyorsunuz"

	et_misc_texts["ENGLISH",15]="Internet Portal"
	et_misc_texts["SPANISH",15]="Portal de Internet"
	et_misc_texts["FRENCH",15]="Portail Internet"
	et_misc_texts["CATALAN",15]="Portal d&#39;Internet"
	et_misc_texts["PORTUGUESE",15]="Portal de Internet"
	et_misc_texts["RUSSIAN",15]="Интернет-портал"
	et_misc_texts["GREEK",15]="Internet Portal"
	et_misc_texts["ITALIAN",15]="Portale Internet"
	et_misc_texts["POLISH",15]="Portal internetowy"
	et_misc_texts["GERMAN",15]="Internet Portal"
	et_misc_texts["TURKISH",15]="İnternet Portalı"

	et_misc_texts["ENGLISH",16]="The password must be at least 8 characters"
	et_misc_texts["SPANISH",16]="La contraseña debe tener al menos 8 caracteres"
	et_misc_texts["FRENCH",16]="La clé de sécurité doit contenir au moins 8 caractères"
	et_misc_texts["CATALAN",16]="La contrasenya ha de tenir almenys 8 caràcters"
	et_misc_texts["PORTUGUESE",16]="A senha deve ter no mínimo 8 caracteres"
	et_misc_texts["RUSSIAN",16]="Длина пароля должна быть не менее 8 символов"
	et_misc_texts["GREEK",16]="Ο κωδικός πρόσβασης πρέπει να αποτελείται από τουλάχιστον 8 χαρακτήρες"
	et_misc_texts["ITALIAN",16]="La password deve essere di almeno 8 caratteri"
	et_misc_texts["POLISH",16]="Hasło musi mieć długość co najmniej 8 znaków"
	et_misc_texts["GERMAN",16]="Das Passwort muss mindestens 8 Zeichen lang sein"
	et_misc_texts["TURKISH",16]="Şifre en az 8 karakter olmalıdır"

	et_misc_texts["ENGLISH",17]="The password is incorrect, redirecting to the main screen"
	et_misc_texts["SPANISH",17]="La contraseña introducida es incorrecta, redirigiendo a la pantalla principal"
	et_misc_texts["FRENCH",17]="Clé de sécurité incorrecte, retour à l&#39;écran principal"
	et_misc_texts["CATALAN",17]="La contrasenya introduïda és incorrecta, redirigint a la pantalla principal"
	et_misc_texts["PORTUGUESE",17]="A senha está incorreta, redirecionando para a pagina principal"
	et_misc_texts["RUSSIAN",17]="Неправильный пароль, возврат на главную страницу"
	et_misc_texts["GREEK",17]="Ο κωδικός πρόσβασης είναι λανθασμένος, Θα καθοδηγηθείτε στην κύρια οθόνη"
	et_misc_texts["ITALIAN",17]="La password non è corretta, reindirizzando alla schermata principale"
	et_misc_texts["POLISH",17]="Wprowadzone hasło jest niepoprawne, zostaniesz przekierowany do ekranu głównego"
	et_misc_texts["GERMAN",17]="Das eingegebene Passwort ist falsch, Sie werden zur Homepage weitergeleitet"
	et_misc_texts["TURKISH",17]="Şifre yanlış, anasayfaya yönlendiriliyorsunuz"

	et_misc_texts["ENGLISH",18]="The password is correct, the connection will be restablished in a few moments"
	et_misc_texts["SPANISH",18]="La contraseña es correcta, la conexión se restablecerá en unos momentos"
	et_misc_texts["FRENCH",18]="Clé de sécurité correcte, la connexion sera établie dans quelques instants"
	et_misc_texts["CATALAN",18]="La contrasenya és correcta, la connexió es restablirà en uns moments"
	et_misc_texts["PORTUGUESE",18]="A senha está correta, a conexão será estabelecida em alguns momentos"
	et_misc_texts["RUSSIAN",18]="Пароль верен, подключение устанавливается"
	et_misc_texts["GREEK",18]="Ο κωδικός πρόσβασης είναι σωστός, η σύνδεση θα αποκατασταθεί σε λίγα λεπτά"
	et_misc_texts["ITALIAN",18]="La password è corretta, la connessione sará ripristinata in un momento"
	et_misc_texts["POLISH",18]="Hasło jest prawidłowe, połączenie zostanie przywrócone za chwilę"
	et_misc_texts["GERMAN",18]="Das Passwort ist richtig, die Verbindung wird in kurzer Zeit wiederhergestellt"
	et_misc_texts["TURKISH",18]="Şifre doğru, bağlantınız bir kaç dakika içerisinde yeniden gerçekleşecektir"

	et_misc_texts["ENGLISH",19]="airgeddon. Captive portal Evil Twin attack captured password"
	et_misc_texts["SPANISH",19]="airgeddon. Contraseña capturada en el portal cautivo del ataque Evil Twin"
	et_misc_texts["FRENCH",19]="airgeddon. Mot de passe capturé par le portail captif de l'attaque Evil Twin"
	et_misc_texts["CATALAN",19]="airgeddon. Contrasenya capturada al portal captiu de l'atac Evil Twin"
	et_misc_texts["PORTUGUESE",19]="airgeddon. Senha capturada no ataque Evil Twin portal cativo"
	et_misc_texts["RUSSIAN",19]="airgeddon. Атака Злой Двойник + Перехватывающий портал захватили пароль"
	et_misc_texts["GREEK",19]="airgeddon. Η επίθεση Evil Twin με captive portal κατέγραψε τον κωδικό πρόσβασης"
	et_misc_texts["ITALIAN",19]="airgeddon. Password catturata nel captive portal dell'attacco Evil Twin"
	et_misc_texts["POLISH",19]="airgeddon. Hasło przechwycone podczas ataku captive portal Evil Twin"
	et_misc_texts["GERMAN",19]="airgeddon. Passwort im Evil Twin Captive Portal gefangen"
	et_misc_texts["TURKISH",19]="airgeddon. Esaret Portalı Şeytani ikizi şifreyi yakaladı"

	et_misc_texts["ENGLISH",20]="Attempts"
	et_misc_texts["SPANISH",20]="Intentos"
	et_misc_texts["FRENCH",20]="Essais"
	et_misc_texts["CATALAN",20]="Intents"
	et_misc_texts["PORTUGUESE",20]="Tentativas"
	et_misc_texts["RUSSIAN",20]="Попытки"
	et_misc_texts["GREEK",20]="Προσπάθειες"
	et_misc_texts["ITALIAN",20]="Tentativi"
	et_misc_texts["POLISH",20]="Próby"
	et_misc_texts["GERMAN",20]="Versuche"
	et_misc_texts["TURKISH",20]="Denemeler"

	et_misc_texts["ENGLISH",21]="last password:"
	et_misc_texts["SPANISH",21]="última contraseña:"
	et_misc_texts["FRENCH",21]="dernier mot de passe:"
	et_misc_texts["CATALAN",21]="última contrasenya:"
	et_misc_texts["PORTUGUESE",21]="última senha:"
	et_misc_texts["RUSSIAN",21]="последний пароль:"
	et_misc_texts["GREEK",21]="τελευταίος κωδικός πρόσβασης:"
	et_misc_texts["ITALIAN",21]="ultima password:"
	et_misc_texts["POLISH",21]="ostatnie hasło:"
	et_misc_texts["GERMAN",21]="letzte Passwort:"
	et_misc_texts["TURKISH",21]="son şifre:"

	et_misc_texts["ENGLISH",22]="Captured passwords on failed attemps"
	et_misc_texts["SPANISH",22]="Contraseñas capturadas en intentos fallidos"
	et_misc_texts["FRENCH",22]="Mots de passe capturés lors des tentatives infructueuses"
	et_misc_texts["CATALAN",22]="Contrasenyes capturades en intents fallits"
	et_misc_texts["PORTUGUESE",22]="Senhas erradas capturadas durante as tentativas"
	et_misc_texts["RUSSIAN",22]="Пароли, захваченные в неудачных попытках"
	et_misc_texts["GREEK",22]="Καταγεγραμμένοι κωδικοί πρόσβασης σε αποτυχημένες προσπάθειες"
	et_misc_texts["ITALIAN",22]="Password catturate in tentativi falliti"
	et_misc_texts["POLISH",22]="Hasła przechwycone podczas nieudanych prób"
	et_misc_texts["GERMAN",22]="Gefangene Passwörter in Fehlversuche"
	et_misc_texts["TURKISH",22]="Başarısız girişimlerde yakalanan şifreler"

	et_misc_texts["ENGLISH",23]="Password captured successfully"
	et_misc_texts["SPANISH",23]="Contraseña capturada con éxito"
	et_misc_texts["FRENCH",23]="Mot de passe capturé avec succès"
	et_misc_texts["CATALAN",23]="Contrasenya capturada amb èxit"
	et_misc_texts["PORTUGUESE",23]="Senha capturada com sucesso"
	et_misc_texts["RUSSIAN",23]="Пароль успешно захвачен"
	et_misc_texts["GREEK",23]="Ο κωδικός πρόσβασης καταγράφτηκε επιτυχώς"
	et_misc_texts["ITALIAN",23]="Password catturata con successo"
	et_misc_texts["POLISH",23]="Hasło zostało pomyślnie przechwycone"
	et_misc_texts["GERMAN",23]="Passwörter erfolgreich gefangen"
	et_misc_texts["TURKISH",23]="Şifre başarıyla yakalandı"

	et_misc_texts["ENGLISH",24]="The password was saved on file"
	et_misc_texts["SPANISH",24]="La contraseña se ha guardado en el fichero"
	et_misc_texts["FRENCH",24]="Le mot de passe est enregistré dans le fichier"
	et_misc_texts["CATALAN",24]="La contrasenya s'ha guardat en el fitxer"
	et_misc_texts["PORTUGUESE",24]="A senha foi salva no arquivo"
	et_misc_texts["RUSSIAN",24]="Пароль был сохранён в файле"
	et_misc_texts["GREEK",24]="Ο κωδικός πρόσβασης αποθηκεύτηκε σε αρχείο"
	et_misc_texts["ITALIAN",24]="La password è stata salvata nel file"
	et_misc_texts["POLISH",24]="Hasło zostało zapisane do pliku"
	et_misc_texts["GERMAN",24]="Das Passwort wurde in der Datei gespeichert"
	et_misc_texts["TURKISH",24]="Şifre dosyaya kaydedildi"

	et_misc_texts["ENGLISH",25]="Press [Enter] on the main script window to continue, this window will be closed"
	et_misc_texts["SPANISH",25]="Pulsa [Enter] en la ventana principal del script para continuar, esta ventana se cerrará"
	et_misc_texts["FRENCH",25]="Appuyez sur [Enter] dans la fenêtre principale du script pour continuer, cette fenêtre se fermera"
	et_misc_texts["CATALAN",25]="Prem [Enter] a la finestra principal del script per continuar, aquesta finestra es tancarà"
	et_misc_texts["PORTUGUESE",25]="Pressione [Enter] na janela principal do script para continuar e esta janela será fechada"
	et_misc_texts["RUSSIAN",25]="Нажмите [Enter] в главном окне для продолжения, это окно будет закрыто"
	et_misc_texts["GREEK",25]="Πατήστε [Enter] στο κύριο παράθυρο του script για να συνεχίσετε, το παράθυρο αυτό θα κλείσει"
	et_misc_texts["ITALIAN",25]="Premere il tasto [Enter] nella finestra principale dello script per continuare, questa finestra si chiuderà"
	et_misc_texts["POLISH",25]="Wciśnij [Enter] w oknie głównym skryptu aby kontynuować, to okno zostanie zamknięte"
	et_misc_texts["GERMAN",25]="Drücken Sie [Enter] im Hauptfenster um fortzufahren, dieses Fenster wird geschlossen"
	et_misc_texts["TURKISH",25]="Devam etmek için [Enter] tuşuna basınız, bu sayfa kapatılacaktır"

	et_misc_texts["ENGLISH",26]="Error. The password must be at least 8 characters. Redirecting to the main screen"
	et_misc_texts["SPANISH",26]="Error. La contraseña debe tener al menos 8 caracteres. Redirigiendo a la pantalla principal"
	et_misc_texts["FRENCH",26]="Erreur. La clé de sécurité doit contenir au moins 8 caractères. Retour à l&#39;écran principal"
	et_misc_texts["CATALAN",26]="Error. La contrasenya ha de tenir almenys 8 caràcters. Redirigint a la pantalla principal"
	et_misc_texts["PORTUGUESE",26]="Erro. A senha deve ter no mínimo 8 caracteres. Redirecionando para a pagina principal"
	et_misc_texts["RUSSIAN",26]="Ошибка. В пароле должно быть не менее 8 символов. Перенаправление на главную страницу"
	et_misc_texts["GREEK",26]="Σφάλμα. Ο κωδικός πρόσβασης πρέπει να αποτελείται από τουλάχιστον 8 χαρακτήρες. Θα καθοδηγηθείτε στην κύρια οθόνη"
	et_misc_texts["ITALIAN",26]="Errore. La password deve essere di almeno 8 caratteri. Reindirizzando alla schermata principale"
	et_misc_texts["POLISH",26]="Błąd. Hasło musi mieć co najmniej 8 znaków. Przekierowywanie do ekranu głównego"
	et_misc_texts["GERMAN",26]="Fehler. Das Passwort muss mindestens 8 Zeichen lang sein. Zur Homepage weitergeleitet"
	et_misc_texts["TURKISH",26]="Hata. Şifre en az 8 karakter olmalıdır. Anasayfaya yönlendiriliyorsunuz"

	et_misc_texts["ENGLISH",27]="This attack has two parts. Watch the sniffer's screen to see if a password appears. You can also open BeEF control panel at ${white_color}${beef_control_panel_url}${pink_color} , log in (user: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) and try to control the clients browser"
	et_misc_texts["SPANISH",27]="Este ataque tiene dos partes. Estate atento a la pantalla del sniffer para ver si aparece alguna contraseña. También puedes abrir el panel de control de BeEF en ${white_color}${beef_control_panel_url}${pink_color} , hacer login (user: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) e intentar controlar el navegador de los clientes"
	et_misc_texts["FRENCH",27]="Cette attaque comporte deux parties. Vérifiez pendant l'attaque dans la console du sniffeur si un mot de passe a été capturé. Vous pouvez également ouvrir le BeEF du panneau de commande dans ${white_color}${beef_control_panel_url}${pink_color} , pour vous connecter (user: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) et essayer de contrôler le navigateur client"
	et_misc_texts["CATALAN",27]="Aquest atac té dues parts. Amb aquest atac, estigues atent a la pantalla de l'sniffer per veure si apareix alguna contrasenya. També pots obrir el panell de control de BeEF en ${white_color}${beef_control_panel_url}${pink_color} , fer login (user: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) i intentar controlar el navegador dels clients"
	et_misc_texts["PORTUGUESE",27]="Este ataque tem duas partes. Com este ataque, fique atento na tela do sniffer para ver se aparece alguma senha. Você também pode abrir o painel de controle do BeEF em ${white_color}${beef_control_panel_url}${pink_color} , login (user: ${white_color}beef${pink_color} / senha: ${white_color}${beef_pass}${pink_color}) e tentar controlar o navegador dos clientes"
	et_misc_texts["RUSSIAN",27]="Эта атака идёт по двум направлениям. Вы можете наблюдать за окном сниффера, чтобы отследить появление пароля. Также можете перейти в панель управления BeEF ${white_color}${beef_control_panel_url}${pink_color} , учётные данные для входа (user: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) и попытаться управлять браузером клиентов"
	et_misc_texts["GREEK",27]="Αυτή η επίθεση έχει δύο μέρη. Παρακολουθήστε την οθόνη του sniffer για να δείτε εαν εμφανιστεί κάποιος κωδικός. Μπορείτε επίσης να ανοίξετε τον πίνακα ελέγχου του BeEF στο ${white_color}${beef_control_panel_url}${pink_color} , συνδεθείτε (user: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) και προσπαθείστε να ελέγξετε τον browser του χρήστη-πελάτη"
	et_misc_texts["ITALIAN",27]="Questo attacco è composto da due parti. Presta attenzione alla schermata dello sniffer per vedere se compare una password. È inoltre possibile aprire il pannello di controllo di BeEF in ${white_color}${beef_control_panel_url}${pink_color} , effettuare il login (utente: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) e cercare di controllare il navigatore degli utenti"
	et_misc_texts["POLISH",27]="Ten atak ma dwie części. Obserwuj ekran sniffera aby sprawdzić, czy pojawia się hasło. Możesz także otworzyć panel sterowania BeEF w ${white_color}${beef_control_panel_url}${pink_color} , zaloguj się (użytkownik: ${white_color}beef${pink_color} / hasło: ${white_color}${beef_pass}${pink_color}) i spróbuj kontrolować przeglądarkę klientów"
	et_misc_texts["GERMAN",27]="Dieser Angriff besteht aus zwei Teilen. Bleiben Sie auf dem Sniffer-Bildschirm, um zu sehen, ob ein Passwort erscheint. Sie können auch das BeEF-Kontrollfeld in ${white_color}${beef_control_panel_url}${pink_color} öffnen, login (Benutzer: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) und versuchen den Browser des Clients zu kontrollieren"
	et_misc_texts["TURKISH",27]="Bu saldırı iki parçadan oluşur. Sniffer ekranını şifre görünene kadar izleyin. Ayrıca BeEF kontrol panelini açabilir ${white_color}${beef_control_panel_url}${pink_color} , log in (user: ${white_color}beef${pink_color} / pass: ${white_color}${beef_pass}${pink_color}) ve kontrol edebilirsiniz"

	declare -gA wps_texts
	wps_texts["ENGLISH",1]="airgeddon. Decrypted password during WPS attack"
	wps_texts["SPANISH",1]="airgeddon. Contraseña desencriptada en ataque WPS"
	wps_texts["FRENCH",1]="airgeddon. Mot de passe déchiffré à l'aide de l'attaque WPS"
	wps_texts["CATALAN",1]="airgeddon. Contrasenya desencriptada amb l'atac WPS"
	wps_texts["PORTUGUESE",1]="airgeddon. Senha decifrada no ataque WPS"
	wps_texts["RUSSIAN",1]="airgeddon. Пароль расшифрован во время WPS атаки"
	wps_texts["GREEK",1]="airgeddon. Ο κωδικός αποκρυπτογραφήθηκε κατά την επίθεση WPS"
	wps_texts["ITALIAN",1]="airgeddon. Password decifrata con l'attacco WPS"
	wps_texts["POLISH",1]="airgeddon. Hasło odszyfrowane w ataku WPS"
	wps_texts["GERMAN",1]="airgeddon. Passwort bei WPS-Angriff entschlüsselt"
	wps_texts["TURKISH",1]="airgeddon. WPS saldırısı sırasında çözülen şifre"

	wps_texts["ENGLISH",2]="Channel"
	wps_texts["SPANISH",2]="Canal"
	wps_texts["FRENCH",2]="Canal"
	wps_texts["CATALAN",2]="Canal"
	wps_texts["PORTUGUESE",2]="Canal"
	wps_texts["RUSSIAN",2]="Канал"
	wps_texts["GREEK",2]="Κανάλι"
	wps_texts["ITALIAN",2]="Canale"
	wps_texts["POLISH",2]="Kanał"
	wps_texts["GERMAN",2]="Kanal"
	wps_texts["TURKISH",2]="Kanal"

	wps_texts["ENGLISH",3]="The password was saved on file"
	wps_texts["SPANISH",3]="La contraseña se ha guardado en el fichero"
	wps_texts["FRENCH",3]="Le mot de passe est enregistré dans le fichier"
	wps_texts["CATALAN",3]="La contrasenya s'ha guardat en el fitxer"
	wps_texts["PORTUGUESE",3]="A senha foi salva no arquivo"
	wps_texts["RUSSIAN",3]="Пароль был сохранён в файле"
	wps_texts["GREEK",3]="Ο κωδικός πρόσβασης αποθηκεύτηκε σε αρχείο"
	wps_texts["ITALIAN",3]="La password è stata salvata nel file"
	wps_texts["POLISH",3]="Hasło zostało zapisane do pliku"
	wps_texts["GERMAN",3]="Das Passwort wurde in der Datei gespeichert"
	wps_texts["TURKISH",3]="Şifre dosyaya kaydedildi"

	declare -gA wep_texts
	wep_texts["ENGLISH",1]="airgeddon. Decrypted password during WEP attack"
	wep_texts["SPANISH",1]="airgeddon. Contraseña desencriptada en ataque WEP"
	wep_texts["FRENCH",1]="airgeddon. Mot de passe déchiffré à l'aide de l'attaque WEP"
	wep_texts["CATALAN",1]="airgeddon. Contrasenya desencriptada amb l'atac WEP"
	wep_texts["PORTUGUESE",1]="airgeddon. Senha decifrada no ataque WEP"
	wep_texts["RUSSIAN",1]="airgeddon. Пароль расшифрован во время WEP атаки"
	wep_texts["GREEK",1]="airgeddon. Ο κωδικός αποκρυπτογραφήθηκε κατά την επίθεση WEP"
	wep_texts["ITALIAN",1]="airgeddon. Password decifrata con l'attacco WEP"
	wep_texts["POLISH",1]="airgeddon. Hasło odszyfrowane w ataku WEP"
	wep_texts["GERMAN",1]="airgeddon. Passwort bei WEP-Angriff entschlüsselt"
	wep_texts["TURKISH",1]="airgeddon. WEP saldırısı sırasında çözülen şifre"

	wep_texts["ENGLISH",2]="Channel"
	wep_texts["SPANISH",2]="Canal"
	wep_texts["FRENCH",2]="Canal"
	wep_texts["CATALAN",2]="Canal"
	wep_texts["PORTUGUESE",2]="Canal"
	wep_texts["RUSSIAN",2]="Канал"
	wep_texts["GREEK",2]="Κανάλι"
	wep_texts["ITALIAN",2]="Canale"
	wep_texts["POLISH",2]="Kanał"
	wep_texts["GERMAN",2]="Kanal"
	wep_texts["TURKISH",2]="Kanal"

	wep_texts["ENGLISH",3]="Hexadecimal"
	wep_texts["SPANISH",3]="Hexadecimal"
	wep_texts["FRENCH",3]="Hexadécimal"
	wep_texts["CATALAN",3]="Hexadecimal"
	wep_texts["PORTUGUESE",3]="Hexadecimal"
	wep_texts["RUSSIAN",3]="Шестнадцатеричный"
	wep_texts["GREEK",3]="Δεκαεξαδικό"
	wep_texts["ITALIAN",3]="Esadecimale"
	wep_texts["POLISH",3]="Hexadecymalny"
	wep_texts["GERMAN",3]="Hexadezimal"
	wep_texts["TURKISH",3]="Hexadecimal"

	wep_texts["ENGLISH",4]="WEP key decrypted successfully:"
	wep_texts["SPANISH",4]="Clave WEP desencriptada con éxito:"
	wep_texts["FRENCH",4]="Clef WEP déchiffré:"
	wep_texts["CATALAN",4]="Clau WEP desencriptada amb èxit:"
	wep_texts["PORTUGUESE",4]="Senha WEP descriptografada com sucesso:"
	wep_texts["RUSSIAN",4]="Ключ WEP расшифрован:"
	wep_texts["GREEK",4]="Το κλειδί WEP αποκρυπτογραφήθηκε με επιτυχία:"
	wep_texts["ITALIAN",4]="Chiave WEP decifrata con successo:"
	wep_texts["POLISH",4]="Klucz WEP odszyfrowywany prawidłowo:"
	wep_texts["GERMAN",4]="WEP-Schlüssel erfolgreich entschlüsselt:"
	wep_texts["TURKISH",4]="WEP anahtarı başarıyla çözüldü"

	wep_texts["ENGLISH",5]="WEP AP Info"
	wep_texts["SPANISH",5]="Info WEP AP"
	wep_texts["FRENCH",5]="Info WEP AP"
	wep_texts["CATALAN",5]="Info WEP AP"
	wep_texts["PORTUGUESE",5]="Info WEP AP"
	wep_texts["RUSSIAN",5]="Информация о WEP ТД"
	wep_texts["GREEK",5]="Πληροφορίες WEP AP"
	wep_texts["ITALIAN",5]="Info WEP AP"
	wep_texts["POLISH",5]="Informacja o AP WEP"
	wep_texts["GERMAN",5]="Info über WEP AP"
	wep_texts["TURKISH",5]="WEP AP Bilgisi"

	wep_texts["ENGLISH",6]="The password was saved on file"
	wep_texts["SPANISH",6]="La contraseña se ha guardado en el fichero"
	wep_texts["FRENCH",6]="Le mot de passe est enregistré dans le fichier"
	wep_texts["CATALAN",6]="La contrasenya s'ha guardat en el fitxer"
	wep_texts["PORTUGUESE",6]="A senha foi salva no arquivo"
	wep_texts["RUSSIAN",6]="Пароль был сохранён в файле"
	wep_texts["GREEK",6]="Ο κωδικός πρόσβασης αποθηκεύτηκε σε αρχείο"
	wep_texts["ITALIAN",6]="La password è stata salvata nel file"
	wep_texts["POLISH",6]="Hasło zostało zapisane do pliku"
	wep_texts["GERMAN",6]="Das Passwort wurde in der Datei gespeichert"
	wep_texts["TURKISH",6]="Şifre dosyaya kaydedildi"

	wep_texts["ENGLISH",7]="Press [Enter] on the main script window to continue, this window will be closed"
	wep_texts["SPANISH",7]="Pulsa [Enter] en la ventana principal del script para continuar, esta ventana se cerrará"
	wep_texts["FRENCH",7]="Appuyez sur [Enter] dans la fenêtre principale du script pour continuer, cette fenêtre se fermera"
	wep_texts["CATALAN",7]="Prem [Enter] a la finestra principal del script per continuar, aquesta finestra es tancarà"
	wep_texts["PORTUGUESE",7]="Pressione [Enter] na janela principal do script para continuar e esta janela será fechada"
	wep_texts["RUSSIAN",7]="Нажмите [Enter] в главном окне для продолжения, это окно будет закрыто"
	wep_texts["GREEK",7]="Πατήστε [Enter] στο κύριο παράθυρο του script για να συνεχίσετε, το παράθυρο αυτό θα κλείσει"
	wep_texts["ITALIAN",7]="Premere il tasto [Enter] nella finestra principale dello script per continuare, questa finestra si chiuderà"
	wep_texts["POLISH",7]="Wciśnij [Enter] w oknie głównym skryptu aby kontynuować, to okno zostanie zamknięte"
	wep_texts["GERMAN",7]="Drücken Sie [Enter] im Hauptfenster des Skripts um fortzufahren. Dieses Fenster wird geschlossen"
	wep_texts["TURKISH",7]="Yazılımın ana penceresinde [Enter] tuşlayarak devam ediniz. Bu pencere kapatılacak"

	declare -gA hashcat_texts
	hashcat_texts["ENGLISH",1]="airgeddon. Decrypted password using hashcat"
	hashcat_texts["SPANISH",1]="airgeddon. Contraseña desencriptada con hashcat"
	hashcat_texts["FRENCH",1]="airgeddon. Mot de passe déchiffré avec hashcat"
	hashcat_texts["CATALAN",1]="airgeddon. Contrasenya desencriptada amb hashcat"
	hashcat_texts["PORTUGUESE",1]="airgeddon descriptografou a senha usando hashcat"
	hashcat_texts["RUSSIAN",1]="airgeddon. Пароль расшифрован с использованием hashcat"
	hashcat_texts["GREEK",1]="airgeddon. Αποκρυπτογραφημένος κωδικός πρόσβασης με χρήση hashcat"
	hashcat_texts["ITALIAN",1]="airgeddon. Password decifrata con hashcat"
	hashcat_texts["POLISH",1]="airgeddon. Hasło odszyfrowane z użyciem hashcat"
	hashcat_texts["GERMAN",1]="airgeddon. Passwort mit hashcat entschlüsselt"
	hashcat_texts["TURKISH",1]="airgeddon. Hashcat kullanarak şifreyi çözdü"

	declare -gA aircrack_texts
	aircrack_texts["ENGLISH",1]="airgeddon. Decrypted password using aircrack"
	aircrack_texts["SPANISH",1]="airgeddon. Contraseña desencriptada con aircrack"
	aircrack_texts["FRENCH",1]="airgeddon. Mot de passe déchiffré avec aircrack"
	aircrack_texts["CATALAN",1]="airgeddon. Contrasenya desencriptada amb aircrack"
	aircrack_texts["PORTUGUESE",1]="airgeddon descriptografou a senha usando aircrack"
	aircrack_texts["RUSSIAN",1]="airgeddon. Пароль расшифрован с использованием aircrack"
	aircrack_texts["GREEK",1]="airgeddon. Αποκρυπτογραφημένος κωδικός πρόσβασης με χρήση aircrack"
	aircrack_texts["ITALIAN",1]="airgeddon. Password decifrata con aircrack"
	aircrack_texts["POLISH",1]="airgeddon. Hasło odszyfrowane z użyciem aircrack"
	aircrack_texts["GERMAN",1]="airgeddon. Passwort mit aircrack entschlüsselt"
	aircrack_texts["TURKISH",1]="airgeddon. Aircrack kullanarak şifreyi çözdü"

	declare -gA footer_texts
	footer_texts["ENGLISH",1]="If you enjoyed the script and found it useful, you can support the project by making a donation. Through PayPal (${mail}) or sending a fraction of cryptocurrency (Bitcoin, Ethereum, Litecoin...). Any amount, no matter how small (1, 2, 5 $/€) is welcome. More information and direct links to do it at: ${urlgithub_wiki}/Contributing"
	footer_texts["SPANISH",1]="Si te gustó el script y te pareció útil, puedes apoyar el proyecto haciendo una donación. A través de PayPal (${mail}) o enviando una fracción de criptomoneda (Bitcoin, Ethereum, Litecoin...). Cualquier cantidad por pequeña que sea (1, 2, 5 $/€) es bien recibida. Más información y enlaces directos para realizarla en: ${urlgithub_wiki}/Contributing"
	footer_texts["FRENCH",1]="Si le script vous a plus et que vous l'avez trouvé utile, vous pouvez soutenir le projet en faisant un don PayPal (${mail}) ou en envoyant une fraction de crypto-monnaie (Bitcoin, Ethereum, Litecoin...). Toute contribution (1, 2, 5 $/€) est bienvenue. Pour faire un don allez à: ${urlgithub_wiki}/Contributing"
	footer_texts["CATALAN",1]="Si et va agradar el script i et va semblar útil, pots donar suport al projecte fent una donació. A través de PayPal (${mail}) o enviant una fracció criptomoneda (Bitcoin, Ethereum, Litecoin...). Qualsevol quantitat per petita que sigui (1, 2, 5 $/€) és ben rebuda. Més informació i enllaços directes per a realitzar-la en: ${urlgithub_wiki}/Contributing"
	footer_texts["PORTUGUESE",1]="Se você gostou do script e o achou útil, apoie o projeto fazendo uma doação através: do PayPal (${mail}) ou enviando uma fração de uma criptomoeda (Bitcoin, Ethereum, Litecoin...). Qualquer quantidade, mesmo pequena (1, 2, 5 $/€) é bem-vinda. Links diretos e de com realizar em: ${urlgithub_wiki}/Contributing"
	footer_texts["RUSSIAN",1]="Если вам понравилась эта программа и она оказался для вас полезной, вы можете поддержать проект, сделав пожертвование. Доступны переводы через PayPal (${mail}) и криптовалюту (Bitcoin, Ethereum, Litecoin...). Приветствуется любая сумма, даже небольшая (1, 2, 5 $/€). Более подробную информацию и прямые ссылки можно получить по адресу: ${urlgithub_wiki}/Contributing"
	footer_texts["GREEK",1]="Εαν μείνατε ευχαριστημένοι από το script και το βρήκατε χρήσιμο, μπορείτε να υποστηρίξετε το project κάνοντας κάποια δωρεά. Μέσω PayPal (${mail}) ή αποστέλλοντας κάποιο κλάσμα κρυπτονομίσματος (Bitcoin, Ethereum, Litecoin...). Είναι καλοδεχούμενο οποιοδήποτε ποσό (1, 2, 5 $/€), δεν έχει σημασία το πόσο λίγο μπορεί να είναι. Δίνονται περισσότερες πληροφορίες και links για να κάνετε δωρεά, στη διεύθυνση: ${urlgithub_wiki}/Contributing"
	footer_texts["ITALIAN",1]="Se ti è piaciuto lo script e l'hai trovato utile, puoi sostenere il progetto con una donazione. Attraverso PayPal (${mail}) o inviando una frazione di criptovaluta (Bitcoin, Ethereum, Litecoin...). Qualsiasi importo per quanto piccolo (1, 2, 5 $/€) è ben accolto. Piú informazioni e collegamenti diretti per realizzarla in: ${urlgithub_wiki}/Contributing"
	footer_texts["POLISH",1]="Jeśli podobał Ci się ten skrypt i okazał się użyteczny, możesz poprzeć ten projekt, składając donację. Za pośrednictwem usługi PayPal (${mail}) lub wysyłając ułamek kryptowaluty (Bitcoin, Ethereum, Litecoin...). Każda kwota, nawet malutka (1, 2, 5 $/€) będzie mile widziana. Więcej informacji i linki do donacji: ${urlgithub_wiki}/Contributing"
	footer_texts["GERMAN",1]="Wenn Ihnen das Skript gefallen hat und Sie es nützlich fanden, können Sie das Projekt mit einer Spende unterstützen. Durch PayPal (${mail}) oder durch Senden eines Bruchteils von Kryptowährung (Bitcoin, Ethereum, Litecoin...). Jeder kleine Betrag (1, 2, 5 $/€) wird gut angenommen. Weitere Informationen und direkte Links dazu finden Sie unter: ${urlgithub_wiki}/Contributing"
	footer_texts["TURKISH",1]="Eğer bu yazılımı kullanışlı ve eğlenceli bulduysanız, bize bağış yaparak destekte bulunabilirsiniz. PayPal üzerinden (${mail}) ya da herhangi bir kripto para birimi ile (Bitcoin, Ethereum, Litecoin...) Yolladığınız miktarın küçüklüğü fark etmez (1, 2, 5 $/€). Daha fazla fazla bilgi için linkler: ${urlgithub_wiki}/Contributing"

	declare -A arr
	arr["ENGLISH",0]="This interface ${current_iface_on_messages} is already in managed mode"
	arr["SPANISH",0]="Esta interfaz ${current_iface_on_messages} ya está en modo managed"
	arr["FRENCH",0]="L'interface ${current_iface_on_messages} est déjà en mode managed"
	arr["CATALAN",0]="Aquesta interfície ${current_iface_on_messages} ja està en mode managed"
	arr["PORTUGUESE",0]="Esta interface ${current_iface_on_messages} já está em modo managed"
	arr["RUSSIAN",0]="Этот интерфейс ${current_iface_on_messages} уже в управляемом режиме"
	arr["GREEK",0]="Αυτή η διεπαφή ${current_iface_on_messages} είναι ήδη σε ετερόκλητη κατάσταση"
	arr["ITALIAN",0]="Questa interfaccia ${current_iface_on_messages} è già in modalità managed"
	arr["POLISH",0]="Ten interfejs ${current_iface_on_messages} jest już w trybie managed"
	arr["GERMAN",0]="Diese ${current_iface_on_messages}-Schnittstelle befindet sich bereits im managed Modus"
	arr["TURKISH",0]="Bu arayüz ${current_iface_on_messages} zaten yönetici modunda"

	arr["ENGLISH",1]="This interface ${current_iface_on_messages} is not a wifi card. It doesn't support managed mode"
	arr["SPANISH",1]="Esta interfaz ${current_iface_on_messages} no es una tarjeta wifi. No soporta modo managed"
	arr["FRENCH",1]="L'interface ${current_iface_on_messages} n'est pas une carte wifi. Elle n'est donc pas compatible mode managed"
	arr["CATALAN",1]="Aquesta interfície ${current_iface_on_messages} no és una targeta wifi vàlida. No es compatible amb mode managed"
	arr["PORTUGUESE",1]="Esta interface ${current_iface_on_messages} não é wifi. Ela não suporta o modo managed"
	arr["RUSSIAN",1]="Этот интерфейс ${current_iface_on_messages} не является wifi картой. Он не поддерживает управляемый режим"
	arr["GREEK",1]="Αυτή η διεπαφή ${current_iface_on_messages} δεν είναι κάρτα wifi. Δεν υποστηρίζει ετερόκλητη κατάσταση"
	arr["ITALIAN",1]="Questa interfaccia ${current_iface_on_messages} non è una scheda wifi. Non supporta la modalità managed"
	arr["POLISH",1]="Interfejs ${current_iface_on_messages} nie jest kartą wifi. Nie obsługuje trybu zarządzania"
	arr["GERMAN",1]="Diese ${current_iface_on_messages}-Schnittstelle ist keine wifi-Karte. Managed modus ist nicht unterstützt"
	arr["TURKISH",1]="Bu arayüz ${current_iface_on_messages} wifi kart değildir. Yönetici modunu desteklemiyor"

	arr["ENGLISH",2]="English O.S. language detected. Supported by script. Automatically changed"
	arr["SPANISH",2]="Idioma Español del S.O. detectado. Soportado por el script. Se cambió automáticamente"
	arr["FRENCH",2]="S.E. en Français détecté. Langue prise en charge par le script et changé automatiquement"
	arr["CATALAN",2]="Idioma Català del S.O. detectat. Suportat pel script. S'ha canviat automàticament"
	arr["PORTUGUESE",2]="S.O. em Português detectado. Compatível com o script. Idioma automaticamente alterada"
	arr["RUSSIAN",2]="Определена ОС на русском. Поддерживается скриптом. Локализация автоматически изменена. Помощь на русском: https://hackware.ru/?p=670"
	arr["GREEK",2]="Εντοπίστηκε Ελληνική γλώσσα συστήματος. Υποστηρίξιμη από το script. Άλλαξε αυτόματα"
	arr["ITALIAN",2]="Lingua Italiana del S.O. rilevata. Supportata dallo script. Viene cambiata automaticamente"
	arr["POLISH",2]="Wykryto system operacyjny w języku Polskim. Obsługiwany przez skrypt. Zmieniono automatycznie"
	arr["GERMAN",2]="Deutsch als Betriebssystemsprache erkannt. Vom Skript unterstützt. Sie wurde automatisch geändert"
	arr["TURKISH",2]="Türkçe İşletim Sistemi tespit edildi. Yazılım tarafından otomatik olarak değiştirildi"

	arr["ENGLISH",3]="Select target network:"
	arr["SPANISH",3]="Selecciona la red objetivo:"
	arr["FRENCH",3]="Sélectionnez le réseau cible:"
	arr["CATALAN",3]="Selecciona la xarxa objectiu:"
	arr["PORTUGUESE",3]="Selecione uma rede como objetivo:"
	arr["RUSSIAN",3]="Выбор целевой сети:"
	arr["GREEK",3]="Διαλέξτε δίκτυο:"
	arr["ITALIAN",3]="Scegliere una rete come obiettivo:"
	arr["POLISH",3]="Wybierz sieć docelową:"
	arr["GERMAN",3]="Wählen Sie das Zielnetzwerk aus:"
	arr["TURKISH",3]="Hedef ağı seçiniz:"

	arr["ENGLISH",4]="Press [Enter] key to start attack..."
	arr["SPANISH",4]="Pulse la tecla [Enter] para comenzar el ataque..."
	arr["FRENCH",4]="Pressez [Enter] pour commencer l'attaque..."
	arr["CATALAN",4]="Premi la tecla [Enter] per començar l'atac..."
	arr["PORTUGUESE",4]="Pressione [Enter] para iniciar o ataque..."
	arr["RUSSIAN",4]="Нажмите клавишу [Enter] для начала атаки..."
	arr["GREEK",4]="Πατήστε [Enter] για να ξεκινήσει η επίθεση..."
	arr["ITALIAN",4]="Premere il tasto [Enter] per iniziare l'attacco..."
	arr["POLISH",4]="Naciśnij klawisz [Enter], aby rozpocząć atak..."
	arr["GERMAN",4]="Drücken Sie die [Enter]-Taste um den Angriff zu starten..."
	arr["TURKISH",4]="Saldırıya başlamak için [Enter] tuşuna basınız..."

	arr["ENGLISH",5]="It looks like your internet connection is unstable. The script can't connect to repository. It will continue without updating..."
	arr["SPANISH",5]="Parece que tu conexión a internet no es estable. El script no puede conectar al repositorio. Continuará sin actualizarse..."
	arr["FRENCH",5]="Votre connexion internet est trop médiocre pour pouvoir se connecter aux dépôts comme ils se doit. Le script va s’exécuter sans s'actualiser..."
	arr["CATALAN",5]="Sembla que la teva connexió a internet no és estable. El script no pot connectar amb el repositori. Continuarà sense actualitzar-se..."
	arr["PORTUGUESE",5]="Parece que sua conexão com a internet não é estável. O script não pode conectar-se ao repositório. Ele continuará sem atualizar..."
	arr["RUSSIAN",5]="Интернет-подключение кажется нестабильным. Скрипт не может подключиться к репозиторию. Он продолжит без обновления..."
	arr["GREEK",5]="Φαίνεται πως η σύνδεση με το διαδίκτυο δεν είναι σταθερή. Το script δεν μπορεί να συνδεθεί στο αποθετήριο. Θα συνεχίσει χωρίς να έχει ενημερωθεί..."
	arr["ITALIAN",5]="Sembra che la connessione a internet non sia stabile. Lo script non riesce a connettersi al repository. Continuerà senza aggiornarsi..."
	arr["POLISH",5]="Wygląda na to, że połączenie internetowe nie jest stabilne. Skrypt nie może połączyć się z repozytorium. Będzie kontynuowany bez aktualizacji..."
	arr["GERMAN",5]="Anscheinend ist Ihre Internetverbindung nicht stabil. Das Skript kann keine Verbindung zum Repository herstellen. Es wird ohne Aktualisierung fortgesetzt..."
	arr["TURKISH",5]="Görünüşe göre internet bağlantınız dengesiz. Yazılım depoya bağlanamadı. Güncelleme olmadan devam edilecek..."

	arr["ENGLISH",6]="Welcome to airgeddon script v${airgeddon_version}"
	arr["SPANISH",6]="Bienvenid@ a airgeddon script v${airgeddon_version}"
	arr["FRENCH",6]="Bienvenue au script airgeddon v${airgeddon_version}"
	arr["CATALAN",6]="Benvingut a airgeddon script v${airgeddon_version}"
	arr["PORTUGUESE",6]="Bem-vindo ao script airgeddon v${airgeddon_version}"
	arr["RUSSIAN",6]="Добро пожаловать в скрипт airgeddon v${airgeddon_version}"
	arr["GREEK",6]="Καλωσήρθατε στο airgeddon v${airgeddon_version}"
	arr["ITALIAN",6]="Benvenuti a airgeddon script v${airgeddon_version}"
	arr["POLISH",6]="Witaj w skrypcie airgeddon v${airgeddon_version}"
	arr["GERMAN",6]="Willkommen bei airgeddon Skript v${airgeddon_version}"
	arr["TURKISH",6]="airgeddon yazılımına hoşgeldiniz v${airgeddon_version}"

	arr["ENGLISH",7]="This script is only for educational purposes. Be good boyz&girlz!"
	arr["SPANISH",7]="Este script se ha hecho sólo con fines educativos. Sed buen@s chic@s!"
	arr["FRENCH",7]="Ce script a été fait à des fins purement éducatives. Portez-vous biens!"
	arr["CATALAN",7]="Aquest script s'ha fet només amb fins educatius. Porteu-vos bé!"
	arr["PORTUGUESE",7]="Este script foi feito apenas para fins educacionais. Comportem-se!"
	arr["RUSSIAN",7]="Этот скрипт только для образовательных целей. Будьте хорошими мальчиками и девочками!"
	arr["GREEK",7]="Αυτό το script είναι για διδακτικούς σκοπούς. Να είστε φρόνιμοι!"
	arr["ITALIAN",7]="Questo script è stato fatto solo per scopi didattici. Fate i bravi!"
	arr["POLISH",7]="Ten skrypt został napisany tylko do celów edukacyjnych. Bądź grzeczny!"
	arr["GERMAN",7]="Dieses Skript wurde nur für Bildungszwecke erstellt. Seid brav, Jungs!"
	arr["TURKISH",7]="Bu yazılım sadece eğitim amaçlıdır. Akıllı olun çocuklar!"

	arr["ENGLISH",8]="Known compatible distros with this script:"
	arr["SPANISH",8]="Distros conocidas compatibles con este script:"
	arr["FRENCH",8]="Distros connus compatibles avec ce script:"
	arr["CATALAN",8]="Distros conegudes compatibles amb aquest script:"
	arr["PORTUGUESE",8]="Distros conhecidas compatíveis com este script:"
	arr["RUSSIAN",8]="Дистрибутивы о которых известно, что они совместимы со скриптом:"
	arr["GREEK",8]="Γνώστες εκδόσεις που υποστηρίζουν αυτό το script:"
	arr["ITALIAN",8]="Distribuzioni note compatibili con questo script:"
	arr["POLISH",8]="Znane dystrybucje kompatybilne z tym skryptem:"
	arr["GERMAN",8]="Bekannte Distros, die mit diesem Skript kompatibel sind:"
	arr["TURKISH",8]="Bu komut dosyasıyla bilinen uyumlu dağıtımlar:"

	arr["ENGLISH",9]="Detecting system..."
	arr["SPANISH",9]="Detectando sistema..."
	arr["FRENCH",9]="Détection du système..."
	arr["CATALAN",9]="Detecció del sistema..."
	arr["PORTUGUESE",9]="Detectando sistema..."
	arr["RUSSIAN",9]="Определяем систему..."
	arr["GREEK",9]="Το σύστημα εντοπίζεται..."
	arr["ITALIAN",9]="Rilevando sistema..."
	arr["POLISH",9]="Wykrywanie systemu..."
	arr["GERMAN",9]="Systemerkennung..."
	arr["TURKISH",9]="Sistem tespit ediliyor..."

	arr["ENGLISH",10]="This interface ${current_iface_on_messages} is already in monitor mode"
	arr["SPANISH",10]="Esta interfaz ${current_iface_on_messages} ya está en modo monitor"
	arr["FRENCH",10]="L'interface ${current_iface_on_messages} est déjà en mode moniteur"
	arr["CATALAN",10]="Aquesta interfície ${current_iface_on_messages} ja està en mode monitor"
	arr["PORTUGUESE",10]="Esta interface ${current_iface_on_messages} já está em modo monitor"
	arr["RUSSIAN",10]="Этот интерфейс ${current_iface_on_messages} уже в режиме монитора"
	arr["GREEK",10]="Αυτή η διεπαφή ${current_iface_on_messages} είναι ήδη σε κατάσταση παρακολούθησης"
	arr["ITALIAN",10]="Questa interfaccia ${current_iface_on_messages} è già in modalità monitor"
	arr["POLISH",10]="Ten interfejs ${current_iface_on_messages} jest już w trybie monitorowania"
	arr["GERMAN",10]="Diese ${current_iface_on_messages}-Schnittstelle befindet sich bereits im monitor-Modus"
	arr["TURKISH",10]="Bu arayüz ${current_iface_on_messages} zaten izleme modunda"

	arr["ENGLISH",11]="Exiting airgeddon script v${airgeddon_version} - See you soon! :)"
	arr["SPANISH",11]="Saliendo de airgeddon script v${airgeddon_version} - Nos vemos pronto! :)"
	arr["FRENCH",11]="Fermeture du script airgeddon v${airgeddon_version} - A bientôt! :)"
	arr["CATALAN",11]="Sortint de airgeddon script v${airgeddon_version} - Ens veiem aviat! :)"
	arr["PORTUGUESE",11]="Saindo do script airgeddon v${airgeddon_version} - Até breve! :)"
	arr["RUSSIAN",11]="Выход из скрипта airgeddon v${airgeddon_version} - До встречи! :)"
	arr["GREEK",11]="Κλείσιμο του airgeddon v${airgeddon_version} - Αντίο! :)"
	arr["ITALIAN",11]="Abbandonando airgeddon script v${airgeddon_version} - A presto! :)"
	arr["POLISH",11]="Wyjście z skryptu airgeddon v${airgeddon_version} - Do zobaczenia wkrótce! :)"
	arr["GERMAN",11]="Sie verlassen airgeddon Skript v${airgeddon_version} - Bis bald! :)"
	arr["TURKISH",11]="airgeddon yazılımından çıkış yapılıyor v${airgeddon_version} - Tekrar görüşürüz! :)"

	arr["ENGLISH",12]="${blue_color}Interruption detected. ${green_color}Do you really want to exit? ${normal_color}${visual_choice}"
	arr["SPANISH",12]="${blue_color}Detectada interrupción. ${green_color}¿Quieres realmente salir del script? ${normal_color}${visual_choice}"
	arr["FRENCH",12]="${blue_color}Interruption détectée. ${green_color}Voulez-vous vraiment arrêter le script? ${normal_color}${visual_choice}"
	arr["CATALAN",12]="${blue_color}Interrupció detectada. ${green_color}¿Realment vols sortir de l'script? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",12]="${blue_color}Interrupção detectada. ${green_color}Você quer realmente sair o script? ${normal_color}${visual_choice}"
	arr["RUSSIAN",12]="${blue_color}Обнаружено прерывание. ${green_color}Вы действительно хотите выйти? ${normal_color}${visual_choice}"
	arr["GREEK",12]="${blue_color}Εντοπίστηκε διακοπή. ${green_color}Είστε σίγουροι ότι θέλετε να τερματίσετε το script; ${normal_color}${visual_choice}"
	arr["ITALIAN",12]="${blue_color}Rilevata interruzione. ${green_color}Vuoi davvero uscire dallo script? ${normal_color}${visual_choice}"
	arr["POLISH",12]="${blue_color}Wykryto przerwanie. ${green_color}Czy naprawdę chcesz wyjść ze skryptu? ${normal_color}${visual_choice}"
	arr["GERMAN",12]="${blue_color}Unterbrechung wurde erkannt. ${green_color}Wollen Sie wirklich aus dem Skript raus? ${normal_color}${visual_choice}"
	arr["TURKISH",12]="${blue_color}Kesinti algılandı. ${green_color}Gerçekten çıkış yapmak istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",13]="This interface ${current_iface_on_messages} is not a wifi card. It doesn't support monitor mode"
	arr["SPANISH",13]="Esta interfaz ${current_iface_on_messages} no es una tarjeta wifi. No soporta modo monitor"
	arr["FRENCH",13]="L'interface ${current_iface_on_messages} n'est pas une carte wifi. Elle n'est donc pas compatible mode moniteur"
	arr["CATALAN",13]="Aquesta interfície ${current_iface_on_messages} no és una targeta wifi vàlida. No es compatible amb mode monitor"
	arr["PORTUGUESE",13]="Esta interface ${current_iface_on_messages} não é wifi. Ela não suporta o modo monitor"
	arr["RUSSIAN",13]="Этот интерфейс ${current_iface_on_messages} не является wifi картой. Он не поддерживает режим монитора"
	arr["GREEK",13]="Αυτή η διεπαφή ${current_iface_on_messages} δεν έιναι κάρτα wifi. Δεν υποστηρίζει κατάσταση παρακολούθησης"
	arr["ITALIAN",13]="Questa interfaccia ${current_iface_on_messages} non è una scheda wifi. Non supporta la modalità del monitor"
	arr["POLISH",13]="Interfejs ${current_iface_on_messages} nie jest kartą wifi. Nie obsługuje trybu monitorowania"
	arr["GERMAN",13]="Diese ${current_iface_on_messages}-interface ist keine WLAN-Karte. Monitor Modus ist nicht unterstützt"
	arr["TURKISH",13]="Bu arayüz ${current_iface_on_messages} bir wifi kartı değildir. İzleme modunu desteklemiyor"

	arr["ENGLISH",14]="This interface ${current_iface_on_messages} is not in monitor mode"
	arr["SPANISH",14]="Esta interfaz ${current_iface_on_messages} no está en modo monitor"
	arr["FRENCH",14]="L'interface ${current_iface_on_messages} n'est pas en mode moniteur"
	arr["CATALAN",14]="Aquesta interfície ${current_iface_on_messages} no està en mode monitor"
	arr["PORTUGUESE",14]="Esta interface ${current_iface_on_messages} não está em modo monitor"
	arr["RUSSIAN",14]="Этот интерфейс ${current_iface_on_messages} не в режиме монитора"
	arr["GREEK",14]="Αυτή η διεπαφή ${current_iface_on_messages} δεν είναι σε κατάσταση παρακολούθησης"
	arr["ITALIAN",14]="Questa interfaccia ${current_iface_on_messages} non è in modalità monitor"
	arr["POLISH",14]="Ten interfejs ${current_iface_on_messages} nie jest w trybie monitorowania"
	arr["GERMAN",14]="Diese ${current_iface_on_messages}-Interface befindet sich nicht im monitor Modus"
	arr["TURKISH",14]="Bu arayüz ${current_iface_on_messages} izleme modunda değildir"

	arr["ENGLISH",15]="The interface changed its name while setting in managed mode. Autoselected"
	arr["SPANISH",15]="Esta interfaz ha cambiado su nombre al ponerse en modo managed. Se ha seleccionado automáticamente"
	arr["FRENCH",15]="Le nom de l'interface a changé lors du passage en mode managed. Elle a été sélectionnée automatiquement"
	arr["CATALAN",15]="Aquesta interfície ha canviat de nom al posar-la en mode managed. S'ha triat automàticament"
	arr["PORTUGUESE",15]="Esta interface mudou de nome ao ser colocada em modo managed. Ela foi selecionada automaticamente"
	arr["RUSSIAN",15]="Интерфейс изменил имя во время перевода в управляемый режим. Выбран автоматически"
	arr["GREEK",15]="Η διεπάφη άλλαξε όνομα καθώς ήταν σε ετερόκλητη κατάσταση. Επιλέχθηκε αυτόματα"
	arr["ITALIAN",15]="Questa interfaccia ha cambiato il suo nome passando in modalità managed. È stata selezionata automaticamente"
	arr["POLISH",15]="Ten interfejs zmienił nazwę w trakcie uruchamiania trybu zarządzania. Wybrany automatycznie"
	arr["GERMAN",15]="Diese Interface hat im Managed-Modus ihren Namen geändert. Es wurde automatisch ausgewählt"
	arr["TURKISH",15]="Arayüz ismi yönetici moduna alınırken değiştirildi. Otomatik olarak seçildi"

	arr["ENGLISH",16]="Managed mode now is set on ${current_iface_on_messages}"
	arr["SPANISH",16]="Se ha puesto el modo managed en ${current_iface_on_messages}"
	arr["FRENCH",16]="${current_iface_on_messages} est maintenant en mode manged"
	arr["CATALAN",16]="${current_iface_on_messages} s'ha configurat en mode managed"
	arr["PORTUGUESE",16]="Modo managed configurado em ${current_iface_on_messages}"
	arr["RUSSIAN",16]="Управляемый режим теперь установлен на ${current_iface_on_messages}"
	arr["GREEK",16]="Η διεπαφή ${current_iface_on_messages} είναι τώρα σε ετερόκλητη κατάσταση"
	arr["ITALIAN",16]="${current_iface_on_messages} è stata configurata in modalitá managed"
	arr["POLISH",16]="Tryb zarządzany został ustawiony na ${current_iface_on_messages}"
	arr["GERMAN",16]="Der Managed-Modus wurde auf ${current_iface_on_messages} festgelegt"
	arr["TURKISH",16]="Yönetici modu açıldı ${current_iface_on_messages}"

	arr["ENGLISH",17]="Setting your interface in managed mode..."
	arr["SPANISH",17]="Poniendo la interfaz en modo managed..."
	arr["FRENCH",17]="L'interface est en train de passer en mode managed..."
	arr["CATALAN",17]="Configurant la interfície en mode managed..."
	arr["PORTUGUESE",17]="Colocando a interface em modo managed..."
	arr["RUSSIAN",17]="Переводим ваш интерфейс в управляемый режим..."
	arr["GREEK",17]="Ενεργοποιείται η ετερόκλητη κατάσταση στην διεπαφή..."
	arr["ITALIAN",17]="Mettendo l'interfaccia in modalità managed..."
	arr["POLISH",17]="Ustawianie interfejsu w trybie zarządzania..."
	arr["GERMAN",17]="Interface wird zum Managed-Modus versetzt..."
	arr["TURKISH",17]="Arayüzünüz yönetici moduna çeviriliyor..."

	arr["ENGLISH",18]="Setting your interface in monitor mode..."
	arr["SPANISH",18]="Poniendo la interfaz en modo monitor..."
	arr["FRENCH",18]="L'interface est en train de passer en mode moniteur..."
	arr["CATALAN",18]="Configurant la interfície en mode monitor..."
	arr["PORTUGUESE",18]="Colocando a interface em modo monitor..."
	arr["RUSSIAN",18]="Переводим ваш интерфейс в режим монитора..."
	arr["GREEK",18]="Ενεργοποιείται η κατάσταση παρακολούθησης στην διεπαφή..."
	arr["ITALIAN",18]="Mettendo l'interfaccia modalità monitor..."
	arr["POLISH",18]="Ustawianie interfejsu w trybie monitorowania..."
	arr["GERMAN",18]="Interface wird zum monitor-Modus versetzt..."
	arr["TURKISH",18]="Arayüzünüz izleme moduna çeviriliyor..."

	arr["ENGLISH",19]="Please be patient. Maybe killing some conflicting processes..."
	arr["SPANISH",19]="Por favor ten paciencia. Puede que esté matando algunos procesos que podrían causar conflicto..."
	arr["FRENCH",19]="Soyez patients s'il vous plaît. Il se peut qu'il faile tuer des processus conflictuels..."
	arr["CATALAN",19]="Si us plau té paciència. Pot ser que s'estiguin matant alguns processos que podrien causar conflicte..."
	arr["PORTUGUESE",19]="Por favor, seja paciente. Matando alguns processos que podem causar conflitos..."
	arr["RUSSIAN",19]="Пожалуйста, подождите. Возможно завершение некоторых конфликтующих процессов..."
	arr["GREEK",19]="Παρακαλώ δείξτε υπομονή. Ίσως τερματίζουν κάποιες εμπλέκουσες διεργασίες..."
	arr["ITALIAN",19]="Si prega di essere pazienti. Puó eessre che si stiano terminando alcuni processi che potrebbero causare un conflitto..."
	arr["POLISH",19]="Cierpliwości. Zakańczam procesy, które mogłyby powodować konflikty..."
	arr["GERMAN",19]="Wir bitten um Geduld. Mögliche konfliktreiche Prozesse werden gerade gestoppt..."
	arr["TURKISH",19]="Lütfen sabırlı olun. Bazı çelişkili süreçler sonlandırılıyor..."

	arr["ENGLISH",20]="This interface ${current_iface_on_messages} doesn't support monitor mode"
	arr["SPANISH",20]="Esta interfaz ${current_iface_on_messages} no soporta modo monitor"
	arr["FRENCH",20]="L'interface ${current_iface_on_messages} n'est pas compatible mode moniteur"
	arr["CATALAN",20]="Aquesta interfície ${current_iface_on_messages} no suporta mode monitor"
	arr["PORTUGUESE",20]="Esta interface ${current_iface_on_messages} não suporta o modo monitor"
	arr["RUSSIAN",20]="Этот интерфейс ${current_iface_on_messages} не поддерживает режим монитора"
	arr["GREEK",20]="Αυτή η διεπαφή ${current_iface_on_messages} δεν υποστηρίζει κατάσταση παρακολούθησης"
	arr["ITALIAN",20]="Questa interfaccia ${current_iface_on_messages} non supporta la modalità monitor"
	arr["POLISH",20]="Interfejs ${current_iface_on_messages} nie obsługuje trybu monitorowania"
	arr["GERMAN",20]="Diese ${current_iface_on_messages}-Interface unterstützt den monitor-Modus nicht"
	arr["TURKISH",20]="Bu arayüz ${current_iface_on_messages} izleme modunu desteklemiyor"

	arr["ENGLISH",21]="The interface changed its name while setting in monitor mode. Autoselected"
	arr["SPANISH",21]="Esta interfaz ha cambiado su nombre al ponerla en modo monitor. Se ha seleccionado automáticamente"
	arr["FRENCH",21]="Le nom de l'interface à changé lors de l'activation du mode moniteur. Elle a été automatiquement sélectionnée"
	arr["CATALAN",21]="Aquesta interfície ha canviat de nom al posar-la en mode monitor. S'ha seleccionat automàticament"
	arr["PORTUGUESE",21]="Esta interface mudou de nome ao ser colocada em modo monitor. Ela foi selecionada automaticamente"
	arr["RUSSIAN",21]="Этот интерфейс изменил своё имя во время перевода в режим монитора. Выбран автоматически"
	arr["GREEK",21]="Η διεπαφή άλλαξε όνομα καθώς ήταν σε κατάσταση παρακολούθησης"
	arr["ITALIAN",21]="Questa interfaccia ha cambiato il suo nome passando in modalità monitor. È stata selezionata automaticamente"
	arr["POLISH",21]="Ten interfejs zmienił nazwę w trakcie uruchamiania trybu monitorowania. Wybrany automatycznie"
	arr["GERMAN",21]="Diese Interface hat im monitor-Modus ihren Namen geändert. Es wurde automatisch ausgewählt"
	arr["TURKISH",21]="Arayüz, monitör moduna girerken adını değiştirdi. Autoselected"

	arr["ENGLISH",22]="Monitor mode now is set on ${current_iface_on_messages}"
	arr["SPANISH",22]="Se ha puesto el modo monitor en ${current_iface_on_messages}"
	arr["FRENCH",22]="Mode moniteur activé sur l'interface ${current_iface_on_messages}"
	arr["CATALAN",22]="S'ha configurat el mode monitor en ${current_iface_on_messages}"
	arr["PORTUGUESE",22]="Modo monitor foi ativo em ${current_iface_on_messages}"
	arr["RUSSIAN",22]="Режим монитора установлен на ${current_iface_on_messages}"
	arr["GREEK",22]="Η διεπαφή ${current_iface_on_messages} είναι τώρα σε κατάσταση παρακολούθησης"
	arr["ITALIAN",22]="È stato impostato il modo monitor in ${current_iface_on_messages}"
	arr["POLISH",22]="Tryb monitorowania został ustawiony na ${current_iface_on_messages}"
	arr["GERMAN",22]="Monitor-Modus wurde auf ${current_iface_on_messages} gesetzt"
	arr["TURKISH",22]="İzleme modu açıldı ${current_iface_on_messages}"

	arr["ENGLISH",23]="There is a problem with the selected interface. Redirecting you to script exit"
	arr["SPANISH",23]="Hay un problema con la interfaz seleccionada. Redirigiendo a la salida del script"
	arr["FRENCH",23]="Il y a un problème avec l'interface choisie. Vous allez être dirigés vers la sortie du script"
	arr["CATALAN",23]="Hi ha un problema amb la interfície seleccionada. Redirigint cap a la sortida del script"
	arr["PORTUGUESE",23]="Existe um problema com a interface selecionada. Saindo do script"
	arr["RUSSIAN",23]="Проблема с выбранным интерфейсом. Перенаправляем вас к выходу из скрипта"
	arr["GREEK",23]="Υπάρχει πρόβλημε με την επιλεγμένη διεπαφή. Θα καθοδηγηθείτε στην έξοδο του script"
	arr["ITALIAN",23]="C'è un problema con l'interfaccia selezionata. Reindirizzando l'output dello script"
	arr["POLISH",23]="Wystąpił problem z wybranym interfejsem. Przekierowanie do wyjścia ze skryptu"
	arr["GERMAN",23]="Ein Problem ist mit der ausgewählten Interface aufgetreten. Weiterleitung zur Ausgabe des Skripts"
	arr["TURKISH",23]="Seçilen arayüz ile ilgili bir problem oluştu. Yazılımdan çıkışa yönlendiriliyorsunuz"

	arr["ENGLISH",24]="Select an interface to work with:"
	arr["SPANISH",24]="Selecciona una interfaz para trabajar con ella:"
	arr["FRENCH",24]="Sélectionnez l'interface pour travailler:"
	arr["CATALAN",24]="Seleccionar una interfície per treballar-hi:"
	arr["PORTUGUESE",24]="Selecione uma interface para trabalhar:"
	arr["RUSSIAN",24]="Выберите интерфейс для работы:"
	arr["GREEK",24]="Επιλέξτε διεπαφή:"
	arr["ITALIAN",24]="Seleziona un'interfaccia con cui lavorare:"
	arr["POLISH",24]="Wybierz interfejs:"
	arr["GERMAN",24]="Wählen Sie eine Interface aus, mit der Sie arbeiten möchten:"
	arr["TURKISH",24]="Çalışmak için bir arayüz seçiniz:"

	arr["ENGLISH",25]="Set channel (1-14):"
	arr["SPANISH",25]="Selecciona un canal (1-14):"
	arr["FRENCH",25]="Sélectionnez un canal (1-14):"
	arr["CATALAN",25]="Seleccioni un canal (1-14):"
	arr["PORTUGUESE",25]="Escolha um canal (1-14):"
	arr["RUSSIAN",25]="Установите канал (1-14):"
	arr["GREEK",25]="Θέστε κανάλι (1-14):"
	arr["ITALIAN",25]="Seleziona un canale (1-14):"
	arr["POLISH",25]="Wybierz kanał (1-14):"
	arr["GERMAN",25]="Wähle einen Kanal (1-14):"
	arr["TURKISH",25]="Kanal ayarlayınız (1-14):"

	arr["ENGLISH",26]="Channel set to ${normal_color}${channel}"
	arr["SPANISH",26]="Canal elegido ${normal_color}${channel}"
	arr["FRENCH",26]="Le canal ${normal_color}${channel}${blue_color} a été choisi"
	arr["CATALAN",26]="El canal ${normal_color}${channel}${blue_color} s'ha escollit"
	arr["PORTUGUESE",26]="Canal ${normal_color}${channel}${blue_color} selecionado"
	arr["RUSSIAN",26]="Канал установлен на ${normal_color}${channel}"
	arr["GREEK",26]="Το κανάλι ${normal_color}${channel}${blue_color} έχει επιλεχθεί"
	arr["ITALIAN",26]="Canale selezionato ${normal_color}${channel}"
	arr["POLISH",26]="Wybrany kanał ${normal_color}${channel}"
	arr["GERMAN",26]="Ausgewählter Kanal ${normal_color}${channel}"
	arr["TURKISH",26]="Kanal şu şekilde ayarlandı ${normal_color}${channel}"

	arr["ENGLISH",27]="Type target BSSID (example: 00:11:22:33:44:55):"
	arr["SPANISH",27]="Escribe el BSSID objetivo (ejemplo: 00:11:22:33:44:55):"
	arr["FRENCH",27]="Veuillez entrer le BSSID de l'objectif (exemple: 00:11:22:33:44:55):"
	arr["CATALAN",27]="Escriu el BSSID objectiu (exemple: 00:11:22:33:44:55):"
	arr["PORTUGUESE",27]="Escreva o BSSID alvo (exemplo: 00:11:22:33:44:55):"
	arr["RUSSIAN",27]="Введите BSSID цели (пример: 00:11:22:33:44:55):"
	arr["GREEK",27]="Πληκτρολογήστε BSSID στόχου (παράδειγμα: 00:11:22:33:44:55):"
	arr["ITALIAN",27]="Scrivere l'BSSID obiettivo (es: 00:11:22:33:44:55):"
	arr["POLISH",27]="Wpisz BSSID celu (przykład: 00:11:22:33:44:55):"
	arr["GERMAN",27]="Schreiben Sie die Ziel-BSSID (Beispiel: 00:11:22:33:44:55):"
	arr["TURKISH",27]="Hedef türü BSSID (example: 00:11:22:33:44:55):"

	arr["ENGLISH",28]="BSSID set to ${normal_color}${bssid}"
	arr["SPANISH",28]="BSSID elegido ${normal_color}${bssid}"
	arr["FRENCH",28]="Le BSSID choisi est ${normal_color}${bssid}"
	arr["CATALAN",28]="El BSSID escollit ${normal_color}${bssid}"
	arr["PORTUGUESE",28]="BSSID escolhido ${normal_color}${bssid}"
	arr["RUSSIAN",28]="BSSID установлена на ${normal_color}${bssid}"
	arr["GREEK",28]="Το BSSID τέθηκε σε ${normal_color}${bssid}"
	arr["ITALIAN",28]="BSSID selezionato ${normal_color}${bssid}"
	arr["POLISH",28]="Wybrany BSSID ${normal_color}${bssid}"
	arr["GERMAN",28]="Gewählte BSSID ${normal_color}${bssid}"
	arr["TURKISH",28]="BSSID şu şekilde ayarlandı ${normal_color}${bssid}"

	arr["ENGLISH",29]="Type target ESSID:"
	arr["SPANISH",29]="Escribe el ESSID objetivo:"
	arr["FRENCH",29]="Écrivez l'ESSID du réseau cible:"
	arr["CATALAN",29]="Escriu el ESSID objectiu:"
	arr["PORTUGUESE",29]="Escreva o ESSID do alvo:"
	arr["RUSSIAN",29]="Введите BSSID цели:"
	arr["GREEK",29]="Πληκτρολογήστε ESSID στόχου:"
	arr["ITALIAN",29]="Scrivere l'ESSID obiettivo:"
	arr["POLISH",29]="Wpisz ESSID celu:"
	arr["GERMAN",29]="Schreiben Sie das ESSID Ziel:"
	arr["TURKISH",29]="Hedef türü ESSID:"

	arr["ENGLISH",30]="You have selected a hidden network ESSID. Can't be used. Select another one or perform a BSSID based attack instead of this"
	arr["SPANISH",30]="Has seleccionado un ESSID de red oculta. No se puede usar. Selecciona otro o ejecuta un ataque basado en BSSID en lugar de este"
	arr["FRENCH",30]="Vous avez choisi un réseau dont l'ESSID est caché et ce n'est pas possible. Veuillez sélectionner une autre cible ou bien effectuer une attaque qui se fonde sur le BSSID au lieu de celle-ci"
	arr["CATALAN",30]="Has seleccionat un ESSID de xarxa oculta. No es pot utilitzar. Selecciona un altre o executa un atac basat en BSSID en lloc d'aquest"
	arr["PORTUGUESE",30]="Você selecionou uma rede com ESSID oculto. Você não pode utilizar. Selecione outro ou execute um ataque com BSSID ao invés deste"
	arr["RUSSIAN",30]="Вы выбрали сеть со скрытым ESSID. Использование невозможно. Выберите другую или вместо этой выполните атаку, основанную на BSSID"
	arr["GREEK",30]="Επιλέξατε ESSID κρυφού δικτύου. Δεν μπορεί να χρησιμοποιηθεί. Επιλέξτε κάποιο άλλο ή ξεκινήστε μία επίθεση βασισμένη στο BSSID αντί αυτού"
	arr["ITALIAN",30]="È stata selezionata una rete ESSID nascosta. Non puó essere utilizzata. Selezionare un altro o eseguire un attacco basato in BSSID invece di questo"
	arr["POLISH",30]="Wybrałeś ukrytą sieć ESSID. Nie można jej używać. Wybierz inną lub uruchom atak oparty na BSSID"
	arr["GERMAN",30]="Sie haben ein verstecktes Netzwerk-ESSID ausgewählt. Es kann nicht verwendet werden. Wählen Sie einen anderen oder führen Sie stattdessen einen BSSID-basierenden Angriff aus"
	arr["TURKISH",30]="Gizli bir ağ seçtiniz ESSID. Bu kullanılamaz. Bunun yerine BSSID tabanlı başka bir saldırı seçiniz"

	arr["ENGLISH",31]="ESSID set to ${normal_color}${essid}"
	arr["SPANISH",31]="ESSID elegido ${normal_color}${essid}"
	arr["FRENCH",31]="l'ESSID sélectionné est ${normal_color}${essid}"
	arr["CATALAN",31]="l'ESSID seleccionat ${normal_color}${essid}"
	arr["PORTUGUESE",31]="ESSID escolhido ${normal_color}${essid}"
	arr["RUSSIAN",31]="ESSID установлена на ${normal_color}${essid}"
	arr["GREEK",31]="Το ESSID τέθηκε σε ${normal_color}${essid}"
	arr["ITALIAN",31]="ESSID selezionato ${normal_color}${essid}"
	arr["POLISH",31]="Wybrany ESSID ${normal_color}${essid}"
	arr["GERMAN",31]="Gewähltes ESSID ${normal_color}${essid}"
	arr["TURKISH",31]="ESSID şu şekilde ayarlandı ${normal_color}${essid}"

	arr["ENGLISH",32]="All parameters set"
	arr["SPANISH",32]="Todos los parámetros están listos"
	arr["FRENCH",32]="Tous les paramètres sont correctement établis"
	arr["CATALAN",32]="Tots els paràmetres establerts"
	arr["PORTUGUESE",32]="Todos os parâmetros configurados"
	arr["RUSSIAN",32]="Все параметры установлены"
	arr["GREEK",32]="Έχουν τεθεί όλοι οι παράμετροι"
	arr["ITALIAN",32]="Tutti i parametri sono pronti"
	arr["POLISH",32]="Wszystkie parametry są gotowe"
	arr["GERMAN",32]="Alle Parameter eingestellt"
	arr["TURKISH",32]="Tüm parametreler ayalandı"

	arr["ENGLISH",33]="Starting attack. When started, press [Ctrl+C] to stop..."
	arr["SPANISH",33]="Comenzando ataque. Una vez empezado, pulse [Ctrl+C] para pararlo..."
	arr["FRENCH",33]="L'attaque est lancé. Pressez [Ctrl+C] pour l'arrêter..."
	arr["CATALAN",33]="Començant l'atac. Un cop començat, premeu [Ctrl+C] per aturar-lo..."
	arr["PORTUGUESE",33]="Começando ataque. Uma vez iniciado, pressione [Ctrl+C] para parar..."
	arr["RUSSIAN",33]="Атака запускается. Нажмите [Ctrl+C] для остановки..."
	arr["GREEK",33]="Έναρξη επίθεσης. Όταν ξεκινήσει, πατήστε [Ctrl+C] για να σταματήσει..."
	arr["ITALIAN",33]="Cominciando l'attacco. Una volta avviato, premere [Ctrl+C] per fermare..."
	arr["POLISH",33]="Uruchomienie ataku. Waciśnij [Ctrl+C] w trakcie działania, aby go przerwać..."
	arr["GERMAN",33]="Angriff starten. Einmal gestartet, drücken Sie [Ctrl+C], um es zu stoppen..."
	arr["TURKISH",33]="Saldırı başlıyor. Başladıktan sonra, durdurmak için [Ctrl+C] basınız..."

	arr["ENGLISH",34]="Selected interface ${current_iface_on_messages} is in monitor mode. Attack can be performed"
	arr["SPANISH",34]="La interfaz seleccionada ${current_iface_on_messages} está en modo monitor. El ataque se puede realizar"
	arr["FRENCH",34]="L'interface ${current_iface_on_messages} qui a été sélectionnée est bien en mode moniteur. L'attaque peut être lancée"
	arr["CATALAN",34]="La interfície seleccionada ${current_iface_on_messages} està configurada en mode monitor. L'atac es pot realitzar"
	arr["PORTUGUESE",34]="Interface selecionada ${current_iface_on_messages} está em modo monitor. O ataque pode ser realizado"
	arr["RUSSIAN",34]="Выбранный интерфейс ${current_iface_on_messages} в режиме монитора. Можно выполнить атаку"
	arr["GREEK",34]="Η επιλεγμένη διεπαφή ${current_iface_on_messages} είναι σε κατάσταση παρακολούθησης. Μπορεί να γίνει επίθεση"
	arr["ITALIAN",34]="L'interfaccia selezionata ${current_iface_on_messages} è in modalità monitor. L'attacco può essere eseguito"
	arr["POLISH",34]="Wybrany interfejs ${current_iface_on_messages} jest w trybie monitorowania. Można wykonać atak"
	arr["GERMAN",34]="Die ausgewählte Interface ${current_iface_on_messages} befindet sich im monitor Modus. Der Angriff kann ausgeführt werden"
	arr["TURKISH",34]="Seçilen arayüz ${current_iface_on_messages} izleme modunda. Saldırı yapılabilir"

	arr["ENGLISH",35]="Deauthentication / Dissasociation mdk3 attack chosen (monitor mode needed)"
	arr["SPANISH",35]="Elegido ataque de Desautenticación / Desasociación mdk3 (modo monitor requerido)"
	arr["FRENCH",35]="L'attaque de Dés-authentification / Dissociation mdk3 a été choisie (mode moniteur nécessaire)"
	arr["CATALAN",35]="Seleccionat atac de Desautenticació / Dissociació mdk3 (es requereix mode monitor)"
	arr["PORTUGUESE",35]="Ataque de desautenticação com mdk3 (modo monitor obrigatório)"
	arr["RUSSIAN",35]="Выбрана mdk3 атака Деаутентификации / Разъединения (необходим режим монитора)"
	arr["GREEK",35]="Deauthentication / Έχει επιλεχθεί επίθεση dissasociation mdk3 (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",35]="Attacco Deauth / Disassociation mdk3 scelto (modalità monitor richiesta)"
	arr["POLISH",35]="Wybrano atak Deauthentication / Disassociation mdk3 (wymagany tryb monitorowania)"
	arr["GERMAN",35]="Deauthentication / Disassociation mdk3 Angriff ausgewählt (monitor-Modus erforderlich)"
	arr["TURKISH",35]="Deauthentication / Dissasociation mdk3 saldırısı seçildi (izleme modu gereklidir)"

	arr["ENGLISH",36]="Deauthentication aireplay attack chosen (monitor mode needed)"
	arr["SPANISH",36]="Elegido ataque de Desautenticación aireplay (modo monitor requerido)"
	arr["FRENCH",36]="L'attaque de Dés-authentification aireplay a été choisie (mode moniteur nécessaire)"
	arr["CATALAN",36]="Seleccionat atac de Desautenticació aireplay (es requereix mode monitor)"
	arr["PORTUGUESE",36]="Ataque de desautenticação com Aireplay (modo monitor obrigatório)"
	arr["RUSSIAN",36]="Выбрана aireplay атака Деаутентификации (необходим режим монитора)"
	arr["GREEK",36]="Έχει επιλεχθεί επίθεση deauthentication aireplay (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",36]="Attacco Deauth aireplay scelto (modalità monitor richiesta)"
	arr["POLISH",36]="Wybrano atak Deauthentication aireplay (wymagany tryb monitorowania)"
	arr["GERMAN",36]="Airplay-Deauthentifizierungsangriff ausgewählt (monitor-Modus erforderlich)"
	arr["TURKISH",36]="Deauthentication aireplay saldırısı seçildi (izleme modu gereklidir)"

	arr["ENGLISH",37]="WIDS / WIPS / WDS Confusion attack chosen (monitor mode needed)"
	arr["SPANISH",37]="Elegido ataque Confusion WIDS / WIPS / WDS (modo monitor requerido)"
	arr["FRENCH",37]="L'attaque Confusion WIDS / WIPS / WDS a été choisie (mode moniteur nécessaire)"
	arr["CATALAN",37]="Seleccionat atac Confusion WIDS /WIPS / WDS (es requereix mode monitor)"
	arr["PORTUGUESE",37]="Ataque Confusion WIDS / WIPS / WDS (modo monitor obrigatório)"
	arr["RUSSIAN",37]="Выбрана атака запутывания WIDS / WIPS / WDS (необходим режим монитора)"
	arr["GREEK",37]="Έχει επιλεχθεί επίθεση σύγχυσης WIDS / WIPS / WDS (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",37]="Attacco Confusion / WIDS / WIPS / WDS scelto (modalità monitor richiesta)"
	arr["POLISH",37]="Wybrano ataki typu WIDS / WIPS / WDS Confusion (wymagany tryb monitorowania)"
	arr["GERMAN",37]="Confusion WIDS / WIPS / WDS Angriff ausgewählt (monitor-Modus erforderlich)"
	arr["ENGLISH",37]="WIDS / WIPS / WDS Confusion saldırısı seçildi (izleme modu gereklidir)"

	arr["ENGLISH",38]="Beacon flood attack chosen (monitor mode needed)"
	arr["SPANISH",38]="Elegido ataque Beacon flood (modo monitor requerido)"
	arr["FRENCH",38]="L'attaque Beacon flood a été choisie (mode moniteur nécessaire)"
	arr["CATALAN",38]="Seleccionat atac Beacon flood (es requereix mode monitor)"
	arr["PORTUGUESE",38]="Ataque de Beacon flood (modo monitor obrigatório)"
	arr["RUSSIAN",38]="Выбрана атака флуда маяками (необходим режим монитора)"
	arr["GREEK",38]="Έχει επιλεχθεί επίθεση πλημμύρας φάρου (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",38]="Attacco Beacon flood scelto (modalità monitor richiesta)"
	arr["POLISH",38]="Wybrano atak Beacon flood (wymagany tryb monitorowania)"
	arr["GERMAN",38]="Beacon flood Angriff ausgewählt (monitor-Modus erforderlich)"
	arr["TURKISH",38]="Beacon flood saldırısı seçildi (izleme modu gereklidir)"

	arr["ENGLISH",39]="Auth DoS attack chosen (monitor mode needed)"
	arr["SPANISH",39]="Elegido ataque Auth DoS (modo monitor requerido)"
	arr["FRENCH",39]="L'attaque Auth DoS a été choisie (modo moniteur nécessaire)"
	arr["CATALAN",39]="Seleccionat atac Auth DoS (es requereix mode monitor)"
	arr["PORTUGUESE",39]="O ataque DoS Auth foi escolhido (modo monitor obrigatório)"
	arr["RUSSIAN",39]="Выбрана атака Auth DoS (необходим режим монитора)"
	arr["GREEK",39]="Έχει επιλεχθεί επίθεση Auth DoS (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",39]="Attacco DoS Auth scelto (modalità monitor richiesta)"
	arr["POLISH",39]="Wybrano atak DoS Auth (wymagany tryb monitorowania)"
	arr["GERMAN",39]="Auth DoS Angriff ausgewählt (monitor-Modus erforderlich)"
	arr["TURKISH",39]="Auth DoS saldırısı seçildi (izleme modu gereklidir)"

	arr["ENGLISH",40]="Michael Shutdown (TKIP) attack chosen (monitor mode needed)"
	arr["SPANISH",40]="Elegido ataque Michael Shutdown (TKIP) (modo monitor requerido)"
	arr["FRENCH",40]="L'attaque Michael Shutdown (TKIP) a été choisie (mode moniteur nécessaire)"
	arr["CATALAN",40]="Seleccionat atac Michael Shutdown (TKIP) (es requereix mode monitor)"
	arr["PORTUGUESE",40]="Ataque selecionado Michael Shutdown (TKIP) (modo monitor obrigatório)"
	arr["RUSSIAN",40]="Выбрана атака Michael Shutdown (TKIP) (необходим режим монитора)"
	arr["GREEK",40]="Έχει επιλεχθεί επίθεση Michael Shutdown (TKIP) (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",40]="Attacco Michael Shutdown (TKIP) scelto (modalità monitor richiesta)"
	arr["POLISH",40]="Wybrano atak Michael Shutdown (TKIP) (wymagany tryb monitorowania)"
	arr["GERMAN",40]="Michael Shutdown (TKIP) Angriff ausgewählt (monitor-Modus erforderlich)"
	arr["TURKISH",40]="Michael Shutdown (TKIP) saldırısı seçildi (izleme modu gereklidir)"

	arr["ENGLISH",41]="No interface selected. You'll be redirected to select one"
	arr["SPANISH",41]="No hay interfaz seleccionada. Serás redirigido para seleccionar una"
	arr["FRENCH",41]="Aucune interface sélectionnée. Vous allez retourner au menu de sélection pour en choisir une"
	arr["CATALAN",41]="No hi ha intefície seleccionada. Seràs redirigit per seleccionar una"
	arr["PORTUGUESE",41]="Nenhuma interface selecionada. Você será redirecionado para selecionar uma"
	arr["RUSSIAN",41]="Интерфейс не выбран. Вы будете перенаправлены на выбор интерфейса"
	arr["GREEK",41]="Δεν έχει επιλεχθεί κάποια διεπαφή. Θα καθοδηγηθείτε για να επιλέξετε μία"
	arr["ITALIAN",41]="Nessuna interfaccia selezionata. Sarai reindirizzato per selezionarne una"
	arr["POLISH",41]="Nie wybrano interfejsu. Zostaniesz przekierowany, aby któryś wybrać"
	arr["GERMAN",41]="Keine Interface ausgewählt. Sie werden zur Auswahl weitergeleitet"
	arr["TURKISH",41]="Hiçbir arayüz seçilmedi. Seçmeniz için yönlendiriliyorsunuz"

	arr["ENGLISH",42]="Interface ${pink_color}${current_iface_on_messages}${blue_color} selected. Mode: ${pink_color}${ifacemode}${normal_color}"
	arr["SPANISH",42]="Interfaz ${pink_color}${current_iface_on_messages}${blue_color} seleccionada. Modo: ${pink_color}${ifacemode}${normal_color}"
	arr["FRENCH",42]="Interface ${pink_color}${current_iface_on_messages}${blue_color} sélectionnée. Mode: ${pink_color}${ifacemode}${normal_color}"
	arr["CATALAN",42]="Interfície ${pink_color}${current_iface_on_messages}${blue_color} seleccionada. Mode: ${pink_color}${ifacemode}${normal_color}"
	arr["PORTUGUESE",42]="Interface ${pink_color}${current_iface_on_messages}${blue_color} selecionada. Modo: ${pink_color}${ifacemode}${normal_color}"
	arr["RUSSIAN",42]="Интерфейс ${pink_color}${current_iface_on_messages}${blue_color} выбран. Режим: ${pink_color}${ifacemode}${normal_color}"
	arr["GREEK",42]="Η διεπαφή ${pink_color}${current_iface_on_messages}${blue_color} έχει επιλεχθεί. Κατάσταση: ${pink_color}${ifacemode}${normal_color}"
	arr["ITALIAN",42]="Interfaccia ${pink_color}${current_iface_on_messages}${blue_color} selezionata. Modalità: ${pink_color}${ifacemode}${normal_color}"
	arr["POLISH",42]="Interfejs ${pink_color}${current_iface_on_messages}${blue_color} został wybrany. Tryb: ${pink_color}${ifacemode}${normal_color}"
	arr["GERMAN",42]="Interface ${pink_color}${current_iface_on_messages}${blue_color} ausgewählt. Modus: ${pink_color}${ifacemode}${normal_color}"
	arr["TURKISH",42]="Arayüz ${pink_color}${current_iface_on_messages}${blue_color} seçildi. Mod: ${pink_color}${ifacemode}${normal_color}"

	arr["ENGLISH",43]="Selected BSSID: ${pink_color}${bssid}${normal_color}"
	arr["SPANISH",43]="BSSID seleccionado: ${pink_color}${bssid}${normal_color}"
	arr["FRENCH",43]="BSSID sélectionné: ${pink_color}${bssid}${normal_color}"
	arr["CATALAN",43]="BSSID seleccionat: ${pink_color}${bssid}${normal_color}"
	arr["PORTUGUESE",43]="BSSID selecionado: ${pink_color}${bssid}${normal_color}"
	arr["RUSSIAN",43]="Выбранный BSSID: ${pink_color}${bssid}${normal_color}"
	arr["GREEK",43]="Επιλεγμένο BSSID: ${pink_color}${bssid}${normal_color}"
	arr["ITALIAN",43]="BSSID selezionato: ${pink_color}${bssid}${normal_color}"
	arr["POLISH",43]="Wybrany BSSID: ${pink_color}${bssid}${normal_color}"
	arr["GERMAN",43]="Ausgewählte BSSID: ${pink_color}${bssid}${normal_color}"
	arr["TURKISH",43]="Seçildi BSSID: ${pink_color}${bssid}${normal_color}"

	arr["ENGLISH",44]="Selected channel: ${pink_color}${channel}${normal_color}"
	arr["SPANISH",44]="Canal seleccionado: ${pink_color}${channel}${normal_color}"
	arr["FRENCH",44]="Canal sélectionné: ${pink_color}${channel}${normal_color}"
	arr["CATALAN",44]="Canal seleecionat: ${pink_color}${channel}${normal_color}"
	arr["PORTUGUESE",44]="Canal selecionado: ${pink_color}${channel}${normal_color}"
	arr["RUSSIAN",44]="Выбранный канал: ${pink_color}${channel}${normal_color}"
	arr["GREEK",44]="Επιλεγμένο κανάλι: ${pink_color}${channel}${normal_color}"
	arr["ITALIAN",44]="Canale selezionato: ${pink_color}${channel}${normal_color}"
	arr["POLISH",44]="Wybrany kanał: ${pink_color}${channel}${normal_color}"
	arr["GERMAN",44]="Ausgewählter Kanal: ${pink_color}${channel}${normal_color}"
	arr["TURKISH",44]="Seçilen kanal: ${pink_color}${channel}${normal_color}"

	arr["ENGLISH",45]="Selected ESSID: ${pink_color}${essid}${blue_color} <- can't be used"
	arr["SPANISH",45]="ESSID seleccionado: ${pink_color}${essid}${blue_color} <- no se puede usar"
	arr["FRENCH",45]="ESSID sélectionné: ${pink_color}${essid}${blue_color} <- ne peut pas être utilisé"
	arr["CATALAN",45]="ESSID seleccionat: ${pink_color}${essid}${blue_color} <- no es pot utilitzar"
	arr["PORTUGUESE",45]="ESSID selecionado: ${pink_color}${essid}${blue_color} <- não pode ser utilizada"
	arr["RUSSIAN",45]="Выбранный ESSID: ${pink_color}${essid}${blue_color} <- не может быть использован"
	arr["GREEK",45]="Επιλεγμένο ESSID: ${pink_color}${essid}${blue_color} <- δεν μπορεί να χρησιμοποιηθεί"
	arr["ITALIAN",45]="ESSID selezionato: ${pink_color}${essid}${blue_color} <- non può essere utilizzato"
	arr["POLISH",45]="Wybrany ESSID: ${pink_color}${essid}${blue_color} <- nie można używać"
	arr["GERMAN",45]="Ausgewähltes ESSID: ${pink_color}${essid}${blue_color} <- kann nicht verwendet werden"
	arr["TURKISH",45]="Seçilen ESSID: ${pink_color}${essid}${blue_color} <- kullanılamaz"

	arr["ENGLISH",46]="Selected ESSID: ${pink_color}${essid}${normal_color}"
	arr["SPANISH",46]="ESSID seleccionado: ${pink_color}${essid}${normal_color}"
	arr["FRENCH",46]="ESSID sélectionné: ${pink_color}${essid}${normal_color}"
	arr["CATALAN",46]="ESSID seleccionat: ${pink_color}${essid}${normal_color}"
	arr["PORTUGUESE",46]="ESSID selecionado: ${pink_color}${essid}${normal_color}"
	arr["RUSSIAN",46]="Выбранный ESSID: ${pink_color}${essid}${normal_color}"
	arr["GREEK",46]="Επιλεγμένο ESSID: ${pink_color}${essid}${normal_color}"
	arr["ITALIAN",46]="ESSID selezionato: ${pink_color}${essid}${normal_color}"
	arr["POLISH",46]="Wybrano ESSID: ${pink_color}${essid}${normal_color}"
	arr["GERMAN",46]="Ausgewähltes ESSID: ${pink_color}${essid}${normal_color}"
	arr["TURKISH",46]="Seçildi ESSID: ${pink_color}${essid}${normal_color}"

	arr["ENGLISH",47]="Select an option from menu:"
	arr["SPANISH",47]="Selecciona una opción del menú:"
	arr["FRENCH",47]="Choisissez une des options du menu:"
	arr["CATALAN",47]="Selecciona una opció del menú:"
	arr["PORTUGUESE",47]="Selecione uma opção no menu:"
	arr["RUSSIAN",47]="Выбор опции из меню:"
	arr["GREEK",47]="Επιλέξτε μία επιλογή από το μενού:"
	arr["ITALIAN",47]="Selezionare un'opzione del menú:"
	arr["POLISH",47]="Wybierz opcję z menu:"
	arr["GERMAN",47]="Wählen Sie eine Menüoption:"
	arr["TURKISH",47]="Menüden bir ayar seçiniz"

	arr["ENGLISH",48]="1.  Select another network interface"
	arr["SPANISH",48]="1.  Selecciona otra interfaz de red"
	arr["FRENCH",48]="1.  Sélectionnez une autre interface réseaux"
	arr["CATALAN",48]="1.  Selecciona una altre interfície de xarxa"
	arr["PORTUGUESE",48]="1.  Selecione outra interface de rede"
	arr["RUSSIAN",48]="1.  Выбрать другой сетевой интерфейс"
	arr["GREEK",48]="1.  Επιλογή διαφορετικής διεπαφής"
	arr["ITALIAN",48]="1.  Selezionare un'altra interfaccia di rete"
	arr["POLISH",48]="1.  Wybierz inny interfejs sieciowy"
	arr["GERMAN",48]="1.  Wählen Sie eine andere Netzwerk-Interface"
	arr["TURKISH",48]="1.  Başka bir ağ arayüzü seç"

	arr["ENGLISH",49]="4.  Explore for targets (monitor mode needed)"
	arr["SPANISH",49]="4.  Explorar para buscar objetivos (modo monitor requerido)"
	arr["FRENCH",49]="4.  Détection des réseaux pour choisir une cible (modo moniteur obligatoire)"
	arr["CATALAN",49]="4.  Explorar per buscar objectius (es requereix mode monitor)"
	arr["PORTUGUESE",49]="4.  Procurar objetivos (modo monitor obrigatório)"
	arr["RUSSIAN",49]="4.  Поиск целей (необходим режим монитора)"
	arr["GREEK",49]="4.  Εξερεύνηση στόχων (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",49]="4.  Esplora per cercare obiettivi (modalità monitor richiesta)"
	arr["POLISH",49]="4.  Skanowanie możliwych celów (wymagany tryb monitorowania)"
	arr["GERMAN",49]="4.  Scannen, um Ziele zu finden (monitor-Modus erforderlich)"
	arr["TURKISH",49]="4.  Hedefleri tara (izleme modu gereklidir)"

	arr["ENGLISH",50]="monitor mode needed for attacks"
	arr["SPANISH",50]="modo monitor requerido en ataques"
	arr["FRENCH",50]="modo moniteur obligatoire pour ces attaques"
	arr["CATALAN",50]="mode monitor requerit per atacs"
	arr["PORTUGUESE",50]="modo monitor necessário para ataques"
	arr["RUSSIAN",50]="для атак необходим режим монитора"
	arr["GREEK",50]="χρειάζεται η κατάσταση παρακολούθησης για τις επιθέσεις"
	arr["ITALIAN",50]="modalità monitor richiesta per gli attacchi"
	arr["POLISH",50]="wymagany tryb monitorowania do wykonania ataku"
	arr["GERMAN",50]="monitor-Modus bei Angriffen erforderlich"
	arr["TURKISH",50]="saldırılar için izleme modu gereklidir"

	arr["ENGLISH",51]="5.  Deauth / disassoc amok mdk3 attack"
	arr["SPANISH",51]="5.  Ataque Deauth / Disassoc amok mdk3"
	arr["FRENCH",51]="5.  Attaque Deauth / Disassoc amok mdk3"
	arr["CATALAN",51]="5.  Atac Death /Disassoc amok mdk3"
	arr["PORTUGUESE",51]="5.  Ataque Deauth / Disassoc amok mdk3"
	arr["RUSSIAN",51]="5.  Атака деаутентификации / разъединения amok mdk3"
	arr["GREEK",51]="5.  Επίθεση Deauth / Disassoc amok mdk3"
	arr["ITALIAN",51]="5.  Attacco Deauth / Disassoc amok mdk3"
	arr["POLISH",51]="5.  Atak Deauth / Disassoc amok mdk3"
	arr["GERMAN",51]="5.  Deauth / Disassoc Amok mdk3 Angriff"
	arr["TURKISH",51]="5.  Deauth / disassoc amok mdk3 saldırısı"

	arr["ENGLISH",52]="6.  Deauth aireplay attack"
	arr["SPANISH",52]="6.  Ataque Deauth aireplay"
	arr["FRENCH",52]="6.  Attaque Deauth aireplay"
	arr["CATALAN",52]="6.  Atac Deauth aireplay"
	arr["PORTUGUESE",52]="6.  Ataque Deauth aireplay"
	arr["RUSSIAN",52]="6.  Атака деаутентификации aireplay"
	arr["GREEK",52]="6.  Επίθεση Deauth aireplay"
	arr["ITALIAN",52]="6.  Attacco Deauth aireplay"
	arr["POLISH",52]="6.  Atak Deauth aireplay"
	arr["GERMAN",52]="6.  Deauth aireplay Angriff"
	arr["TURKISH",52]="6.  Deauth aireplay saldırısı"

	arr["ENGLISH",53]="7.  WIDS / WIPS / WDS Confusion attack"
	arr["SPANISH",53]="7.  Ataque WIDS / WIPS / WDS Confusion"
	arr["FRENCH",53]="7.  Attaque WIDS / WIPS / WDS Confusion"
	arr["CATALAN",53]="7.  Atac WIDS / WIPS / WDS Confusion"
	arr["PORTUGUESE",53]="7.  Ataque Confusion WIDS / WIPS / WDS"
	arr["RUSSIAN",53]="7.  Атака смешения WIDS / WIPS / WDS"
	arr["GREEK",53]="7.  Επίθεση σύγχυσης WIDS / WIPS / WDS"
	arr["ITALIAN",53]="7.  Attacco WIDS / WIPS / WDS Confusion"
	arr["POLISH",53]="7.  Ataki WIDS / WIPS / WDS"
	arr["GERMAN",53]="7.  WIDS / WIPS / WDS Confusion Angriff"
	arr["TURKISH",53]="7.  WIDS / WIPS / WDS Confusion saldırısı"

	arr["ENGLISH",54]="old \"obsolete/non very effective\" attacks"
	arr["SPANISH",54]="antiguos ataques \"obsoletos/no muy efectivos\""
	arr["FRENCH",54]="anciennes attaques \"obsolètes/peu efficaces\""
	arr["CATALAN",54]="antics atacs \"obsolets/no gaire efectius\""
	arr["PORTUGUESE",54]="ataques antigos \"obsoletos/não muito eficazes\""
	arr["RUSSIAN",54]="старые \"абсолютно/не очень эффективные\" атаки"
	arr["GREEK",54]="παλιές \"απαρχαιωμένες/όχι και τόσο αποδοτικές\" επιθέσεις"
	arr["ITALIAN",54]="vecchi attacchi \"obsoleti/non molto efficaci\""
	arr["POLISH",54]="stare ataki \"przestarzałe/niezbyt skuteczne\""
	arr["GERMAN",54]="alte Angriffe \"veraltet/nicht sehr effektiv\""
	arr["TURKISH",54]="eski \"obsolete/non çok etkili\" saldırılar"

	arr["ENGLISH",55]="2.  Put interface in monitor mode"
	arr["SPANISH",55]="2.  Poner la interfaz en modo monitor"
	arr["FRENCH",55]="2.  Passer l'interface en mode moniteur"
	arr["CATALAN",55]="2.  Configurar la interfície en mode monitor"
	arr["PORTUGUESE",55]="2.  Colocar a interface em modo monitor"
	arr["RUSSIAN",55]="2.  Перевести интерфейс в режим монитора"
	arr["GREEK",55]="2.  Βάλτε τη διεπαφή σε κατάσταση παρακολούθησης"
	arr["ITALIAN",55]="2.  Mettere l'interfaccia in modalità monitor"
	arr["POLISH",55]="2.  Uruchom interfejs w trybie monitorowania"
	arr["GERMAN",55]="2.  Setzen Sie die Interface im monitor-Modus ein"
	arr["TURKISH",55]="2.  Arayüzün izleme modunu aç"

	arr["ENGLISH",56]="3.  Put interface in managed mode"
	arr["SPANISH",56]="3.  Poner la interfaz en modo managed"
	arr["FRENCH",56]="3.  Passer l'interface en mode managed"
	arr["CATALAN",56]="3.  Configurar la interfície en mode managed"
	arr["PORTUGUESE",56]="3.  Colocar a interface em modo managed"
	arr["RUSSIAN",56]="3.  Перевести интерфейс в управляемый режим"
	arr["GREEK",56]="3.  Βάλτε τη διεπαφή σε ετερόκλητη κατάσταση"
	arr["ITALIAN",56]="3.  Mettere l'interfaccia in modalità managed"
	arr["POLISH",56]="3.  Uruchom interfejs w trybie zarządzanym"
	arr["GERMAN",56]="3.  Setzen Sie die Interface im managed-Modus ein"
	arr["TURKISH",56]="3.  Arayüzün yönetici modunu aç"

	arr["ENGLISH",57]="Language changed to Polish"
	arr["SPANISH",57]="Idioma cambiado a Polaco"
	arr["FRENCH",57]="Le script sera maintenant en Polonais"
	arr["CATALAN",57]="Idioma canviat a Polonès"
	arr["PORTUGUESE",57]="Idioma alterado para Polonês"
	arr["RUSSIAN",57]="Язык изменён на польский"
	arr["GREEK",57]="Η γλώσσα άλλαξε στα Πολωνικά"
	arr["ITALIAN",57]="Lingua cambiata a Polacco"
	arr["POLISH",57]="Zmieniono język na Polski"
	arr["GERMAN",57]="Die Sprache wurde zu Polnisch geändert"
	arr["TURKISH",57]="Dil Polish olarak değiştirildi"

	arr["ENGLISH",58]="9.  Polish"
	arr["SPANISH",58]="9.  Polaco"
	arr["FRENCH",58]="9.  Polonais"
	arr["CATALAN",58]="9.  Polonès"
	arr["PORTUGUESE",58]="9.  Polonês"
	arr["RUSSIAN",58]="9.  Польский"
	arr["GREEK",58]="9.  Πολωνικά"
	arr["ITALIAN",58]="9.  Polacco"
	arr["POLISH",58]="9.  Polski"
	arr["GERMAN",58]="9.  Polnisch"
	arr["TURKISH",58]="9.  Polish"

	arr["ENGLISH",59]="0.  Return to main menu"
	arr["SPANISH",59]="0.  Volver al menú principal"
	arr["FRENCH",59]="0.  Retourner au menu principal"
	arr["CATALAN",59]="0.  Tornar al menú principal"
	arr["PORTUGUESE",59]="0.  Voltar ao menu principal"
	arr["RUSSIAN",59]="0.  Вернуться в главное меню"
	arr["GREEK",59]="0.  Επιστροφή στο αρχικό μενού"
	arr["ITALIAN",59]="0.  Torna al menu principale"
	arr["POLISH",59]="0.  Wróć do menu głównego"
	arr["GERMAN",59]="0.  Zum Hauptmenü zurück"
	arr["TURKISH",59]="0.  Ana menüye dön"

	arr["ENGLISH",60]="10. About & Credits"
	arr["SPANISH",60]="10. Acerca de & Créditos"
	arr["FRENCH",60]="10. A propos de & Crédits"
	arr["CATALAN",60]="10. Sobre & Crédits"
	arr["PORTUGUESE",60]="10. Sobre & Créditos"
	arr["RUSSIAN",60]="10. О программе и Благодарности"
	arr["GREEK",60]="10. Σχετικά με & Εύσημα"
	arr["ITALIAN",60]="10. Informazioni & Credits"
	arr["POLISH",60]="10. O programie & Podziękowania"
	arr["GERMAN",60]="10. About & Credits"
	arr["TURKISH",60]="10. Hakkında & Güven"

	arr["ENGLISH",61]="0.  Exit script"
	arr["SPANISH",61]="0.  Salir del script"
	arr["FRENCH",61]="0.  Sortir du script"
	arr["CATALAN",61]="0.  Sortir del script"
	arr["PORTUGUESE",61]="0.  Sair do script"
	arr["RUSSIAN",61]="0.  Выйти из скрипта"
	arr["GREEK",61]="0.  Έξοδος script"
	arr["ITALIAN",61]="0.  Uscire dallo script"
	arr["POLISH",61]="0.  Zamknij skrypt"
	arr["GERMAN",61]="0.  Skript beenden"
	arr["TURKISH",61]="0.  Yazılımdan çıkış yap"

	arr["ENGLISH",62]="8.  Beacon flood attack"
	arr["SPANISH",62]="8.  Ataque Beacon flood"
	arr["FRENCH",62]="8.  Attaque Beacon flood"
	arr["CATALAN",62]="8.  Atac Beacon flood"
	arr["PORTUGUESE",62]="8.  Ataque Beacon flood"
	arr["RUSSIAN",62]="8.  Атака флудом маяков (beacon)"
	arr["GREEK",62]="8.  Επίθεση πλημμύρας φάρου (beacon)"
	arr["ITALIAN",62]="8.  Attacco Beacon flood"
	arr["POLISH",62]="8.  Atak Beacon flood"
	arr["GERMAN",62]="8.  Beacon flood Angriff"
	arr["TURKISH",62]="8.  Beacon flood saldırısı"

	arr["ENGLISH",63]="9.  Auth DoS attack"
	arr["SPANISH",63]="9.  Ataque Auth DoS"
	arr["FRENCH",63]="9.  Attaque Auth DoS"
	arr["CATALAN",63]="9.  Atac Auth Dos"
	arr["PORTUGUESE",63]="9.  Ataque Auth DoS"
	arr["RUSSIAN",63]="9.  DoS атака деаутентификации"
	arr["GREEK",63]="9.  Επίθεση Auth DoS"
	arr["ITALIAN",63]="9.  Attacco Auth DoS"
	arr["POLISH",63]="9.  Atak Auth DoS"
	arr["GERMAN",63]="9.  Auth DoS Angriff"
	arr["TURKISH",63]="9.  Auth DoS saldırısı"

	arr["ENGLISH",64]="10. Michael shutdown exploitation (TKIP) attack"
	arr["SPANISH",64]="10. Ataque Michael shutdown exploitation (TKIP)"
	arr["FRENCH",64]="10. Attaque Michael shutdown exploitation (TKIP)"
	arr["CATALAN",64]="10. Atac Michael shutdown exploitation (TKIP)"
	arr["PORTUGUESE",64]="10. Ataque Michael shutdown exploitation (TKIP)"
	arr["RUSSIAN",64]="10. Атака отключения эксплуатации от Michael (TKIP)"
	arr["GREEK",64]="10. Επίθεση Michael shutdown exploitation (TKIP)"
	arr["ITALIAN",64]="10. Attacco Michael shutdown exploitation (TKIP)"
	arr["POLISH",64]="10. Atak Michael shutdown exploitation (TKIP)"
	arr["GERMAN",64]="10. Michael Shutdown Exploitation Angriff (TKIP)"
	arr["TURKISH",64]="10. Michael shutdown exploitation (TKIP) saldırısı"

	arr["ENGLISH",65]="Exploring for targets option chosen (monitor mode needed)"
	arr["SPANISH",65]="Elegida opción de exploración para buscar objetivos (modo monitor requerido)"
	arr["FRENCH",65]="L'option de recherche des objectifs a été choisie (modo moniteur nécessaire)"
	arr["CATALAN",65]="Seleccionada opció d'exploració per buscar objectius (requerit mode monitor)"
	arr["PORTUGUESE",65]="Selecione uma opção de busca para encontar objetivos (modo monitor obrigatório)"
	arr["RUSSIAN",65]="Выбрано сканирование целей (необходим режим монитора)"
	arr["GREEK",65]="Η επιλογή για εξερεύνηση στόχων έχει επιλεχθεί (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",65]="Scelta la opzione di scansione per cercare obiettivi (modalità monitor richiesta)"
	arr["POLISH",65]="Opcja skanowania w celu wyszukania celów wybrana (wymaga trybu monitorowania)"
	arr["GERMAN",65]="Zielsuche ausgewählt (monitor-Modus erforderlich)"
	arr["TURKISH",65]="Hedef tarama modu seçildi (izleme modu gereklidir)"

	arr["ENGLISH",66]="Selected interface ${current_iface_on_messages} is in monitor mode. Exploration can be performed"
	arr["SPANISH",66]="La interfaz seleccionada ${current_iface_on_messages} está en modo monitor. La exploración se puede realizar"
	arr["FRENCH",66]="L'interface choisie ${current_iface_on_messages} est en mode moniteur. L'exploration des réseaux environnants peut s'effectuer"
	arr["CATALAN",66]="La interfície seleccionada ${current_iface_on_messages} està en mode monitor. L'exploració es pot realitzar"
	arr["PORTUGUESE",66]="A interface selecionada ${current_iface_on_messages} está no modo monitor. A verificação pode ser realizada"
	arr["RUSSIAN",66]="Выбранный интерфейс ${current_iface_on_messages} в режиме монитора. Сканирование может быть выполнено"
	arr["GREEK",66]="Η επιλεγμένη διεπαφή ${current_iface_on_messages} είναι σε κατάσταση παρακολούθησης. Μπορεί να γίνει εξερεύνηση"
	arr["ITALIAN",66]="L'interfaccia selezionata ${current_iface_on_messages} è in modalità monitor. La scansione può essere eseguita"
	arr["POLISH",66]="Wybrany interfejs ${current_iface_on_messages} jest w trybie monitorowania. Można wykonać skanowanie"
	arr["GERMAN",66]="Die ausgewählte Interface ${current_iface_on_messages} befindet sich im monitor-Modus. Der Scan kann durchgeführt werden"
	arr["TURKISH",66]="Seçilen arayüz ${current_iface_on_messages} izleme modunda. Tarama gerçekleştirilebilir"

	arr["ENGLISH",67]="WEP filter enabled in scan. When started, press [Ctrl+C] to stop..."
	arr["SPANISH",67]="Filtro WEP activado en escaneo. Una vez empezado, pulse [Ctrl+C] para pararlo..."
	arr["FRENCH",67]="Le filtre WEP est activé dans le scan. Une fois l'opération lancée, veuillez presser [Ctrl+C] pour l'arrêter..."
	arr["CATALAN",67]="Filtre WEP activat en escaneig. Una vegada iniciat, polsi [Ctrl+C] per detenir-ho..."
	arr["PORTUGUESE",67]="Filtro WEP ativo na busca de redes wifi. Uma vez iniciado, pressione [Ctrl+C] para pará-lo..."
	arr["RUSSIAN",67]="Для сканирования активирован фильтр WEP. После запуска, нажмите [Ctrl+C] для остановки..."
	arr["GREEK",67]="Το φίλτρο WEP ενεργοποιήθηκε κατά τη σάρωση. Όταν αρχίσει, μπορείτε να το σταματήσετε πατώντας [Ctrl+C]..."
	arr["ITALIAN",67]="Filtro WEP attivato durante la scansione. Una volta avviato, premere [Ctrl+C] per fermarlo..."
	arr["POLISH",67]="Filtr WEP aktywowany podczas skanowania. Naciśnij [Ctrl+C] w trakcie trwania, aby zatrzymać..."
	arr["GERMAN",67]="WEP-Filter beim Scannen aktiviert. Nach den Start, drücken Sie [Ctrl+C], um es zu stoppen..."
	arr["TURKISH",67]="WEP filtesi taraması etkin. Başladıktan sonra, durdurmak için [Ctrl+C] tuşlayınız..."

	arr["ENGLISH",68]="No networks found"
	arr["SPANISH",68]="No se encontraron redes"
	arr["FRENCH",68]="Aucun réseau détecté"
	arr["CATALAN",68]="No s'han trobat xarxes"
	arr["PORTUGUESE",68]="Nenhuma rede encontrada"
	arr["RUSSIAN",68]="Сети не найдены"
	arr["GREEK",68]="Δεν βρέθηκαν δίκτυα"
	arr["ITALIAN",68]="Nessuna rete trovata"
	arr["POLISH",68]="Nie znaleziono sieci"
	arr["GERMAN",68]="Keine Netzwerke wurden gefunden"
	arr["TURKISH",68]="Herhangi bir ağ bulunamadı"

	arr["ENGLISH",69]="  N.         BSSID      CHANNEL  PWR   ENC    ESSID"
	arr["SPANISH",69]="  N.         BSSID        CANAL  PWR   ENC    ESSID"
	arr["FRENCH",69]="  N.         BSSID        CANAL  PWR   ENC    ESSID"
	arr["CATALAN",69]="  N.         BSSID        CANAL  PWR   ENC    ESSID"
	arr["PORTUGUESE",69]="  N.         BSSID        CANAL  PWR   ENC    ESSID"
	arr["RUSSIAN",69]="  N.         BSSID      CHANNEL  PWR   ENC    ESSID"
	arr["GREEK",69]="  N.         BSSID      CHANNEL  PWR   ENC    ESSID"
	arr["ITALIAN",69]="  N.         BSSID       CANALE  PWR   ENC    ESSID"
	arr["POLISH",69]="  N.         BSSID        KANAŁ  PWR   ENC    ESSID"
	arr["GERMAN",69]="  N.         BSSID        KANAL  PWR   ENC    ESSID"
	arr["TURKISH",69]="  N.         BSSID      KANAL  PWR   ENC    ESSID"

	arr["ENGLISH",70]="Only one target detected. Autoselected"
	arr["SPANISH",70]="Sólo un objetivo detectado. Se ha seleccionado automáticamente"
	arr["FRENCH",70]="Un seul réseau a été détecté. Il a été automatiquement sélectionné"
	arr["CATALAN",70]="Només un objectiu detectat. Seleccionat automàticament"
	arr["PORTUGUESE",70]="Apenas uma rede encontrada. Ela foi selecionada automaticamente"
	arr["RUSSIAN",70]="Обнаружена только одна цель. Выбрана автоматически"
	arr["GREEK",70]="Εντοπίστηκε μόνο ένας στόχος. Επιλέχθηκε αυτόματα"
	arr["ITALIAN",70]="Solo un obiettivo rilevato. É stato selezionato automaticamente"
	arr["POLISH",70]="Wykryto tylko jeden cel. Wybrany automatycznie"
	arr["GERMAN",70]="Nur ein Ziel erkannt. Es wurde automatisch ausgewählt"
	arr["TURKISH",70]="Sadece bir hedef tespit edildi. Otomatik olarak seçildi"

	arr["ENGLISH",71]="(*) Network with clients"
	arr["SPANISH",71]="(*) Red con clientes"
	arr["FRENCH",71]="(*) Réseau avec clients"
	arr["CATALAN",71]="(*) Xarxa amb clients"
	arr["PORTUGUESE",71]="(*) Rede com clientes"
	arr["RUSSIAN",71]="(*) Сеть с клиентами"
	arr["GREEK",71]="(*) Δίκτυο με χρήστες"
	arr["ITALIAN",71]="(*) Rete con clienti"
	arr["POLISH",71]="(*) Sieć z podłączonymi klientami"
	arr["GERMAN",71]="(*) Netzwerk mit Kunden"
	arr["TURKISH",71]="(*) Ağ ile istemciler"

	arr["ENGLISH",72]="Invalid target network was chosen"
	arr["SPANISH",72]="Red objetivo elegida no válida"
	arr["FRENCH",72]="Le choix du réseau cible est invalide"
	arr["CATALAN",72]="Xarxa de destí seleccionada no vàlida"
	arr["PORTUGUESE",72]="A rede escolhida é inválida"
	arr["RUSSIAN",72]="Была выбрана неподходящая целевая сеть"
	arr["GREEK",72]="Επιλέχθηκε άκυρο δίκτυο"
	arr["ITALIAN",72]="La rete scelta come obiettivo non è valida"
	arr["POLISH",72]="Wybrano nieprawidłową sieć docelową"
	arr["GERMAN",72]="Zielnetzwerk nicht gültig"
	arr["TURKISH",72]="Gerçersiz hedef ağ seçildi"

	arr["ENGLISH",73]="airgeddon script v${airgeddon_version} developed by:"
	arr["SPANISH",73]="airgeddon script v${airgeddon_version} programado por:"
	arr["FRENCH",73]="Le script airgeddon v${airgeddon_version} a été programmé par:"
	arr["CATALAN",73]="airgeddon script v${airgeddon_version} desenvolupat per:"
	arr["PORTUGUESE",73]="Script airgeddon v${airgeddon_version} desenvolvido por:"
	arr["RUSSIAN",73]="скрипт airgeddon v${airgeddon_version} создал:"
	arr["GREEK",73]="Το airgeddon script v${airgeddon_version} προγραμματίστηκε από:"
	arr["ITALIAN",73]="airgeddon script v${airgeddon_version} sviluppato da:"
	arr["POLISH",73]="Skrypt airgeddon v${airgeddon_version} napisany przez:"
	arr["GERMAN",73]="airgeddon Skript v${airgeddon_version} entwickelt von:"
	arr["TURKISH",73]="airgeddon yazılımı v${airgeddon_version} geliştiricisi:"

	arr["ENGLISH",74]="This script is under GPLv3 (or later) License"
	arr["SPANISH",74]="Este script está bajo Licencia GPLv3 (o posterior)"
	arr["FRENCH",74]="Script publié sous Licence GPLv3 (ou version supèrieure)"
	arr["CATALAN",74]="Aquest script està publicat sota llicència GPLv3 (o versió superior)"
	arr["PORTUGUESE",74]="Este script está sob licença GPLv3 (ou posterior)"
	arr["RUSSIAN",74]="Этот скрипт под лицензией GPLv3 (или более поздней)"
	arr["GREEK",74]="Αυτό το script είναι υπό την άδεια GPLv3 (ή νεότερη)"
	arr["ITALIAN",74]="Questo script è sotto GPLv3 (o versione successiva)"
	arr["POLISH",74]="Ten skrypt objęty jest licencją GPLv3 (lub nowszą)"
	arr["GERMAN",74]="Dieses Skript ist unter GPLv3 (oder höher) lizenziert"
	arr["TURKISH",74]="Bu yazılım GPLv3 (ya da daha üstü) lisansı altındadır "

	arr["ENGLISH",75]="Thanks to the \"Spanish pentesting crew\", to the \"Wifislax Staff\", to the forums people who help me, my collaborators, translators and specially to kcdtv and xtonousou for beta testing and support received"
	arr["SPANISH",75]="Gracias al \"Spanish pentesting crew\", al \"Wifislax Staff\", a la gente de los foros que me ayuda, a mis colaboradores, traductores y en especial a kcdtv y xtonousou por el beta testing y el apoyo recibido"
	arr["FRENCH",75]="Merci au \"Spanish pentesting crew\" , au \"Wifislax Staff\", aux gens des forums qui m'ont aidés, à mes collaborateurs, aux traducteurs et tout spécialement à kcdtv et xtonousou pour les tests en phase bêta et son soutien"
	arr["CATALAN",75]="Agraïments al \"Spanish pentesting crew\", al \"Wifislax Staff\", a la gent dels fòrums que m'ajuda, als meus col·laboradors, traductors i especialment al kcdtv i xtonousou per les proves beta i el suport rebut"
	arr["PORTUGUESE",75]="Agradecimentos a \"Spanish pentesting crew\", \"Wifislax Staff\", as pessoas dos fóruns por me ajudar, os colaboradores, tradutores e especialmente para kcdtv e xtonousou por testes beta e também a todo apoio recebido"
	arr["RUSSIAN",75]="Спасибо \"Spanish pentesting crew\", за \"Wifislax Staff\", людям с форумов, которые мне помогают, тем, кто принимает участие в проекте, переводчикам и особенно kcdtv и xtonousou за бета тестирование и полученную поддержку"
	arr["GREEK",75]="Τις ευχαριστίες μου στην \"Ισπανική ομάδα pentesting\", στο \"Wifislax Staff\", στα άτομα από το forum που με βοηθάνε, στους συνεργάτες μου, στους μεταφραστές και ειδικά στον kcdtv και στον xtonousou για το beta testing και την υποστήριξη που λάβαμε"
	arr["ITALIAN",75]="Grazie alla \"Spanish pentesting crew\", a \"Wifislax Staff\", alla gente dei forum per aiutarmi, al mio staff, ai traduttori e soprattutto a kcdtv e xtonousou per il beta testing e il supporto ricevuto"
	arr["POLISH",75]="Podziękowania dla \"Spanish pentesting crew\", \"Wifislax Staff\", ludziom z forum którzy mi pomagają, moim współpracownikom, tłumaczom, a zwłaszcza kcdtv i xtonousou za testy beta i otrzymane wsparcie"
	arr["GERMAN",75]="Danke an die \"Spanish Pentesting Crew\", an den \"Wifislax Staff\", an die Leute in den Foren, die mir helfen, an meine Mitarbeiter, Übersetzer und besonders an kcdtv und xtonousou für den Beta-Test und die erhaltene Unterstützung"
	arr["TURKISH",75]="Teşekkürler \"Spanish pentesting crew\", to the \"Wifislax Staff\", to the forums people who help me, my collaborators, translators and specially to kcdtv and xtonousou for beta testing and support received"

	arr["ENGLISH",76]="Invalid menu option was chosen"
	arr["SPANISH",76]="Opción del menú no válida"
	arr["FRENCH",76]="Option erronée"
	arr["CATALAN",76]="Opció del menú no vàlida"
	arr["PORTUGUESE",76]="Opção inválida"
	arr["RUSSIAN",76]="Выбрана недействительная опция"
	arr["GREEK",76]="Επιλέχθηκε άκυρη επιλογή μενού"
	arr["ITALIAN",76]="Opzione del menú non valida"
	arr["POLISH",76]="Niewłaściwa opcja"
	arr["GERMAN",76]="Ungültige Menüoption"
	arr["TURKISH",76]="Geçersiz bir menü seçildi"

	arr["ENGLISH",77]="Invalid interface was chosen"
	arr["SPANISH",77]="Interfaz no válida"
	arr["FRENCH",77]="L'interface choisie n'existe pas"
	arr["CATALAN",77]="Interfície no vàlida"
	arr["PORTUGUESE",77]="Interface inválida"
	arr["RUSSIAN",77]="Был выбран недействительный интерфейс"
	arr["GREEK",77]="Επιλέχθηκε άκυρη διεπαφή"
	arr["ITALIAN",77]="Interfaccia non valida"
	arr["POLISH",77]="Nieprawidłowy interfejs"
	arr["GERMAN",77]="Ungültige Interface"
	arr["TURKISH",77]="Geçersiz bir arayüz seçildi"

	arr["ENGLISH",78]="1.  Change language"
	arr["SPANISH",78]="1.  Cambiar idioma"
	arr["FRENCH",78]="1.  Changer de langue"
	arr["CATALAN",78]="1.  Canviar l'idioma"
	arr["PORTUGUESE",78]="1.  Alterar idioma"
	arr["RUSSIAN",78]="1.  Сменить язык"
	arr["GREEK",78]="1.  Αλλαγή γλώσσας"
	arr["ITALIAN",78]="1.  Cambiare la lingua"
	arr["POLISH",78]="1.  Zmień język"
	arr["GERMAN",78]="1.  Sprache ändern"
	arr["TURKISH",78]="1.  Dil değiştir"

	arr["ENGLISH",79]="1.  English"
	arr["SPANISH",79]="1.  Inglés"
	arr["FRENCH",79]="1.  Anglais"
	arr["CATALAN",79]="1.  Anglés"
	arr["PORTUGUESE",79]="1.  Inglês"
	arr["RUSSIAN",79]="1.  Английский"
	arr["GREEK",79]="1.  Αγγλικά"
	arr["ITALIAN",79]="1.  Inglese"
	arr["POLISH",79]="1.  Angielski"
	arr["GERMAN",79]="1.  Englisch"
	arr["TURKISH",79]="1.  İngilizce"

	arr["ENGLISH",80]="2.  Spanish"
	arr["SPANISH",80]="2.  Español"
	arr["FRENCH",80]="2.  Espagnol"
	arr["CATALAN",80]="2.  Espanyol"
	arr["PORTUGUESE",80]="2.  Espanhol"
	arr["RUSSIAN",80]="2.  Испанский"
	arr["GREEK",80]="2.  Ισπανικά"
	arr["ITALIAN",80]="2.  Spagnolo"
	arr["POLISH",80]="2.  Hiszpański"
	arr["GERMAN",80]="2.  Spanisch"
	arr["TURKISH",80]="2.  İspanyolca"

	arr["ENGLISH",81]="Select a language:"
	arr["SPANISH",81]="Selecciona un idioma:"
	arr["FRENCH",81]="Choisissez une langue:"
	arr["CATALAN",81]="Selecciona un idioma:"
	arr["PORTUGUESE",81]="Selecione um idioma:"
	arr["RUSSIAN",81]="Выберите язык:"
	arr["GREEK",81]="Επιλέξτε μία γλώσσα:"
	arr["ITALIAN",81]="Scegli una lingua:"
	arr["POLISH",81]="Wybierz język:"
	arr["GERMAN",81]="Wählen Sie eine Sprache:"
	arr["TURKISH",81]="Bir dil seçiniz:"

	arr["ENGLISH",82]="Invalid language was chosen"
	arr["SPANISH",82]="Idioma no válido"
	arr["FRENCH",82]="Langue non valide"
	arr["CATALAN",82]="Idioma no vàlid"
	arr["PORTUGUESE",82]="Idioma inválido"
	arr["RUSSIAN",82]="Был выбран неверный язык"
	arr["GREEK",82]="Επιλέχθηκε άκυρη γλώσσα"
	arr["ITALIAN",82]="Lingua non valida"
	arr["POLISH",82]="Nieprawidłowy język"
	arr["GERMAN",82]="Ungültige Sprache"
	arr["TURKISH",82]="Yanlış bir dil seçildi"

	arr["ENGLISH",83]="Language changed to English"
	arr["SPANISH",83]="Idioma cambiado a Inglés"
	arr["FRENCH",83]="Le script sera maintenant en Anglais"
	arr["CATALAN",83]="Idioma canviat a Anglés"
	arr["PORTUGUESE",83]="Idioma alterado para Inglês"
	arr["RUSSIAN",83]="Язык изменён на английский"
	arr["GREEK",83]="Η γλώσσα άλλαξε στα Αγγλικά"
	arr["ITALIAN",83]="Lingua cambiata in Inglese"
	arr["POLISH",83]="Zmieniono język na Angielski"
	arr["GERMAN",83]="Die Sprache wurde zu Englisch eingestellt"
	arr["TURKISH",83]="Dil İngilizce olarak değiştirildi"

	arr["ENGLISH",84]="Language changed to Spanish"
	arr["SPANISH",84]="Idioma cambiado a Español"
	arr["FRENCH",84]="Le script sera maintenant en Espagnol"
	arr["CATALAN",84]="Idioma canviat a Espanyol"
	arr["PORTUGUESE",84]="Idioma alterado para Espanhol"
	arr["RUSSIAN",84]="Язык изменён на испанский"
	arr["GREEK",84]="Η γλώσσα άλλαξε στα Ισπανικά"
	arr["ITALIAN",84]="Lingua cambiata in Spagnolo"
	arr["POLISH",84]="Zmieniono język na Hiszpański"
	arr["GERMAN",84]="Die Sprache wurde zu Spanisch eingestellt"
	arr["TURKISH",84]="Dil İspanyolca olarak değiştirildi"

	arr["ENGLISH",85]="Send me bugs or suggestions to ${normal_color}${mail}"
	arr["SPANISH",85]="Enviadme errores o sugerencias a ${normal_color}${mail}"
	arr["FRENCH",85]="Envoyer des erreurs ou des suggestions à ${normal_color}${mail}"
	arr["CATALAN",85]="Envieu-me errorrs o suggeriments a ${normal_color}${mail}"
	arr["PORTUGUESE",85]="Envie erros ou sugestões para ${normal_color}${mail}"
	arr["RUSSIAN",85]="Отправляйте ошибки и предложения мне на почту ${normal_color}${mail}"
	arr["GREEK",85]="Στείλτε μου αναφορές για bugs ή συστάσεις στο ${normal_color}${mail}"
	arr["ITALIAN",85]="Inviatemi errori o suggerimenti a ${normal_color}${mail}"
	arr["POLISH",85]="Wyślij mi błędy lub sugestie na ${normal_color}${mail}"
	arr["GERMAN",85]="Senden Sie mir Fehler oder Vorschläge zu ${normal_color}${mail}"
	arr["TURKISH",85]="Hataları ve önerileri bize yollayın ${normal_color}${mail}"

	arr["ENGLISH",86]="Welcome"
	arr["SPANISH",86]="Bienvenid@"
	arr["FRENCH",86]="Bienvenue"
	arr["CATALAN",86]="Benvingut"
	arr["PORTUGUESE",86]="Bem-vindo"
	arr["RUSSIAN",86]="Добро пожаловать"
	arr["GREEK",86]="Καλως ορίσατε"
	arr["ITALIAN",86]="Benvenuti"
	arr["POLISH",86]="Witaj"
	arr["GERMAN",86]="Willkommen"
	arr["TURKISH",86]="Hoşgeldiniz"

	arr["ENGLISH",87]="Change language"
	arr["SPANISH",87]="Cambiar idioma"
	arr["FRENCH",87]="Changer de langue"
	arr["CATALAN",87]="Canviar d'idioma"
	arr["PORTUGUESE",87]="Mudar idioma"
	arr["RUSSIAN",87]="Сменить язык"
	arr["GREEK",87]="Αλλάξτε γλώσσα"
	arr["ITALIAN",87]="Cambia la lingua"
	arr["POLISH",87]="Zmień język"
	arr["GERMAN",87]="Sprache ändern"
	arr["TURKISH",87]="Dili Değiştir"

	arr["ENGLISH",88]="Interface selection"
	arr["SPANISH",88]="Selección de interfaz"
	arr["FRENCH",88]="Sélection de l'interface"
	arr["CATALAN",88]="Selecció de interfície"
	arr["PORTUGUESE",88]="Seleção de interface"
	arr["RUSSIAN",88]="Выбор интерфейса"
	arr["GREEK",88]="Επιλογή διεπαφής"
	arr["ITALIAN",88]="Selezione dell'interfaccia"
	arr["POLISH",88]="Wybór interfejsu"
	arr["GERMAN",88]="Interface-Auswahl"
	arr["TURKISH",88]="Arayüz seçimi"

	arr["ENGLISH",89]="Mdk3 amok action"
	arr["SPANISH",89]="Acción mdk3 amok"
	arr["FRENCH",89]="Action mdk3 amok"
	arr["CATALAN",89]="Acció mdk3 amok"
	arr["PORTUGUESE",89]="Ação mdk3 amok"
	arr["RUSSIAN",89]="Mdk3 amok в действии"
	arr["GREEK",89]="Ενέργεια mdk3 amok"
	arr["ITALIAN",89]="Azione mdk3 amok"
	arr["POLISH",89]="Akcja mdk3 amok"
	arr["GERMAN",89]="mdk3 amok Aktion"
	arr["TURKISH",89]="Mdk3 amok etkisi"

	arr["ENGLISH",90]="Aireplay deauth action"
	arr["SPANISH",90]="Acción aireplay deauth"
	arr["FRENCH",90]="Action aireplay deauth"
	arr["CATALAN",90]="Acció aireplay deauth"
	arr["PORTUGUESE",90]="Ação deauth aireplay"
	arr["RUSSIAN",90]="Деаутентификация Aireplay в действии"
	arr["GREEK",90]="Ενέργεια aireplay deauth"
	arr["ITALIAN",90]="Azione aireplay deauth"
	arr["POLISH",90]="Akcja aireplay deauth"
	arr["GERMAN",90]="Aireplay deauth Aktion"
	arr["TURKISH",90]="Aireplay deauth etkisi"

	arr["ENGLISH",91]="WIDS / WIPS / WDS confusion action"
	arr["SPANISH",91]="Acción WIDS / WIPS / WDS confusion"
	arr["FRENCH",91]="Action WIDS / WIPS / WDS confusion"
	arr["CATALAN",91]="Acció WIDS / WIPS / WDS confusion"
	arr["PORTUGUESE",91]="Ação WIDS / WIPS / confusão WDS"
	arr["RUSSIAN",91]="Смешение WIDS / WIPS / WDS в действии"
	arr["GREEK",91]="Ενέργεια σύγχυσης WIDS / WIPS / WDS"
	arr["ITALIAN",91]="Azione WIDS / WIPS / WDS confusion"
	arr["POLISH",91]="Akcja WIDS / WIPS / WDS confusion"
	arr["GERMAN",91]="WIDS / WIPS / WDS confusion Aktion"
	arr["TURKISH",91]="WIDS / WIPS / WDS confusion etkisi"

	arr["ENGLISH",92]="Beacon flood action"
	arr["SPANISH",92]="Acción Beacon flood"
	arr["FRENCH",92]="Action Beacon flood"
	arr["CATALAN",92]="Acció Beacon flood"
	arr["PORTUGUESE",92]="Ação Beacon flood"
	arr["RUSSIAN",92]="Флуд маяками в действии"
	arr["GREEK",92]="Ενέργεια πλημμυρίσματος φάρου"
	arr["ITALIAN",92]="Azione Beacon flood"
	arr["POLISH",92]="Akcja Beacon flood"
	arr["GERMAN",92]="Beacon flood Aktion"
	arr["TURKISH",92]="Beacon flood etkisi"

	arr["ENGLISH",93]="Auth DoS action"
	arr["SPANISH",93]="Acción Auth DoS"
	arr["FRENCH",93]="Action Auth DoS"
	arr["CATALAN",93]="Acció Auth DoS"
	arr["PORTUGUESE",93]="Ação Auth DoS"
	arr["RUSSIAN",93]="DoS аутентификации в действии"
	arr["GREEK",93]="Ενέργεια Auth DoS"
	arr["ITALIAN",93]="Azione Auth DoS"
	arr["POLISH",93]="Akcja Auth DoS"
	arr["GERMAN",93]="Auth DoS Aktion"
	arr["TURKISH",93]="Auth DoS etkisi"

	arr["ENGLISH",94]="Michael Shutdown action"
	arr["SPANISH",94]="Acción Michael Shutdown"
	arr["FRENCH",94]="Action Michael Shutdown"
	arr["CATALAN",94]="Acció Michael Shutdown"
	arr["PORTUGUESE",94]="Ação Michael Shutdown"
	arr["RUSSIAN",94]="Отключение Michael в действии"
	arr["GREEK",94]="Ενέργεια Michael Shutdown"
	arr["ITALIAN",94]="Azione Michael Shutdown"
	arr["POLISH",94]="Akcja Michael Shutdown"
	arr["GERMAN",94]="Michael Shutdown Aktion"
	arr["TURKISH",94]="Michael Shutdown etkisi"

	arr["ENGLISH",95]="Mdk3 amok parameters"
	arr["SPANISH",95]="Parámetros Mdk3 amok"
	arr["FRENCH",95]="Paramètres Mdk3 amok"
	arr["CATALAN",95]="Paràmetres Mdk3 amok"
	arr["PORTUGUESE",95]="Parâmetros Mdk3 amok"
	arr["RUSSIAN",95]="Параметры Mdk3 amok"
	arr["GREEK",95]="Παράμετροι Mdk3 amok"
	arr["ITALIAN",95]="Parametri Mdk3 amok"
	arr["POLISH",95]="Parametry Mdk3 amok"
	arr["GERMAN",95]="Mdk3 amok Parameter"
	arr["TURKISH",95]="Mdk3 amok parametreleri"

	arr["ENGLISH",96]="Aireplay deauth parameters"
	arr["SPANISH",96]="Parámetros Aireplay deauth"
	arr["FRENCH",96]="Paramètres Aireplay deauth"
	arr["CATALAN",96]="Paràmetres Aireplay deauth"
	arr["PORTUGUESE",96]="Parâmetros Aireplay deauth"
	arr["RUSSIAN",96]="Параметры деаутентификации Aireplay"
	arr["GREEK",96]="Παράμετροι Aireplay deauth"
	arr["ITALIAN",96]="Parametri Aireplay deauth"
	arr["POLISH",96]="Parametry Aireplay deauth"
	arr["GERMAN",96]="Aireplay deauth Parameter"
	arr["TURKISH",96]="Aireplay deauth parametreleri"

	arr["ENGLISH",97]="WIDS / WIPS / WDS parameters"
	arr["SPANISH",97]="Parámetros WIDS / WIPS / WDS"
	arr["FRENCH",97]="Paramètres WIDS / WIPS / WDS"
	arr["CATALAN",97]="Paràmetres WIDS / WIPS / WDS"
	arr["PORTUGUESE",97]="Parâmetros WIDS / WIPS / WDS"
	arr["RUSSIAN",97]="Параметры WIDS / WIPS / WDS"
	arr["GREEK",97]="Παράμετροι WIDS / WIPS / WDS"
	arr["ITALIAN",97]="Parametri WIDS / WIPS / WDS"
	arr["POLISH",97]="Parametry WIDS / WIPS / WDS"
	arr["GERMAN",97]="WIDS / WIPS / WDS Parameter"
	arr["TURKISH",97]="WIDS / WIPS / WDS parametreleri"

	arr["ENGLISH",98]="Beacon flood parameters"
	arr["SPANISH",98]="Parámetros Beacon flood"
	arr["FRENCH",98]="Paramètres Beacon flood"
	arr["CATALAN",98]="Paràmetres Beacon flood"
	arr["PORTUGUESE",98]="Parâmetros Beacon flood"
	arr["RUSSIAN",98]="Параметры флуда маяками"
	arr["GREEK",98]="Παράμετροι πλημμυρίσματος φάρου"
	arr["ITALIAN",98]="Parametri Beacon flood"
	arr["POLISH",98]="Parametry Beacon flood"
	arr["GERMAN",98]="Beacon flood Parameter"
	arr["TURKISH",98]="Beacon flood parametreleri"

	arr["ENGLISH",99]="Auth DoS parameters"
	arr["SPANISH",99]="Parámetros Auth DoS"
	arr["FRENCH",99]="Paramètres Auth DoS"
	arr["CATALAN",99]="Paràmetres Auth DoS"
	arr["PORTUGUESE",99]="Parâmetros Auth DoS"
	arr["RUSSIAN",99]="Параметры аутентификации DoS"
	arr["GREEK",99]="Παράμετροι Auth DoS"
	arr["ITALIAN",99]="Parametri Auth DoS"
	arr["POLISH",99]="Parametry Auth DoS"
	arr["GERMAN",99]="Auth DoS Parameter"
	arr["TURKISH",99]="Auth DoS parametreleri"

	arr["ENGLISH",100]="Michael Shutdown parameters"
	arr["SPANISH",100]="Parámetros Michael Shutdown"
	arr["FRENCH",100]="Paramètres Michael Shutdown"
	arr["CATALAN",100]="Paràmetres Michael Shutdown"
	arr["PORTUGUESE",100]="Parâmetros Michael Shutdown"
	arr["RUSSIAN",100]="Параметры Michael Shutdown"
	arr["GREEK",100]="Παράμετροι Michael Shutdown"
	arr["ITALIAN",100]="Parametri Michael Shutdown"
	arr["POLISH",100]="Parametry Michael Shutdown"
	arr["GERMAN",100]="Michael Shutdown Parameter"
	arr["TURKISH",100]="Michael Shutdown parametreleri"

	arr["ENGLISH",101]="airgeddon main menu"
	arr["SPANISH",101]="Menú principal airgeddon"
	arr["FRENCH",101]="Menu principal d'airgeddon"
	arr["CATALAN",101]="Menú principal airgeddon"
	arr["PORTUGUESE",101]="Menu principal airgeddon"
	arr["RUSSIAN",101]="Главное меню airgeddon"
	arr["GREEK",101]="Αρχικό μενού airgeddon"
	arr["ITALIAN",101]="Menú principale airgeddon"
	arr["POLISH",101]="Menu główne airgeddon"
	arr["GERMAN",101]="airgeddon-Hauptmenü"
	arr["TURKISH",101]="airgeddon ana menü"

	arr["ENGLISH",102]="DoS attacks menu"
	arr["SPANISH",102]="Menú ataques DoS"
	arr["FRENCH",102]="Menu des attaques DoS"
	arr["CATALAN",102]="Menú d'atacs DoS"
	arr["PORTUGUESE",102]="Menu de ataques DoS"
	arr["RUSSIAN",102]="Меню DoS атак"
	arr["GREEK",102]="Μενού επιθέσεων DoS"
	arr["ITALIAN",102]="Menú attacchi DoS"
	arr["POLISH",102]="Menu ataków DoS"
	arr["GERMAN",102]="DoS-Angriffsmenü"
	arr["TURKISH",102]="DoS saldırı menüsü"

	arr["ENGLISH",103]="Exploring for targets"
	arr["SPANISH",103]="Explorar para buscar objetivos"
	arr["FRENCH",103]="Détection pour trouver des cibles"
	arr["CATALAN",103]="Explorar per buscar objectius"
	arr["PORTUGUESE",103]="Busca para encontrar objetivos"
	arr["RUSSIAN",103]="Сканирование целей"
	arr["GREEK",103]="Εξερεύνηση στόχων"
	arr["ITALIAN",103]="Scansionare per cercare obiettivi"
	arr["POLISH",103]="Skanowanie w poszukiwaniu celów"
	arr["GERMAN",103]="Scans, um Ziele zu finden"
	arr["TURKISH",103]="Hedefler taranıyor"

	arr["ENGLISH",104]="Select target"
	arr["SPANISH",104]="Seleccionar objetivo"
	arr["FRENCH",104]="Selection de l'objectif"
	arr["CATALAN",104]="Seleccionar objectiu"
	arr["PORTUGUESE",104]="Escolha um objetivo"
	arr["RUSSIAN",104]="Выбор цели"
	arr["GREEK",104]="Επιλέξτε στόχο"
	arr["ITALIAN",104]="Selezionare obiettivo"
	arr["POLISH",104]="Wybierz cel"
	arr["GERMAN",104]="Wählen Sie das Ziel aus"
	arr["TURKISH",104]="Hedef seçiniz"

	arr["ENGLISH",105]="About & Credits"
	arr["SPANISH",105]="Acerca de & Créditos"
	arr["FRENCH",105]="A propos de & Crédits"
	arr["CATALAN",105]="Sobre de & Crédits"
	arr["PORTUGUESE",105]="Sobre & Créditos"
	arr["RUSSIAN",105]="О программе и Благодарности"
	arr["GREEK",105]="Σχετικά με & Εύσυμα"
	arr["ITALIAN",105]="Informazioni & Crediti"
	arr["POLISH",105]="Informacje & Podziękowania"
	arr["GERMAN",105]="About & Credits"
	arr["TURKISH",105]="Hakkımızda & Güven"

	arr["ENGLISH",106]="Exiting"
	arr["SPANISH",106]="Saliendo"
	arr["FRENCH",106]="Sortie du script"
	arr["CATALAN",106]="Sortint"
	arr["PORTUGUESE",106]="Saindo"
	arr["RUSSIAN",106]="Выход"
	arr["GREEK",106]="Γίνεται έξοδος"
	arr["ITALIAN",106]="Uscendo"
	arr["POLISH",106]="Wychodzenie"
	arr["GERMAN",106]="Verlassen"
	arr["TURKISH",106]="Çıkış yapılıyor"

	arr["ENGLISH",107]="Join the project at ${normal_color}${urlgithub}"
	arr["SPANISH",107]="Únete al proyecto en ${normal_color}${urlgithub}"
	arr["FRENCH",107]="Rejoignez le projet: ${normal_color}${urlgithub}"
	arr["CATALAN",107]="Uneix-te al projecte a ${normal_color}${urlgithub}"
	arr["PORTUGUESE",107]="Junte-se ao projeto em ${normal_color}${urlgithub}"
	arr["RUSSIAN",107]="Присоединитесь к проекту на ${normal_color}${urlgithub}"
	arr["GREEK",107]="Συμμετέχετε στο project ${normal_color}${urlgithub}"
	arr["ITALIAN",107]="Unisciti al progetto in ${normal_color}${urlgithub}"
	arr["POLISH",107]="Dołącz do projektu w ${normal_color}${urlgithub}"
	arr["GERMAN",107]="Treten Sie das Projekt in ${normal_color}${urlgithub} ${pink_color}bei"
	arr["TURKISH",107]="Projeye buradan katılın ${normal_color}${urlgithub}"

	arr["ENGLISH",108]="Let's check if you have installed what script needs"
	arr["SPANISH",108]="Vamos a chequear si tienes instalado lo que el script requiere"
	arr["FRENCH",108]="Nous allons vérifier si les dépendances sont bien installées"
	arr["CATALAN",108]="Anem a verificar si tens instal·lat el que l'script requereix"
	arr["PORTUGUESE",108]="Vamos verificar se você tem instalado tudo que o script exige"
	arr["RUSSIAN",108]="Давайте проверим, всё ли у вас установлено, что нужно скрипту"
	arr["GREEK",108]="Ας ελέγξουμε αν έχετε εγκαταστήσει ό,τι χρειάζεται το script"
	arr["ITALIAN",108]="Andiamo a verificare se è stato installato quello che richiede lo script"
	arr["POLISH",108]="Sprawdźmy czy jest zainstalowane to, czego wymaga skrypt"
	arr["GERMAN",108]="Lassen Sie uns überprüfen, ob Sie die vom Skript benötigte Paketen installiert sind"
	arr["TURKISH",108]="Hadi yazılımın ihtiyacı olan diğer yazılımları kontrol edelim"

	arr["ENGLISH",109]="Essential tools: checking..."
	arr["SPANISH",109]="Herramientas esenciales: comprobando..."
	arr["FRENCH",109]="Vérification de la présence des outils nécessaires..."
	arr["CATALAN",109]="Eines essencials: comprovant..."
	arr["PORTUGUESE",109]="Verificando se as ferramentas necessárias estão presentes..."
	arr["RUSSIAN",109]="Основные инструменты: проверка..."
	arr["GREEK",109]="Απαραίτητα εργαλεία: γίνεται έλεγχος..."
	arr["ITALIAN",109]="Strumenti essenziali: controllando..."
	arr["POLISH",109]="Podstawowe narzędzia: sprawdzanie..."
	arr["GERMAN",109]="Wesentliche Werkzeuge: Überprüfung..."
	arr["TURKISH",109]="Temel araçlar: kontrol ediliyor..."

	arr["ENGLISH",110]="Your distro has all necessary essential tools. Script can continue..."
	arr["SPANISH",110]="Tu distro tiene todas las herramientas esenciales necesarias. El script puede continuar..."
	arr["FRENCH",110]="Les outils essentiels nécessaires au bon fonctionnement du programme sont tous présents dans votre système. Le script peut continuer..."
	arr["CATALAN",110]="La teva distro té totes les eines essencials necessàries. El script pot continuar..."
	arr["PORTUGUESE",110]="Sua distro tem as ferramentas essenciais. O script pode continuar..."
	arr["RUSSIAN",110]="Ваша система имеет все необходимые основные инструменты. Скрипт может продолжать..."
	arr["GREEK",110]="Η διανομή σας έχει όλα τα απαραίτητα εργαλεία. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",110]="La tua distro ha tutti gli strumenti essenziali necessari. Lo script può continuare..."
	arr["POLISH",110]="Twój distro posiada wszystkie niezbędne niezbędne narzędzia. Skrypt może kontynuować..."
	arr["GERMAN",110]="Ihre Distribution verfügt über alle notwendigen Werkzeuge. Das Skript kann fortfahren..."
	arr["TURKISH",110]="Senin dağıtımın tüm gerekli temel araçları barındırıyor. Yazılım devam edebilir..."

	arr["ENGLISH",111]="You need to install some essential tools before running this script"
	arr["SPANISH",111]="Necesitas instalar algunas herramientas esenciales antes de lanzar este script"
	arr["FRENCH",111]="Vous devez installer quelques programmes avant de pouvoir lancer ce script"
	arr["CATALAN",111]="Necessites instal·lar algunes eines essencials abans d'executar aquest script"
	arr["PORTUGUESE",111]="Você precisa instalar algumas ferramentas essenciais antes de executar este script"
	arr["RUSSIAN",111]="Перед работой в этом скрипте, вам нужно установить некоторые основные инструменты"
	arr["GREEK",111]="Χρειάζεται να εγκαταστήσετε κάποια απαραίτητα εργαλεία πριν τρέξετε το script"
	arr["ITALIAN",111]="È necessario installare alcuni strumenti essenziali prima di lanciare questo script"
	arr["POLISH",111]="Przed uruchomieniem tego skryptu musisz zainstalować kilka niezbędnych narzędzi"
	arr["GERMAN",111]="Sie müssen einige wichtige Tools installieren, bevor Sie dieses Skript starten"
	arr["TURKISH",111]="Bu yazılımı çalıştırmadan önce bazı temel araçları yüklemeniz gerekmektedir"

	arr["ENGLISH",112]="Language changed to French"
	arr["SPANISH",112]="Idioma cambiado a Francés"
	arr["FRENCH",112]="Le script sera maintenant en Français"
	arr["CATALAN",112]="Llenguatge canviat a Francès"
	arr["PORTUGUESE",112]="Idioma alterado para Francês"
	arr["RUSSIAN",112]="Язык изменён на французский"
	arr["GREEK",112]="Η γλώσσα άλλαξε στα Γαλλικά"
	arr["ITALIAN",112]="Lingua cambiata in Francese"
	arr["POLISH",112]="Zmieniono język na Francuski"
	arr["GERMAN",112]="Sprache wurde auf Französisch geändert"
	arr["TURKISH",112]="Dil Fransızca olarak değiştirildi"

	arr["ENGLISH",113]="3.  French"
	arr["SPANISH",113]="3.  Francés"
	arr["FRENCH",113]="3.  Français"
	arr["CATALAN",113]="3.  Francès"
	arr["PORTUGUESE",113]="3.  Francês"
	arr["RUSSIAN",113]="3.  Французский"
	arr["GREEK",113]="3.  Γαλλικά"
	arr["ITALIAN",113]="3.  Francese"
	arr["POLISH",113]="3.  Francuski"
	arr["GERMAN",113]="3.  Französisch"
	arr["TURKISH",113]="3.  Fransızca"

	arr["ENGLISH",114]="Use it only on your own networks!!"
	arr["SPANISH",114]="Utilízalo solo en tus propias redes!!"
	arr["FRENCH",114]="Utilisez-le seulement dans vos propres réseaux!!"
	arr["CATALAN",114]="Utilitza'l només a les teves pròpies xarxes!!"
	arr["PORTUGUESE",114]="Use-o apenas em suas próprias redes!!"
	arr["RUSSIAN",114]="Используйте только на ваших собственных сетях!!"
	arr["GREEK",114]="Χρησιμοποιήστε το μόνο σε δικά σας δίκτυα!!"
	arr["ITALIAN",114]="Usalo solo nelle tue reti!!"
	arr["POLISH",114]="Używaj tylko we własnych sieciach!!"
	arr["GERMAN",114]="Verwenden Sie es nur in Ihren eigenen Netzwerken!!"
	arr["TURKISH",114]="Sadece kendi ağlarında kullan!!"

	arr["ENGLISH",115]="Press [Enter] key to continue..."
	arr["SPANISH",115]="Pulsa la tecla [Enter] para continuar..."
	arr["FRENCH",115]="Pressez [Enter] pour continuer..."
	arr["CATALAN",115]="Prem la tecla [Enter] per continuar..."
	arr["PORTUGUESE",115]="Pressione a tecla [Enter] para continuar..."
	arr["RUSSIAN",115]="Нажмите клавишу [Enter] для продолжения..."
	arr["GREEK",115]="Πατήστε το κουμπί [Enter] για να συνεχίσετε..."
	arr["ITALIAN",115]="Premere il tasto [Enter] per continuare..."
	arr["POLISH",115]="Naciśnij klawisz [Enter], aby kontynuować..."
	arr["GERMAN",115]="Drücken Sie die [Enter]-Taste, um fortzufahren..."
	arr["TURKISH",115]="Devam etmek için [Enter] tuşlayınız..."

	arr["ENGLISH",116]="4.  Catalan"
	arr["SPANISH",116]="4.  Catalán"
	arr["FRENCH",116]="4.  Catalan"
	arr["CATALAN",116]="4.  Català"
	arr["PORTUGUESE",116]="4.  Catalão"
	arr["RUSSIAN",116]="4.  Каталонский"
	arr["GREEK",116]="4.  Καταλανικά"
	arr["ITALIAN",116]="4.  Catalano"
	arr["POLISH",116]="4.  Kataloński"
	arr["GERMAN",116]="4.  Katalanisch"
	arr["TURKISH",116]="4.  Katalan"

	arr["ENGLISH",117]="Language changed to Catalan"
	arr["SPANISH",117]="Idioma cambiado a Catalán"
	arr["FRENCH",117]="Le script sera maintenant en Catalan"
	arr["CATALAN",117]="Idioma canviat a Català"
	arr["PORTUGUESE",117]="Idioma alterado para Catalão"
	arr["RUSSIAN",117]="Язык изменён на каталонский"
	arr["GREEK",117]="Η γλώσσα άλλαξε στα Καταλανικά"
	arr["ITALIAN",117]="Lingua cambiata in Catalano"
	arr["POLISH",117]="Zmieniono język na Kataloński"
	arr["GERMAN",117]="Die Sprache wurde auf Katalanisch geändert"
	arr["TURKISH",117]="Dil Katalan olarak değiştirildi"

	arr["ENGLISH",118]="4.  DoS attacks menu"
	arr["SPANISH",118]="4.  Menú de ataques DoS"
	arr["FRENCH",118]="4.  Menu des attaques DoS"
	arr["CATALAN",118]="4.  Menú d'atacs DoS"
	arr["PORTUGUESE",118]="4.  Menu de ataques DoS"
	arr["RUSSIAN",118]="4.  Меню DoS атак"
	arr["GREEK",118]="4.  Μενού επιθέσεων DoS"
	arr["ITALIAN",118]="4.  Menù attacchi DoS"
	arr["POLISH",118]="4.  Menu ataków DoS"
	arr["GERMAN",118]="4.  DoS-Angriffsmenü"
	arr["TURKISH",118]="4.  DoS attacks menüsü"

	arr["ENGLISH",119]="5.  Handshake tools menu"
	arr["SPANISH",119]="5.  Menú de herramientas Handshake"
	arr["FRENCH",119]="5.  Menu des outils pour Handshake"
	arr["CATALAN",119]="5.  Menú d'eines Handshake"
	arr["PORTUGUESE",119]="5.  Menu ferramentas Handshake"
	arr["RUSSIAN",119]="5.  Меню инструментов для работы с рукопожатием"
	arr["GREEK",119]="5.  Μενού εργαλειών Χειραψίας"
	arr["ITALIAN",119]="5.  Menù degli strumenti Handshake"
	arr["POLISH",119]="5.  Menu narzędzi Handshake"
	arr["GERMAN",119]="5.  Handshake-Tools-Menü"
	arr["TURKISH",119]="5.  Handshake araçları menüsü"

	arr["ENGLISH",120]="Handshake tools menu"
	arr["SPANISH",120]="Menú de herramientas Handshake"
	arr["FRENCH",120]="Menu des outils pour Handshake"
	arr["CATALAN",120]="Menú d'eines Handshake"
	arr["PORTUGUESE",120]="Menu de ferramentas Handshake"
	arr["RUSSIAN",120]="Меню инструментов для работы с рукопожатием"
	arr["GREEK",120]="Μενού εργαλειών Χειραψίας"
	arr["ITALIAN",120]="Menù degli strumenti Handshake"
	arr["POLISH",120]="Menu narzędzi Handshake"
	arr["GERMAN",120]="Handshake-Tools-Menü"
	arr["ENGLISH",120]="Handshake araçları menüsü"

	arr["ENGLISH",121]="5.  Capture Handshake"
	arr["SPANISH",121]="5.  Capturar Handshake"
	arr["FRENCH",121]="5.  Capture du Handshake"
	arr["CATALAN",121]="5.  Captura Handshake"
	arr["PORTUGUESE",121]="5.  Capturar Handshake"
	arr["RUSSIAN",121]="5.  Захват рукопожатия"
	arr["GREEK",121]="5.  Καταγράψτε την Χειραψία"
	arr["ITALIAN",121]="5.  Catturare Handshake"
	arr["POLISH",121]="5.  Przechwyć Handshake"
	arr["GERMAN",121]="5.  Handshake ergreifen"
	arr["TURKISH",121]="5.  Handshake yakala"

	arr["ENGLISH",122]="6.  Clean/optimize Handshake file"
	arr["SPANISH",122]="6.  Limpiar/optimizar fichero de Handshake"
	arr["FRENCH",122]="6.  Laver/optimiser le fichier Handshake"
	arr["CATALAN",122]="6.  Netejar/optimitzar fitxer de Handshake"
	arr["PORTUGUESE",122]="6.  Limpar arquivo/otimizar Handshake"
	arr["RUSSIAN",122]="6.  Очистка/оптимизация файла рукопожатия"
	arr["GREEK",122]="6.  Καθαρισμός/βελτιστοποίηση του αρχείου Χειραψίας"
	arr["ITALIAN",122]="6.  Pulire/ottimizzare file Handshake"
	arr["POLISH",122]="6.  Oczyść/zoptymalizuj plik Handshake"
	arr["GERMAN",122]="6.  Handshake-Datei bereinigen/optimieren"
	arr["TURKISH",122]="6.  Handshake dosyalarını Temizle/Optimize et"

	arr["ENGLISH",123]="If the password for the wifi network is obtained with the WPS attack, you should decide where to save it. ${green_color}Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${wps_potpath}]"
	arr["SPANISH",123]="Si se consigue la contraseña de la red wifi con el ataque WPS, hay que decidir donde guardarla. ${green_color}Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${wps_potpath}]"
	arr["FRENCH",123]="Si le mot de passe est obtenu par une attaque WPS, il faut ensuite indiquer l'endroit pour la sauvegarder. ${green_color}Entrez le chemin de l'endroit où vous voulez garder le fichier ou bien appuyez sur [Enter] si le chemin proposée par défaut vous convient ${normal_color}[${wps_potpath}]"
	arr["CATALAN",123]="Si s'aconsegueix la contrasenya de la xarxa wifi amb l'atac WPS, cal decidir on guardar-la. ${green_color}Escriu la ruta on guardarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${wps_potpath}]"
	arr["PORTUGUESE",123]="Se a senha da rede wifi for obtida com o ataque WPS, onde deseja salvá-la?. ${green_color}Digite o caminho onde armazenar o arquivo ou pressione [Enter] para aceitar o padrão ${normal_color}[${wps_potpath}]"
	arr["RUSSIAN",123]="Если во время WPS атаки на Wi-Fi сеть получен пароль, вы должны решить, где его сохранить. ${green_color} Наберите путь для сохранения файла или нажмите [Enter] для принятия значения по умолчанию ${normal_color}[${wps_potpath}]"
	arr["GREEK",123]="Θα πρέπει να εισάγετε μονοπάτι για την αποθήκευση του κωδικού σε αρχείο, εάν βρεθεί ο κωδικός πρόσβασης του ασύρματου δικτύου με την επίθεση WPS. ${green_color}Πληκτρολογήστε το μονοπάτι για την αποθήκευση του αρχείου ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${wps_potpath}]"
	arr["ITALIAN",123]="Se si ottiene la password della rete wireless con l'attacco WPS, bisogna decidere dove salvarla. ${green_color}Scrivere il percorso dove salvare il file o premere [Enter] per accettare la proposta di default ${normal_color}[${wps_potpath}]"
	arr["POLISH",123]="Jeśli hasło sieci wifi zostanie uzyskane atakiem WPS, musisz zdecydować gdzie je zapisać. ${green_color}Wpisz ścieżkę, w której będziemy zapisywać plik lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${wps_potpath}]"
	arr["GERMAN",123]="Wenn Sie das WLAN-Passwort mit dem WPS-Angriff erhalten, müssen Sie entscheiden, wo Sie es speichern möchten. ${green_color} Geben Sie den Pfad ein, unter dem die Datei gespeichert werden soll, oder drücken Sie die [Enter]-Taste, um den Standardvorschlag ${normal_color}[${wps_potpath}] ${blue_color}zu akzeptieren"
	arr["TURKISH",123]="Eğer wifi şifresini WPS saldırısı yöntemi ile elde ettiyseniz, nereye kaydedileceğini belirlemelisiniz. ${green_color}Dizin yolu girin veya [Enter] tuşuna varsayılan yere kaydedin. ${normal_color}[${wps_potpath}]"

	arr["ENGLISH",124]="monitor mode needed for capturing"
	arr["SPANISH",124]="modo monitor requerido en captura"
	arr["FRENCH",124]="modo moniteur nécessaire pour la capture"
	arr["CATALAN",124]="mode monitor requerit en captura"
	arr["PORTUGUESE",124]="modo monitor necessário para captura"
	arr["RUSSIAN",124]="для захвата необходим режим монитора"
	arr["GREEK",124]="χρειάζεται η κατάσταση παρακολούθησης για την καταγραφή"
	arr["ITALIAN",124]="modo monitor richesto per la cattura"
	arr["POLISH",124]="aby przechwytywać wymagany jest tryb monitorowania"
	arr["GERMAN",124]="monitor-Modus für die Erfassung erforderlich"
	arr["TURKISH",124]="yakalamak için izleme modu gereklidir"

	arr["ENGLISH",125]="There is no valid target network selected. You'll be redirected to select one"
	arr["SPANISH",125]="No hay una red objetivo válida seleccionada. Serás redirigido para seleccionar una"
	arr["FRENCH",125]="Le choix du réseau cible est incorrect. Vous allez être redirigé vers le menu de sélection pour effectuer un nouveau choix"
	arr["CATALAN",125]="No hi ha una xarxa objectiu vàlida seleccionada. Seràs redirigit per seleccionar una"
	arr["PORTUGUESE",125]="Nenhuma rede válida selecionada. Você será redirecionado para selecionar uma"
	arr["RUSSIAN",125]="Не выбрана подходящая целевая сеть. Вы будете перенаправлены на выбор сети"
	arr["GREEK",125]="Δεν έχει επιλεχθεί κάποιο έγκυρο δίκτυο-στόχος. Θα καθοδηγηθείτε ώστε να επιλέξετε ένα"
	arr["ITALIAN",125]="Nessuna rete valida selezionata come obiettivo. Sarai reindirizzato per selezionarne una"
	arr["POLISH",125]="Nie wybrano prawidłowej sieci docelowej. Zostaniesz przekierowany, aby ją wybrać"
	arr["GERMAN",125]="Kein gültiges Ziel-Netzwerk wurde ausgewählt. Sie werden zur Auswahl weitergeleitet"
	arr["TURKISH",125]="Geçerli bir hedef ağ seçilmedi. Seçmek için yönlendiriliyorsunuz"

	arr["ENGLISH",126]="You have a valid WPA/WPA2 target network selected. Script can continue..."
	arr["SPANISH",126]="Tienes una red objetivo WPA/WPA2 válida seleccionada. El script puede continuar..."
	arr["FRENCH",126]="Choix du réseau cible WPA/WPA2 valide. Le script peut continuer..."
	arr["CATALAN",126]="Tens una xarxa objectiu WPA/WPA2 vàlida seleccionada. El script pot continuar..."
	arr["PORTUGUESE",126]="Você tem uma rede WPA/WPA2 válida selecionada. O script pode continuar..."
	arr["RUSSIAN",126]="У вас есть подходящая целевая сеть WPA/WPA2. Скрипт может продолжать..."
	arr["GREEK",126]="Έχετε επιλέξει ένα έγκυρο δίκτυο-στόχος WPA/WPA2. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",126]="Hai selezionato una rete WPA/WPA2 valida. Lo script può continuare..."
	arr["POLISH",126]="Wybrano prawidłową sieć docelową WPA/WPA2. Skrypt może kontynuować..."
	arr["GERMAN",126]="Sie haben ein gültiges WPA/WPA2-Zielnetzwerk ausgewählt. Das Skript kann fortfahren..."
	arr["ENGLISH",126]="Geçerli bir WPA/WPA2 hedef ağı seçtiniz. Yazılım devam edebilir..."

	arr["ENGLISH",127]="The natural order to proceed in this menu is usually: 1-Select wifi card 2-Put it in monitor mode 3-Select target network 4-Capture Handshake"
	arr["SPANISH",127]="El orden natural para proceder en este menú suele ser: 1-Elige tarjeta wifi 2-Ponla en modo monitor 3-Elige red objetivo 4-Captura Handshake"
	arr["FRENCH",127]="La marche à suivre est généralement: 1-Selectionner la carte wifi 2-Activer le mode moniteur 3-Choisir un réseau cible 4-Capturer le Handshake"
	arr["CATALAN",127]="L'ordre natural per procedir a aquest menú sol ser: 1-Tria targeta wifi 2-Posa-la en mode monitor 3-Tria xarxa objectiu 4-Captura Handshake"
	arr["PORTUGUESE",127]="A ordem normal para esse menu é: 1-Escolha de uma interface wifi 2-colocar interface wifi no modo monitor 3-Selecionar uma rede 4-Capturar Handshake"
	arr["RUSSIAN",127]="Естественный порядок работы в этом меню: 1-Выбрать wifi карту 2-Перевести её в режим монитора 3-Выбрать целевую сеть 4-Захватить рукопожатие"
	arr["GREEK",127]="Η σειρά εντολών για να προχωρήσετε σε αυτό το μενού είναι συνήθως: 1-Επιλέξτε κάρτα wifi 2-Βάλτε την σε κατάσταση παρακολούθησης 3-Επιλέξτε δίκτυο-στόχος 4-Καταγράψτε την Χειραψία"
	arr["ITALIAN",127]="L'ordine naturale per procedere in questo menú di solito è: 1-Seleziona la scheda wifi 2-Mettila in modalità monitor 3-Seleziona rete obiettivo 4-Cattura Handshake"
	arr["POLISH",127]="Naturalnym sposobem kontynuowania w tym menu jest zazwyczaj: 1-Wybierz kartę wifi 2-Włącz tryb monitorowania 3-Wybierz sieć docelową 4-Przechwyć Handshake"
	arr["GERMAN",127]="Die natürliche Reihenfolge, um in diesem Menü fortzufahren, ist normalerweise: 1-Wählen Sie die WLAN-Karte 2-Setzen Sie sie in den monitor-Modus 3-Wählen Sie das Ziel-Netzwerk 4-Handshake ergreifen"
	arr["TURKISH",127]="Normal olarak izlemeniz gereken yol: 1-Wifi kartı seç 2-İzleme modunu aç 3-Hedef ağ seç 4-Handshake yakala"

	arr["ENGLISH",128]="Select a wifi card to work in order to be able to do more actions than with an ethernet interface"
	arr["SPANISH",128]="Selecciona una interfaz wifi para poder realizar más acciones que con una interfaz ethernet"
	arr["FRENCH",128]="Veuillez sélectionner une carte wifi au lieu d'une carte ethernet afin d'être en mesure de réaliser plus d'actions"
	arr["CATALAN",128]="Seleccioneu una targeta wifi per treballar amb la finalitat de ser capaç de fer més accions que amb una interfície ethernet"
	arr["PORTUGUESE",128]="Selecione uma interface wifi para realizar mais ações do que com uma interface ethernet"
	arr["RUSSIAN",128]="Выберите wifi карту для работы, чтобы вы могли выполнить больше действий, чем с ethernet интерфейсом"
	arr["GREEK",128]="Επιλέξτε κάρτα wifi ώστε να μπορείτε να έχετε περισσοτερες επιλογές από μία διεπαφή ethernet"
	arr["ITALIAN",128]="Seleziona un'interfaccia wifi per poter eseguire più azioni che con un interfaccia ethernet"
	arr["POLISH",128]="Wybierz interfejs wifi, aby wykonać więcej czynności niż z interfejsem sieci ethernet"
	arr["GERMAN",128]="Wählen Sie eine WLAN-Interface, um mehr Aktionen als mit einer ethernet-Schnittstelle auszuführen"
	arr["TURKISH",128]="Bir ethernet arabiriminden daha fazla işlem yapabilmek için çalışmak üzere bir wifi kartı seçin"

	arr["ENGLISH",129]="The natural order to proceed in this menu is usually: 1-Select wifi card 2-Put it in monitor mode 3-Select target network 4-Start attack"
	arr["SPANISH",129]="El orden natural para proceder en este menú suele ser: 1-Elige tarjeta wifi 2-Ponla en modo monitor 3-Elige red objetivo 4-Comienza el ataque"
	arr["FRENCH",129]="La marche à suivre est généralement: 1-Selectionner la carte wifi 2-Activer le mode moniteur 3-Choisir un réseau cible 4-Capturer le Handshake"
	arr["CATALAN",129]="L'ordre natural per procedir a aquest menú sol ser: 1-Tria targeta wifi 2-Posa-la en mode monitor 3-Tria xarxa objectiu 4-Iniciar l'atac"
	arr["PORTUGUESE",129]="A ordem normal para esse menu é: 1-Escolha de uma interface wifi 2-colocar a interface wifi no modo monitor 3-Selecionar uma rede 4-Começar o ataque"
	arr["RUSSIAN",129]="Обычный порядок работы в этом меню: 1-Выберите wifi карту 2-Переведите её в режим монитора 3-Выберите целевую сеть 4-Запустите атаку"
	arr["GREEK",129]="Η διαδικασία για να προχωρήσετε σε αυτό το μενού είναι συνήθως: 1-Επιλέξτε κάρτα wifi 2-Βάλτε την σε κατάσταση παρακολούθησης 3-Επιλέξτε δίκτυο-στόχος 4-Ξεκινήστε την επίθεση"
	arr["ITALIAN",129]="L'ordine naturale per procedere in questo menú di solito è: 1-Seleziona la scheda wifi 2-Mettila in modalità monitor 3-Seleziona rete obiettivo 4-Inizia l'attacco"
	arr["POLISH",129]="Naturalnym sposobem działania w tym menu jest zazwyczaj: 1-Wybierz kartę wifi 2-Włącz tryb monitorowania 3-Wybierz sieć docelową 4-Rozpocznij ataku"
	arr["GERMAN",129]="Um in diesem Menü fortzufahren folgendes zu machen: 1-Wählen Sie die WLAN-Karte 2-Stellen Sie sie im Monitur-modus ein 3-Wählen Sie das Zielnetzwerk 4-Starten Sie den Angriff"
	arr["TURKISH",129]="Bu menüde devam etmek için genellikle şu yol izlenir: 1-Wifi kartı seçmi 2-İzleme modunu açma 3-Hedef ağ seçme 4-Saldırıya başlama"

	arr["ENGLISH",130]="Remember to select a target network with clients to capture Handshake"
	arr["SPANISH",130]="Recuerda seleccionar una red objetivo con clientes para capturar el Handshake"
	arr["FRENCH",130]="Rappelez-vous de sélectionner un réseau cible avec un/des client(s) connecté(s) pour pouvoir capturer un Handshake"
	arr["CATALAN",130]="Recorda que has de seleccionar una xarxa de destinació amb clients per capturar el Handshake"
	arr["PORTUGUESE",130]="Lembre-se de selecionar uma rede com clientes para capturar o Handshake"
	arr["RUSSIAN",130]="Не забудьте выбрать целевую сеть с клиентами для захвата рукопожатия"
	arr["GREEK",130]="Θυμηθείτε να επιλέξετε ένα δίκτυο-στόχος με έναν ή παραπάνω χρήστες για να καταγράψετε μία Χειραψία"
	arr["ITALIAN",130]="Ricorda di selezionare una rete di destinazione con clienti per poter catturare l'Handshake"
	arr["POLISH",130]="W celu przechwycenia Handshake, pamiętaj aby wybrać sieć docelową z klientami"
	arr["GERMAN",130]="Denken Sie daran, ein Zielnetzwerk mit Clients auszuwählen, um den Handshake zu erfassen"
	arr["TURKISH",130]="Handshake'i yakalamak için istemcilerle bir hedef ağ seçmeyi unutmayın"

	arr["ENGLISH",131]="Not all attacks affect all access points. If an attack is not working against an access point, choose another one :)"
	arr["SPANISH",131]="No todos los ataques afectan a todos los puntos de acceso. Si un ataque no funciona contra un punto de acceso, elige otro :)"
	arr["FRENCH",131]="Toutes les attaques n'affectent pas les points d'accès de la même manière. Si une attaque ne donne pas de résultats, choisissez en une autre :)"
	arr["CATALAN",131]="No tots els atacs afecten tots els punts d'accés. Si un atac no està treballant cap a un punt d'accés, tria un altre :)"
	arr["PORTUGUESE",131]="Nem todos os ataques funcionam em todas as redes. Se um ataque não funcionar contra uma rede, escolha outro :)"
	arr["RUSSIAN",131]="Не все атаки справляются со всеми точками доступа. Если атака не работает в отношении точки доступа, выберите другую :)"
	arr["GREEK",131]="Δεν είναι όλες οι επιθέσεις αποτελεσματικές σε όλα τα σημεία πρόσβασης. Αν μια επίθεση δεν δουλεύει ενάντια σε ένα σημείο πρόσβασης, διαλέξτε κάποια άλλη :)"
	arr["ITALIAN",131]="Non tutti gli attacchi funzionano su tutti gli access point. Se un attacco non funziona contro un access point, selezionane un altro :)"
	arr["POLISH",131]="Nie wszystkie ataki działają na wszystkie punkty dostępu. Jeśli atak nie działa przeciwko któremuś punktowi dostępowemu, wybierz inny :)"
	arr["GERMAN",131]="Nicht alle Angriffe betreffen alle Access Points. Wenn ein Angriff gegen einen Access Point nicht funktioniert, wählen Sie einen anderen :)"
	arr["TURKISH",131]="Tüm saldırılar tüm erişim noktalarını etkilemez. Bir saldırı bir erişim noktasına karşı çalışmıyorsa, başka birini seçin :)"

	arr["ENGLISH",132]="Cleaning a Handshake file is recommended only for big size files. It's better to have a backup, sometimes file can be corrupted while cleaning it"
	arr["SPANISH",132]="Limpiar un fichero de Handshake se recomienda solo para ficheros grandes. Es mejor hacer una copia de seguridad antes, a veces el fichero se puede corromper al limpiarlo"
	arr["FRENCH",132]="Épurer le fichier contenant le Handshake est seulement recommandable si le fichier est volumineux. Si vous décidez d'épurer le fichier il est conseillé de faire une copie de sauvegarde du fichier originel, l'opération de nettoyage comporte des risques et peut le rendre illisible"
	arr["CATALAN",132]="Netejar un fitxer de Handshake es recomana només per a fitxers grans. És millor fer una còpia de seguretat abans, de vegades el fitxer es pot corrompre al netejar-lo"
	arr["PORTUGUESE",132]="Limpar um Handshake é recomendado apenas para arquivos grandes. É melhor fazer um backup antes, porque as vezes o arquivo pode corromper ao limpar"
	arr["RUSSIAN",132]="Очистка файла рукопожатия рекомендована только для файлов больших размеров. Лучше иметь резервную копию, иногда во время очистки файл может быть повреждён"
	arr["GREEK",132]="Ο καθαρισμός ενός αρχείου Χειραψίας συνιστάται μόνο για μεγάλου μεγέθους αρχεία. Καλύτερα κρατήστε ένα backup, μερικές φορές το αρχείο μπορεί να καταστραφεί κατά τη διάρκεια του καθαρισμού"
	arr["ITALIAN",132]="Pulire un file di Handshake è consigliato solo per file di grandi dimensioni. Meglio fare un backup prima, a volte il file si può corrompere con la pulizia"
	arr["POLISH",132]="Usunięcie pliku Handshake jest zalecane tylko w przypadku dużych plików. Lepiej jest zachować kopie zapasowe, czasami plik może być uszkodzony podczas czyszczenia"
	arr["GERMAN",132]="Das Bereinigen einer Handshake-Datei wird nur für große Dateien empfohlen. Es ist besser, vorher ein Backup zu erstellen, manchmal kann die Datei beim Säubern beschädigt werden"
	arr["TURKISH",132]="Bir Handshake dosyasının temizlenmesi yalnızca büyük boyutlu dosyalar için önerilir. Bir yedeğin olması daha iyidir, bazen dosya temizlenirken bozulabilir"

	arr["ENGLISH",133]="If you select a target network with hidden ESSID, you can't use it, but you can perform BSSID based attacks to that network"
	arr["SPANISH",133]="Si seleccionas una red objetivo con el ESSID oculto, no podrás usarlo, pero puedes hacer ataques basados en BSSID sobre esa red"
	arr["FRENCH",133]="Si vous sélectionnez un réseau cible avec un ESSID caché, vous n'allez pas pouvoir utiliser l'ESSID pour attaquer, mais vous pourrez effectuer les attaques basées sur le BSSID du réseau"
	arr["CATALAN",133]="Si selecciones una xarxa objectiu amb el ESSID ocult, no podràs usar-lo, però pots fer atacs basats en BSSID sobre aquesta xarxa"
	arr["PORTUGUESE",133]="Se você selecionar uma rede com ESSID oculto você não poderá usá-la, mas você poderá fazer ataques com base no BSSID"
	arr["RUSSIAN",133]="Если вы выбрали целевую сеть со скрытым ESSID, вы не сможете использовать её, но вы можете выполнить атаку на эту сеть на основе BSSID"
	arr["GREEK",133]="Αν επιλέξετε ένα δίκτυο-στόχος με κρυφό ESSID, δεν μπορείτε να το χρησιμοποιήσετε, αλλά μπορείτε να εκτελέσετε επιθέσεις BSSID σε αυτό το δίκτυο"
	arr["ITALIAN",133]="Se si seleziona una rete obiettivo con ESSID nascosto, non potrai utilizzarla, peró puoi fare attacchi a questa rete basati sul BSSID"
	arr["POLISH",133]="Jeśli wybierzesz sieć docelową z ukrytym identyfikatorem ESSID, nie będziesz w stanie jej używać, ale możesz atakować tą sieć w oparciu o BSSID"
	arr["GERMAN",133]="Wenn Sie ein Zielnetzwerk mit ausgeblendeter ESSID auswählen, können Sie es nicht verwenden, Sie können jedoch BSSID-basierte Angriffe auf dieses Netzwerk durchführen"
	arr["TURKISH",133]="Gizli ESSID ile bir hedef ağ seçerseniz, bunu kullanamazsınız, ancak bu ağa BSSID tabanlı saldırılar gerçekleştirebilirsiniz"

	arr["ENGLISH",134]="If your Linux is a virtual machine, it is possible that integrated wifi cards are detected as ethernet. Use an external usb wifi card"
	arr["SPANISH",134]="Si tu Linux es una máquina virtual, es posible que las tarjetas wifi integradas sean detectadas como ethernet. Utiliza una tarjeta wifi externa usb"
	arr["FRENCH",134]="Si votre système d'exploitation Linux est lancé dans une machine virtuelle, il est probable que les cartes wifi internes soient détectées comme des cartes ethernet. Il vaut mieux dans ce cas utiliser un dispositif wifi usb"
	arr["CATALAN",134]="Si el teu Linux és a una màquina virtual, és possible que les targetes wifi integrades siguin detectades com ethernet. Utilitza una targeta wifi externa usb"
	arr["PORTUGUESE",134]="Se seu Linux for uma máquina virtual, suas placas wireless integradas são detectadas como ethernet. Use uma placa usb externa"
	arr["RUSSIAN",134]="Если ваш Linux в виртуально машине, то интегрированная wifi карта может определиться как Ethernet. Используйте внешнюю usb wifi карту"
	arr["GREEK",134]="Αν το Linux σας είναι εικονική μηχανή, είναι πιθανόν οι ενσωματωμένες κάρτες wifi να εντοπιστούν σαν ethernet. Χρησιμοποιήστε μία εξωτερική usb κάρτα wifi"
	arr["ITALIAN",134]="Se il tuo Linux è una macchina virtuale, è possibile che le schede wireless integrate vengono rilevate come ethernet. Utilizza una scheda usb WiFi esterna"
	arr["POLISH",134]="Jeśli twój Linux jest maszyną wirtualną, możliwe jest, że zintegrowane karty wifi są wykrywane jako ethernet. Użyj zewnętrznej karty usb"
	arr["GERMAN",134]="Wenn Ihr Linux eine virtuelle Maschine ist, können integrierte WLAN-Karten als Ethernet erkannt werden. Verwendet eine externe usb-WLAN-Karte"
	arr["TURKISH",134]="Linux'unuz sanal bir makineyse, entegre wifi kartlarının ethernet olarak algılanması mümkündür. Harici bir USB wifi kartı kullanmalısınız"

	arr["ENGLISH",135]="Type of encryption: ${pink_color}${enc}${normal_color}"
	arr["SPANISH",135]="Tipo de encriptado: ${pink_color}${enc}${normal_color}"
	arr["FRENCH",135]="Type de chiffrement: ${pink_color}${enc}${normal_color}"
	arr["CATALAN",135]="Tipus d'encriptat: ${pink_color}${enc}${normal_color}"
	arr["PORTUGUESE",135]="Tipo de criptografia: ${pink_color}${enc}${normal_color}"
	arr["RUSSIAN",135]="Тип шифрования: ${pink_color}${enc}${normal_color}"
	arr["GREEK",135]="Τύπος κρυπτογράφησης: ${pink_color}${enc}${normal_color}"
	arr["ITALIAN",135]="Tipo di crittografia: ${pink_color}${enc}${normal_color}"
	arr["POLISH",135]="Typ szyfrowania: ${pink_color}${enc}${normal_color}"
	arr["GERMAN",135]="Verschlüsselungsart: ${pink_color}${enc}${normal_color}"
	arr["TURKISH",135]="Şifreleme tipi: ${pink_color}${enc}${normal_color}"

	arr["ENGLISH",136]="Obtaining a Handshake is only for networks with encryption WPA or WPA2"
	arr["SPANISH",136]="La obtención de un Handshake es solo para redes con encriptación WPA o WPA2"
	arr["FRENCH",136]="L'obtention d'un Handshake est seulement possible sur des réseaux protégés par chiffrement WPA ou WPA2"
	arr["CATALAN",136]="L'obtenció d'un Handshake és només per a xarxes amb encriptació WPA o WPA2"
	arr["PORTUGUESE",136]="A obtenção de um Handshake só é possível em redes com criptografia WPA ou WPA2"
	arr["RUSSIAN",136]="Получение рукопожатия только для сетей с шифрованием WPA или WPA2"
	arr["GREEK",136]="Η απόκτηση μιας Χειραψίας ισχύει μόνο σε δίκτυα με κρυπτογράφηση WPA ή WPA2"
	arr["ITALIAN",136]="Ottenere un Handshake è possibile solo per le reti con crittografia WPA o WPA2"
	arr["POLISH",136]="Przechwytywanie Handshake dotyczy tylko sieci z szyfrowaniem WPA lub WPA2"
	arr["GERMAN",136]="Das Erhalten eines Handshakes ist nur für Netzwerke mit WPA oder WPA2-Verschlüsselung möglich"
	arr["TURKISH",136]="Bir Handshake Edinme sadece WPA veya WPA2 şifrelemeli ağlar içindir"

	arr["ENGLISH",137]="The selected network is invalid. To get a Handshake, encryption type of target network should be WPA or WPA2"
	arr["SPANISH",137]="La red seleccionada no es válida. Para obtener un Handshake, el tipo de encriptación de la red objetivo debe ser WPA o WPA2"
	arr["FRENCH",137]="Le réseau sélectionné est invalide . Pour obtenir un Handshake le réseau cible doit être en WPA ou WPA2"
	arr["CATALAN",137]="La xarxa seleccionada no és vàlida. Per obtenir un Handshake, el tipus d'encriptació de la xarxa objectiu ha de ser WPA o WPA2"
	arr["PORTUGUESE",137]="A rede selecionada é inválida. Para obter um Handshake, o tipo de criptografia da rede deve ser WPA ou WPA2"
	arr["RUSSIAN",137]="Выбранная сеть не подходит. Для получения рукопожатия, тип шифрования должен быть WPA или WPA2"
	arr["GREEK",137]="Το επιλεγμένο δίκτυο είναι άκυρο. Για να αποκτήσετε μία Χειραψία, ο τύπος κρυπτογράφησης του δικτύου-στόχου πρέπει να έιναι WPA ή WPA2"
	arr["ITALIAN",137]="La rete selezionata non è valida. Per ottenere un Handshake, il tipo di crittografia della rete obiettivo deve essere WPA o WPA2"
	arr["POLISH",137]="Wybrana sieć jest nieprawidłowa. Aby przechwycić Handshake, typem szyfrowania sieci docelowej musi być WPA lub WPA2"
	arr["GERMAN",137]="Das ausgewählte Netzwerk ist nicht gültig. Um einen Handshake zu erhalten, muss die Verschlüsselungsart des Zielnetzwerks WPA oder WPA2 sein"
	arr["TURKISH",137]="Seçilen ağ geçersiz. Bir Handshake almak için, şifreleme türü hedef ağ WPA veya WPA2 olmalıdır"

	arr["ENGLISH",138]="Attack for Handshake"
	arr["SPANISH",138]="Ataque para Handshake"
	arr["FRENCH",138]="Attaque pour obtenir un Handshake"
	arr["CATALAN",138]="Atac de Handshake"
	arr["PORTUGUESE",138]="Ataque para obter um Handshake"
	arr["RUSSIAN",138]="Атаковать для рукопожатия"
	arr["GREEK",138]="Επίθεση για Χειραψία"
	arr["ITALIAN",138]="Attacco per Handshake"
	arr["POLISH",138]="Atak na Handshake"
	arr["GERMAN",138]="Handshake-Angriff"
	arr["TURKISH",138]="Saldırı için Handshake"

	arr["ENGLISH",139]="1.  Deauth / disassoc amok mdk3 attack"
	arr["SPANISH",139]="1.  Ataque Deauth / Disassoc amok mdk3"
	arr["FRENCH",139]="1.  Attaque Deauth / Disassoc amok mdk3"
	arr["CATALAN",139]="1.  Atac Deauth / Disassoc amok mdk3"
	arr["PORTUGUESE",139]="1.  Ataque Deauth / Disassoc amok mdk3"
	arr["RUSSIAN",139]="1.  Атака деаутентификации / разъединения amok mdk3"
	arr["GREEK",139]="1.  Επίθεση Deauth / disassoc amok mdk3"
	arr["ITALIAN",139]="1.  Attacco Deauth / Disassoc amok mdk3"
	arr["POLISH",139]="1.  Atak Deauth / Disassoc amok mdk3"
	arr["GERMAN",139]="1.  Deauth / Disassoc Amok mdk3 Angriff"
	arr["TURKISH",139]="1.  Deauth / disassoc amok mdk3 saldırısı"

	arr["ENGLISH",140]="2.  Deauth aireplay attack"
	arr["SPANISH",140]="2.  Ataque Deauth aireplay"
	arr["FRENCH",140]="2.  Attaque Deauth aireplay"
	arr["CATALAN",140]="2.  Atac Deauth aireplay"
	arr["PORTUGUESE",140]="2.  Ataque Deauth aireplay"
	arr["RUSSIAN",140]="2.  Атака деаутентификации aireplay"
	arr["GREEK",140]="2.  Επίθεση Deauth aireplay"
	arr["ITALIAN",140]="2.  Attacco Deauth aireplay"
	arr["POLISH",140]="2.  Atak Deauth aireplay"
	arr["GERMAN",140]="2.  Deauth aireplay Angriff"
	arr["TURKISH",140]="2.  Deauth aireplay saldırısı"

	arr["ENGLISH",141]="3.  WIDS / WIPS / WDS Confusion attack"
	arr["SPANISH",141]="3.  Ataque WIDS / WIPS / WDS Confusion"
	arr["FRENCH",141]="3.  Attaque WIDS / WIPS / WDS Confusion"
	arr["CATALAN",141]="3.  Atac WIDS / WIPS / WDS Confusion"
	arr["PORTUGUESE",141]="3.  Ataque WIDS / WIPS / Confusão WDS"
	arr["RUSSIAN",141]="3.  Атака смешения WIDS / WIPS / WDS"
	arr["GREEK",141]="3.  Επίθεση σύγχυσης WIDS / WIPS / WDS"
	arr["ITALIAN",141]="3.  Attacco WIDS / WIPS / WDS Confusion"
	arr["POLISH",141]="3.  Atak WIDS / WIPS / WDS Confusion"
	arr["GERMAN",141]="3.  WIDS / WIPS / WDS Confusion Angriff"
	arr["TURKISH",141]="3.  WIDS / WIPS / WDS Confusion saldırısı"

	arr["ENGLISH",142]="If the Handshake doesn't appear after an attack, try again or change the type of attack"
	arr["SPANISH",142]="Si tras un ataque el Handshake no aparece, vuelve a intentarlo o cambia de ataque hasta conseguirlo"
	arr["FRENCH",142]="Si vous n'obtenez pas le Handshake après une attaque, veuillez recommencer ou bien changer d'attaque jusqu'à son obtention"
	arr["CATALAN",142]="Si després d'un atac el Handshake no apareix, torna a intentar-ho o canvia d'atac fins aconseguir-ho"
	arr["PORTUGUESE",142]="Se o Handshake não aparecer após um ataque, tente novamente ou tente alterar o tipo de ataque"
	arr["RUSSIAN",142]="Если рукопожатие не появилось после атаки, попробуйте снова или измените тип атаки"
	arr["GREEK",142]="Αν η Χειραψία δεν εμφανιστεί μετά από την επίθεση, προσπαθήστε ξανά ή αλλάξτε τύπο επίθεσης"
	arr["ITALIAN",142]=" Se dopo un attacco non compare l'Handshake, prova di nuovo o cambia attacco fino ad ottenerlo"
	arr["POLISH",142]="Jeśli po ataku nie pojawi się Handshake, spróbuj ponownie lub zmień atak"
	arr["GERMAN",142]="Wenn nach einem Angriff der Handshake nicht erscheint, versuchen Sie es erneut oder ändern Sie den Angriff, bis Sie ihn erhalten"
	arr["TURKISH",142]="Eğer handshake başarısız olduysa, başka bir saldırı yöntemi deneyin"

	arr["ENGLISH",143]="Two windows will be opened. One with the Handshake capturer and other with the attack to force clients to reconnect"
	arr["SPANISH",143]="Se abrirán dos ventanas. Una con el capturador del Handshake y otra con el ataque para expulsar a los clientes y forzarles a reconectar"
	arr["FRENCH",143]="Deux fenêtres vont s'ouvrir: La première pour capturer le handshake et la deuxième pour effectuer l'attaque visant à expulser les clients du réseau et les forcer à renégocier un Handshake pour se reconnecter"
	arr["CATALAN",143]="S'obriran dues finestres. Una amb el capturador de Handshake i una altra amb l'atac per expulsar als clients i forçar-los a reconnectar"
	arr["PORTUGUESE",143]="Duas janelas serão abertas. Uma para captura do Handshake e outra com o ataque para forçar os clientes a se reconectarem"
	arr["RUSSIAN",143]="Будут открыты два окна. Одно с захватчиком рукопожатия, а другое с атакой для принудительного переподключения клиентов"
	arr["GREEK",143]="Θα ανοίξουν δύο παράθυρα. Ένα με τον καταγραφέα Χειραψίας, και ένα με την επίθεση εξαναγκασμένης επανασύνδεσης των χρηστών"
	arr["ITALIAN",143]="Si apriranno due finestre. Una con il catturatore dell'Handshake, l'altra con l'attacco per cacciare i clienti e costringerli a riconnettersi"
	arr["POLISH",143]="Otworzą się dwa okna. Jedna z przechwytywaczem Handshake, a druga z atakiem, zmuszającym klientów ich do ponownego połączenia"
	arr["GERMAN",143]="Zwei Fenster werden sich öffnen. Eine mit dem Handshake-Grabber und eine mit dem Angriff, der die Kunden zwingt, sich wieder zu verbinden"
	arr["TURKISH",143]="Eğer Handshake bir saldırıdan sonra görünmezse, tekrar deneyin veya saldırı türünü değiştirin"

	arr["ENGLISH",144]="Don't close any window manually, script will do when needed. In about ${timeout} seconds maximum you'll know if you've got the Handshake"
	arr["SPANISH",144]="No cierres manualmente ninguna ventana, el script lo hará cuando proceda. En unos ${timeout} segundos como máximo sabrás si conseguiste el Handshake"
	arr["FRENCH",144]="Ne pas fermer une des fenêtres manuellement: Le script va le faire automatiquement si besoin est. Vos saurez dans tout a plus ${timeout} secondes si avez obtenu le Handshake"
	arr["CATALAN",144]="No tanquis manualment cap finestra, el script ho farà quan escaigui. En uns ${timeout} segons com a màxim sabràs si vas aconseguir el Handshake"
	arr["PORTUGUESE",144]="Não feche nenhuma janela manualmente, o script fechará quando necessário. Em cerca de ${timeout} segundos no máximo você vai saber se tem o Handshake"
	arr["RUSSIAN",144]="Не закрывайте вручную какое-либо окно, скрипт сделает это когда нужно. Примерно в максимум ${timeout} секунд вы узнаете, получили ли вы рукопожатие"
	arr["GREEK",144]="Μην επιχειρήσετε το κλείσιμο κάποιου παραθύρου χειροκίνητα, εάν χρειαστεί το script θα το κάνει μόνο του. Σε περίπου ${timeout} δευτερόλεπτα το μέγιστο θα μάθετε αν αποκτήσατε την Χειραψία"
	arr["ITALIAN",144]="Non chiudere nessuna finestra manualmente, lo script lo fará cuando necessario. In ${timeout} secondi al massimo scoprirai se hai catturato l'Handshake"
	arr["POLISH",144]="Nie należy ręcznie zamykać okien, skrypt to zrobi w razie potrzeby. W ciągu co najwyżej ${timeout} sekund dowiesz się, czy masz Handshake"
	arr["GERMAN",144]="Schließen Sie kein Fenster manuell, das Skript wird dies bei Bedarf tun. In ungefähr ${timeout} Sekunden werden Sie wissen, ob Sie den Handshake bekommen haben"
	arr["TURKISH",144]="Herhangi bir pencereyi elle kapatmayın, yazılım gerektiğinde yapacaktır. Yaklaşık ${timeout} saniye içinde, Handshake'e sahip olup olmadığınızı bileceksiniz"

	arr["ENGLISH",145]="${blue_color}Your wifi card supports the 5Ghz band but your \"wash\" version included in reaver package (v${reaver_version}) is not able to scan both bands at once. To use dual band scan feature you must have at least version v${minimum_wash_dualscan_version} so you have to make a choice. ${green_color}Do you want to scan the 5Ghz band? ${pink_color}(If you answer no (\"n\"), 2.4Ghz band will be scanned) ${normal_color}${visual_choice}"
	arr["SPANISH",145]="${blue_color}Tu tarjeta wifi soporta la banda de los 5Ghz pero tu versión de \"wash\" incluido en el paquete reaver (v${reaver_version}) no es capaz de escanear ambas bandas a la vez. Para utilizar el escaneo dual debes tener al menos la versión v${minimum_wash_dualscan_version} por lo que has de elegir. ${green_color}¿Deseas escanear en la banda de los 5Ghz? ${pink_color}(Si respondes que no (\"n\"), se escaneará la banda de 2.4Ghz) ${normal_color}${visual_choice}"
	arr["FRENCH",145]="${blue_color}Votre carte wifi supporte la bande 5Ghz mais votre version du \"wash\" incluse dans le paquet reaver (v${reaver_version}) n'est pas capable de balayer les deux bandes en même temps. Pour utiliser l'analyse dual, vous devez avoir au moins la version v${minimum_wash_dualscan_version} vous devez donc choisir. ${green_color}Voulez-vous scanner dans la bande 5Ghz? ${pink_color}(Si vous répondez non (\"n\"), la bande 2.4Ghz sera analysée) ${normal_color}${visual_choice}"
	arr["CATALAN",145]="${blue_color}La teva targeta wifi suporta la banda dels 5Ghz però la vostra versió del \"wash\" inclòs en el paquet reaver (v${reaver_version}) no és capaç d'escanejar les dues bandes alhora. Per utilitzar l'escaneig dual has de tenir almenys la versió v${minimum_wash_dualscan_version} pel que has de triar. ${green_color}¿Voleu escanejar a la banda dels 5Ghz? ${pink_color}(Si respons que no (\"n\"), es escanejarà la banda de 2.4Ghz) ${normal_color}${visual_choice}"
	arr["PORTUGUESE",145]="${blue_color}A sua interface wifi suporta a banda 5Ghz, mas a sua versão do \"wash\" incluída no pacote reaver (v${reaver_version}) não é capaz de escanear ambas as bandas ao mesmo tempo. Para usar a varredura dupla, você deve ter pelo menos a versão v${minimum_wash_dualscan_version}. Você deve escolher. ${green_color}Deseja escanear a banda 5Ghz? ${pink_color}(Se você responder não (\"n\"), somente banda 2.4Ghz será digitalizada) ${normal_color}${visual_choice}"
	arr["RUSSIAN",145]="${blue_color}Ваша карта wifi поддерживает диапазон 5Ghz, но ваша версия \"wash\", включенная в пакет reaver (v${reaver_version}), не может одновременно сканировать обе полосы. Чтобы использовать двойное сканирование, вы должны иметь хотя бы версию v${minimum_wash_dualscan_version}, поэтому вам нужно выбрать только одну из частот. ${green_color}Вы хотите сканировать частоты 5Ghz? ${pink_color}(Если вы ответите нет (\"n\"), будут просканированы частоты 2.4Ghz) ${normal_color}${visual_choice}"
	arr["GREEK",145]="${blue_color}Η κάρτα wifi σας υποστηρίζει την 5Ghz ζώνη, αλλά η έκδοση του \"wash\" που περιλαμβάνεται στο πακέτο του reaver (v${reaver_version}) δεν είναι σε θέση να σαρώσει ταυτόχρονα και τις δύο ζώνες (dual band). Για να χρησιμοποιήσετε την σάρωση για dual band, πρέπει να έχετε τουλάχιστον την έκδοση v${minimum_wash_dualscan_version} για να μπορέσετε να συνεχίσετε. ${green_color}Θέλετε να σαρώσετε στην 5Ghz ζώνη; ${pink_color}(Εάν απαντήσετε όχι (\"n\"), η 2.4Ghz ζώνη θα σαρωθεί) ${normal_color}${visual_choice}"
	arr["ITALIAN",145]="${blue_color}La tua scheda wifi supporta la banda 5Ghz ma la tua versione di \"wash\" inclusa nel pacchetto reaver (v${reaver_version}) non è in grado di scansionare entrambe le bande contemporaneamente. Per usare la doppia scansione devi avere almeno la versione v${minimum_wash_dualscan_version}, quindi devi sceglierne una. ${green_color}Vuoi eseguire la scansione nella banda 5Ghz? ${pink_color}(Se rispondi no (\"n\"), verrà scansionata la banda 2.4Ghz) ${normal_color}${visual_choice}"
	arr["POLISH",145]="${blue_color}Twoja karta wifi obsługuje pasmo 5Ghz, ale twoja wersja \"wash\" zawarta w pakiecie reaver (v${reaver_version}) nie jest w stanie skanować obu pasm w tym samym czasie. Aby użyć podwójnego skanowania, musisz mieć przynajmniej wersję v${minimum_wash_dualscan_version}. ${green_color}Musisz wybrać: czy chcesz skanować w paśmie 5Ghz? ${pink_color}(Jeśli odpowiesz nie (\"n\"), zostanie zeskanowane pasmo 2.4Ghz) ${normal_color}${visual_choice}"
	arr["GERMAN",145]="${blue_color}Ihre WLAN-Karte unterstützt das 5Ghz-Band, aber Ihre im reaver-Paket enthaltene Version von \"wash\" (v${reaver_version}) kann nicht beide Bänder gleichzeitig scannen. Um den dualen Scan zu verwenden, müssen Sie mindestens Version v${minimum_wash_dualscan_version} haben, also müssen Sie wählen. ${green_color}Möchten Sie im 5Ghz-Band scannen? ${pink_color}(Wenn Sie nein (\"n\" antworten), wird das 2.4Ghz-Band gescannt) ${normal_color}${visual_choice}"
	arr["TURKISH",145]="${blue_color}Wifi kartınız 5Ghz destekliyor fakat \"wash\" versiyonunuz iki bandı aynı anda taramayı desteklemiyor. İkili band taramayı yapabilmek için en son versiyona v${minimum_wash_dualscan_version} sahip olmanız gerekiyor. ${green_color}5Ghz band taramayı istiyor musunuz? ${pink_color}(Eğer cevabınız hayır ise (\"n\"), 2.4Ghz band taranacak) ${normal_color}${visual_choice}"

	arr["ENGLISH",146]="It seems we failed... try it again, choose another attack or increase the timeout"
	arr["SPANISH",146]="Parece que no lo hemos conseguido... inténtalo de nuevo, elige otro ataque o incrementa el timeout"
	arr["FRENCH",146]="Il semble que c'est un échec... Essayez à nouveau, choisissez une autre attaque ou augmentez le timeout"
	arr["CATALAN",146]="Sembla que no ho hem aconseguit... intenta-ho de nou, tria un altre atac o incrementa el timeout"
	arr["PORTUGUESE",146]="Parece que nos falhamos... Tente novamente, escolha outro ataque ou aumente o timeout"
	arr["RUSSIAN",146]="Кажется мы потерпели неудачу... повторите попытку, выберите другую атаку или увеличьте время ожидания"
	arr["GREEK",146]="Φαίνεται πως αποτύχαμε... προσπαθήστε ξανά ή επιλέξτε άλλου είδους επίθεση ή αυξήστε το timeout"
	arr["ITALIAN",146]="Sembra che abbiamo fallito... riprova, scegli un altro attacco o aumenta il timeout"
	arr["POLISH",146]="Wygląda na to, że się nie udało... spróbuj ponownie, wybierz inny atak lub zwiększ timeout"
	arr["GERMAN",146]="Anscheinend haben wir es nicht geschafft... versuchen Sie es erneut oder erhöhen Sie den timeout"
	arr["TURKISH",146]="Başarısız görünüyoruz... tekrar deneyin, başka bir saldırı seçin veya zaman aşımını artırın"

	arr["ENGLISH",147]="0.  Return to Handshake tools menu"
	arr["SPANISH",147]="0.  Volver al menú de herramientas Handshake"
	arr["FRENCH",147]="0.  Retourner au menu des outils pour la capture du Handshake"
	arr["CATALAN",147]="0.  Tornar al menú d'eines Handshake"
	arr["PORTUGUESE",147]="0.  Voltar para o menu de ferramentas Handshake"
	arr["RUSSIAN",147]="0.  Возврат в меню инструментов для работы с рукопожатием"
	arr["GREEK",147]="0.  Επιστροφή στο μενού με τα εργαλεία Χειραψίας"
	arr["ITALIAN",147]="0.  Torna al menu degli strumenti dell'Handshake"
	arr["POLISH",147]="0.  Wróć do menu narzędzi Handshake"
	arr["GERMAN",147]="0.  Zurück zum Handshake Werkzeugmenü"
	arr["TURKISH",147]="0.  Handshake menüsüne geri dön"

	arr["ENGLISH",148]="Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${handshakepath}]"
	arr["SPANISH",148]="Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${handshakepath}]"
	arr["FRENCH",148]="Entrez le chemin où vous voulez enregistrer le fichier ou bien appuyez sur [Enter] pour prendre le chemin proposé par défaut ${normal_color}[${handshakepath}]"
	arr["CATALAN",148]="Escriu la ruta on guardarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${handshakepath}]"
	arr["PORTUGUESE",148]="Digite o caminho para salvar o arquivo ou pressione [Enter] para o caminho padrão ${normal_color}[${handshakepath}]"
	arr["RUSSIAN",148]="Напечатайте путь, по которому сохранить файл или нажмите [Enter] для принятия предложения по умолчанию ${normal_color}[${handshakepath}]"
	arr["GREEK",148]="Πληκτρολογήστε το μονοπάτι για την αποθήκευση του αρχείου ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${handshakepath}]"
	arr["ITALIAN",148]="Scrivere il percorso dove memorizzare il file o premere [Enter] per accettare la proposta di default ${normal_color}[${handshakepath}]"
	arr["POLISH",148]="Wpisz ścieżkę do zapisywania plików lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${handshakepath}]"
	arr["GERMAN",148]="Schreiben Sie den Pfad, unter dem die Datei gespeichert werden soll, oder drücken Sie die [Enter]-Taste, um den Standardvorschlag ${normal_color}[${handshakepath}] ${green_color}zu benutzen"
	arr["TURKISH",148]="Dosyayı depolamak için yolu yazın veya varsayılan teklifi kabul etmek için [Enter] tuşuna basın ${normal_color}[${handshakepath}]"

	arr["ENGLISH",149]="Handshake file generated successfully at [${normal_color}${enteredpath}${blue_color}]"
	arr["SPANISH",149]="Fichero de Handshake generado con éxito en [${normal_color}${enteredpath}${blue_color}]"
	arr["FRENCH",149]="Fichier Handshake généré avec succès dans [${normal_color}${enteredpath}${blue_color}]"
	arr["CATALAN",149]="Fitxer de Handshake generat amb èxit a [${normal_color}${enteredpath}${blue_color}]"
	arr["PORTUGUESE",149]="Arquivo de Handshake gerado com sucesso [${normal_color}${enteredpath}${blue_color}]"
	arr["RUSSIAN",149]="Файл рукопожатия успешно создан в [${normal_color}${enteredpath}${blue_color}]"
	arr["GREEK",149]="Το αρχείο Χειραψίας δημιουργήθηκε επιτυχώς στο [${normal_color}${enteredpath}${blue_color}]"
	arr["ITALIAN",149]="Handshake del file generato con successo in [${normal_color}${enteredpath}${blue_color}]"
	arr["POLISH",149]="Plik Handshake został pomyślnie wygenerowany w [${normal_color}${enteredpath}${blue_color}]"
	arr["GERMAN",149]="Handshake-Datei erfolgreich in [${normal_color}${enteredpath}${blue_color}] erstellt"
	arr["TURKISH",149]="Handshake dosyası şu hedefte başarıyla oluşturuldu [${normal_color}${enteredpath}${blue_color}]"

	arr["ENGLISH",150]="No captured Handshake file detected during this session..."
	arr["SPANISH",150]="No se ha detectado ningún fichero de Handshake capturado en esta sesión..."
	arr["FRENCH",150]="Aucun fichier Handshake valide détecté durant cette session..."
	arr["CATALAN",150]="No s'ha detectat un fitxer de Handshake capturat en aquesta sessió..."
	arr["PORTUGUESE",150]="Nenhum Handshake capturado nessa sessão..."
	arr["RUSSIAN",150]="За эту сессию не обнаружено захваченного рукопожатия..."
	arr["GREEK",150]="Δεν εντοπίστηκε κάποιο αρχείο καταγραφής Χειραψίας κατά τη διάρκεια της συνεδρίας..."
	arr["ITALIAN",150]="Non è stato trovato nessun file di Handshake catturato in questa sessione..."
	arr["POLISH",150]="Nie wykryto pliku Handshake przechwyconego w tej sesji..."
	arr["GERMAN",150]="Keine erfasste Handshake-Datei wurde in dieser Sitzung erkannt..."
	arr["TURKISH",150]="Bu oturumda hiçbir handshake dosyayı tespit edilmedi..."

	arr["ENGLISH",151]="Handshake captured file detected during this session [${normal_color}${enteredpath}${blue_color}]"
	arr["SPANISH",151]="Se ha detectado un fichero de Handshake capturado en esta sesión [${normal_color}${enteredpath}${blue_color}]"
	arr["FRENCH",151]="Un fichier contenant un Handshake a été détecté pour la session effectuée et se trouve dans ${normal_color}${enteredpath}${blue_color}]"
	arr["CATALAN",151]="S'ha detectat un fitxer de Handshake capturat en aquesta sessió [${normal_color}${enteredpath}${blue_color}]"
	arr["PORTUGUESE",151]="Handshake capturado com sucesso [${normal_color}${enteredpath}${blue_color}]"
	arr["RUSSIAN",151]="В этой сессии обнаружен файл с захваченным рукопожатием [${normal_color}${enteredpath}${blue_color}]"
	arr["GREEK",151]="Εντοπίστηκε αρχείο καταγραφής Χειραψίας κατά τη διάρκεια της συνεδρίας [${normal_color}${enteredpath}${blue_color}]"
	arr["ITALIAN",151]="Trovato un file di Handshake catturato in questa sessione [${normal_color}${enteredpath}${blue_color}]"
	arr["POLISH",151]="Plik Handshake został przechwycony w tej sesji został [${normal_color}${enteredpath}${blue_color}]"
	arr["GERMAN",151]="Eine erfasste Handshake-Datei wurde erkannt [${normal_color}${enteredpath}${blue_color}]"
	arr["TURKISH",151]="Bu oturum sırasında yakalanmış bir handshake dosyası tespit edildi [${normal_color}${enteredpath}${blue_color}]"

	arr["ENGLISH",152]="Do you want to clean/optimize the Handshake captured file during this session? ${normal_color}${visual_choice}"
	arr["SPANISH",152]="¿Quieres limpiar/optimizar el fichero de Handshake capturado en esta sesión? ${normal_color}${visual_choice}"
	arr["FRENCH",152]="Voulez-vous nettoyer/optimiser le fichier Handshake capturé pendant cette session? ${normal_color}${visual_choice}"
	arr["CATALAN",152]="¿Vols netejar/optimitzar el fitxer de Handshake capturat en aquesta sessió? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",152]="Quer limpar/otimizar o arquivo handshake capturado nesta sessão? ${normal_color}${visual_choice}"
	arr["RUSSIAN",152]="Вы хотите очистить/оптимизировать захваченный за эту сессию файл рукопожания? ${normal_color}${visual_choice}"
	arr["GREEK",152]="Θέλετε να καθαρίσετε/βελτιστοποιήσετε το αρχείο καταγραφής Χειραψίας της συνεδρίας; ${normal_color}${visual_choice}"
	arr["ITALIAN",152]="Vuoi pulire/ottimizzare il file di Handshake catturato in questa sessione? ${normal_color}${visual_choice}"
	arr["POLISH",152]="Czy chcesz wyczyścić/zoptymalizować plik Handshake przechwycony w tej sesji? ${normal_color}${visual_choice}"
	arr["GERMAN",152]="Möchten Sie die Handshake-Datei bereinigen/optimieren? ${normal_color}${visual_choice}"
	arr["TURKISH",152]="Handshake ele geçirilmiş dosyayı bu oturum sırasında temizlemek/optimize etmek ister misiniz? ${normal_color}${visual_choice}"

	arr["ENGLISH",153]="File cleaned/optimized successfully"
	arr["SPANISH",153]="Fichero limpiado/optimizado con éxito"
	arr["FRENCH",153]="Fichier lavé/optimisé avec succès"
	arr["CATALAN",153]="Fitxer netejat/optimitzat amb èxit"
	arr["PORTUGUESE",153]="Arquivo limpo/otimizado com sucesso"
	arr["RUSSIAN",153]="Файл успешно очищен/оптимизирован"
	arr["GREEK",153]="Το αρχείο καθαρίστηκε/βελτιστοποιήθηκε επιτυχώς"
	arr["ITALIAN",153]="File pulito/ottimizzato con successo"
	arr["POLISH",153]="Plik pomyślnie wyczyszczony/zoptymalizowany"
	arr["GERMAN",153]="Datei erfolgreich bereinigt/optimiert"
	arr["TURKISH",153]="Dosya başarıyla temizlendi/optimize edildi"

	arr["ENGLISH",154]="Set path to file:"
	arr["SPANISH",154]="Introduce la ruta al fichero:"
	arr["FRENCH",154]="Entrez le chemin vers le fichier:"
	arr["CATALAN",154]="Introdueix la ruta al fitxer:"
	arr["PORTUGUESE",154]="Digite o caminho do arquivo:"
	arr["RUSSIAN",154]="Установить путь до файла:"
	arr["GREEK",154]="Θέστε μονοπάτι για το αρχείο:"
	arr["ITALIAN",154]="Introdurre il percorso del file:"
	arr["POLISH",154]="Wprowadź ścieżkę do pliku:"
	arr["GERMAN",154]="Geben Sie den Pfad zur Datei ein:"
	arr["TURKISH",154]="Path dizini girin:"

	arr["ENGLISH",155]="The directory exists but you didn't specify filename. It will be autogenerated [${normal_color}${suggested_filename}${yellow_color}]"
	arr["SPANISH",155]="El directorio existe pero no se especificó nombre de fichero. Se autogenerará [${normal_color}${suggested_filename}${yellow_color}]"
	arr["FRENCH",155]="Le dossier existe mais sans qu'aucun nom pour le fichier soit précisé. Il sera donc appelé [${normal_color}${suggested_filename}${yellow_color}]"
	arr["CATALAN",155]="El directori existeix però no s'ha especificat nom de fitxer. Es autogenerará [${normal_color}${suggested_filename}${yellow_color}]"
	arr["PORTUGUESE",155]="O diretório existe, mas o nome do arquivo não foi especificado. Será gerado automaticamente [${normal_color}${suggested_filename}${yellow_color}]"
	arr["RUSSIAN",155]="Директория существует, но вы не указали имя файла. Оно будет сгенерировано автоматически [${normal_color}${suggested_filename}${yellow_color}]"
	arr["GREEK",155]="Ο κατάλογος υπάρχει αλλά δεν έχετε προσδιορίσει το όνομα του αρχείου [${normal_color}${suggested_filename}${yellow_color}]"
	arr["ITALIAN",155]="La directory esiste, peró non è stato specificato il nome del file. Sarà generato automaticamente [${normal_color}${suggested_filename}${yellow_color}]"
	arr["POLISH",155]="Katalog istnieje, ale nie określono nazwy pliku. Zostanie ona wygenerowana automatycznie [${normal_color}${suggested_filename}${yellow_color}]"
	arr["GERMAN",155]="Das Verzeichnis existiert, aber es wurde kein Dateiname angegeben. Es wird sich selbst erzeugen [${normal_color}${suggested_filename}${yellow_color}]"
	arr["TURKISH",155]="Dizin var ancak dosya adı belirtmediniz. O otomatik üretilecek [${normal_color}${suggested_filename}${yellow_color}]"

	arr["ENGLISH",156]="Directory not exists"
	arr["SPANISH",156]="El directorio no existe"
	arr["FRENCH",156]="Le dossier n'existe pas"
	arr["CATALAN",156]="El directori no existeix"
	arr["PORTUGUESE",156]="O diretório não existe"
	arr["RUSSIAN",156]="Директория не существует"
	arr["GREEK",156]="Ο κατάλογος δεν υπάρχει"
	arr["ITALIAN",156]="La directory non esiste"
	arr["POLISH",156]="Katalog nie istnieje"
	arr["GERMAN",156]="Das Verzeichnis existiert nicht"
	arr["TURKISH",156]="Dizn bulunamadı"

	arr["ENGLISH",157]="The path exists but you don't have write permissions"
	arr["SPANISH",157]="La ruta existe pero no tienes permisos de escritura"
	arr["FRENCH",157]="Le chemin existe mais vous ne disposez pas des permis d'écriture"
	arr["CATALAN",157]="La ruta existeix, però no tens permisos d'escriptura"
	arr["PORTUGUESE",157]="O diretório existe, mas você não tem permissões de gravação"
	arr["RUSSIAN",157]="Путь существует, но у вас нет прав на запись"
	arr["GREEK",157]="Το μονοπάτι υπάρχει, αλλά δεν έχετε δικαιώματα εγγραφής"
	arr["ITALIAN",157]="Il percorso esiste, ma non si dispone dei permessi di scrittura"
	arr["POLISH",157]="Ścieżka istnieje, ale nie masz uprawnień do zapisu"
	arr["GERMAN",157]="Die Route existiert, Sie haben jedoch keine Schreibberechtigung"
	arr["TURKISH",157]="Path bulundu ama sizin yazma hakkınız yok"

	arr["ENGLISH",158]="The path is valid and you have write permissions. Script can continue..."
	arr["SPANISH",158]="La ruta es válida y tienes permisos de escritura. El script puede continuar..."
	arr["FRENCH",158]="Le chemin est valide et vous disposez des privilèges nécessaires pour l'écriture. Le script peut continuer..."
	arr["CATALAN",158]="La ruta és vàlida i tens permisos d'escriptura. El script pot continuar..."
	arr["PORTUGUESE",158]="O diretório é válido e você tem permissões de gravação. O script pode continuar..."
	arr["RUSSIAN",158]="Путь существует и у вас есть права на запись. Скрипт может продолжить..."
	arr["GREEK",158]="Το μονοπάτι είναι έγκυρο και έχετε δικαιώματα εγγραφής. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",158]="Il percorso è valido e si dispone di permessi di scrittura. Lo script può continuare..."
	arr["POLISH",158]="Ścieżka jest poprawna i masz uprawnienia do zapisu. Skrypt może kontynuować..."
	arr["GERMAN",158]="Die Route ist gültig und Sie haben Schreibberechtigung. Das Skript kann fortfahren..."
	arr["TURKISH",158]="Path doğrulandı ve yazma hakkınız var. Yazılım devam edebilir..."

	arr["ENGLISH",159]="The file doesn't need to be cleaned/optimized"
	arr["SPANISH",159]="El fichero no necesita ser limpiado/optimizado"
	arr["FRENCH",159]="Le fichier n'a pas besoin d'être nettoyé/optimisé"
	arr["CATALAN",159]="El fitxer no necessita ser netejat/optimitzat"
	arr["PORTUGUESE",159]="O arquivo não precisa ser limpo/otimizado"
	arr["RUSSIAN",159]="Файлу не требуется очистка/оптимизация"
	arr["GREEK",159]="Το αρχείο δεν χρειάζεται να καθαριστεί/βελτιστοποιηθεί"
	arr["ITALIAN",159]="Il file non ha bisogno di essere pulito/ottimizzato"
	arr["POLISH",159]="Nie ma potrzeby wyczyszczenia/zoptymalizowania tego pliku"
	arr["GERMAN",159]="Die Datei braucht nicht gereinigt/optimiert werden"
	arr["TURKISH",159]="Dosyanın temizlenmeye/optimize edilmeye ihtiyacı yok"

	arr["ENGLISH",160]="No tasks to perform on exit"
	arr["SPANISH",160]="No hay que realizar ninguna tarea a la salida"
	arr["FRENCH",160]="Aucune opération n'est planifiée pour l’arrêt du script"
	arr["CATALAN",160]="No cal fer cap tasca a la sortida"
	arr["PORTUGUESE",160]="Não há tarefas a serem executadas na saída"
	arr["RUSSIAN",160]="Нет задач для выполнения перед выходом"
	arr["GREEK",160]="Δεν απομένει κάποιο task για να εκτελεστεί στην έξοδο"
	arr["ITALIAN",160]="Non bisogna fare niente dopo l'uscita dello script"
	arr["POLISH",160]="Plik nie musi być wczyszczony/zoptymalizowany"
	arr["GERMAN",160]="Es gibt keine Aufgabe beim Verlassen"
	arr["TURKISH",160]="Çıkışta gerçekleştirilecek görev yok"

	arr["ENGLISH",161]="File doesn't exist"
	arr["SPANISH",161]="El fichero no existe"
	arr["FRENCH",161]="Le fichier n' existe pas"
	arr["CATALAN",161]="El fitxer no existeix"
	arr["PORTUGUESE",161]="O arquivo não existe"
	arr["RUSSIAN",161]="Файл не существует"
	arr["GREEK",161]="Το αρχείο δεν υπάρχει"
	arr["ITALIAN",161]="Il file non esiste"
	arr["POLISH",161]="Plik nie istnieje"
	arr["GERMAN",161]="Die Datei existiert nicht"
	arr["TURKISH",161]="Dosya bulunamadı"

	arr["ENGLISH",162]="Congratulations!!"
	arr["SPANISH",162]="Enhorabuena!!"
	arr["FRENCH",162]="Félicitations!!"
	arr["CATALAN",162]="Enhorabona!!"
	arr["PORTUGUESE",162]="Parabéns!!"
	arr["RUSSIAN",162]="Поздравления!!"
	arr["GREEK",162]="Συγχαρητήρια!!"
	arr["ITALIAN",162]="Congratulazioni!!"
	arr["POLISH",162]="Gratulacje!!"
	arr["GERMAN",162]="Herzlichen Glückwunsch!!"
	arr["TURKISH",162]="Tebrikler!!"

	arr["ENGLISH",163]="When airgeddon requests you to enter a path to a file either to use a dictionary, a Handshake or anything else, did you know that you can drag and drop the file over the airgeddon window? In this way you don't have to type the path manually"
	arr["SPANISH",163]="Cuando airgeddon solicita que introduzcas una ruta a un fichero ya sea para utilizar un diccionario, un Handshake o cualquier otra cosa, ¿sabías que puedes arrastrar y soltar el fichero sobre la ventana de airgeddon? Así no tendrás que escribir la ruta manualmente"
	arr["FRENCH",163]="Quand airgeddon demande d'entrer un chemin d'accès vers un fichier soit pour utiliser un dictionnaire, un Handshake ou autre chose, saviez-vous que vous pouvez faire glisser le fichier sur la fenêtre airgeddon? Donc vous n'avez pas à taper la route manuellement"
	arr["CATALAN",163]="Quan airgeddon sol·licita que introdueixis una ruta a un fitxer ja sigui per utilitzar un diccionari, un Handshake o qualsevol altra cosa, ¿saps que pots arrossegar i deixar anar el fitxer sobre la finestra de airgeddon? Així no hauràs d'escriure la ruta manualment"
	arr["PORTUGUESE",163]="Quando a airgeddon solicita que você insira o caminho de: um dicionário, um Handshake ou qualquer outra coisa, você sabia que pode arrastar o arquivo para janela do airgeddon? Assim você não precisa digitar o caminho manualmente"
	arr["RUSSIAN",163]="Когда airgeddon просит вас ввести путь до файла, будь то словарь, рукопожатие или что-то ещё, знаете ли вы, что можно захватить этот файл мышкой, перетащить и бросить этот файл прямо в окно airgeddon? Таким образом вам не придётся вводить путь до файла вручную"
	arr["GREEK",163]="Γνωρίζατε ότι μπορείτε να εισάγετε μονοπάτι για κάποιο αρχείο είτε για να χρησιμοποιήσετε λεξικό, αρχείο Χειραψίας ή οτιδήποτε άλλο, κάνοντας Drag & Drop το αρχείο αυτό στο παράθυρο του airgeddon; Με αυτόν τον τρόπο δεν χρειάζεται να πλεικτρολογείτε το μονοπάτι χειροκίνητα"
	arr["ITALIAN",163]="Quando airgeddon chiede di introdurre il percorso di un file per utilizzare un dizionario, un Handshake o qualsiasi altra cosa, sapevi che puoi trascinare e rilasciare il file sulla finestra di airgeddon? Cosí non dovrai digitare manualmente il percorso"
	arr["POLISH",163]="Wiesz, że kiedy airgeddon poprosi Cię o podanie ścieżki do pliku aby użyć słownika, pliku Handshake lub cokolwiek innego, możesz przeciągnąć i upuścić plik przez okno airgeddon? Nie musisz wpisywać scieżki ręcznie"
	arr["GERMAN",163]="Wenn airgeddon Sie auffordert, einen Dateipfad einzugeben, um ein Wörterbuch, einen Handshake oder etwas anderes zu verwenden, wussten Sie, dass Sie die Datei per Drag & Drop auf das airgeddon-Fenster ziehen können? Sie müssen die Route nicht manuell schreiben"
	arr["TURKISH",163]="airgeddon, bir sözlük, bir Handshake veya başka bir şey kullanmak için dosyaya bir yol girmenizi istediğinde, dosyayı airgeddon penceresinin üzerine sürükleyip bırakabileceğinizi biliyor muydunuz? Bu şekilde yolu elle yazmanız gerekmez"

	arr["ENGLISH",164]="Cleaning temp files"
	arr["SPANISH",164]="Limpiando archivos temporales"
	arr["FRENCH",164]="Effacement des fichiers temporaires"
	arr["CATALAN",164]="Netejant arxius temporals"
	arr["PORTUGUESE",164]="Limpando arquivos temporários"
	arr["RUSSIAN",164]="Очистка временных файлов"
	arr["GREEK",164]="Γίνεται καθαρισμός προσωρινών αρχείων"
	arr["ITALIAN",164]="Pulendo i file temporanei"
	arr["POLISH",164]="Usuwanie plików tymczasowych"
	arr["GERMAN",164]="Temporäre Dateien bereinigen"
	arr["TURKISH",164]="Temp dosyaları temizleniyor"

	arr["ENGLISH",165]="Checking if cleaning/restoring tasks are needed..."
	arr["SPANISH",165]="Comprobando si hay que realizar tareas de limpieza/restauración..."
	arr["FRENCH",165]="Vérification de la nécessité d'effectuer ou pas des opérations de nettoyage/restauration..."
	arr["CATALAN",165]="Comprovant si cal realitzar tasques de neteja/restauració..."
	arr["PORTUGUESE",165]="Verificando se é necessário executar tarefas de limpeza/restauração..."
	arr["RUSSIAN",165]="Проверка, нужны ли задачи по очистке/восстановлению..."
	arr["GREEK",165]="Γίνεται έλεγχος αν χρειάζονται tasks καθαρισμού/αποκατάστασης..."
	arr["ITALIAN",165]="Verificando se è necessarrio eseguire la pulizia/restauro..."
	arr["POLISH",165]="Sprawdzenie czy wymagane jest czyszczenie/przywrócenie..."
	arr["GERMAN",165]="Überprüfung, ob Reinigungs/Restaurierungsarbeiten durchgeführt werden müssen..."
	arr["TURKISH",165]="Temizlik/geri yükleme görevlerinin gerekli olup olmadığı denetleniyor..."

	arr["ENGLISH",166]="Do you want to preserve monitor mode for your card on exit? ${normal_color}${visual_choice}"
	arr["SPANISH",166]="¿Deseas conservar el modo monitor de tu interfaz al salir? ${normal_color}${visual_choice}"
	arr["FRENCH",166]="Voulez-vous laisser votre interface en mode moniteur après l'arrêt du script? ${normal_color}${visual_choice}"
	arr["CATALAN",166]="¿Vols conservar el mode monitor de la teva interfície en sortir? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",166]="Quer manter sua interface em modo monitor ao sair do script? ${normal_color}${visual_choice}"
	arr["RUSSIAN",166]="Вы хотите сохранить режим монитора вашей карты при выходе? ${normal_color}${visual_choice}"
	arr["GREEK",166]="Θέλετε να παραμείνει η κάρτα σε κατάσταση παρακολούθησης κατά την έξοδο; ${normal_color}${visual_choice}"
	arr["ITALIAN",166]="Vuoi mantenere l'interfaccia in modalità monitor dopo essere uscito? ${normal_color}${visual_choice}"
	arr["POLISH",166]="Czy chcesz zachować tryb monitorowania teojej karty sieciowej po wyjsciu? ${normal_color}${visual_choice}"
	arr["GERMAN",166]="Möchten Sie den monitor-Modus Ihrer Interface beim Beenden beibehalten? ${normal_color}${visual_choice}"
	arr["TURKISH",166]="Çıkışta kartınızın monitör modunu korumak istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",167]="Setting your interface in managed mode"
	arr["SPANISH",167]="Poniendo interfaz en modo managed"
	arr["FRENCH",167]="L'interface est en train de passer en mode managed"
	arr["CATALAN",167]="Configurant la interfície en mode managed"
	arr["PORTUGUESE",167]="Colocando interface de modo managed"
	arr["RUSSIAN",167]="Перевод вашего интерфейса в управляемый режим"
	arr["GREEK",167]="Η διεπαφή μπαίνει σε ετερόκλητη κατάσταση"
	arr["ITALIAN",167]="Mettendo l'interfaccia in modalità managed"
	arr["POLISH",167]="Uruchamianie w trybie zarządzania"
	arr["GERMAN",167]="Interface wird im managed-Modus eingestellt"
	arr["TURKISH",167]="Arayüzünüzün yönetici modu açılıyor"

	arr["ENGLISH",168]="Launching previously killed processes"
	arr["SPANISH",168]="Arrancando procesos cerrados anteriormente"
	arr["FRENCH",168]="Lancement des processus précédemment tués"
	arr["CATALAN",168]="Llançant processos tancats anteriorment"
	arr["PORTUGUESE",168]="Processos de inicialização previamente fechados"
	arr["RUSSIAN",168]="Запуск ранее убитых процессов"
	arr["GREEK",168]="Γίνεται έναρξη των προηγούμενων σταματημένων διεργασιών"
	arr["ITALIAN",168]="Lanciando i processi chiusi precedentemente"
	arr["POLISH",168]="Uruchamianie wcześniej zakończonych procesów"
	arr["GERMAN",168]="Vorab geschlossene Prozesse starten"
	arr["TURKISH",168]="Daha önce sonlandırılan görevler başlatılıyor"

	arr["ENGLISH",169]="6.  Offline WPA/WPA2 decrypt menu"
	arr["SPANISH",169]="6.  Menú de desencriptado WPA/WPA2 offline"
	arr["FRENCH",169]="6.  Menu crack WPA/WPA2 offline"
	arr["CATALAN",169]="6.  Menú per desxifrar WPA/WPA2 offline"
	arr["PORTUGUESE",169]="6.  Menu de descriptografia WPA/WPA2 offline"
	arr["RUSSIAN",169]="6.  Меню офлайн расшифровки WPA/WPA2"
	arr["GREEK",169]="6.  Μενού offline αποκρυπτογράφησης WPA/WPA2"
	arr["ITALIAN",169]="6.  Menù per decifrare WPA/WPA2 offline"
	arr["POLISH",169]="6.  Menu deszyfrowania WPA/WPA2 offline"
	arr["GERMAN",169]="6.  Offline WPA/WPA2-Entschlüsselungsmenü"
	arr["TURKISH",169]="6.  Çevrimdışı WPA/WPA2 decrypt menüsü"

	arr["ENGLISH",170]="Offline WPA/WPA2 decrypt menu"
	arr["SPANISH",170]="Menú de desencriptado WPA/WPA2 offline"
	arr["FRENCH",170]="Menu crack WPA/WPA2 offline"
	arr["CATALAN",170]="Menú per desxifrar WPA/WPA2 offline"
	arr["PORTUGUESE",170]="Menu de descriptografia WPA/WPA2 offline"
	arr["RUSSIAN",170]="Меню офлайн расшифровки WPA/WPA2"
	arr["GREEK",170]="Μενού offline αποκρυπτογράφησης WPA/WPA2"
	arr["ITALIAN",170]="Menù per decifrare WPA/WPA2 offline"
	arr["POLISH",170]="Menu deszyfrowania WPA/WPA2 offline"
	arr["GERMAN",170]="Offline WPA/WPA2-Entschlüsselungsmenü"
	arr["TURKISH",170]="Çevrimdışı WPA/WPA2 decrypt menüsü"

	arr["ENGLISH",171]="The key decrypt process is performed offline on a previously captured file"
	arr["SPANISH",171]="El proceso de desencriptado de las claves se realiza de manera offline sobre un fichero capturado previamente"
	arr["FRENCH",171]="Le crack de la clef s'effectue offline en utilisant le fichier capturé antérieurement"
	arr["CATALAN",171]="El procés de desencriptació de les claus es realitza de manera offline sobre un fitxer capturat prèviament"
	arr["PORTUGUESE",171]="O processo de descriptografia é realizada de modo offline em um arquivo previamente capturado"
	arr["RUSSIAN",171]="Процесс расшифровки ключа выполняется офлайн на ранее захваченном файле"
	arr["GREEK",171]="Η διεργασία αποκρυπτογράφησης κλειδιού έχει εκτελεστεί offline σε προηγούμενο αρχείο καταγραφής"
	arr["ITALIAN",171]="Il processo di decodifica della chiave viene eseguito offline su un file catturato precedentemente"
	arr["POLISH",171]="Proces deszyfrowania klucza odbywa się offline na poprzednio przechwyconym pliku"
	arr["GERMAN",171]="Die Entschlüsselung erfolgt offline über eine zuvor erfasste Datei"
	arr["TURKISH",171]="Anahtar şifre çözme işlemi daha önce yakalanan bir dosyada çevrimdışı gerçekleştirilir"

	arr["ENGLISH",172]="1.  (aircrack) Dictionary attack against capture file"
	arr["SPANISH",172]="1.  (aircrack) Ataque de diccionario sobre fichero de captura"
	arr["FRENCH",172]="1.  (aircrack) Attaque de dictionnaire en utilisant le fichier de capture"
	arr["CATALAN",172]="1.  (aircrack) Atac de diccionari sobre fitxer de captura"
	arr["PORTUGUESE",172]="1.  (aircrack) Ataque de dicionário em um arquivo de captura"
	arr["RUSSIAN",172]="1.  (aircrack) Атака по словарю в отношении захваченного файла"
	arr["GREEK",172]="1.  (aircrack) Επίθεση με χρήση λεξικού σε αρχείο καταγραφής"
	arr["ITALIAN",172]="1.  (aircrack) Attacco dizionario sul file di cattura"
	arr["POLISH",172]="1.  (aircrack) Atak słownikowy na plik przechwytywania"
	arr["GERMAN",172]="1.  (aircrack) Wörterbuchangriff auf der aufgenommene Datei"
	arr["TURKISH",172]="1.  (aircrack) Yakalanan dosyaya Dictionary saldırısı"

	arr["ENGLISH",173]="Selected capture file: ${pink_color}${enteredpath}${normal_color}"
	arr["SPANISH",173]="Fichero de captura seleccionado: ${pink_color}${enteredpath}${normal_color}"
	arr["FRENCH",173]="Fichier de capture sélectionné: ${pink_color}${enteredpath}${normal_color}"
	arr["CATALAN",173]="Fitxer de captura seleccionat: ${pink_color}${enteredpath}${normal_color}"
	arr["PORTUGUESE",173]="Arquivo de captura selecionado: ${pink_color}${enteredpath}${normal_color}"
	arr["RUSSIAN",173]="Выбранный файл захвата: ${pink_color}${enteredpath}${normal_color}"
	arr["GREEK",173]="Επιλεγμένο αρχείο καταγραφής: ${pink_color}${enteredpath}${normal_color}"
	arr["ITALIAN",173]="File di cattura selezionato: ${pink_color}${enteredpath}${normal_color}"
	arr["POLISH",173]="Wybrany plik przechwytywania: ${pink_color}${enteredpath}${normal_color}"
	arr["GERMAN",173]="Ausgewählte Capture-Datei: ${pink_color}${enteredpath}${normal_color}"
	arr["TURKISH",173]="Seçilen yakalama dosyası: ${pink_color}${enteredpath}${normal_color}"

	arr["ENGLISH",174]="It seems you have an unsupported by airgeddon bettercap version. The last bettercap supported version is ${maximum_bettercap_supported_version}. If you want to get this attack working you should perform a downgrade of the package. For more information, see the Bettercap section of the Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["SPANISH",174]="Parece que tienes una versión de bettercap no soportada por airgeddon. La última versión soportada de bettercap es la ${maximum_bettercap_supported_version}. Si quieres realizar este ataque deberías hacer un downgrade del paquete. Para más información consulta la sección Bettercap del Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["FRENCH",174]="Il semble que vous avez une version non supportée de bettercap par airgeddon. La dernière version prise en charge par bettercap est ${maximum_bettercap_supported_version}. Si vous voulez que cette attaque fonctionne, vous devez effectuer une downgrade du paquet. Pour plus d'informations, consultez la section Bettercap de notre Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["CATALAN",174]="Sembla que teniu una versió de bettercap no suportada per airgeddon. L'última versió suportada de bettercap és ${maximum_bettercap_supported_version}. Si voleu que aquest atac funcioni, hauríeu de realitzar un downgrade del paquet. Per a més informació consulta la secció Bettercap del Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["PORTUGUESE",174]="Sua versão do bettercap não é suportada pelo airgeddon. A última versão suportada é ${maximum_bettercap_supported_version}. Se você quiser que este ataque funcione, você deve fazer um downgrade. Para mais informações consulte a seção Bettercap Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["RUSSIAN",174]="Кажется, ваша версия bettercap не поддерживается airgeddon. Последняя поддерживаемая версия bettercap ${maximum_bettercap_supported_version}. Если вы хотите, чтобы эта атака работала, вы должны понизить версию этого пакета. Для получения дополнительной информации см. раздел Bettercap в Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["GREEK",174]="Φαίνεται πως η έκδοση του bettercap δεν υποστηρίζεται από το airgeddon. Η παλαιότερη έκδοση του bettercap που υποστηρίζεται από το  airgeddon είναι η ${maximum_bettercap_supported_version}. Αν θέλετε αυτή η επίθεση να επιτύχει, θα πρέπει να κάνετε υποβάθμιση (downgrade) του πακέτου. Για περισσότερες πληροφορίες, ανατρέξτε στην ενότητα Bettercap του Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["ITALIAN",174]="Sembra che tu abbia una versione di bettercap non supportata da airgeddon. L'ultima versione di bettercap supportata è ${maximum_bettercap_supported_version}. Se vuoi far funzionare questo attacco devi eseguire un downgrade del pacchetto. Per ulteriori informazioni consultare la sezione Bettercap della nostra Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["POLISH",174]="Wygląda na to, że masz nieobsługiwaną przez airgeddon wersję bettercap. Ostatnia obsługiwana wersja bettercap to ${maximum_bettercap_supported_version}. Jeśli chcesz, aby ten atak działał, musisz obniżyć wersje. Aby uzyskać więcej informacji, zobacz sekcję Bettercap Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["GERMAN",174]="Anscheinend ist die benutzte bettercap version von airgeddon nicht unterstützt. Die letzte unterstützte bettercap Version ist ${maximum_bettercap_supported_version}. Wenn Sie diesen Angriff beuntzen wollen, sollten Sie ein Downgrade des bettercap-Pakets durchführen. Weitere Informationen finden Sie im Abschnitt Bettercap des Wiki: ${normal_color}${urlgithub_wiki}/Bettercap Tips"
	arr["TURKISH",174]="Airgeddon bettercap sürümününüz desteklenmiyor gibi görünüyor. Son çıkan en iyi desteklenen sürüm ${maximum_bettercap_supported_version}. Bu saldırıyı gerçekleştirmek istiyorsanız, paketin bir sürümünün düşürülmesi gerekir. Daha fazla bilgi için, Wiki'nin Bettercap bölümüne bakın: ${normal_color}${urlgithub_wiki}/Bettercap Tips"

	arr["ENGLISH",175]="2.  (aircrack + crunch) Bruteforce attack against capture file"
	arr["SPANISH",175]="2.  (aircrack + crunch) Ataque de fuerza bruta sobre fichero de captura"
	arr["FRENCH",175]="2.  (aircrack + crunch) Attaque de force brute en utilisant le fichier de capture"
	arr["CATALAN",175]="2.  (aircrack + crunch) Atac de força bruta sobre fitxer de captura"
	arr["PORTUGUESE",175]="2.  (aircrack + crunch) Ataque de força bruta em um arquivo de captura"
	arr["RUSSIAN",175]="2.  (aircrack + crunch) Атака методом грубой силы в отношении захваченного файла"
	arr["GREEK",175]="2.  (aircrack + crunch) Επίθεση ωμής βίας σε αρχείο καταγραφής"
	arr["ITALIAN",175]="2.  (aircrack + crunch) Attacco di forza bruta sul file di cattura"
	arr["POLISH",175]="2.  (aircrack + crunch) Atak brute force na pliku przechwytywania"
	arr["GERMAN",175]="2.  (aircrack + crunch) Brute-Force-Angriff auf die Capture-Datei"
	arr["TURKISH",175]="2.  (aircrack + crunch) Yakalama dosyasına karşı bruteforce saldırısı"

	arr["ENGLISH",176]="aircrack CPU, non GPU attacks"
	arr["SPANISH",176]="ataques aircrack CPU, no GPU"
	arr["FRENCH",176]="attaques aircrack CPU, pas GPU"
	arr["CATALAN",176]="atacs aircrack CPU, no GPU"
	arr["PORTUGUESE",176]="ataques aircrack CPU, não GPU"
	arr["RUSSIAN",176]="aircrack атаки с использованием процессора, а не видеокарты"
	arr["GREEK",176]="επιθέσεις aircrack CPU, όχι GPU"
	arr["ITALIAN",176]="attacchi aircrack CPU, non GPU"
	arr["POLISH",176]="ataki CPU, nie GPU"
	arr["GERMAN",176]="CPU aircrack Angriffe, keine GPU"
	arr["TURKISH",176]="aircrack CPU, GPU olmayan saldırılar"

	arr["ENGLISH",177]="Selected captured file: ${pink_color}None${normal_color}"
	arr["SPANISH",177]="Fichero capturado seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",177]="Fichier de capture sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",177]="Fitxer capturat seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",177]="Arquivo de captura selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",177]="Выбран файл захвата: ${pink_color}Нет${normal_color}"
	arr["GREEK",177]="Επιλεγμένο αρχείο καταγραφής: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",177]="File catturato selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",177]="Wybrany przechwycony plik: ${pink_color}Brak${normal_color}"
	arr["GERMAN",177]="Ausgewählte erfasste Datei: ${pink_color}Keine${normal_color}"
	arr["TURKISH",177]="Seçilen yakalanmış dosya: ${pink_color}None${normal_color}"

	arr["ENGLISH",178]="To decrypt the key of a WPA/WPA2 network, the capture file must contain a Handshake"
	arr["SPANISH",178]="Para desencriptar la clave de una red WPA/WPA2, el fichero de captura debe contener un Handshake"
	arr["FRENCH",178]="Pour cracker la clé d'un réseau WPA/WPA2 le fichier de capture doit contenir un Handshake"
	arr["CATALAN",178]="Per desencriptar la clau d'una xarxa WPA/WPA2 el fitxer de captura ha de contenir un Handshake"
	arr["PORTUGUESE",178]="Para descriptografar a senha de uma rede WPA/WPA2, o arquivo de captura deve conter um Handshake"
	arr["RUSSIAN",178]="Для расшифровки ключа сетей WPA/WPA2, файл захвата должен содержать четырёхэтапное рукопожатие"
	arr["GREEK",178]="Για να αποκρυπτογραφήσετε το κλειδί ενός WPA/WPA2 δικτύου, το αρχείο καταγραφής πρέπει να περιέχει μία Χειραψία"
	arr["ITALIAN",178]="Per decriptare la chiave per una rete WPA/WPA2, il file di cattura deve contenere un Handshake"
	arr["POLISH",178]="Aby odszyfrować klucz sieci WPA/WPA2, plik przechwytywania musi zawierać Handshake"
	arr["GERMAN",178]="Um den Schlüssel eines WPA/WPA2-Netzwerks zu entschlüsseln, muss die Erfassungsdatei einen Handshake enthalten"
	arr["TURKISH",178]="WPA/WPA2 ağının şifresini çözmek için, yakalama dosyası bir Handshake içermelidir"

	arr["ENGLISH",179]="Decrypting by bruteforce, it could pass hours, days, weeks or even months to take it depending on the complexity of the password and your processing speed"
	arr["SPANISH",179]="Desencriptando por fuerza bruta, podrían pasar horas, días, semanas o incluso meses hasta conseguirlo dependiendo de la complejidad de la contraseña y de tu velocidad de proceso"
	arr["FRENCH",179]="Le crack de la clef par attaque de type brute force peut prendre des heures, des jours, des semaines ou même des mois en fonction de la complexité de la clef et de la puissance de calcul de votre matériel"
	arr["CATALAN",179]="Desencriptant per força bruta, podrien passar hores, dies, setmanes o fins i tot mesos fins a aconseguir-ho depenent de la complexitat de la contrasenya i de la teva velocitat de procés"
	arr["PORTUGUESE",179]="Descriptografar com força bruta pode levar horas, dias, semanas ou mesmo meses dependendo da complexidade da senha e velocidade de processamento"
	arr["RUSSIAN",179]="Расшифровка полным перебором может занять часы, дни, недели или даже месяцы в зависимости от сложности пароля и вашей скорости обработки"
	arr["GREEK",179]="Αποκρυπτογραφώντας με χρήση ωμής βίας, μπορεί να περάσουν ώρες, μέρες, εβδομάδες ή ακόμη και μήνες για να το αποκτήσετε έχοντας υπόψιν την πολυπλοκότητα του κωδικού πρόσβασης και την ταχύτητα του επεξεργαστή"
	arr["ITALIAN",179]="Decifrando con forza bruta, potrebbero trascorrere ore, giorni, settimane o addirittura mesi per ottenere la password a seconda della sua complessità e della velocità del processore"
	arr["POLISH",179]="Odszyfrowywanie przez brut force może trwać godziny, dni, tygodnie lub nawet miesiące w zależności od złożoności hasła i szybkości przetwarzania"
	arr["GERMAN",179]="Die Entschlüsselung mit roher Gewalt könnte Stunden, Tage, Wochen oder sogar Monate in Anspruch nehmen, abhängig von der Komplexität des Passworts und der Geschwindigkeit des Prozesses"
	arr["TURKISH",179]="Bruteforce tarafından şifresini çözmek, şifrenin karmaşıklığına ve işlem hızınıza bağlı olarak bunu almak için saatler, günler, haftalar hatta aylar geçirebilir"

	arr["ENGLISH",180]="Enter the path of a dictionary file:"
	arr["SPANISH",180]="Introduce la ruta de un fichero de diccionario:"
	arr["FRENCH",180]="Saisissez un chemin vers un dictionnaire d'attaque:"
	arr["CATALAN",180]="Introdueix la ruta d'un fitxer de diccionari:"
	arr["PORTUGUESE",180]="Digite o caminho de um arquivo de dicionário:"
	arr["RUSSIAN",180]="Введите путь до файла словаря:"
	arr["GREEK",180]="Εισάγετε το μονοπάτι ενός λεξικού:"
	arr["ITALIAN",180]="Immettere il percorso di un file dizionario:"
	arr["POLISH",180]="Wprowadź ścieżkę pliku słownika:"
	arr["GERMAN",180]="Geben Sie den Pfad einer Wörterbuchdatei ein:"
	arr["TURKISH",180]="Dosya yolunu girin:"

	arr["ENGLISH",181]="The path to the dictionary file is valid. Script can continue..."
	arr["SPANISH",181]="La ruta al fichero de diccionario es válida. El script puede continuar..."
	arr["FRENCH",181]="Le chemin vers le fichier dictionnaire est valide. Le script peut continuer..."
	arr["CATALAN",181]="La ruta cap al fitxer de diccionari és vàlida. El script pot continuar..."
	arr["PORTUGUESE",181]="O caminho para o arquivo de dicionário é válido. O script pode continuar..."
	arr["RUSSIAN",181]="Путь до файла словаря правильный. Скрипт может продолжить..."
	arr["GREEK",181]="Το μονοπάτι για το λεξικό είναι έγκυρο. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",181]="Il percorso del file dizionario è valido. Lo script può continuare..."
	arr["POLISH",181]="Ścieżka do pliku słownika jest prawidłowa. Skrypt może kontynuować..."
	arr["GERMAN",181]="Der Pfad zur Wörterbuchdatei ist gültig. Das Skript kann fortfahren..."
	arr["TURKISH",181]="Dosya yolu geçerli. Yazılım devam edebilir..."

	arr["ENGLISH",182]="Selected dictionary file: ${pink_color}${DICTIONARY}${normal_color}"
	arr["SPANISH",182]="Fichero de diccionario seleccionado: ${pink_color}${DICTIONARY}${normal_color}"
	arr["FRENCH",182]="Fichier dictionnaire sélectionné: ${pink_color}${DICTIONARY}${normal_color}"
	arr["CATALAN",182]="Fitxer de diccionari seleccionat: ${pink_color}${DICTIONARY}${normal_color}"
	arr["PORTUGUESE",182]="Dicionário selecionado: ${pink_color}${DICTIONARY}${normal_color}"
	arr["RUSSIAN",182]="Выбранный файл словаря: ${pink_color}${DICTIONARY}${normal_color}"
	arr["GREEK",182]="Επιλεγμένο λεξικό: ${pink_color}${DICTIONARY}${normal_color}"
	arr["ITALIAN",182]="File di dizionario selezionato: ${pink_color}${DICTIONARY}${normal_color}"
	arr["POLISH",182]="Wybrany plik słownika: ${pink_color}${DICTIONARY}${normal_color}"
	arr["GERMAN",182]="Ausgewählte Wörterbuchdatei: ${pink_color}${DICTIONARY}${normal_color}"
	arr["TURKISH",182]="Seçilen sözlük dosyası: ${pink_color}${DICTIONARY}${normal_color}"

	arr["ENGLISH",183]="You already have selected a dictionary file during this session [${normal_color}${DICTIONARY}${blue_color}]"
	arr["SPANISH",183]="Ya tienes seleccionado un fichero de diccionario en esta sesión [${normal_color}${DICTIONARY}${blue_color}]"
	arr["FRENCH",183]="Vous avez déjà sélectionné un fichier dictionnaire pour cette session ${normal_color}${DICTIONARY}${blue_color}]"
	arr["CATALAN",183]="Ja tens seleccionat un fitxer de diccionari en aquesta sessió [${normal_color}${DICTIONARY}${blue_color}]"
	arr["PORTUGUESE",183]="Você selecionou um arquivo de dicionário nesta sessão [${normal_color}${DICTIONARY}${blue_color}]"
	arr["RUSSIAN",183]="Во время этой сессии вы выбрали файл словаря [${normal_color}${DICTIONARY}${blue_color}]"
	arr["GREEK",183]="Έχετε ήδη επιλέξει λεξικό κατά τη διάρκεια της συνεδρίας [${normal_color}${DICTIONARY}${blue_color}]"
	arr["ITALIAN",183]="È stato selezionato un file di dizionario in questa sessione [${normal_color}${DICTIONARY}${blue_color}]"
	arr["POLISH",183]="W tej sesji wybrano plik słownika [${normal_color}${DICTIONARY}${blue_color}]"
	arr["GERMAN",183]="Sie haben in dieser Sitzung bereits eine Wörterbuchdatei ausgewählt [${normal_color}${DICTIONARY}${blue_color}]"
	arr["TURKISH",183]="Bu oturumda zaten sözlük dosyası seçtiniz [${normal_color}${DICTIONARY}${blue_color}]"

	arr["ENGLISH",184]="Do you want to use this already selected dictionary file? ${normal_color}${visual_choice}"
	arr["SPANISH",184]="¿Quieres utilizar este fichero de diccionario ya seleccionado? ${normal_color}${visual_choice}"
	arr["FRENCH",184]="Souhaitez vous utiliser le dictionnaire déjà sélectionné? ${normal_color}${visual_choice}"
	arr["CATALAN",184]="¿Vols fer servir aquest fitxer de diccionari ja seleccionat? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",184]="Você quer usar esse arquivo de dicionário já selecionado? ${normal_color}${visual_choice}"
	arr["RUSSIAN",184]="Вы хотите использовать этот уже выбранный файл словаря? ${normal_color}${visual_choice}"
	arr["GREEK",184]="Θέλετε να χρησιμοποιήσετε το ήδη επιλεγμένο λεξικό; ${normal_color}${visual_choice}"
	arr["ITALIAN",184]="Vuoi utilizzare questo file di dizionario già selezionato? ${normal_color}${visual_choice}"
	arr["POLISH",184]="Czy chcesz użyć już wybraniego pliku słownika? ${normal_color}${visual_choice}"
	arr["GERMAN",184]="Möchten Sie diese ausgewählte Wörterbuchdatei verwenden? ${normal_color}${visual_choice}"
	arr["TURKISH",184]="Seçilen sözlük dosyasını kullanmak istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",185]="Selected BSSID: ${pink_color}None${normal_color}"
	arr["SPANISH",185]="BSSID seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",185]="BSSID sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",185]="BSSID seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",185]="BSSID selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",185]="Выбранная BSSID: ${pink_color}Нет${normal_color}"
	arr["GREEK",185]="Επιλεγμένο BSSID: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",185]="BSSID selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",185]="Wybrany BSSID: ${pink_color}Brak${normal_color}"
	arr["GERMAN",185]="Ausgewählte BSSID: ${pink_color}Keine${normal_color}"
	arr["TURKISH",185]="Seçilen BSSID: ${pink_color}None${normal_color}"

	arr["ENGLISH",186]="You already have selected a capture file during this session [${normal_color}${enteredpath}${blue_color}]"
	arr["SPANISH",186]="Ya tienes seleccionado un fichero de captura en esta sesión [${normal_color}${enteredpath}${blue_color}]"
	arr["FRENCH",186]="Vous avez déjà sélectionné un fichier de capture pour cette session ${normal_color}${enteredpath}${blue_color}]"
	arr["CATALAN",186]="Ja tens seleccionat un fitxer de captura en aquesta sessió [${normal_color}${enteredpath}${blue_color}]"
	arr["PORTUGUESE",186]="Você selecionou um arquivo de captura nesta sessão [${normal_color}${enteredpath}${blue_color}]"
	arr["RUSSIAN",186]="Вы уже выбрали файл захвата во время этой сессии [${normal_color}${enteredpath}${blue_color}]"
	arr["GREEK",186]="Έχετε ήδη επιλέξει αρχείο καταγραφής κατά τη διάρκεια της συνεδρίας [${normal_color}${enteredpath}${blue_color}]"
	arr["ITALIAN",186]="È stato selezionato un file di cattura in questa sessione [${normal_color}${enteredpath}${blue_color}]"
	arr["POLISH",186]="W tej sesji wybrano już plik przechwytywania [${normal_color}${enteredpath}${blue_color}]"
	arr["GERMAN",186]="Sie haben bereits eine Capture-Datei in dieser Sitzung ausgewählt [${normal_color}${enteredpath}${blue_color}]"
	arr["TURKISH",186]="Bu oturumda zaten bir yakalama dosyası seçtiniz [${normal_color} ${enteredpath}${blue_color}]"

	arr["ENGLISH",187]="Do you want to use this already selected capture file? ${normal_color}${visual_choice}"
	arr["SPANISH",187]="¿Quieres utilizar este fichero de captura ya seleccionado? ${normal_color}${visual_choice}"
	arr["FRENCH",187]="Souhaitez vous utiliser le fichier de capture déjà sélectionné? ${normal_color}${visual_choice}"
	arr["CATALAN",187]="¿Vols fer servir aquest fitxer de captura ja seleccionat? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",187]="Você quer usar esse arquivo de captura selecionado? ${normal_color}${visual_choice}"
	arr["RUSSIAN",187]="Вы хотите использовать этот уже выбранный файл захвата? ${normal_color}${visual_choice}"
	arr["GREEK",187]="Θέλετε να χρησιμοποιήσετε το ήδη επιλεγμένο αρχείο καταγραφής; ${normal_color}${visual_choice}"
	arr["ITALIAN",187]="Vuoi utilizzare questo file di cattura giá selezionato? ${normal_color}${visual_choice}"
	arr["POLISH",187]="Czy chcesz użyć już wybranego pliku przechwytywania? ${normal_color}${visual_choice}"
	arr["GERMAN",187]="Möchten Sie diese ausgewählte Capture-Datei verwenden? ${normal_color}${visual_choice}"
	arr["TURKISH",187]="Bu yakalama dosyasını kullanmak istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",188]="Enter the path of a captured file:"
	arr["SPANISH",188]="Introduce la ruta de un fichero de captura:"
	arr["FRENCH",188]="Entrez le chemin vers un fichier de capture:"
	arr["CATALAN",188]="Introdueix la ruta d'un fitxer de captura:"
	arr["PORTUGUESE",188]="Digite o caminho para um arquivo de captura:"
	arr["RUSSIAN",188]="Введите путь файла захвата:"
	arr["GREEK",188]="Εισάγετε το μονοπάτι για ένα αρχείο καταγραφής:"
	arr["ITALIAN",188]="Immettere il percorso di un file di cattura:"
	arr["POLISH",188]="Wprowadź ścieżkę do pliku przechwytywania:"
	arr["GERMAN",188]="Geben Sie den Pfad einer Capture-Datei ein:"
	arr["TURKISH",188]="Yakalama dosyasının yolunu girin:"

	arr["ENGLISH",189]="The path to the capture file is valid. Script can continue..."
	arr["SPANISH",189]="La ruta al fichero de captura es válida. El script puede continuar..."
	arr["FRENCH",189]="Le chemin du fichier de capture est valide. Le script peut continuer..."
	arr["CATALAN",189]="La ruta al fitxer de captura és vàlida. El script pot continuar..."
	arr["PORTUGUESE",189]="O caminho para o arquivo de captura é válido. O script pode continuar..."
	arr["RUSSIAN",189]="Путь до файла захвата верен. Скрипт может продолжать..."
	arr["GREEK",189]="Το μονοπάτι για το αρχείο καταγραφής είναι έγκυρο. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",189]="Il percorso del file di cattura è valido. Lo script può continuare..."
	arr["POLISH",189]="Ścieżka do pliku przechwytywania jest prawidłowa. Skrypt może kontynuować..."
	arr["GERMAN",189]="Der Pfad zur Capture-Datei ist gültig. Das Skript kann fortfahren..."
	arr["TURKISH",189]="Yakalama dosyasının yolu doğru. Yazılım devam edebilir..."

	arr["ENGLISH",190]="Starting decrypt. When started, press [Ctrl+C] to stop..."
	arr["SPANISH",190]="Comenzando desencriptado. Una vez empezado, pulse [Ctrl+C] para pararlo..."
	arr["FRENCH",190]="Lancement du crack. Pressez [Ctrl+C] pour l'arrêter..."
	arr["CATALAN",190]="Començant el desencriptat. Un cop començat, premeu [Ctrl+C] per aturar-lo..."
	arr["PORTUGUESE",190]="Começando a descriptografar. Uma vez iniciado, pressione [Ctrl+C] para parar..."
	arr["RUSSIAN",190]="Начало расшифровки. После запуска, нажмите [Ctrl+C] для остановки..."
	arr["GREEK",190]="Γίνεται έναρξη αποκρυπτογράφησης. Όταν ξεκινήσει, πατήστε [Ctrl+C] για να σταματήσει..."
	arr["ITALIAN",190]="Cominciando a decifrare. Una volta avviato, premere [Ctrl+C] per fermare..."
	arr["POLISH",190]="Uruchamianie odszyfrowania. Naciśnij [Ctrl+C] w trakcie trwania aby go zatrzymać..."
	arr["GERMAN",190]="Entschlüsselung starten. Nach dem Start drücken Sie [Ctrl+C], um es zu stoppen..."
	arr["TURKISH",190]="Şifre çözme başlıyor. Başladıktan sonra, durdurmak için [Ctrl+C] basınız..."

	arr["ENGLISH",191]="${blue_color}airgeddon can't find the directory path where you have BeEF installed. ${green_color}Do you want to enter it manually? ${normal_color}${visual_choice}"
	arr["SPANISH",191]="${blue_color}airgeddon no ha podido encontrar la ruta del directorio donde tienes instalado BeEF. ${green_color}¿Quieres introducirla manualmente? ${normal_color}${visual_choice}"
	arr["FRENCH",191]="${blue_color}airgeddon n'a pas trouvé le dossier qui contient BeEF. ${green_color}Voulez-vous l'indiquer manuellement? ${normal_color}${visual_choice}"
	arr["CATALAN",191]="${blue_color}airgeddon no ha pogut trobar la ruta del directori on tens instal·lat BeEF. ${green_color}¿Vols introduir-la manualment? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",191]="${blue_color}O airgeddon não conseguiu encontrar o diretório onde você instalou o BeEF. ${green_color}Você quer inseri-lo manualmente? ${normal_color}${visual_choice}"
	arr["RUSSIAN",191]="${blue_color}airgeddon не может найти путь к каталогу, где вы установили BeEF. ${green_color}Вы хотите ввести его вручную? ${normal_color}${visual_choice}"
	arr["GREEK",191]="${blue_color}Το airgeddon δεν μπορεί να βρει το μονοπάτι για τον κατάλογο όπου έχετε εγκαταστημένο το BeEF. ${green_color}Θέλετε να το εισάγετε χειροκίνητα; ${normal_color}${visual_choice}"
	arr["ITALIAN",191]="${blue_color}airgeddon non ha potuto trovare il percorso della directory in cui è stato installato BeEF. ${green_color}Vuoi inserirlo manualmente? ${normal_color}${visual_choice}"
	arr["POLISH",191]="${blue_color}airgeddon nie mógł znaleźć ścieżki, w której zainstalowano BeEF. ${green_color}Czy chcesz ją wprowadzić ręcznie? ${normal_color}${visual_choice}"
	arr["GERMAN",191]="${blue_color}airgeddon konnte den Verzeichnispfad, in den BeEF installiert ist, nicht finden. ${green_color}Möchten Sie es manuell eingeben? ${normal_color}${visual_choice}"
	arr["TURKISH",191]="${blue_color}airgeddon BeEF yazılımının kurulu olduğu dizini bulamadı. ${green_color}Elle girmek ister misiniz? ${normal_color}${visual_choice}"

	arr["ENGLISH",192]="You already have selected a BSSID during this session and is present in capture file [${normal_color}${bssid}${blue_color}]"
	arr["SPANISH",192]="Ya tienes seleccionado un BSSID en esta sesión y está presente en el fichero de captura [${normal_color}${bssid}${blue_color}]"
	arr["FRENCH",192]="Vous avez déjà sélectionné un BSSID pour la session en cours et est présent dans le fichier de capture ${normal_color}${bssid}${blue_color}]"
	arr["CATALAN",192]="Ja tens seleccionat un BSSID en aquesta sessió i està present en el fitxer de captura [${normal_color}${bssid}${blue_color}]"
	arr["PORTUGUESE",192]="Você selecionou um BSSID nesta sessão que está presente no arquivo de captura [${normal_color}${bssid}${blue_color}]"
	arr["RUSSIAN",192]="У вас уже есть выбранная во время этой сессии BSSID и она присутствует в файле захвата [${normal_color}${bssid}${blue_color}]"
	arr["GREEK",192]="Έχετε ήδη επιλέξει BSSID κατά τη διάρκεια της συνεδρίας και βρίσκεται στο αρχείο καταγραφής [${normal_color}${bssid}${blue_color}]"
	arr["ITALIAN",192]="È stato selezionato un BSSID in questa sessione che è giá presente nel file di cattura [${normal_color}${bssid}${blue_color}]"
	arr["POLISH",192]="Wybrano już BSSID w tej sesji i jest on obecny w pliku przechwytywania [${normal_color}${bssid}${blue_color}]"
	arr["GERMAN",192]="Sie haben in dieser Sitzung bereits eine BSSID ausgewählt, die in der Erfassungsdatei vorhanden ist [${normal_color}${bssid}${blue_color}]"
	arr["TURKISH",192]="Bu oturum sırasında zaten bir BSSID seçtiniz ve yakalama dosyasında mevcut [${normal_color}${bssid}${blue_color}]"

	arr["ENGLISH",193]="Do you want to use this already selected BSSID? ${normal_color}${visual_choice}"
	arr["SPANISH",193]="¿Quieres utilizar este BSSID ya seleccionado? ${normal_color}${visual_choice}"
	arr["FRENCH",193]="Souhaitez vous utiliser le BSSID déjà sélectionné? ${normal_color}${visual_choice}"
	arr["CATALAN",193]="¿Vols fer servir aquest BSSID ja seleccionat? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",193]="Você quer usar este BSSID já selecionado? ${normal_color}${visual_choice}"
	arr["RUSSIAN",193]="Вы хотите использовать эту уже выбранную BSSID? ${normal_color}${visual_choice}"
	arr["GREEK",193]="Θέλετε να χρησιμοποιήσετε το ήδη επιλεγμένο BSSID; ${normal_color}${visual_choice}"
	arr["ITALIAN",193]="Vuoi usare questo BSSID già selezionato? ${normal_color}${visual_choice}"
	arr["POLISH",193]="Czy chcesz użyć już wybranego BSSID? ${normal_color}${visual_choice}"
	arr["GERMAN",193]="Möchten Sie diese ausgewählte BSSID verwenden? ${normal_color}${visual_choice}"
	arr["TURKISH",193]="Seçilen BSSID ile devam etmek ister misiniz? ${normal_color}${visual_choice}"

	arr["ENGLISH",194]="Enter the minimum length of the key to decrypt (8-63):"
	arr["SPANISH",194]="Introduce la longitud mínima de la clave a desencriptar (8-63):"
	arr["FRENCH",194]="Entrez la longueur minimale de la clef à cracker (8-63):"
	arr["CATALAN",194]="Introdueix la longitud mínima de la clau a desxifrar (8-63):"
	arr["PORTUGUESE",194]="Digite o comprimento mínimo da senha para descriptografar (8-63):"
	arr["RUSSIAN",194]="Введите минимальную длину ключа для расшифровки (8-63):"
	arr["GREEK",194]="Εισάγετε το ελάχιστο μήκος κλειδιού για αποκρυπτογράφηση (8-63):"
	arr["ITALIAN",194]="Inserire la lunghezza minima della chiave da decifrare (8-63):"
	arr["POLISH",194]="Wpisz minimalną długość klucza do odszyfrowania (8-63):"
	arr["GERMAN",194]="Geben Sie die Mindestlänge des zu entschlüsselnden Schlüssels ein (8-63):"
	arr["TURKISH",194]="Şifreyi çözmek için anahtarın minimum uzunluğunu girin (8-63):"

	arr["ENGLISH",195]="Enter the maximum length of the key to decrypt (${minlength}-63):"
	arr["SPANISH",195]="Introduce la longitud máxima de la clave a desencriptar (${minlength}-63):"
	arr["FRENCH",195]="Entrez la longueur maximale de la clef à cracker (${minlength}-63):"
	arr["CATALAN",195]="Introdueix la longitud màxima de la clau a desxifrar (${minlength}-63):"
	arr["PORTUGUESE",195]="Digite o comprimento máximo da senha para descriptografar (${minlength}-63):"
	arr["RUSSIAN",195]="Введите максимальную длину ключа для расшифровки (${minlength}-63):"
	arr["GREEK",195]="Εισάγετε το μέγιστο μήκος κλειδιού για αποκρυπτογράφηση (${minlength}-63):"
	arr["ITALIAN",195]="Inserire la lunghezza massima della chiave da decifrare (${minlength}-63):"
	arr["POLISH",195]="Wpisz maksymalną długość klucza do odszyfrowania (${minlength}-63):"
	arr["GERMAN",195]="Geben Sie die maximale Länge des zu entschlüsselnden Schlüssels ein (${minlength}-63):"
	arr["TURKISH",195]="Şifreyi çözmek için anahtarın maximum uzunluğunu girin (${minlength}-63):"

	arr["ENGLISH",196]="Select the character set to use:"
	arr["SPANISH",196]="Selecciona el juego de caracteres a utilizar:"
	arr["FRENCH",196]="Sélectionnez le jeu de caractères à utiliser:"
	arr["CATALAN",196]="Selecciona el joc de caràcters a utilitzar:"
	arr["PORTUGUESE",196]="Selecione o conjunto de caracteres a ser usado:"
	arr["RUSSIAN",196]="Выберите набор символов для использования:"
	arr["GREEK",196]="Επιλέξτε το σετ χαρακτήρων που θα χρησιμοποιηθεί:"
	arr["ITALIAN",196]="Selezionare il set di caratteri da utilizzare:"
	arr["POLISH",196]="Wybierz zestaw znaków do użycia:"
	arr["GERMAN",196]="Wählen Sie den Zeichensatz zu verwenden aus:"
	arr["TURKISH",196]="Kullanılacak karakter kümesini seçin:"

	arr["ENGLISH",197]="1.  Lowercase chars"
	arr["SPANISH",197]="1.  Caracteres en minúsculas"
	arr["FRENCH",197]="1.  Lettres minuscules"
	arr["CATALAN",197]="1.  Caràcters en minúscules"
	arr["PORTUGUESE",197]="1.  Caracteres minúsculos"
	arr["RUSSIAN",197]="1.  Символы нижнего регистра"
	arr["GREEK",197]="1.  Πεζά"
	arr["ITALIAN",197]="1.  Caratteri minuscoli"
	arr["POLISH",197]="1.  Małe litery"
	arr["GERMAN",197]="1.  Zeichen in Kleinbuchstaben"
	arr["TURKISH",197]="1.  Küçük harfli karakterler"

	arr["ENGLISH",198]="2.  Uppercase chars"
	arr["SPANISH",198]="2.  Caracteres en mayúsculas"
	arr["FRENCH",198]="2.  Lettres majuscules"
	arr["CATALAN",198]="2.  Caràcters en majúscules"
	arr["PORTUGUESE",198]="2.  Caracteres maiúsculos"
	arr["RUSSIAN",198]="2.  Символы верхнего регистра"
	arr["GREEK",198]="2.  Κεφαλαία"
	arr["ITALIAN",198]="2.  Caratteri maiuscoli"
	arr["POLISH",198]="2.  Wielkie litery"
	arr["GERMAN",198]="2.  Zeichen in Großbuchstaben"
	arr["TURKISH",198]="2.  Büyük harfli karakterler"

	arr["ENGLISH",199]="3.  Numeric chars"
	arr["SPANISH",199]="3.  Caracteres numéricos"
	arr["FRENCH",199]="3.  Chiffres"
	arr["CATALAN",199]="3.  Caràcters numèrics"
	arr["PORTUGUESE",199]="3.  Caracteres numéricos"
	arr["RUSSIAN",199]="3.  Цифры"
	arr["GREEK",199]="3.  Αριθμοί"
	arr["ITALIAN",199]="3.  Caratteri numerici"
	arr["POLISH",199]="3.  Cyfry"
	arr["GERMAN",199]="3.  Numerische Zeichen"
	arr["TURKISH",199]="3.  Numerik karakterler"

	arr["ENGLISH",200]="4.  Symbol chars"
	arr["SPANISH",200]="4.  Caracteres símbolos"
	arr["FRENCH",200]="4.  Symboles"
	arr["CATALAN",200]="4.  Caràcters símbols"
	arr["PORTUGUESE",200]="4.  Símbolos"
	arr["RUSSIAN",200]="4.  Символы"
	arr["GREEK",200]="4.  Σύμβολα"
	arr["ITALIAN",200]="4.  Simboli"
	arr["POLISH",200]="4.  Symbole"
	arr["GERMAN",200]="4.  Zeichensymbole"
	arr["TURKISH",200]="4.  Sembol karakterler"

	arr["ENGLISH",201]="5.  Lowercase + uppercase chars"
	arr["SPANISH",201]="5.  Caracteres en minúsculas + mayúsculas"
	arr["FRENCH",201]="5.  Lettres minuscules + majuscules"
	arr["CATALAN",201]="5.  Caràcters en minúscules + majúscules"
	arr["PORTUGUESE",201]="5.  Caracteres minúsculos + maiúsculos"
	arr["RUSSIAN",201]="5.  Буквы верхнего + нижнего регистра"
	arr["GREEK",201]="5.  Πεζά + κεφαλαία"
	arr["ITALIAN",201]="5.  Caratteri minuscoli + maiuscoli"
	arr["POLISH",201]="5.  Małe + wielkie litery"
	arr["GERMAN",201]="5.  Zeichen in Klein- und Großbuchstaben"
	arr["TURKISH",201]="5.  Küçük + büyük harfli karakterler"

	arr["ENGLISH",202]="6.  Lowercase + numeric chars"
	arr["SPANISH",202]="6.  Caracteres en minúsculas + numéricos"
	arr["FRENCH",202]="6.  Lettres minuscules + chiffres"
	arr["CATALAN",202]="6.  Caràcters en minúscules + numèrics"
	arr["PORTUGUESE",202]="6.  Caracteres minúsculos + números"
	arr["RUSSIAN",202]="6.  Буквы нижнего регистра + цифры"
	arr["GREEK",202]="6.  Πεζά + αριθμοί"
	arr["ITALIAN",202]="6.  Caratteri minuscoli + numerici"
	arr["POLISH",202]="6.  Małe litery + cyfry"
	arr["GERMAN",202]="6.  Zeichen in Kleinbuchstaben + numerisch"
	arr["TURKISH",202]="6.  Küçük harf + numerik karakterler"

	arr["ENGLISH",203]="7.  Uppercase + numeric chars"
	arr["SPANISH",203]="7.  Caracteres en mayúsculas + numéricos"
	arr["FRENCH",203]="7.  Lettres majuscules + chiffres"
	arr["CATALAN",203]="7.  Caràcters en majúscules + numèrics"
	arr["PORTUGUESE",203]="7.  Caracteres maiúsculos + números"
	arr["RUSSIAN",203]="7.  Буквы верхнего регистра + цифры"
	arr["GREEK",203]="7.  Κεφαλαία + αριθμοί"
	arr["ITALIAN",203]="7.  Caratteri numerici + maiuscoli"
	arr["POLISH",203]="7.  Wielkie litery + cyfry"
	arr["GERMAN",203]="7.  Zeichen in Großbuchstaben + Zahlen"
	arr["TURKISH",203]="7.  Büyük harf + numerik karakterler"

	arr["ENGLISH",204]="8.  Symbol + numeric chars"
	arr["SPANISH",204]="8.  Caracteres símbolos + numéricos"
	arr["FRENCH",204]="8.   Symboles + chiffres"
	arr["CATALAN",204]="8.  Caràcters símbols + numèrics"
	arr["PORTUGUESE",204]="8.  Símbolos + números"
	arr["RUSSIAN",204]="8.  Символы + цифры"
	arr["GREEK",204]="8.  Σύμβολα + αριθμοί"
	arr["ITALIAN",204]="8.  simboli + numeri"
	arr["POLISH",204]="8.  Cyfry + symbole"
	arr["GERMAN",204]="8.  Symbole + Ziffern"
	arr["TURKISH",204]="8.  Sembol + numerik karakterler"

	arr["ENGLISH",205]="9.  Lowercase + uppercase + numeric chars"
	arr["SPANISH",205]="9.  Caracteres en minúsculas + mayúsculas + numéricos"
	arr["FRENCH",205]="9.  Lettres minuscules et majuscules + chiffres"
	arr["CATALAN",205]="9.  Caràcters en minúscules + majúscules + numèrics"
	arr["PORTUGUESE",205]="9.  Caracteres minúsculos + maiúsculos + números"
	arr["RUSSIAN",205]="9.  Буквы нижнего регистра + верхнего регистра + цифры"
	arr["GREEK",205]="9.  Πεζά + κεφαλαία + αριθμοί"
	arr["ITALIAN",205]="9.  Caratteri minuscoli + maiuscoli + numeri"
	arr["POLISH",205]="9.  Małe litery + wielkie litery + cyfry"
	arr["GERMAN",205]="9.  Zeichen in Kleinbuchstaben + Großbuchstaben + Ziffern"
	arr["TURKISH",205]="9.  Küçük + büyük harf + numerik karakterler"

	arr["ENGLISH",206]="10. Lowercase + uppercase + symbol chars"
	arr["SPANISH",206]="10. Caracteres en minúsculas + mayúsculas + símbolos"
	arr["FRENCH",206]="10. Lettres minuscules et majuscules + symboles"
	arr["CATALAN",206]="10. Caràcters en minúscules + majúscules + símbols"
	arr["PORTUGUESE",206]="10. Caracteres minúsculos + maiúsculos + símbolos"
	arr["RUSSIAN",206]="10. Буквы нижнего регистра + верхнего регистра + символы"
	arr["GREEK",206]="10. Πεζά + κεφαλαία + σύμβολα"
	arr["ITALIAN",206]="10. Caratteri minuscoli + maiuscoli + simboli"
	arr["POLISH",206]="10. Małe litery + wielkie + symbole"
	arr["GERMAN",206]="10. Zeichen in Kleinbuchstaben + Großbuchstaben + Symbole"
	arr["TURKISH",206]="10. Küçük + büyük harf + sembol karakterler"

	arr["ENGLISH",207]="11. Lowercase + uppercase + numeric + symbol chars"
	arr["SPANISH",207]="11. Caracteres en minúsculas + mayúsculas + numéricos + símbolos"
	arr["FRENCH",207]="11. Lettres minuscules et majuscules + chiffres + symboles"
	arr["CATALAN",207]="11. Caràcters en minúscules + majúscules + numèrics + símbols"
	arr["PORTUGUESE",207]="11. Caracteres minúsculos + maiúsculos + números + símbolos"
	arr["RUSSIAN",207]="11. Буквы нижнего регистра + верхнего регистра + цифры + символы"
	arr["GREEK",207]="11. Πεζά + κεφαλαία + αριθμοί + σύμβολα"
	arr["ITALIAN",207]="11. Caratteri minuscoli + maiuscoli + numeri + simboli"
	arr["POLISH",207]="11. Małe litery + wielkie litery + cyfry + symbole"
	arr["GERMAN",207]="11. Zeichen in Kleinbuchstaben + Großbuchstaben + Ziffern + Symbole"
	arr["TURKISH",207]="11. Küçük + büyük harf + numerik + sembol karakterler"

	arr["ENGLISH",208]="If you choose a big charset and a long key length, the process could take so much time"
	arr["SPANISH",208]="Si eliges un juego de caracteres amplio y una longitud de clave grande, el proceso podría demorarse mucho tiempo"
	arr["FRENCH",208]="Si vous choisissez un jeu de caractères ample et une longitude de clef importante, le processus pourrait prendre beaucoup de temps"
	arr["CATALAN",208]="Si tries un joc de caràcters ampli i una longitud de clau gran, el procés podria demorar-se molt temps"
	arr["PORTUGUESE",208]="Se você escolher um grande conjunto de caracteres e um grande comprimento da senha, o processo pode levar um longo tempo"
	arr["RUSSIAN",208]="Если вы выберете большой набор символов и большую длинну ключа, процесс может занять очень много времени"
	arr["GREEK",208]="Αν επιλέξετε μεγάλη συμβολοσειρά και μεγάλο μήκος κλειδιού, η διεργασία θα διαρκέσει αρκετά"
	arr["ITALIAN",208]="Se si sceglie un set di caratteri grande e una grande lunghezza della chiave, il processo potrebbe richiedere molto tempo"
	arr["POLISH",208]="Jeśli wybierzesz duży zestaw znaków i dużą długość klucza, proces może potrwać bardzo długo"
	arr["GERMAN",208]="Wenn Sie einen breiten Zeichensatz und eine große Schlüssellänge auswählen, kann der Vorgang sehr lange dauern"
	arr["TURKISH",208]="Büyük bir karakter kümesi ve uzun bir anahtar uzunluğu seçerseniz, süreç çok zaman alabilir"

	arr["ENGLISH",209]="The charset to use is: [${normal_color}${showcharset}${blue_color}]"
	arr["SPANISH",209]="El juego de caracteres elegido es: [${normal_color}${showcharset}${blue_color}]"
	arr["FRENCH",209]="Le jeu de caractères définit est: [${normal_color}${showcharset}${blue_color}]"
	arr["CATALAN",209]="El joc de caràcters escollit és: [${normal_color}${showcharset}${blue_color}]"
	arr["PORTUGUESE",209]="Conjunto de caracteres escolhido: [${normal_color}${showcharset}${blue_color}]"
	arr["RUSSIAN",209]="Символы для использования: [${normal_color}${showcharset}${blue_color}]"
	arr["GREEK",209]="Η συμβολοσειρά που θα χρησιμοποιηθεί είναι: [${normal_color}${showcharset}${blue_color}]"
	arr["ITALIAN",209]="Il set di caratteri scelto è: [${normal_color}${showcharset}${blue_color}]"
	arr["POLISH",209]="Wybrany zestaw znaków to: [${normal_color}${showcharset}${blue_color}]"
	arr["GERMAN",209]="Der gewählte Zeichensatz ist: [${normal_color}${showcharset}${blue_color}]"
	arr["TURKISH",209]="Kullanılacak karakter kümesi: [${normal_color}${showcharset}${blue_color}]"

	arr["ENGLISH",210]="The script will check for internet access looking for a newer version. Please be patient..."
	arr["SPANISH",210]="El script va a comprobar si tienes acceso a internet para ver si existe una nueva versión. Por favor ten paciencia..."
	arr["FRENCH",210]="Le script va vérifier que vous aillez accès à internet pour voir si une nouvelle version du script est disponible. Soyez patients s'il vous plaît..."
	arr["CATALAN",210]="El script va a comprovar si tens accés a internet per veure si hi ha una nova versió. Si us plau té paciència..."
	arr["PORTUGUESE",210]="O script irá verificar se você tem acesso à internet para ver se há uma nova versão. Por favor, seja paciente..."
	arr["RUSSIAN",210]="Скрипт проверит доступ в Интернет для поиска новой версии. Подождите немного..."
	arr["GREEK",210]="Το script θα ελέγξει αν έχετε πρόσβαση στο διαδίκτυο και έπειτα για νεότερη έκδοση. Παρακαλώ κάντε υπομονή..."
	arr["ITALIAN",210]="Lo script controllerà se si ha accesso a internet per vedere se c'è una nuova versione. Si prega di essere pazienti..."
	arr["POLISH",210]="Skrypt sprawdzi, czy masz dostęp do internetu i czy jest nowa wersja. Cierpliwości..."
	arr["GERMAN",210]="Das Skript überprüft, ob Sie Zugriff auf das Internet haben, um zu sehen, ob eine neue Version existiert. Wir bitten um Geduld..."
	arr["TURKISH",210]="${pending_of_translation} Komut, daha yeni bir sürümü arayan internet erişimini kontrol edecektir. Lütfen sabırlı olun..."

	arr["ENGLISH",211]="It seems you have no internet access. The script can't connect to repository. It will continue without updating..."
	arr["SPANISH",211]="Parece que no tienes conexión a internet. El script no puede conectar al repositorio. Continuará sin actualizarse..."
	arr["FRENCH",211]="Il semble que vous ne pouvez pas vous connecter à internet. Impossible dans ces conditions de pouvoir accéder aux dépôts. Le script va donc s’exécuter sans s'actualiser..."
	arr["CATALAN",211]="Sembla que no tens connexió a internet. El script no pot connectar al repositori. Continuarà sense actualitzar-se..."
	arr["PORTUGUESE",211]="Parece que você não tem acesso à internet. O script não pode conectar-se ao repositório. Ele continuará sem atualizar..."
	arr["RUSSIAN",211]="Кажется, у вас нет доступа в Интернет. Скрипт не может подключится к репозиторию. Он продолжит без обновления..."
	arr["GREEK",211]="Φαίνεται πως δεν έχετε πρόσβαση στο διαδίκτυο. Το script δεν μπορεί να συνδεθεί στο αποθετήριο. Θα συνεχίσει χωρίς να έχει ενημερωθεί..."
	arr["ITALIAN",211]="Sembra che tu non abbia alcuna connessione a internet. Lo script non riesce a connettersi al repository. Continuerà senza aggiornarsi..."
	arr["POLISH",211]="Wygląda na to, że nie masz połączenia z internetem. Skrypt nie może połączyć się z repozytorium. Kontynuacja bez aktualizacji..."
	arr["GERMAN",211]="Es scheint, dass Sie keine Internetverbindung haben. Das Skript kann keine Verbindung zum Repository herstellen. Es wird ohne Aktualisierung fortgesetzt..."
	arr["TURKISH",211]="İnternet bağlantınız yok. Yazılım depoya bağlanamadı. Güncelleme olmadan devam edilecek..."

	arr["ENGLISH",212]="The script is already in the latest version. It doesn't need to be updated"
	arr["SPANISH",212]="El script ya está en la última versión. No necesita ser actualizado"
	arr["FRENCH",212]="La dernière version du script est déjà installée. Pas de mise à jour possible"
	arr["CATALAN",212]="El script ja està en l'última versió. No necessita ser actualitzat"
	arr["PORTUGUESE",212]="O script já está na versão mais recente. Ele não necessita ser atualizado"
	arr["RUSSIAN",212]="Скрипт уже последней версии, обновление не требуется"
	arr["GREEK",212]="Το script είναι ήδη στην τελευταία έκδοση. Δεν χρειάζεται να ενημερωθεί"
	arr["ITALIAN",212]="Lo script è già alla sua ultima versione. Non c'è bisogno di aggiornamenti"
	arr["POLISH",212]="Skrypt jest już w najnowszej wersji. Nie ma potrzeby aktualizacji"
	arr["GERMAN",212]="Das Skript ist bereits in der neuesten Version. Es muss nicht aktualisiert werden"
	arr["TURKISH",212]="Yazılım zaten en son sürüm. Güncellemeye gerek yok"

	arr["ENGLISH",213]="A new version of the script exists (v${airgeddon_last_version}). It will be downloaded"
	arr["SPANISH",213]="Existe una nueva versión del script (v${airgeddon_last_version}). Será descargada"
	arr["FRENCH",213]="Une nouvelle version du script est disponible (v${airgeddon_last_version}). Lancement du téléchargement"
	arr["CATALAN",213]="Hi ha una nova versió dels script (v${airgeddon_last_version}). Serà descarregada"
	arr["PORTUGUESE",213]="Existe uma nova versão do script (v${airgeddon_last_version}). Download será iniciado"
	arr["RUSSIAN",213]="Существует новая версия скрипта (v${airgeddon_last_version}). Она будет загружена"
	arr["GREEK",213]="Υπάρχει νεότερη έκδοση του script (v${airgeddon_last_version}). Θα κατέβει"
	arr["ITALIAN",213]="Esiste una nuova versione dello script (v${airgeddon_last_version}). Sarà scaricata"
	arr["POLISH",213]="Jest nowa wersja skryptu (v${airgeddon_last_version}). Zostanie ona pobrana"
	arr["GERMAN",213]="Es gibt eine neue Version des Skripts (v${airgeddon_last_version}). Sie wird automatisch heruntergeladet"
	arr["TURKISH",213]="Yazılımın yeni bir sürümü mevcut (v${airgeddon_last_version}). İndirilecek"

	arr["ENGLISH",214]="The new version was successfully downloaded. The script will be launched again"
	arr["SPANISH",214]="La nueva versión se ha descargado con éxito. El script se lanzará de nuevo"
	arr["FRENCH",214]="Le téléchargement de la dernière version du script a réussit. Le script a été lancé à nouveau"
	arr["CATALAN",214]="La nova versió s'ha descarregat amb èxit. El script es llençarà de nou"
	arr["PORTUGUESE",214]="A nova versão foi baixado com sucesso. O script será carregado novamente"
	arr["RUSSIAN",214]="Новая версия успешно загружена. Скрипт будет перезапущен"
	arr["GREEK",214]="Η νεότερη έκδοση κατέβηκε επιτυχώς. Το script θα επανεκκινηθεί"
	arr["ITALIAN",214]="La nuova versione è stata scaricata con successo. Lo script sarà lanciato di nuovo"
	arr["POLISH",214]="Nowa wersja została pobrana pomyślnie. Skrypt zostanie uruchomiony ponownie"
	arr["GERMAN",214]="Die neue Version wurde erfolgreich heruntergeladen. Das Skript wird erneut gestartet"
	arr["TURKISH",214]="Yeni sürüm başarıyla indirildi. Yazılım yeniden başlatılacak"

	arr["ENGLISH",215]="WPA/WPA2 passwords always has 8 as a minimum length"
	arr["SPANISH",215]="Una contraseña WPA/WPA2 siempre tiene como mínimo una longitud de 8"
	arr["FRENCH",215]="Un mot de passe WPA/WPA2 a une longueur minimale de 8 caractères"
	arr["CATALAN",215]="Una contrasenya WPA/WPA2 sempre té com a mínim una longitud de 8"
	arr["PORTUGUESE",215]="Uma senha WPA/WPA2 deve ter no mínimo 8 caracteres"
	arr["RUSSIAN",215]="WPA/WPA2 пароли всегда имеют длину минимум в 8 символов"
	arr["GREEK",215]="οι κωδικοί πρόσβασης WPA/WPA2 έχουν πάντα ελάχιστο μήκος 8"
	arr["ITALIAN",215]="Una password WPA/WPA2 è sempre lunga almeno 8 caratteri"
	arr["POLISH",215]="Hasło WPA/WPA2 ma zawsze długość co najmniej 8 znaków"
	arr["GERMAN",215]="Ein WPA/WPA2-Passwort hat immer eine Mindestlänge von 8"
	arr["TURKISH",215]="WPA/WPA2 şifrelerinin her zaman minimum uzunluğu 8'dir"

	arr["ENGLISH",216]="No networks found with Handshake captured on the selected file"
	arr["SPANISH",216]="No se encontraron redes con Handshake capturado en el fichero seleccionado"
	arr["FRENCH",216]="Aucun réseau avec son Handshake n'a été trouvé dans le fichier sélectionné"
	arr["CATALAN",216]="No s'han trobat xarxes amb Handshake capturat en el fitxer seleccionat"
	arr["PORTUGUESE",216]="Nenhuma rede encontrada no arquivo Handshake selecionado"
	arr["RUSSIAN",216]="В выбранном файле сети с захваченным рукопожатием не найдены"
	arr["GREEK",216]="Δεν βρέθηκαν δίκτυα με Χειραψία στο επιλεγμένο αρχείο"
	arr["ITALIAN",216]="Nessuna rete trovata con Handshake catturati nel file selezionato"
	arr["POLISH",216]="Nie znaleziono sieci z przechwyconym Handshake w wybranym pliku"
	arr["GERMAN",216]="In der ausgewählten Datei wurden keine Netzwerke mit Handshake gefunden"
	arr["TURKISH",216]="Seçilen dosyada yakalanan Handshake ile ağ bulunamadı"

	arr["ENGLISH",217]="Only one valid target detected on file. BSSID autoselected [${normal_color}${bssid}${blue_color}]"
	arr["SPANISH",217]="Sólo un objetivo válido detectado en el fichero. Se ha seleccionado automáticamente el BSSID [${normal_color}${bssid}${blue_color}]"
	arr["FRENCH",217]="Le seul réseau valide présent dans le fichier choisi a été sélectionné automatiquement, son BSSID est [${normal_color}${bssid}${blue_color}]"
	arr["CATALAN",217]="Només un objectiu vàlid detectat en el fitxer. S'ha seleccionat automàticament el BSSID [${normal_color}${bssid}${blue_color}]"
	arr["PORTUGUESE",217]="Apenas um alvo válido detectado no arquivo. BSSID selecionado automaticamente [${normal_color}${bssid}${blue_color}]"
	arr["RUSSIAN",217]="В файле обнаружена только одна подходящая цель. BSSID выбрана автоматически [${normal_color}${bssid}${blue_color}]"
	arr["GREEK",217]="Μόνο ένας έγκυρος στόχος εντοπίστηκε στο αρχείο. Επιλέχθηκε αυτόματα το BSSID [${normal_color}${bssid}${blue_color}]"
	arr["ITALIAN",217]="Solo un bersaglio valido rilevato nel file. Viene selezionato automaticamente il BSSID [${normal_color}${bssid}${blue_color}]"
	arr["POLISH",217]="W pliku został wykryty tylko jeden prawidłowy cel. BSSID wybrany automatycznie [${normal_color}${bssid}${blue_color}]"
	arr["GERMAN",217]="Nur ein gültiges Ziel wurde in der Datei gefunden. Die BSSID [${normal_color}${bssid}${blue_color}] wurde automatisch ausgewählt"
	arr["TURKISH",217]="Dosyada sadece bir tane geçerli hedef tespit edildi. BSSID otomatik seçildi [${normal_color}${bssid}${blue_color}]"

	arr["ENGLISH",218]="Optional tools: checking..."
	arr["SPANISH",218]="Herramientas opcionales: comprobando..."
	arr["FRENCH",218]="Vérification de la présence des outils optionnels..."
	arr["CATALAN",218]="Eines opcionals: comprovant..."
	arr["PORTUGUESE",218]="Verificando se as ferramentas opcionais estão presentes..."
	arr["RUSSIAN",218]="Опциональные инструменты: проверка..."
	arr["GREEK",218]="Προαιρετικά εργαλεία: γίνεται έλεγχος..."
	arr["ITALIAN",218]="Strumenti opzionali: controllo ..."
	arr["POLISH",218]="Narzędzia opcjonalne: sprawdzanie..."
	arr["GERMAN",218]="Optionale Tools: Überprüfung..."
	arr["TURKISH",218]="İsteğe bağlı araçlar: kontrol ediliyor..."

	arr["ENGLISH",219]="Your distro has the essential tools but it hasn't some optional. The script can continue but you can't use some features. It is recommended to install missing tools"
	arr["SPANISH",219]="Tu distro tiene las herramientas esenciales pero le faltan algunas opcionales. El script puede continuar pero no podrás utilizar algunas funcionalidades. Es recomendable instalar las herramientas que faltan"
	arr["FRENCH",219]="Votre système contient les outils fondamentaux nécessaires à l’exécution du script mais il manque quelques outils pour pouvoir utiliser pleinement toutes les fonctionnalités proposées par le script. Le script va pouvoir être exécuté mais il est conseillé d'installer les outils manquants"
	arr["CATALAN",219]="La teva distro té les eines essencials però li falten algunes opcionals. El script pot continuar però no podràs utilitzar algunes funcionalitats. És recomanable instal·lar les eines que faltin"
	arr["PORTUGUESE",219]="Sua distro tem as ferramentas essenciais, mas carece de algumas opcionais. O script pode continuar, mas você não poderá usar alguns recursos. É aconselhável instalar as ferramentas ausentes"
	arr["RUSSIAN",219]="Ваш дистрибутив имеет базовые инструменты, но не имеет некоторые опциональные. Скрипт может продолжить работу, но вы не сможете использовать некоторые функции. Рекомендуется установить отсутствующие инструменты"
	arr["GREEK",219]="Η διανομή σας έχει τα απαραίτητα εργαλεία αλλά δεν έχει κάποια προαιρετικά. Το script μπορεί να συνεχίσει αλλά δεν θα μπορέσετε να χρησιμοποιήσετε κάποια χαρακτηριστικά. Συνιστάται να εγκαταστήσετε τα λείποντα εργαλεία"
	arr["ITALIAN",219]="La tua distro ha gli strumenti essenziali, ma mancano alcuni opzionali. Lo script può continuare, ma non è possibile utilizzare alcune funzioni. Si consiglia di installare gli strumenti mancanti"
	arr["POLISH",219]="Twoja dystrybucja Linuxa ma podstawowe narzędzia, ale brakuje niektórych opcjonalnych. Skrypt może być kontynuowany, ale nie będziesz mógł używać niektórych funkcji. Zaleca się zainstalowanie brakujących narzędzi"
	arr["GERMAN",219]="Ihre Distribution hat die wesentlichen Werkzeuge, aber einige optionale fehlen. Das Skript kann fortgesetzt werden, Sie können jedoch einige Funktionen nicht verwenden. Es empfiehlt sich, die fehlenden Tools zu installieren"
	arr["TURKISH",219]="Dağıtımınız temel araçlara sahiptir, ancak bazı opsiyonel araçlar mevcut değildir. Yazılım devam edebilir, ancak bazı özellikleri kullanamazsınız. Eksik araçların tamamlanması tavsiye edilir"

	arr["ENGLISH",220]="Locked menu option was chosen"
	arr["SPANISH",220]="Opción del menú bloqueada"
	arr["FRENCH",220]="Cette option du menu est bloquée"
	arr["CATALAN",220]="Opció del menú bloquejada"
	arr["PORTUGUESE",220]="Menu bloqueado"
	arr["RUSSIAN",220]="Была выбрана заблокированная опция меню"
	arr["GREEK",220]="Επιλέχθηκε κλειδωμένη επιλογή"
	arr["ITALIAN",220]="Opzione del menù bloccata"
	arr["POLISH",220]="Opcja zablokowana"
	arr["GERMAN",220]="Blockierte Menüoption"
	arr["TURKISH",220]="Kilitli menü seçeneği seçildi"

	arr["ENGLISH",221]="Accepted bash version (${BASH_VERSION}). Minimum required version: ${minimum_bash_version_required}"
	arr["SPANISH",221]="Versión de bash (${BASH_VERSION}) aceptada. Mínimo requerido versión: ${minimum_bash_version_required}"
	arr["FRENCH",221]="Votre version de bash (${BASH_VERSION}) est acceptée. Version minimale requise: ${minimum_bash_version_required}"
	arr["CATALAN",221]="Versió de bash (${BASH_VERSION}) acceptada. Versió minima requerida: ${minimum_bash_version_required}"
	arr["PORTUGUESE",221]="Versão Bash (${BASH_VERSION}) aceita. Versão mínima exigida: ${minimum_bash_version_required}"
	arr["RUSSIAN",221]="Используемая версия bash (${BASH_VERSION}). Минимальная требуемая версия: ${minimum_bash_version_required}"
	arr["GREEK",221]="Αποδεκτή έκδοση bash (${BASH_VERSION}). Ελάχιστη απαιτούμενη έκδοση: ${minimum_bash_version_required}"
	arr["ITALIAN",221]="Versione di bash (${BASH_VERSION}) accettata. Minima versione richiesta: ${minimum_bash_version_required}"
	arr["POLISH",221]="Zaakceptowano wersję bash (${BASH_VERSION}). Minimalna wymagana wersja: ${minimum_bash_version_required}"
	arr["GERMAN",221]="Bash-Version (${BASH_VERSION}) akzeptiert. Mindestversion erforderlich: ${minimum_bash_version_required}"
	arr["TURKISH",221]="Kabul edilen bash sürümü (${BASH_VERSION}). Gerekli minimum sürüm: ${minimum_bash_version_required}"

	arr["ENGLISH",222]="Insufficient bash version (${BASH_VERSION}). Minimum required version: ${minimum_bash_version_required}"
	arr["SPANISH",222]="Versión de bash insuficiente (${BASH_VERSION}). Mínimo requerido versión: ${minimum_bash_version_required}"
	arr["FRENCH",222]="Votre version de bash (${BASH_VERSION}) n'est pas suffisante. Version minimale requise: ${minimum_bash_version_required}"
	arr["CATALAN",222]="Versió de bash insuficient (${BASH_VERSION}). Versió mínima requerida: ${minimum_bash_version_required}"
	arr["PORTUGUESE",222]="Versão Bash insuficiente (${BASH_VERSION}). Versão mínima exigida: ${minimum_bash_version_required}"
	arr["RUSSIAN",222]="Неудовлетворительная версия bash (${BASH_VERSION}). Минимальная требуемая версия: ${minimum_bash_version_required}"
	arr["GREEK",222]="Ανεπαρκής έκδοση bash (${BASH_VERSION}). Ελάχιστη απαιτούμενη έκδοση: ${minimum_bash_version_required}"
	arr["ITALIAN",222]="Versione di bash insufficiente (${BASH_VERSION}). Versione minima richiesta: ${minimum_bash_version_required}"
	arr["POLISH",222]="Niewystarczająca wersja bash (${BASH_VERSION}). Minimalna wymagana wersja: ${minimum_bash_version_required}"
	arr["GERMAN",222]="Unzureichende Bash-Version (${BASH_VERSION}). Mindestversion erforderlich: ${minimum_bash_version_required}"
	arr["TURKISH",222]="Yetersiz bash sürümü (${BASH_VERSION}). Gerekli minimum sürüm: ${minimum_bash_version_required}"

	arr["ENGLISH",223]="airgeddon needs root permissions to work. Launch the script as root user or using \"sudo\""
	arr["SPANISH",223]="airgeddon necesita permisos de root para funcionar. Lanza el script como usuario root o usando \"sudo\""
	arr["FRENCH",223]="airgeddon a besoin de permissions root pour etre exécuter. Lancez the script en tant que root ou en utilisant \"sudo\""
	arr["CATALAN",223]="airgeddon necessita permisos de root per funcionar. Llança l'script com a usuari root o utilitza \"sudo\""
	arr["PORTUGUESE",223]="airgeddon necessita de permissões root para funcionar. Execute o script como root ou usando \"sudo\""
	arr["RUSSIAN",223]="airgeddon требует для работы прав root. Запустите скрипт как root пользователь или используйте \"sudo\""
	arr["GREEK",223]="Το airgeddon χρειάζεται root δικαιώματα για να δουλέψει. Ανοίξτε το script ως χρήστης root ή χρησιμοποιήστε \"sudo\""
	arr["ITALIAN",223]="airgeddon ha bisogno dei permessi di root per l'esecuzione. Lancia lo script come root o usando \"sudo\""
	arr["POLISH",223]="airgeddon wymaga uprawnień root do pracy. Uruchom skrypt jako root lub użyj \"sudo\""
	arr["GERMAN",223]="airgeddon benötigt root Berechtigungen um zu arbeiten. Starten Sie das Skript als root oder mit \"sudo\""
	arr["TURKISH",223]="airgeddon'un çalışması için root izinlerine ihtiyacı var. Yazılımı root kullanıcısı olarak veya \"sudo\" kullanarak başlat"

	arr["ENGLISH",224]="The script execution continues from exactly the same point where it was"
	arr["SPANISH",224]="El script continua su ejecución desde exactamente el mismo punto en el que estaba"
	arr["FRENCH",224]="L'exécution du script se poursuit à partir exactement le même point où il était"
	arr["CATALAN",224]="El script contínua la seva execució des d'exactament el mateix punt en el qual estava"
	arr["PORTUGUESE",224]="A execução do script continuará exatamente do mesmo ponto"
	arr["RUSSIAN",224]="Выполнение скрипта продолжиться с точно той точки, на которой он был"
	arr["GREEK",224]="Η εκτέλεση του script συνεχίζει ακριβώς από το ίδιο σημείο που ήταν"
	arr["ITALIAN",224]="Lo script continua l'esecuzione esattamente dallo stesso punto in cui era"
	arr["POLISH",224]="Skrypt kontynuuje wykonywanie z punktu, w którym zakończyl"
	arr["GERMAN",224]="Das Skript setzt seine Ausführung von genau dem Punkt fort, wo es war"
	arr["TURKISH",224]="Yazılım tam olarak aynı noktadan devam eder"

	arr["ENGLISH",225]="The script can't check if there is a new version because you haven't installed update tools needed"
	arr["SPANISH",225]="El script no puede comprobar si hay una nueva versión porque no tienes instaladas las herramientas de actualización necesarias"
	arr["FRENCH",225]="Le script ne peut pas vérifier si une nouvelle version est disponible parce que vous n'avez pas installé les outils nécessaires de mise à jour"
	arr["CATALAN",225]="El script no pot comprovar si hi ha una nova versió perquè no tens instal·lades les eines d'actualització necessàries"
	arr["PORTUGUESE",225]="O script não pôde verificar se há uma nova versão porque você não tem instalado as ferramentas de atualização necessárias"
	arr["RUSSIAN",225]="Скрипт не может проверить имеется ли новая версия, поскольку у вас не установлены необходимые инструменты обновления"
	arr["GREEK",225]="Το script δεν μπορεί να ελέγξει αν υπάρχει νεότερη έκδοση γιατί δεν έχετε εγκαταστήσει τα απαραίτητα εργαλεία ενημερώσεων"
	arr["ITALIAN",225]="Lo script non può verificare se c'è una nuova versione perché non sono stati installati gli strumenti di aggiornamento necessari"
	arr["POLISH",225]="Skrypt nie może sprawdzić nowej wersji, ponieważ nie ma zainstalowanych niezbędnych narzędzi aktualizacji"
	arr["GERMAN",225]="Das Skript kann nicht überprüfen, ob eine neue Version vorhanden ist, da die erforderlichen Update-Tools nicht installiert sind"
	arr["TURKISH",225]="Yazılım, ihtiyaç duyduğunuz güncelleme araçlarını yüklemediğinden yeni bir sürüm olup olmadığını kontrol edemiyor"

	arr["ENGLISH",226]="Update tools: checking..."
	arr["SPANISH",226]="Herramientas de actualización: comprobando..."
	arr["FRENCH",226]="Vérification de la présence des outils de mise à jour..."
	arr["CATALAN",226]="Eines d'actualització: comprovant..."
	arr["PORTUGUESE",226]="Verificando ferramentas de atualização..."
	arr["RUSSIAN",226]="Инструменты для обновления: проверка..."
	arr["GREEK",226]="Εργαλεία ενημερώσεων: γίνεται έλεγχος..."
	arr["ITALIAN",226]="Strumenti di aggiornamento: controllo ..."
	arr["POLISH",226]="Narzędzia aktualizacji: sprawdzanie..."
	arr["GERMAN",226]="Update-Tools: Überprüfung..."
	arr["TURKISH",226]="Güncelleme araçları: kontrol ediliyor..."

	arr["ENGLISH",227]="Working...  "
	arr["SPANISH",227]="Trabajando...  "
	arr["FRENCH",227]="Travail...  "
	arr["CATALAN",227]="Treballant...  "
	arr["PORTUGUESE",227]="Trabalhando...  "
	arr["RUSSIAN",227]="Работаем...  "
	arr["GREEK",227]="Δουλεύει...  "
	arr["ITALIAN",227]="Lavorando...  "
	arr["POLISH",227]="Praca...  "
	arr["GERMAN",227]="In der Arbeit...  "
	arr["TURKISH",227]="Çalışıyor...  "

	arr["ENGLISH",228]="                             Developed by ${author}"
	arr["SPANISH",228]="                             Programado por ${author}"
	arr["FRENCH",228]="                             Programmé par ${author}"
	arr["CATALAN",228]="                             Desenvolupat per ${author}"
	arr["PORTUGUESE",228]="                             Programado por ${author}"
	arr["RUSSIAN",228]="                             Создал ${author}"
	arr["GREEK",228]="                             Προγραμματισμένο από ${author}"
	arr["ITALIAN",228]="                             Sviluppato da ${author}"
	arr["POLISH",228]="                             Opracowany przez ${author}"
	arr["GERMAN",228]="                             Entwickelt von ${author}"
	arr["TURKISH",228]="${pending_of_translation}                              ${author} tarafından geliştirilen"

	arr["ENGLISH",229]="hashcat CPU, non GPU attacks"
	arr["SPANISH",229]="ataques hashcat CPU, no GPU"
	arr["FRENCH",229]="attaques hashcat CPU, pas GPU"
	arr["CATALAN",229]="atacs hashcat CPU, no GPU"
	arr["PORTUGUESE",229]="Ataques com hashcat usando CPU, não GPU"
	arr["RUSSIAN",229]="Атаки hashcat с использованием центрального процессора, без использования видеокарты"
	arr["GREEK",229]="επιθέσεις hashcat CPU, όχι GPU"
	arr["ITALIAN",229]="attacchi hashcat CPU, non GPU"
	arr["POLISH",229]="ataki hashcat CPU, nie GPU"
	arr["GERMAN",229]="CPU-hashcat-Angriffe, keine GPUs"
	arr["TURKISH",229]="hashcat CPU, GPU olmayan saldırılar"

	arr["ENGLISH",230]="3.  (hashcat) Dictionary attack against capture file"
	arr["SPANISH",230]="3.  (hashcat) Ataque de diccionario sobre fichero de captura"
	arr["FRENCH",230]="3.  (hashcat) Attaque de dictionnaire en utilisant le fichier de capture"
	arr["CATALAN",230]="3.  (hashcat) Atac de diccionari sobre fitxer de captura"
	arr["PORTUGUESE",230]="3.  (hashcat) Ataque com dicionário em um handshake"
	arr["RUSSIAN",230]="3.  (hashcat) Атака по словарю в отношению захваченного файла"
	arr["GREEK",230]="3.  (hashcat) Επίθεση με χρήση λεξικού σε αρχείο καταγραφής"
	arr["ITALIAN",230]="3.  (hashcat) Attacco di dizionario sul file di cattura"
	arr["POLISH",230]="3.  (hashcat) Atak słownikowy na plik przechwytywania"
	arr["GERMAN",230]="3.  (hashcat) Wörterbuchangriff auf die Aufnahmedatei"
	arr["TURKISH",230]="3.  (hashcat) Yakalama dosyasına karşı sözlük saldırısı"

	arr["ENGLISH",231]="4.  (hashcat) Bruteforce attack against capture file"
	arr["SPANISH",231]="4.  (hashcat) Ataque de fuerza bruta sobre fichero de captura"
	arr["FRENCH",231]="4.  (hashcat) Attaque de force brute en utilisant le fichier de capture"
	arr["CATALAN",231]="4.  (hashcat) Atac de força bruta sobre fitxer de captura"
	arr["PORTUGUESE",231]="4.  (hashcat) Ataque de força bruta em um handshake"
	arr["RUSSIAN",231]="4.  (hashcat) Атака рукопожатия полным перебором"
	arr["GREEK",231]="4.  (hashcat) Επίθεση ωμής βίας σε αρχείο καταγραφής"
	arr["ITALIAN",231]="4.  (hashcat) Attacco di forza bruta sul file di cattura"
	arr["POLISH",231]="4.  (hashcat) Atak brute force na plik przechwytywania"
	arr["GERMAN",231]="4.  (hashcat) Brute-Force-Angriff auf die Capture-Datei"
	arr["TURKISH",231]="4.  (hashcat) Yakalama dosyasına karşı bruteforce saldırısı"

	arr["ENGLISH",232]="5.  (hashcat) Rule based attack against capture file"
	arr["SPANISH",232]="5.  (hashcat) Ataque basado en reglas sobre fichero de captura"
	arr["FRENCH",232]="5.  (hashcat) Attaque fondé sur des règles en utilisant le fichier de capture"
	arr["CATALAN",232]="5.  (hashcat) Atac basat en regles sobre el fitxer de captura"
	arr["PORTUGUESE",232]="5.  (hashcat) Ataque baseado em regras em um arquivo handshake"
	arr["RUSSIAN",232]="5.  (hashcat) Атака на основе правила в отношении захваченного файла"
	arr["GREEK",232]="5.  (hashcat) Επίθεση κανόνων σε αρχείο καταγραφής"
	arr["ITALIAN",232]="5.  (hashcat) Attacco basato su regole contro il file di cattura"
	arr["POLISH",232]="5.  (hashcat) Atak bazujący na regułach na plik przechwytywania"
	arr["GERMAN",232]="5.  (hashcat) Regeln-basierender Angriff gegen der Capture-Datei"
	arr["TURKISH",232]="5.  (hashcat) Yakalama dosyasına karşı kural tabanlı saldırı"

	arr["ENGLISH",233]="Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${hashcat_potpath}]"
	arr["SPANISH",233]="Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${hashcat_potpath}]"
	arr["FRENCH",233]="Entrez le chemin où vous voulez enregistrer le fichier ou bien appuyez sur [Enter] pour utiliser le chemin proposé ${normal_color}[${hashcat_potpath}]"
	arr["CATALAN",233]="Escriu la ruta on guardarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${hashcat_potpath}]"
	arr["PORTUGUESE",233]="Digite o caminho onde armazenar o arquivo ou pressione [Enter] para aceitar o padrão ${normal_color}[${hashcat_potpath}]"
	arr["RUSSIAN",233]="Напечатайте путь к сохранённому файлу или нажмите [Enter] для принятия предложения по умолчанию ${normal_color}[${hashcat_potpath}]"
	arr["GREEK",233]="Πληκτρολογήστε το μονοπάτι για την αποθήκευση του αρχείου ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${hashcat_potpath}]"
	arr["ITALIAN",233]="Immettere il percorso dove memorizzare il file o premere [Enter] per accettare quello di default ${normal_color}[${hashcat_potpath}]"
	arr["POLISH",233]="Wpisz ścieżkę do zapisu pliku lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${hashcat_potpath}]"
	arr["GERMAN",233]="Schreiben Sie den Pfad wo die Datei gespeichert werden soll, oder drücken Sie die [Enter], um den Standardvorschlag zu akzeptieren ${normal_color}[${hashcat_potpath}]"
	arr["TURKISH",233]="Dosyayı depolamak için yolu yazın veya varsayılan teklifi kabul etmek için [Enter] tuşuna basın. ${normal_color}[${hashcat_potpath}]"

	arr["ENGLISH",234]="Contratulations!! It seems the key has been decrypted"
	arr["SPANISH",234]="Enhorabuena!! Parece que la clave ha sido desencriptada"
	arr["FRENCH",234]="Félicitations!! Il semble que la clef a été décryptée"
	arr["CATALAN",234]="Enhorabona!! Sembla que la clau ha estat desencriptada"
	arr["PORTUGUESE",234]="Parabéns!! Parece que a senha foi descriptografada"
	arr["RUSSIAN",234]="Поздравления!! Похоже на то, что ключ был расшифрован"
	arr["GREEK",234]="Συγχαρητήρια!! Φαίνεται πως το κλειδί αποκρυπτογραφήθηκε"
	arr["ITALIAN",234]="Congratulazioni!! Sembra che la password è stata decifrata"
	arr["POLISH",234]="Gratulacje!! Wygląda na to, że klucz został odszyfrowany"
	arr["GERMAN",234]="Herzlichen Glückwunsch!! Es scheint, dass der Schlüssel entschlüsselt wurde"
	arr["TURKISH",234]="Tebrikler!! Görünüşe göre key şifresi çözüldü"

	arr["ENGLISH",235]="Do you want to save the trophy file with the decrypted password? ${normal_color}${visual_choice}"
	arr["SPANISH",235]="¿Quieres guardar el fichero de trofeo con la clave desencriptada? ${normal_color}${visual_choice}"
	arr["FRENCH",235]="Voulez-vous enregistrer le fichier trophée avec le mot de passe déchiffré? ${normal_color}${visual_choice}"
	arr["CATALAN",235]="¿Vols desar el fitxer de trofeu amb la clau desencriptada? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",235]="Você quer salvar arquivo com a senha descriptografada? ${normal_color}${visual_choice}"
	arr["RUSSIAN",235]="Вы хотите сохранить трофейный файл с расшифрованным паролем? ${normal_color}${visual_choice}"
	arr["GREEK",235]="Θέλετε να αποθηκεύσετε το αρχείο τρόπαιο με τον αποκρυπτογραφημένο κωδικό πρόσβασης; ${normal_color}${visual_choice}"
	arr["ITALIAN",235]="Vuoi salvare il file trofeo con la password decifrata? ${normal_color}${visual_choice}"
	arr["POLISH",235]="Czy chcesz zapisać plik trofeum przy użyciu odszyfrowanego klucza? ${normal_color}${visual_choice}"
	arr["GERMAN",235]="Möchten Sie die Trophäendatei mit dem entschlüsselten Schlüssel speichern? ${normal_color}${visual_choice}"
	arr["TURKISH",235]="Trophy dosyasını şifresi çözülmüş olarak kaydetmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",236]="Hashcat trophy file generated successfully at [${normal_color}${potenteredpath}${blue_color}]"
	arr["SPANISH",236]="Fichero de trofeo hashcat generado con éxito en [${normal_color}${potenteredpath}${blue_color}]"
	arr["FRENCH",236]="Le fichier trophée hashcat a bien été crée dans [${normal_color}${potenteredpath}${blue_color}]"
	arr["CATALAN",236]="Fitxer de trofeu hashcat generat amb èxit a [${normal_color}${potenteredpath}${blue_color}]"
	arr["PORTUGUESE",236]="Arquivo de troféu hashcat gerado com sucesso [${normal_color}${potenteredpath}${blue_color}]"
	arr["RUSSIAN",236]="Трофейный файл hashcat был успешно сгенерирован в [${normal_color}${potenteredpath}${blue_color}]"
	arr["GREEK",236]="Το hashcat αρχείο τρόπαιο δημιουργήθηκε επιτυχώς [${normal_color}${potenteredpath}${blue_color}]"
	arr["ITALIAN",236]="File di trofeo di hashcat generato con successo [${normal_color}${potenteredpath}${blue_color}]"
	arr["POLISH",236]="Plik trofeum hashcat został pomyślnie wygenerowany w [${normal_color}${potenteredpath}${blue_color}]"
	arr["GERMAN",236]="Trophäen-Datei-Hashcat erfolgreich in [${normal_color}${potenteredpath}${blue_color}] generiert"
	arr["TURKISH",236]="Hashcat trophy dosyası başarıyla şurada oluşturuldu [${normal_color}${potenteredpath}${blue_color}]"

	arr["ENGLISH",237]="5.  Lowercase + uppercase + numeric + symbol chars"
	arr["SPANISH",237]="5.  Caracteres en minúsculas + mayúsculas + numéricos + símbolos"
	arr["FRENCH",237]="5.  Lettres minuscules et majuscules + chiffres + symboles"
	arr["CATALAN",237]="5.  Caràcters en minúscules + majúscules + numèrics + símbols"
	arr["PORTUGUESE",237]="5.  Caracteres em minúsculos + maiúsculas + números + símbolos"
	arr["RUSSIAN",237]="5.  Буквы нижнего регистра + верхнего регистра + цифры + символы"
	arr["GREEK",237]="5.  Πεζά + κεφαλαία + αριθμοί + σύμβολα"
	arr["ITALIAN",237]="5.  Caratteri minuscoli + maiuscoli + numeri + simboli"
	arr["POLISH",237]="5.  Małe litery + wielkie litery + cyfry + symbole"
	arr["GERMAN",237]="5.  Zeichen in Kleinbuchstaben + Großbuchstaben + Ziffern + Symbole"
	arr["TURKISH",237]="5.  Küçük + büyük harf + numerik + sembol karakterler"

	arr["ENGLISH",238]="Charset selection menu"
	arr["SPANISH",238]="Menú de selección de juego de caracteres"
	arr["FRENCH",238]="Menu de sélection du jeu de caractères"
	arr["CATALAN",238]="Menú de selecció de joc de caràcters"
	arr["PORTUGUESE",238]="Menu de seleção do conjunto de caracteres"
	arr["RUSSIAN",238]="Меню выбора набора символов"
	arr["GREEK",238]="Μενού επιλογής συμβολοσειράς"
	arr["ITALIAN",238]="Menú di selezione del set di caratteri"
	arr["POLISH",238]="Menu wyboru zestawu znaków"
	arr["GERMAN",238]="Zeichensatz-Auswahlmenü"
	arr["TURKISH",238]="Karakter kümesi seçim menüsü"

	arr["ENGLISH",239]="You already have selected a rules file during this session [${normal_color}${RULES}${blue_color}]"
	arr["SPANISH",239]="Ya tienes seleccionado un fichero de reglas en esta sesión [${normal_color}${RULES}${blue_color}]"
	arr["FRENCH",239]="Vous avez déjà sélectionné un fichier règles pour cette session ${normal_color}${RULES}${blue_color}]"
	arr["CATALAN",239]="Ja tens seleccionat un fitxer de regles en aquesta sessió [${normal_color}${RULES}${blue_color}]"
	arr["PORTUGUESE",239]="Você selecionou um arquivo de regras nesta sessão [${normal_color}${RULES}${blue_color}]"
	arr["RUSSIAN",239]="Во время этой сессии вы уже выбрали файл с правилами [${normal_color}${RULES}${blue_color}]"
	arr["GREEK",239]="Έχετε ήδη επιλέξει αρχείο κανόνων κατά τη διάρκεια τησ συνεδρίας [${normal_color}${RULES}${blue_color}]"
	arr["ITALIAN",239]="È giá stato selezionato un file di regole in questa sessione [${normal_color}${RULES}${blue_color}]"
	arr["POLISH",239]="Plik reguły został już wybrany w tej sesji [${normal_color}${RULES}${blue_color}]"
	arr["GERMAN",239]="Sie haben bereits eine Regeldatei ausgewählt [${normal_color}${RULES}${blue_color}]"
	arr["TURKISH",239]="Bu oturumda zaten bir kural dosyası seçtiniz [${normal_color}${RULES}${blue_color}]"

	arr["ENGLISH",240]="Do you want to use this already selected rules file? ${normal_color}${visual_choice}"
	arr["SPANISH",240]="¿Quieres utilizar este fichero de reglas ya seleccionado? ${normal_color}${visual_choice}"
	arr["FRENCH",240]="Souhaitez vous utiliser les règles déjà sélectionné? ${normal_color}${visual_choice}"
	arr["CATALAN",240]="¿Vols fer servir aquest fitxer de regles ja seleccionat? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",240]="Você quer usar esse arquivo regras já selecionado? ${normal_color}${visual_choice}"
	arr["RUSSIAN",240]="Вы хотите использовать этот уже выбранный файл правил? ${normal_color}${visual_choice}"
	arr["GREEK",240]="Θέλετε να χρησιμοποιήσετε το ήδη επιλεγμένο αρχείο κανόνων; ${normal_color}${visual_choice}"
	arr["ITALIAN",240]="Vuoi utilizzare questo file di regole già selezionato? ${normal_color}${visual_choice}"
	arr["POLISH",240]="Czy chcesz użyć tego już wybranego pliku reguł? ${normal_color}${visual_choice}"
	arr["GERMAN",240]="Möchten Sie diese ausgewählte Regeldatei verwenden? ${normal_color}${visual_choice}"
	arr["TURKISH",240]="Zaten seçilmiş olan kural dosyasını kullanmak istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",241]="The path to the rules file is valid. Script can continue..."
	arr["SPANISH",241]="La ruta al fichero de reglas es válida. El script puede continuar..."
	arr["FRENCH",241]="Le chemin vers le fichier règles est valide. Le script peut continuer..."
	arr["CATALAN",241]="La ruta cap al fitxer de regles és vàlida. El script pot continuar..."
	arr["PORTUGUESE",241]="O caminho para o arquivo de regras é válido. O script pode continuar..."
	arr["RUSSIAN",241]="Путь до файла с правилами верный. Скрипт может продолжать..."
	arr["GREEK",241]="Το μονοπάτι για το αρχείο κανόνων είναι έγκυρο. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",241]="Il percorso del file di regole è valido. Lo script può continuare..."
	arr["POLISH",241]="Ścieżka do pliku reguł jest prawidłowa. Skrypt może kontynuować..."
	arr["GERMAN",241]="Der Pfad zur Regeldatei ist gültig. Das Skript kann fortfahren..."
	arr["TURKISH",241]="Kural dosyasının dizini doğru. Yazılım devam edebilir..."

	arr["ENGLISH",242]="Enter the path of a rules file:"
	arr["SPANISH",242]="Introduce la ruta de un fichero de reglas:"
	arr["FRENCH",242]="Saisissez un chemin vers un fichier règles d'attaque:"
	arr["CATALAN",242]="Introdueix la ruta d'un fitxer de regles:"
	arr["PORTUGUESE",242]="Digite o caminho para um arquivo de regras:"
	arr["RUSSIAN",242]="Введите путь файла с правилами:"
	arr["GREEK",242]="Εισάγετε το μονοπάτι για ένα αρχείο κανόνων:"
	arr["ITALIAN",242]="Immettere il percorso di un file di regole:"
	arr["POLISH",242]="Wprowadź ścieżkę do pliku reguł:"
	arr["GERMAN",242]="Geben Sie den Pfad einer Regeldatei ein:"
	arr["TURKISH",242]="Kural dosyasının dizinini girin:"

	arr["ENGLISH",243]="Selected rules file: ${pink_color}${RULES}${normal_color}"
	arr["SPANISH",243]="Fichero de reglas seleccionado: ${pink_color}${RULES}${normal_color}"
	arr["FRENCH",243]="Fichier règles sélectionné: ${pink_color}${RULES}${normal_color}"
	arr["CATALAN",243]="Fitxer de regles seleccionat: ${pink_color}${RULES}${normal_color}"
	arr["PORTUGUESE",243]="Arquivo de regras selecionado: ${pink_color}${RULES}${normal_color}"
	arr["RUSSIAN",243]="Выбранный файл правил: ${pink_color}${RULES}${normal_color}"
	arr["GREEK",243]="Επιλεγμένο αρχείο κανόνων: ${pink_color}${RULES}${normal_color}"
	arr["ITALIAN",243]="File di regole selezionato: ${pink_color}${RULES}${normal_color}"
	arr["POLISH",243]="Wybrany plik reguł: ${pink_color}${RULES}${normal_color}"
	arr["GERMAN",243]="Ausgewählte Regeldatei: ${pink_color}${RULES}${normal_color}"
	arr["TURKISH",243]="Seçilen kural dosyası: ${pink_color}${RULES}${normal_color}"

	arr["ENGLISH",244]="Rule based attacks change the words of the dictionary list according to the rules written in the rules file itself. They are very useful. Some distros has predefined rule files (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["SPANISH",244]="Los ataques basados en reglas modifican las palabras de la lista del diccionario según las reglas escritas en el propio fichero de reglas. Son muy útiles. Algunas distros ya traen ficheros predefinidos de reglas (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["FRENCH",244]="Les attaques basées sur des règles modifient les mots du dictionnaire selon les règles établies dans le fichier règles. Ils sont très utiles. Certaines distros comportent des fichiers de règles prédéfinies (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["CATALAN",244]="Els atacs basats en regles modifiquen les paraules de la llista del diccionari segons les regles escrites en el propi fitxer de regles. Són molt útils. Algunes distros ja porten fitxers de regles predefinits (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["PORTUGUESE",244]="Ataques baseados em regras mudam as palavras de um dicionário de acordo com as regras escritas. Eles são muito úteis. Algumas distros já possuem regras predefinidas em (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["RUSSIAN",244]="Атака, основанная на правилах, изменяет слова из словаря в соответствии с правилами, написанными в самом файле правил. Они очень полезны. Некоторые дистрибутивы имеют предустановленные правила (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["GREEK",244]="Οι επιθέσεις κανόνων αλλάζουν τις λέξεις του λεξικού ανάλογα με τους κανόνες που έχουν γραφτεί στο αρχείο κανόνων. Είναι πολύ χρήσιμοι. Κάποιες διανομές έχουν προκαθορισμένα αρχεία κανόνων (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["ITALIAN",244]="Gli attacchi basato su regole cambiano le parole della lista del dizionario secondo le regole scritte nel file delle regole stesso. Essi sono molto utili. Alcune distribuzioni hanno giá file di regole predefiniti (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["POLISH",244]="Ataki bazujące na regułach modyfikują wyrazy ze słowników. Są bardzo przydatne. Niektóre dystrybucje Linuxa mają już predefiniowane pliki reguł (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["GERMAN",244]="Regelbasierte Angriffe modifizieren die Wörter in der Wörterbuchliste gemäß den Regeln, die in der Regeldatei selbst geschrieben sind. Sie sind sehr nützlich. Einige Distributionen bringen bereits vordefinierte Regeldateien mit (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"
	arr["TURKISH",244]="Kural tabanlı saldırılar, kural listesindeki kurallara göre sözlük listesindeki kelimeleri değiştirir. Çok faydalılar. Bazı dağıtımlarda önceden tanımlanmış kural dosyaları vardır (Kali: /usr/share/hashcat/rules // Wifislax: /opt/hashcat/rules)"

	arr["ENGLISH",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["SPANISH",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["FRENCH",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["CATALAN",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["PORTUGUESE",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["RUSSIAN",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["GREEK",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["ITALIAN",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["POLISH",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["GERMAN",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"
	arr["TURKISH",245]="// ${yellow_color}Chipset:${normal_color} ${unknown_chipsetvar}"

	arr["ENGLISH",246]="Every time you see a text with the prefix ${cyan_color}${pending_of_translation}${pink_color} acronym for \"Pending of Translation\", means the translation has been automatically generated and is still pending of review"
	arr["SPANISH",246]="Cada vez que veas un texto con el prefijo ${cyan_color}${pending_of_translation}${pink_color} acrónimo de \"Pending of Translation\", significa que su traducción ha sido generada automáticamente y que aún está pendiente de revisión"
	arr["FRENCH",246]="Chaque fois que vous voyez un texte précédé par ${cyan_color}${pending_of_translation}${pink_color} acronyme de \"Pending of Translation\" cela signifie que la traduction a été faite automatiquement et est en attente de correction"
	arr["CATALAN",246]="Cada vegada que vegis un text amb el prefix ${cyan_color}${pending_of_translation}${pink_color} acrònim de \"Pending of Translation\", vol dir que la traducció ha estat generada automàticament i encara està pendent de revisió"
	arr["PORTUGUESE",246]="Cada vez que você ver um texto com o prefixo ${cyan_color}${pending_of_translation}${pink_color} acrônimo para \"Pending of Translation\" significa que a tradução foi gerada automaticamente e ainda está pendente de revisão"
	arr["RUSSIAN",246]="Каждый раз, когда вы видите текст с префиксом ${cyan_color}${pending_of_translation}${pink_color} (акроним для \"Pending of Translation\"), это означает, что перевод был сгенерирован автоматически и ещё ожидает проверки"
	arr["GREEK",246]="Κάθε φορά που θα βλέπετε κείμενο με πρόθεμα ${cyan_color}${pending_of_translation}${pink_color} ακρωνύμιο για \"Pending of Translation\", σημαίνει πως η μετάφραση δημιουργήθηκε αυτόματα και αναμένεται κριτική"
	arr["ITALIAN",246]="Ogni volta che vedi un testo con il prefisso ${cyan_color}${pending_of_translation}${pink_color} acronimo di \"Pending of Translation\" significa che la traduzione è stata generata automaticamente ed è ancora in attesa di revisione"
	arr["POLISH",246]="Za każdym razem, gdy zobaczysz tekst z symbolem ${cyan_color}${pending_of_translation}${pink_color} dla \"Pending of Translation\", to tłumaczenie zostało wygenerowane automatycznie i nadal oczekuje na ręczną korektę"
	arr["GERMAN",246]="Jedes Mal, wenn Sie einen Text mit dem Präfix ${cyan_color}${pending_of_translation}${pink_color} Akronym für \"Pending of Translation\" sehen, bedeutet dies, dass Ihre Übersetzung automatisch erstellt wurde"
	arr["TURKISH",246]="Every time you see a text with the prefix ${cyan_color}${pending_of_translation}${pink_color} acronym for \"Pending of Translation\", means the translation has been automatically generated and is still pending of review"

	arr["ENGLISH",247]="Despite having all essential tools installed, your system uses airmon-zc instead of airmon-ng. In order to work properly you need to install ethtool and you don't have it right now. Please, install it and launch the script again"
	arr["SPANISH",247]="A pesar de tener todas las herramientas esenciales instaladas, tu sistema usa airmon-zc en lugar de airmon-ng. Para poder funcionar necesitas tener instalado ethtool y tú no lo tienes en este momento. Por favor, instálalo y vuelve a lanzar el script"
	arr["FRENCH",247]="En dépit d'avoir tous les outils essentiels installés votre système utilise airmon-zc au lieu de airmon-ng. Vous devez installer ethtool que vous n'avez pas à ce moment. S'il vous plaît, installez-le et relancez le script"
	arr["CATALAN",247]="Tot i tenir totes les eines essencials instal·lades, el teu sistema fa servir airmon-zc en lloc del airmon-ng. Per poder funcionar necessites tenir instal·lat ethtool i tu no el tens en aquest moment. Si us plau, instal·la-ho i torna a executar el script"
	arr["PORTUGUESE",247]="Apesar de ter todas as ferramentas essenciais instaladas, o sistema utiliza airmon-zc em vez de airmon-ng. Para funcionar você precisa instalar ethtool e você não tem neste momento. Por favor, instale e execute o script novamente"
	arr["RUSSIAN",247]="Не смотря на то, что все базовые инструменты установлены, система использует airmon-zc вместо airmon-ng. Чтобы работать должным образом, должен быть установлен пакет ethtool, а в данный момент он отсутствует. Пожалуйста, установите его и запустите скрипт снова"
	arr["GREEK",247]="Παρά του ότι είναι εγκατεστημένα όλα τα απραίτητα εργαλεία, το σύστημά σας χρησιμοποιεί το airmon-zc αντί το airmon-ng. Για να λειτουργήσει σωστά πρέπει να εγκαταστήσετε το ethtool το οποίο δεν το έχετε αυτή τη στιγμή. Παρακαλώ, εγκαταστήστε το και ξανανοίξτε το script"
	arr["ITALIAN",247]="Pur avendo tutti gli strumenti essenziali installati, il sistema utilizza airmon-zc invece di airmon-ng. Per funzionare è necessario installare ethtool e tu non lo hai in questo momento. Si prega di installaro e lanciare nuovamente lo script"
	arr["POLISH",247]="Mimo, iż zainstalowano wszystkie niezbędne narzędzia, twój system zamiast airmon-ng wykorzystuje airmon-zc. Aby móc korzystać ze skryptu, musisz zainstalować program ethtool, którego obecnie nie masz. Zainstaluj go i ponownie uruchom skrypt"
	arr["GERMAN",247]="Obwohl alle wesentlichen Tools installiert sind, verwendet Ihr System airmon-zc anstelle von airmon-ng. Um zu arbeiten, müssen Sie ethtool installiert haben und Sie haben es zur Zeit nicht. Bitte installieren Sie es und starten Sie das Skript erneut"
	arr["TURKISH",247]="Tüm gerekli araçlara sahip olmanıza rağmen, sisteminiz airmon-ng yerine airmon-zc kullanıyor. Düzgün çalışması için ethtool yüklemeniz gerekiyor ve şu anda ona sahip değilsiniz. Lütfen kurun ve komut dosyasını tekrar başlatın"

	arr["ENGLISH",248]="Language changed to Portuguese"
	arr["SPANISH",248]="Idioma cambiado a Portugués"
	arr["FRENCH",248]="Le script sera maintenant en Portugais"
	arr["CATALAN",248]="Idioma canviat a Portuguès"
	arr["PORTUGUESE",248]="Idioma alterado para Português"
	arr["RUSSIAN",248]="Язык изменён на португальский"
	arr["GREEK",248]="Η γλώσσα άλλαξε στα Πορτογαλικά"
	arr["ITALIAN",248]="Lingua cambiata a Portoghese"
	arr["POLISH",248]="Zmieniono język na Portugalski"
	arr["GERMAN",248]="Die Sprache wurde in Portugiesisch geändert"
	arr["TURKISH",248]="Dil portekizce olarak değiştirildi"

	arr["ENGLISH",249]="5.  Portuguese"
	arr["SPANISH",249]="5.  Portugués"
	arr["FRENCH",249]="5.  Portugais"
	arr["CATALAN",249]="5.  Portuguès"
	arr["PORTUGUESE",249]="5.  Português"
	arr["RUSSIAN",249]="5.  Португальский"
	arr["GREEK",249]="5.  Πορτογαλικά"
	arr["ITALIAN",249]="5.  Portoghese"
	arr["POLISH",249]="5.  Portugalski"
	arr["GERMAN",249]="5.  Portugiesisch"
	arr["TURKISH",249]="5.  Portekizce"

	arr["ENGLISH",250]="If you see any bad translation or just want ${cyan_color}${pending_of_translation}${pink_color} marks to dissapear, write me to ${normal_color}${mail}${pink_color} to collaborate with translations"
	arr["SPANISH",250]="Si ves alguna traducción incorrecta o quieres que desparezcan las marcas ${cyan_color}${pending_of_translation}${pink_color}, escríbeme a ${normal_color}${mail}${pink_color} para colaborar con las traducciones"
	arr["FRENCH",250]="Si vous voyez des erreurs et contresens ou si vous voulez voir les marques ${cyan_color}${pending_of_translation}${pink_color} disparaitre, écrivez à ${normal_color}${mail}${pink_color} pour collaborer avec les traductions"
	arr["CATALAN",250]="Si veus alguna traducció incorrecta o vols que desapareguin les marques ${cyan_color}${pending_of_translation}${pink_color}, escriu-me a ${normal_color}${mail}${pink_color} per col·laborar amb les traduccions"
	arr["PORTUGUESE",250]="Se você ver qualquer erro de tradução ou quer que as marcas ${cyan_color}${pending_of_translation}${pink_color} sejam retiradas, escreva para ${normal_color}${mail}${pink_color} para colaborar com as traduções"
	arr["RUSSIAN",250]="Если вы видите плохой перевод или просто хотите снять пометку ${cyan_color}${pending_of_translation}${pink_color} напишите мне на ${normal_color}${mail}${pink_color} для сотрудничества с переводчиками"
	arr["GREEK",250]="Αν δείτε κάποια λανθασμένη ή ατελής μετάφραση ή απλά θέλετε τα σημάδια ${cyan_color}${pending_of_translation}${pink_color} να εξαφανιστούν, στείλτε μου στο ${normal_color}${mail}${pink_color} για να συνεργαστούμε με τις μεταφράσεις"
	arr["ITALIAN",250]="Se vedi qualche errore di traduzione o vuoi che spariscano le marche ${cyan_color}${pending_of_translation}${pink_color}, scrivimi a ${normal_color}${mail}${pink_color} per collaborare con le traduzioni"
	arr["POLISH",250]="Jeśli widzisz nieprawidłowe tłumaczenie lub chcesz usunąć tagi ${cyan_color}${pending_of_translation}${pink_color}, napisz do mnie ${normal_color}${mail}${pink_color}, aby współpracować przy tłumaczeniu"
	arr["GERMAN",250]="Wenn Sie eine falsche Übersetzung sehen oder möchten, dass die Marken ${cyan_color}${pending_of_translation}${pink_color} verschwinden, schreiben Sie mir an ${normal_color}${mail}${pink_color}, um mit den Übersetzungen zusammenzuarbeiten"
	arr["TURKISH",250]="Eğer kötü bir çeviri gördüyseniz veya sadece çeviri yapmak istiyorsanız ${cyan_color}${pending_of_translation}${pink_color} işaretleyip bana yazın. ${normal_color}${mail}"

	arr["ENGLISH",251]="You have chosen the same language that was selected. No changes will be done"
	arr["SPANISH",251]="Has elegido el mismo idioma que estaba seleccionado. No se realizarán cambios"
	arr["FRENCH",251]="Vous venez de choisir la langue qui est en usage. Pas de changements"
	arr["CATALAN",251]="Has triat el mateix idioma que estava seleccionat. No es realitzaran canvis"
	arr["PORTUGUESE",251]="Você escolheu o mesmo idioma que estava selecionado. Nenhuma alteração será feita"
	arr["RUSSIAN",251]="Вы выбрали такой же язык, какой и был. Никаких изменений не будет сделано"
	arr["GREEK",251]="Επιλέξατε την ίδια γλώσσα που ήταν ήδη επιλεγμένη. Δεν θα γίνει καμία αλλαγή"
	arr["ITALIAN",251]="Hai scelto la stessa lingua che è giá selezionata. Non sará effettutata nessuna modifica"
	arr["POLISH",251]="Wybrałeś ten sam język, który jest używany. Żadne zmiany nie zostaną wprowadzone"
	arr["GERMAN",251]="Sie haben die selbe Sprache ausgewählt. Es werden keine Änderungen vorgenommen"
	arr["TURKISH",251]="Seçilmiş olan dili seçtiniz. Hiçbir değişiklik yapılmayacak"

	arr["ENGLISH",252]="7.  Evil Twin attacks menu"
	arr["SPANISH",252]="7.  Menú de ataques Evil Twin"
	arr["FRENCH",252]="7.  Menu des attaques Evil Twin"
	arr["CATALAN",252]="7.  Menú d'atacs Evil Twin"
	arr["PORTUGUESE",252]="7.  Menu de ataques Evil Twin"
	arr["RUSSIAN",252]="7.  Меню атак Злой Двойник"
	arr["GREEK",252]="7.  Μενού επιθέσεων Evil Twin"
	arr["ITALIAN",252]="7.  Menu degli attacchi Evil Twin"
	arr["POLISH",252]="7.  Menu ataków Evil Twin"
	arr["GERMAN",252]="7.  Evil Twin Angriffsmenü"
	arr["TURKISH",252]="7.  Şeytani İkiz saldırısı menüsü"

	arr["ENGLISH",253]="Evil Twin attacks menu"
	arr["SPANISH",253]="Menú de ataques Evil Twin"
	arr["FRENCH",253]="Menu des attaques Evil Twin"
	arr["CATALAN",253]="Menú d'atacs Evil Twin"
	arr["PORTUGUESE",253]="Menu de ataques Evil Twin"
	arr["RUSSIAN",253]="Меню атак Злой Двойник"
	arr["GREEK",253]="Μενού επιθέσεων Evil Twin"
	arr["ITALIAN",253]="Menu degli attacchi Evil Twin"
	arr["POLISH",253]="Menu ataków Evil Twin"
	arr["GERMAN",253]="Evil Twin Angriffsmenü"
	arr["TURKISH",253]="Şeytani İkiz saldırısı menüsü"

	arr["ENGLISH",254]="In order to use the Evil Twin just AP and sniffing attacks, you must have another one interface in addition to the wifi network interface will become the AP, which will provide internet access to other clients on the network. This doesn't need to be wifi, can be ethernet"
	arr["SPANISH",254]="Para utilizar los ataques de Evil Twin de solo AP y con sniffing, deberás tener además de la interfaz wifi que se transformará en el AP, otra interfaz de red con acceso a internet para proporcionar este servicio a otros clientes de la red. Esta no hace falta que sea wifi, puede ser ethernet"
	arr["FRENCH",254]="Pour effectuer l'attaque Evil Twin combinant Rogue AP et capture des données vous avez besoin d'une interface réseau en plus de celle utilisée pour créer le point d'accès. Cette interface supplémentaire devra être connecté à l'internet afin d'en proportionner l'accès aux clients du réseau. L'interface peut être une interface ethernet ou wifi"
	arr["CATALAN",254]="Per utilitzar els atacs d'Evil Twin només amb AP i sniffing, hauràs de tenir a més de la interfície wifi que es transformarà en el AP, una altre interfície de xarxa amb accés a internet per proporcionar aquest servei a altres clients de la xarxa. Aquesta no cal que sigui wifi, pot ser ethernet"
	arr["PORTUGUESE",254]="Para usar ataques Evil Twin Somente AP e com sniffing, você deve ter além da interface wifi que se tornará o AP, uma outra interface de rede com acesso à internet para fornecer este serviço a outros clientes da rede. Não precisa ser wifi, pode ser ethernet"
	arr["RUSSIAN",254]="Чтобы использовать Злого Двойника точки доступа и атаку сниффинга, вы должны иметь другой интерфейс в дополнение к сетевому интерфейсу wifi. Сетевой интерфейс wifi станет точкой доступа, к которому будут подключаться жертвы. Для того, чтобы у этой точки доступа было Интернет-подключение и используется второй сетевой адаптер. Ему необязательно быть wifi, достаточно ethernet"
	arr["GREEK",254]="Για να χρησιμοποιήσετε τις επιθέσεις sniffing και Evil Twin με AP, πρέπει να έχετε άλλη μία διεπαφή παράλληλα με την διεπαφή δικτύου wifi που θα γίνει AP, η οποία θα παρέχει πρόσβαση στο διαδίκτυο στους άλλες χρήστες του δικτύου. Δεν χρειάζεται να είναι wifi, μπορεί να έιναι και ethernet"
	arr["ITALIAN",254]="Per utilizzare gli attacchi Evil Twin con solo AP e con sniffing, è necessario che, oltre all'interfaccia wifi che diventerà l'AP, sia presente un'altra interfaccia di rete con connessione internet per fornire questo servizio agli altri clienti della rete. Questo non ha bisogno di essere wifi, può essere ethernet"
	arr["POLISH",254]="Aby używać ataków Evil Twin tylko z AP i sniffingiem pakietów, musisz oprócz interfejsu wifi, który stanie się AP, posiadać drugi interfejs sieciowy z dostępem do internetu, aby go udzielić innym klientom w sieci. To nie musi być wifi, może to być ethernet"
	arr["GERMAN",254]="Um die Evil-Twin-Angriffe von nur AP und mit Sniffing zu verwenden, müssen Sie zusätzlich zu der WLAN-Interface, die in den AP umgewandelt wird, eine andere Netzwerk-Interface mit Internetzugang haben, um diesen Dienst anderen Clients im Netzwerk bereitzustellen. Dies muss nicht WLAN sein, es kann Ethernet sein"
	arr["TURKISH",254]="Evil Twin'i sadece AP ve sniffing saldırılarını kullanmak için, ağdaki diğer istemcilere internet erişimi sağlayacak olan WiFi ağ arayüzüne ek olarak başka bir arabiriminiz de AP olacaktır. Bu wifi olması gerekmez, ethernet olabilir"

	arr["ENGLISH",255]="without sniffing, just AP"
	arr["SPANISH",255]="sin sniffing, solo AP"
	arr["FRENCH",255]="rogue AP sans capture des données"
	arr["CATALAN",255]="sense sniffing, només AP"
	arr["PORTUGUESE",255]="somente AP, sem sniffing"
	arr["RUSSIAN",255]="без сниффинга, просто ТД"
	arr["GREEK",255]="χωρίς sniffing, μόνο AP"
	arr["ITALIAN",255]="senza sniffing, solo AP"
	arr["POLISH",255]="brak sniffingu, tylko AP"
	arr["GERMAN",255]="kein Sniffing, nur AP"
	arr["TURKISH",255]="siniffing olmadan, sadece AP"

	arr["ENGLISH",256]="5.  Evil Twin attack just AP"
	arr["SPANISH",256]="5.  Ataque Evil Twin solo AP"
	arr["FRENCH",256]="5.  Attaque Evil Twin Rogue AP simple"
	arr["CATALAN",256]="5.  Atac Evil Twin només AP"
	arr["PORTUGUESE",256]="5.  Ataque Evil Twin só AP"
	arr["RUSSIAN",256]="5.  Атака Злой Двойник, только ТД"
	arr["GREEK",256]="5.  Επίθεση Evil Twin μόνο AP"
	arr["ITALIAN",256]="5.  Attacco Evil Twin solo AP"
	arr["POLISH",256]="5.  Atak Evil Twin tylko AP"
	arr["GERMAN",256]="5.  Attack Evil Twin nur AP"
	arr["TURKISH",256]="5.  Şeytani İkiz saldırısı sadece AP"

	arr["ENGLISH",257]="with sniffing"
	arr["SPANISH",257]="con sniffing"
	arr["FRENCH",257]="avec capture des données"
	arr["CATALAN",257]="amb sniffing"
	arr["PORTUGUESE",257]="com sniffing"
	arr["RUSSIAN",257]="со сниффингом"
	arr["GREEK",257]="με sniffing"
	arr["ITALIAN",257]="con sniffing"
	arr["POLISH",257]="ze sniffingiem"
	arr["GERMAN",257]="mit sniffing"
	arr["TURKISH",257]="sniffing ile"

	arr["ENGLISH",258]="If you use the attack without sniffing, just AP, you'll can use any external to script sniffer software"
	arr["SPANISH",258]="Si utilizas el ataque sin sniffing, solo AP, podrás usar cualquier programa sniffer externo al script"
	arr["FRENCH",258]="Si vous lancez l'attaque sans capture des données (Rogue AP) vous pouvez utiliser un programme externe pour les capturer"
	arr["CATALAN",258]="Si utilitzes l'atac sense sniffing, només AP, podràs fer servir qualsevol programa sniffer extern a l'script"
	arr["PORTUGUESE",258]="Se você usar o ataque sem sniffing, apenas AP, você pode usar qualquer programa sniffer externo ao script"
	arr["RUSSIAN",258]="Если вы используете атаку без сниффинга, только ТД, то вы сможете использовать любое внешнее ПО для сниффинга"
	arr["GREEK",258]="Αν χρησιμοποιήσετε την επίθεση χωρίς sniffing, μόνο AP, θα μπορείτε να χρησιμοποιήσετε οποιοδήποτε εξωτερίκό sniffer script"
	arr["ITALIAN",258]="Se si utilizza l'attacco senza sniffing, solo AP, è possibile utilizzare qualsiasi programma di sniffer esterno per lo script"
	arr["POLISH",258]="Jeśli użyjesz ataku bez sniffingu, tylko AP, możesz użyć dowolnego zewnętrznego programu sniffującego"
	arr["GERMAN",258]="Wenn Sie den Angriff ohne Sniffing, nur AP, verwenden, können Sie jedes Sniffer-Programm außerhalb des Skripts verwenden"
	arr["TURKISH",258]="Saldırıyı kullanmadan sadece AP'yi kullanırsanız, sniffer yazılımı için herhangi bir harici komut kullanabilirsiniz"

	arr["ENGLISH",259]="6.  Evil Twin AP attack with sniffing"
	arr["SPANISH",259]="6.  Ataque Evil Twin AP con sniffing"
	arr["FRENCH",259]="6.  Attaque Evil Twin avec Rogue AP et capture des données"
	arr["CATALAN",259]="6.  Atac Evil Twin AP amb sniffing"
	arr["PORTUGUESE",259]="6.  Ataque Evil Twin AP com sniffing"
	arr["RUSSIAN",259]="6.  Атака Злой Двойник ТД со сниффингом"
	arr["GREEK",259]="6.  Επίθεση Evil Twin AP με sniffing"
	arr["ITALIAN",259]="6.  Attacco Evil Twin AP con sniffing"
	arr["POLISH",259]="6.  Atak Evil Twin AP ze sniffingiem"
	arr["GERMAN",259]="6.  Evil Twin AP Angriff mit Sniffing"
	arr["TURKISH",259]="6.  Şeytani İkiz AP Saldırısı sniffing ile birlikte"

	arr["ENGLISH",260]="Language changed to German"
	arr["SPANISH",260]="Idioma cambiado a Alemán"
	arr["FRENCH",260]="Le script sera maintenant en Allemand"
	arr["CATALAN",260]="Idioma canviat a Alemany"
	arr["PORTUGUESE",260]="Idioma alterado para Alemão"
	arr["RUSSIAN",260]="Язык изменён на Немецкий"
	arr["GREEK",260]="Η γλώσσα άλλαξε στα Γερμανικά"
	arr["ITALIAN",260]="Lingua cambiata a Tedesco"
	arr["POLISH",260]="Zmieniono język na Niemiecki"
	arr["GERMAN",260]="Sprache wurde auf Deutsch geändert"
	arr["TURKISH",260]="Dil Almanca olarak değiştirildi"

	arr["ENGLISH",261]="7.  Evil Twin AP attack with sniffing and sslstrip"
	arr["SPANISH",261]="7.  Ataque Evil Twin AP con sniffing y sslstrip"
	arr["FRENCH",261]="7.  Attaque Evil Twin avec capture des données et sslstrip"
	arr["CATALAN",261]="7.  Atac Evil Twin AP amb sniffing i sslstrip"
	arr["PORTUGUESE",261]="7.  Ataque Evil Twin AP com sniffing e sslstrip"
	arr["RUSSIAN",261]="7.  Атака Злой Двойник ТД со сниффингом и sslstrip"
	arr["GREEK",261]="7.  Επίθεση Evil Twin AP με sniffing και sslstrip"
	arr["ITALIAN",261]="7.  Attacco Evil Twin AP con sniffing e sslstrip"
	arr["POLISH",261]="7.  Ataku Evil Twin AP ze sniffingiem i sslstrip"
	arr["GERMAN",261]="7.  Evil Twin AP Angriff mit Sniffing und sslstrip"
	arr["TURKISH",261]="7.  Şeytani İkiz AP saldırısı sniffing ve sslstrip ile birlikte"

	arr["ENGLISH",262]="without sniffing, captive portal"
	arr["SPANISH",262]="sin sniffing, portal cautivo"
	arr["FRENCH",262]="sans capture des données avec portail captif"
	arr["CATALAN",262]="sense sniffing, portal captiu"
	arr["PORTUGUESE",262]="sem sniffing, portal cativo"
	arr["RUSSIAN",262]="без сниффинга, перехватывающий портал"
	arr["GREEK",262]="χωρίς sniffing, captive portal"
	arr["ITALIAN",262]="senza sniffing, captive portal"
	arr["POLISH",262]="bez sniffingu, captive portal"
	arr["GERMAN",262]="ohne Sniffing, Captive Portal"
	arr["TURKISH",262]="sniffing olmadan, esaret portalı"

	arr["ENGLISH",263]="9.  Evil Twin AP attack with captive portal (monitor mode needed)"
	arr["SPANISH",263]="9.  Ataque Evil Twin AP con portal cautivo (modo monitor requerido)"
	arr["FRENCH",263]="9.  Attaque Evil Twin avec portail captif (mode moniteur nécessaire)"
	arr["CATALAN",263]="9.  Atac Evil Twin AP amb portal captiu (es requereix mode monitor)"
	arr["PORTUGUESE",263]="9.  Ataque Evil Twin AP com portal cativo (modo monitor obrigatório)"
	arr["RUSSIAN",263]="9.  Атака Злой Двойник ТД с перехватывающим порталом (необходим режим монитора)"
	arr["GREEK",263]="9.  Επίθεση Evil Twin AP με captive portal (χρειάζεται η κατάσταση παρακολούθησης)"
	arr["ITALIAN",263]="9.  Attacco Evil Twin AP con captive portal (modalità monitor richiesta)"
	arr["POLISH",263]="9.  Atak Evil Twin AP z captive portal (wymagany tryb monitorowania)"
	arr["GERMAN",263]="Evil Twin AP Angriff mit Captive Portal (monitor-Modus erforderlich)"
	arr["TURKISH",263]="9.  Şeytani İkiz AP saldırısı esaret portalı ile birlikte (izleme modu gerekli)"

	arr["ENGLISH",264]="The captive portal attack tries to one of the network clients provide us the password for the wifi network by entering it on our portal"
	arr["SPANISH",264]="El ataque del portal cautivo intentará conseguir que uno de los clientes de la red nos proporcione la contraseña de la red wifi introduciéndola en nuestro portal"
	arr["FRENCH",264]="Le portail captif d'attaque tente d'obtenir l'un des clients du réseau nous fournir le mot de passe pour le réseau sans fil en entrant sur notre site"
	arr["CATALAN",264]="L'atac de portal captiu intenta aconseguir que un dels clients de la xarxa ens proporcioni la contrasenya de la xarxa wifi introduint-la al nostre portal"
	arr["PORTUGUESE",264]="O ataque com portal cativo tenta fazer com que um dos clientes da rede nos forneça a senha digitando-a em nosso site"
	arr["RUSSIAN",264]="Атака с перехватывающим порталом заключается в том, что мы ждём когда кто-то из пользователей введёт верный пароль от Wi-Fi на веб-странице, которую мы ему показываем"
	arr["GREEK",264]="Η επίθεση captive portal κάνει έναν από τους χρήστες του δικτύου να μας παρέχει τον κωδικό πρόσβασης του δικτύου wifi βάζοντάς τον στο portal μας"
	arr["ITALIAN",264]="L'attacco con il captive portal cercherà di ottenere che uno dei clienti della rete ci dia la password per la rete wireless inserendola sul nostro sito"
	arr["POLISH",264]="Atak w portalu captive spróbuje uzyskać hasło WiFi od jednego z klientów sieci, który wprowadzi je w naszym portalu"
	arr["GERMAN",264]="Der Angriff des Captive-Portals wird versuchen, einen der Clients des Netzwerks dazu zu bringen, uns das WLAN-Passwort zur Verfügung zu stellen, indem sie es in unser Portal eingeben"
	arr["TURKISH",264]="Esaret Portalı saldırısı, ağ istemcilerinden birinin portalımıza girerek wifi ağı için şifre sağlamasını dener"

	arr["ENGLISH",265]="Evil Twin deauth"
	arr["SPANISH",265]="Desautenticación para Evil Twin"
	arr["FRENCH",265]="Dés-authentification pour Evil Twin"
	arr["CATALAN",265]="Desautenticació per Evil Twin"
	arr["PORTUGUESE",265]="Desautenticação para Evil Twin"
	arr["RUSSIAN",265]="Деаутентификация для Злого Двойника"
	arr["GREEK",265]="Evil Twin deauth"
	arr["ITALIAN",265]="Desautenticazione per Evil Twin"
	arr["POLISH",265]="Deautentykacja dla Evil Twin"
	arr["GERMAN",265]="Deauthentifizierung für das Evil Twin"
	arr["TURKISH",265]="Şeytani İkiz deauth"

	arr["ENGLISH",266]="0.  Return to Evil Twin attacks menu"
	arr["SPANISH",266]="0.  Volver al menú de ataques Evil Twin"
	arr["FRENCH",266]="0.  Retour au menu d'attaques Evil Twin"
	arr["CATALAN",266]="0.  Tornar al menú d'atacs Evil Twin"
	arr["PORTUGUESE",266]="0.  Voltar ao menu de ataques Evil Twin"
	arr["RUSSIAN",266]="0.  Вернуться в меню атак Злой Двойник"
	arr["GREEK",266]="0.  Επιστροφή στο μενού επιθέσεων Evil Twin"
	arr["ITALIAN",266]="0.  Tornare al menu attacchi Evil Twin"
	arr["POLISH",266]="0.  Wróć do menu Evil Twin Atak"
	arr["GERMAN",266]="0.  Zurück zum Evil Twin Angriffsmenü"
	arr["TURKISH",266]="0.  Şeytani İkiz saldırı menüsüne geri dön"

	arr["ENGLISH",267]="If you can't deauth clients from an AP using an attack, choose another one :)"
	arr["SPANISH",267]="Si no consigues desautenticar a los clientes de un AP con un ataque, elige otro :)"
	arr["FRENCH",267]="Si vous ne pouvez pas dé-authentifier des clients avec une attaque, choisissez-en une autre :)"
	arr["CATALAN",267]="Si no aconsegueixes desautenticar als clients d'un AP amb un atac, tria un altre :)"
	arr["PORTUGUESE",267]="Se você não conseguir desautenticar clientes de um AP usando um ataque, escolha outro :)"
	arr["RUSSIAN",267]="Если вы не можете деаутентифицировать клиентов от ТД используя эту атаку, выберите другую :)"
	arr["GREEK",267]="Αν δεν μπορείτε να κάνετε deauth τους χρήστες από ένα AP χρησιμοποιώντας μία επίθεση, διαλέξτε κάποια άλλη :)"
	arr["ITALIAN",267]="Se non è possibile scollegare i clienti da un AP con un attacco, scegline un altro :)"
	arr["POLISH",267]="Jeśli nie możesz deautentykować klientów AP tym atakiem, wybierz inny :)"
	arr["GERMAN",267]="Wenn es Ihnen nicht gelingt, die Clients eines AP mit einem Angriff zu deaktivieren, wählen Sie einen anderen :)"
	arr["TURKISH",267]="Eğer deauth yapamadıysanız başka bir yöntem seçiniz :)"

	arr["ENGLISH",268]="With this attack, we'll try to deauth clients from the legitimate AP. Hopefully they'll reconnect to our Evil Twin AP"
	arr["SPANISH",268]="Con este ataque, intentaremos desautenticar a los clientes del AP legítimo. Con suerte reconectarán pero a nuestro Evil Twin AP"
	arr["FRENCH",268]="Avec cette attaque nous essayons de déconnecter des clients du point d'accès légitime en espérant qu'ils se connectent au notre Evil Twin AP"
	arr["CATALAN",268]="Amb aquest atac, intentarem desautenticar als clients del AP legítim. Amb sort reconectarán però al nostre Evil Twin AP"
	arr["PORTUGUESE",268]="Com este ataque, tentamos desautenticar clientes do AP legítimo e esperemos que eles se reconectem no nosso AP Evil Twin"
	arr["RUSSIAN",268]="Этой атакой мы попытаемся деаутентифицировать клиентов от легитимной ТД. В надежде, что они переподключатся к нашему Злому Двойнику ТД"
	arr["GREEK",268]="Με αυτήν την επίθεση, θα προσπαθήσουμε να κάνουμε deauth τους χρήστες από το αρχικό AP. Ας ελπίσουμε ότι θα επανασυνδεθούν στο Evil Twin AP μας"
	arr["ITALIAN",268]="Con questo attacco, si cerca di scollegare i clienti dal AP legittimo. Se abbiamo fortuna si riconnetteranno al nostro Evil Twin AP"
	arr["POLISH",268]="W tym ataku podejmiemy próbę deautentykacji legalnych klientów AP. Dzięki temu być może połączą się z naszym Evil Twin AP"
	arr["GERMAN",268]="Mit diesem Angriff werden wir versuchen, die Clients des legitimen AP zu deaktivieren. Hoffentlich werden sie sich wieder mit unserem Evil Twin AP verbinden"
	arr["TURKISH",268]="Bu saldırı ile, istemcileri meşru AP'den çıkarmaya çalışacağız. Umarız Şeytani İkiz AP'ye tekrar bağlanırlar"

	arr["ENGLISH",269]="To perform an Evil Twin attack you'll need to be very close to the target AP or have a very powerful wifi antenna. Your signal must reach clients equally strong or more than the legitimate AP"
	arr["SPANISH",269]="Para realizar un ataque Evil Twin necesitarás estar muy cerca del AP objetivo o tener una antena wifi muy potente. Tu señal ha de llegar a los clientes igual de fuerte o más que la del AP legítimo"
	arr["FRENCH",269]="Pour mener à bien une attaque Evil Twin il vous faut être dans de bonnes conditions d'émission et de réception tantôt avec le point d'accès qu'avec le(s) client(s)"
	arr["CATALAN",269]="Per realitzar un atac Evil Twin et caldrà estar molt a prop de l'AP objectiu o tenir una antena wifi molt potent. El teu senyal ha d'arribar als clients igual de fort o més que la de l'AP legítim"
	arr["PORTUGUESE",269]="Para fazer um ataque Evil Twin você precisa estar perto do alvo ou ter uma antena wifi muito poderosa. Seu sinal deve atingir os clientes igualmente forte ou mais do que o AP legítimo"
	arr["RUSSIAN",269]="Для выполнения атаки Злой Двойник, вы должны быть очень близко к целевой ТД или иметь очень мощную wifi антенну. Ваш сигнал должен достигать клиентов с такой же силой, или даже сильнее, чем легитимная ТД"
	arr["GREEK",269]="Για να πραγματοποιηθεί μία επίθεση Evil Twin θα πρέπει να είστε αρκετά κοντά στο AP-στόχο ή να έχετε μία πολύ ισχυρή κεραία. Το σήμα πρέπει να φτάνει στους χρήστες το ίδιο ή περισσότερο από το αρχικό AP"
	arr["ITALIAN",269]="Per un attacco Evil Twin c'è bisogno di essere vicino al punto di accesso obiettivo o di avere un'antenna wifi potente. Il segnale deve raggiungere i clienti come o piú forte che il legittimo AP"
	arr["POLISH",269]="Aby wykonać atak Evil Twin, musisz być bardzo blisko docelowego punktu dostępowego lub mieć bardzo silną antenę wifi. Twój sygnał musi dotrzeć do klientów con najmniej tak samo silny lub silniejszy od legalnego AP"
	arr["GERMAN",269]="Um einen Evil Twin Angriff durchzuführen, müssen Sie sehr nah am Ziel-AP sein oder eine sehr leistungsfähige WLAN-Antenne haben. Ihr Signal muss Kunden als stark oder mindestens stärker als die legitime AP erreichen"
	arr["TURKISH",269]="Şeytani İkiz bir saldırı gerçekleştirmek için hedef AP'ye çok yakın olmanız veya çok güçlü bir wifi antenine sahip olmanız gerekir. Sinyaliniz, müşterilere yasal AP'den eşit veya daha güçlü olmalıdır"

	arr["ENGLISH",270]="Evil Twin attack just AP"
	arr["SPANISH",270]="Ataque Evil Twin solo AP"
	arr["FRENCH",270]="Attaque Evil Twin Rogue AP simple"
	arr["CATALAN",270]="Atac Evil Twin només AP"
	arr["PORTUGUESE",270]="Ataque Evil Twin só AP"
	arr["RUSSIAN",270]="Атака Злой Двойник, просто ТД"
	arr["GREEK",270]="Επίθεση Evil Twin μόνο AP"
	arr["ITALIAN",270]="Attacco Evil Twin solo AP"
	arr["POLISH",270]="Atak Evil Twin tylko AP"
	arr["GERMAN",270]="Evil Twin Angriff nur AP"
	arr["TURKISH",270]="Şeytani İkiz saldırısı sadece AP"

	arr["ENGLISH",271]="Selected BSSID: ${pink_color}None${normal_color}"
	arr["SPANISH",271]="BSSID seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",271]="BSSID sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",271]="BSSID seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",271]="BSSID selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",271]="Выбранная BSSID: ${pink_color}Нет${normal_color}"
	arr["GREEK",271]="Επιλεγμένο BSSID: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",271]="BSSID selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",271]="Wybrany BSSID: ${pink_color}Brak${normal_color}"
	arr["GERMAN",271]="Ausgewählte BSSID: ${pink_color}Keine${normal_color}"
	arr["TURKISH",271]="Seçilen BSSID: ${pink_color}None${normal_color}"

	arr["ENGLISH",272]="Deauthentication chosen method: ${pink_color}${et_dos_attack}${normal_color}"
	arr["SPANISH",272]="Método elegido de desautenticación: ${pink_color}${et_dos_attack}${normal_color}"
	arr["FRENCH",272]="Méthode de dés-authentification: ${pink_color}${et_dos_attack}${normal_color}"
	arr["CATALAN",272]="Mètode elegit d'desautenticació: ${pink_color}${et_dos_attack}${normal_color}"
	arr["PORTUGUESE",272]="Método de desautenticação escolhido: ${pink_color}${et_dos_attack}${normal_color}"
	arr["RUSSIAN",272]="Выбор метода деаутентификации: ${pink_color}${et_dos_attack}${normal_color}"
	arr["GREEK",272]="Επιλεγμένη μέθοδος για deauthentication: ${pink_color}${et_dos_attack}${normal_color}"
	arr["ITALIAN",272]="Metodo deauth scelto: ${pink_color}${et_dos_attack}${normal_color}"
	arr["POLISH",272]="Wybrana metoda deautentykacji: ${pink_color}${et_dos_attack}${normal_color}"
	arr["GERMAN",272]="Designierte Methode der De-Authentifizierung: ${pink_color}${et_dos_attack}${normal_color}"
	arr["TURKISH",272]="Deauthentication seçilen yöntem: ${pink_color}${et_dos_attack}${normal_color}"

	arr["ENGLISH",273]="Selected channel: ${pink_color}None${normal_color}"
	arr["SPANISH",273]="Canal seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",273]="Canal sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",273]="Canal seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",273]="Canal selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",273]="Выбранный канал: ${pink_color}Нет${normal_color}"
	arr["GREEK",273]="Επιλεγμένο κανάλι: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",273]="Canale selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",273]="Wybrany kanał: ${pink_color}Brak${normal_color}"
	arr["GERMAN",273]="Ausgewählter Kanal: ${pink_color}Keinen${normal_color}"
	arr["TURKISH",273]="Seçilen kanal: ${pink_color}None${normal_color}"

	arr["ENGLISH",274]="Selected ESSID: ${pink_color}None${normal_color}"
	arr["SPANISH",274]="ESSID seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",274]="ESSID sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",274]="ESSID seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",274]="ESSID selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",274]="Выбранная ESSID: ${pink_color}Нет${normal_color}"
	arr["GREEK",274]="Επιλεγμένο ESSID: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",274]="ESSID selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",274]="Wybrany ESSID: ${pink_color}Brak${normal_color}"
	arr["GERMAN",274]="Ausgewähltes ESSID: ${pink_color}Keines${normal_color}"
	arr["TURKISH",274]="Seçilen ESSID: ${pink_color}None${normal_color}"

	arr["ENGLISH",275]="In addition to the software requirements that already meet if you get here, you need to provide target AP data to carry out the attack"
	arr["SPANISH",275]="Además de los requisitos de software, que ya cumples si has llegado hasta aquí, es necesario proporcionar los datos del AP objetivo para llevar a cabo el ataque"
	arr["FRENCH",275]="Maintenant que les dépendances ont étés vérifiées il vous faut saisir les donnés sur le point d'accès cible"
	arr["CATALAN",275]="A més dels requisits de software, que ja compleixes si has arribat fins aquí, cal proporcionar les dades de l'AP objectiu per dur a terme l'atac"
	arr["PORTUGUESE",275]="Além dos requisitos de software, você precisa fornecer dados do AP objetivo para realizar o ataque"
	arr["RUSSIAN",275]="В дополнение к требованиям по программному обеспечению, которым вы соответствуете, вам нужно обеспечить Интернет подключение вашей ТД для выполнения атаки"
	arr["GREEK",275]="Εκτός από τις απαιτήσεις του λογισμικού οι οποίες πληρούνται αν έχετε φτάσει έως εδώ, χρειάζεται να παρέχετε δεδομένα AP-στόχου για να πραγματοποιηθεί η επίθεση"
	arr["ITALIAN",275]="Oltre ai requisiti software che già soddisfi se sei arrivato qui, è necessario fornire i dati dell'AP obiettivo per effettuare l'attacco"
	arr["POLISH",275]="Oprócz wymogów dotyczących oprogramowania, które już spełniłeś, konieczne jest dostarczenie danych AP docelowego do przeprowadzenia ataku"
	arr["GERMAN",275]="Zusätzlich zu den Softwareanforderungen, die Sie bereits erfüllen, wenn Sie hier angekommen sind, ist es notwendig, die Daten des Ziel-AP bereitzustellen, um den Angriff auszuführen"
	arr["TURKISH",275]="Buraya zaten ulaşmış olduğunuz yazılım gereksinimlerine ek olarak, saldırıyı gerçekleştirmek için hedef AP verileri sağlamanız gerekir"

	arr["ENGLISH",276]="On top of this screen you can see all that is needed to perform the attack. If any of the parameters has no value, you can enter it manually, or you can go back to select a target and then return here"
	arr["SPANISH",276]="En la parte superior de esta pantalla puedes ver todo lo que hace falta para realizar el ataque. Si alguno de los parámetros no tiene valor, puedes introducirlo manualmente, o puedes retroceder para seleccionar un objetivo y regresar aquí"
	arr["FRENCH",276]="Vous pouvez voir dans la partie supérieure de l'écran tout ce qui est nécessaire à l'attaque. Si l'un des paramètres est en blanc vous pouvez l'entrer manuellement ou bien vous pouvez revenir en arrière pour sélectionner une cible et revenir ici"
	arr["CATALAN",276]="A la part superior d'aquesta pantalla pots veure tot el que cal per realitzar l'atac. Si algun dels paràmetres no té valor, pots introduir-lo manualment, o pots retrocedir per a seleccionar un objectiu i tornar aquí"
	arr["PORTUGUESE",276]="No topo da tela você pode ver tudo o que é necessário para realizar o ataque. Se qualquer um dos parâmetros não tem nenhum valor, pode introduzi-los manualmente, ou você pode voltar para selecionar um alvo e voltar aqui"
	arr["RUSSIAN",276]="Наверху экрана вы можете увидеть всё, что вам нужно для выполнения этой атаки. Если какие-либо из этих параметров не имеют значения, вы можете ввести их вручную или вы можете вернуться назад для выбора цели, а затем вернуться сюда"
	arr["GREEK",276]="Πάνω από αυτή την οθόνη μπορείτε να δείτε ό,τι χρειάζεται για να εκτελεστεί η επίθεση. Αν κάποια παραμέτρος δεν έχει τιμή, μπορείτε να την εισάγετε χειροκίνητα, ή μπορείτε να πάτε πίσω για να επιλέξετε εαν στόχο και μετά να επιστρέψετε εδώ"
	arr["ITALIAN",276]="In cima a questa schermata è possibile vedere tutto ciò che è necessario per eseguire l'attacco. Se uno dei parametri non ha alcun valore, è possibile inserirlo manualmente, oppure si può tornare indietro per selezionare un target e tornare qui"
	arr["POLISH",276]="U góry tego ekranu można zobaczyć wszystko, co jest potrzebne do przeprowadzenia ataku. Jeśli któryś z parametrów nie ma wartości, możesz go wprowadzić ręcznie lub wrócić do wybranego celu"
	arr["GERMAN",276]="Oben auf diesem Bildschirm können Sie alles sehen, was Sie für den Angriff benötigen. Wenn einer der Parameter keinen Wert hat, können Sie ihn manuell eingeben, oder Sie können zurückgehen, um ein Ziel auszuwählen und hierher zurückzukehren"
	arr["TURKISH",276]="Bu ekranın tepesinde, saldırıyı gerçekleştirmek için gereken her şeyi görebilirsiniz. Parametrelerden herhangi birinin değeri yoksa, manuel olarak girebilirsiniz veya bir hedef seçmek için geri dönüp buraya dönebilirsiniz"

	arr["ENGLISH",277]="Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",277]="¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",277]="Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",277]="¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",277]="Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",277]="Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",277]="Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",277]="Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",277]="Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",277]="Wollen Sie weitermachen? ${normal_color}${visual_choice}"
	arr["TURKISH",277]="Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",278]="Deauthentication chosen method: ${pink_color}None${normal_color}"
	arr["SPANISH",278]="Método elegido de desautenticación: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",278]="Méthode de dés-authentification: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",278]="Mètode elegit d'desautenticació: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",278]="Método de desautenticação escolhido: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",278]="Выбор метода деаутентификации: ${pink_color}Нет${normal_color}"
	arr["GREEK",278]="Επιλεγμένη μέθοδος deauthentication: ${pink_color}Καμία${normal_color}"
	arr["ITALIAN",278]="Metodo deauth scelto: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",278]="Wybrana metoda deautentykacji: ${pink_color}Brak${normal_color}"
	arr["GERMAN",278]="Designierte Methode der De-Authentifizierung: ${pink_color}Keine${normal_color}"
	arr["TURKISH",278]="Deauthentication seçilen yöntem: ${pink_color}None${normal_color}"

	arr["ENGLISH",279]="Select another interface with internet access:"
	arr["SPANISH",279]="Selecciona otra interfaz que tenga acceso a internet:"
	arr["FRENCH",279]="Choisissez une autre interface qui ait accès à internet:"
	arr["CATALAN",279]="Selecciona una altra interfície que tingui accés a internet:"
	arr["PORTUGUESE",279]="Selecione outra interface que tem acesso à internet:"
	arr["RUSSIAN",279]="Выбор другого интерфейса с Интернет доступом:"
	arr["GREEK",279]="Επιλέξτε άλλη διεπαφή με προσβαση στο διαδίκτυο:"
	arr["ITALIAN",279]="Selezionare un'altra interfaccia che ha accesso a internet:"
	arr["POLISH",279]="Wybierz inny interfejs, który ma dostęp do internetu:"
	arr["GERMAN",279]="Wählen Sie eine andere Interface mit Internetzugang:"
	arr["TURKISH",279]="Başka bir arayyüz seçiniz:"

	arr["ENGLISH",280]="On this screen, it's supposed an additional interface to provide internet access is chosen, but you don't have anyone at this moment"
	arr["SPANISH",280]="En esta pantalla, se supone que deberías elegir otro interfaz adicional para proporcionar acceso a internet, pero no dispones de ninguno en este momento"
	arr["FRENCH",280]="Sur cet écran vous êtes censé choisir une interface supplémentaire connectée à internet mais vous n'en avez pas en ce moment"
	arr["CATALAN",280]="En aquesta pantalla, se suposa que hauries de triar un altre interfície addicional per a proporcionar accés a internet, però no disposes de cap en aquest moment"
	arr["PORTUGUESE",280]="Nesta tela você deveria escolher uma interface adicional para fornecer acesso à internet, mas você não tem nenhuma neste momento"
	arr["RUSSIAN",280]="На этом экране предполагается, что выбран дополнительный интерфейс для предоставления Интернет доступа, но у вас его на текущий момент нет"
	arr["GREEK",280]="Σε αυτή την οθόνη, υποτίθεται πως επιλέγεται μία επιπρόσθετη διεπαφή που παρέχει πρόσβαση στο διαδίκτυο, αλλά δεν έχετε κανέναν αυτή τη στιγμή"
	arr["ITALIAN",280]="In questa schermata, si suppone che devi scegliere un'interfaccia aggiuntiva per fornire l'accesso a internet, peró in questo momento non ne hai nessuna"
	arr["POLISH",280]="Na tym ekranie powinieneś wybrać inny dodatkowy interfejs, aby zapewnić dostęp do internetu, ale nie masz w tym momencie żadnego"
	arr["GERMAN",280]="Auf diesen Bildschirm sollten Sie eine andere zusätzliche Interface für den Internetzugang auswählen, aber Sie haben derzeit keine"
	arr["TURKISH",280]="Bu ekranda, internet erişimi sağlamak için ek bir arayüz gerekiyordu, ancak şu anda kimseye sahip değilsiniz"

	arr["ENGLISH",281]="The interface ${current_iface_on_messages} you have already selected is not a wifi card. This attack needs a wifi card selected"
	arr["SPANISH",281]="El interfaz ${current_iface_on_messages} que tienes seleccionado no es una tarjeta wifi. Este ataque necesita que la interfaz seleccionada sea wifi"
	arr["FRENCH",281]="L'interface ${current_iface_on_messages} que vous avez sélectionnée n'est pas une carte wifi. Cette attaque exige que l'interface sélectionnée soit une carte wifi"
	arr["CATALAN",281]="La interfície ${current_iface_on_messages} que tens seleccionada no és una targeta wifi. Aquest atac necessita que la interfície seleccionada sigui wifi"
	arr["PORTUGUESE",281]="A interface ${current_iface_on_messages} que você selecionou não é wifi. Este ataque requer uma interface wifi selecionada"
	arr["RUSSIAN",281]="Интерфейс ${current_iface_on_messages}, который вы выбрали не является wifi картой. Эта атака требует выбрать wifi карту"
	arr["GREEK",281]="Η διεπαφή ${current_iface_on_messages} που έχετε ήδη επιλέξει δεν έιναι κάρτα wifi. Αυτή η επίθεση χρειάζεται μία κάρτα wifi επιλεγμένη"
	arr["ITALIAN",281]="L'interfaccia ${current_iface_on_messages} che hai scelto non è una scheda wifi. Per questo attacco è necessario che l'interfaccia selezionata sia wifi"
	arr["POLISH",281]="Interfejs ${current_iface_on_messages}, który wybrałeś, nie jest kartą wifi. Ten atak wymaga wybrania interfejsu wifi"
	arr["GERMAN",281]="Die von Ihnen ausgewählte ${current_iface_on_messages} Interface ist keine WLAN-Karte. Dieser Angriff erfordert, dass die ausgewählte Interface WLAN ist"
	arr["TURKISH",281]="Seçmiş olduğunuz arayüz ${current_iface_on_messages} bir wifi kartı değildir. Bu saldırı bir wifi kartı gerektirir"

	arr["ENGLISH",282]="Selected internet interface: ${pink_color}${internet_interface}${normal_color}"
	arr["SPANISH",282]="Interfaz con internet seleccionada: ${pink_color}${internet_interface}${normal_color}"
	arr["FRENCH",282]="Interface internet sélectionnée: ${pink_color}${internet_interface}${normal_color}"
	arr["CATALAN",282]="Interfície amb internet seleccionada: ${pink_color}${internet_interface}${normal_color}"
	arr["PORTUGUESE",282]="Interface com internet selecionada: ${pink_color}${internet_interface}${normal_color}"
	arr["RUSSIAN",282]="Выбранный Интернет интерфейс: ${pink_color}${internet_interface}${normal_color}"
	arr["GREEK",282]="Επιλεγμένη διεπαφή με πρόσβαση στο διαδίκτυο: ${pink_color}${internet_interface}${normal_color}"
	arr["ITALIAN",282]="Interfaccia internet selezionata: ${pink_color}${internet_interface}${normal_color}"
	arr["POLISH",282]="Wybrany interfejs z internetem: ${pink_color}${internet_interface}${normal_color}"
	arr["GERMAN",282]="Ausgewählte Internet-Interface: ${pink_color}${internet_interface}${normal_color}"
	arr["TURKISH",282]="Seçilen internet arayüzü: ${pink_color}${internet_interface}${normal_color}"

	arr["ENGLISH",283]="Selected internet interface: ${pink_color}None${normal_color}"
	arr["SPANISH",283]="Interfaz con internet seleccionada: ${pink_color}Ninguna${normal_color}"
	arr["FRENCH",283]="Interface internet sélectionnée: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",283]="Interfície amb internet seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",283]="Interface com internet selecionada: ${pink_color}Nenhuma${normal_color}"
	arr["RUSSIAN",283]="Выбранный Интернет интерфейс: ${pink_color}Нет${normal_color}"
	arr["GREEK",283]="Επιλεγμένη διεπαφή με πρόσβαση στο διαδίκτυο: ${pink_color}Καμία${normal_color}"
	arr["ITALIAN",283]="Interfaccia internet selezionata: ${pink_color}Nessuna${normal_color}"
	arr["POLISH",283]="Wybrany interfejs z internetem: ${pink_color}Brak${normal_color}"
	arr["GERMAN",283]="Ausgewählte Internet-Interface: ${pink_color}Keine${normal_color}"
	arr["TURKISH",283]="Seçilen internet arayüzü: ${pink_color}None${normal_color}"

	arr["ENGLISH",284]="Do you want to use this selected interface? ${normal_color}${visual_choice}"
	arr["SPANISH",284]="¿Quieres utilizar esta interfaz ya seleccionada? ${normal_color}${visual_choice}"
	arr["FRENCH",284]="Souhaitez-vous utiliser l'interface déjà sélectionnée? ${normal_color}${visual_choice}"
	arr["CATALAN",284]="¿Vols fer servir aquesta interfície ja seleccionada? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",284]="Você quer usar essa interface selecionada? ${normal_color}${visual_choice}"
	arr["RUSSIAN",284]="Вы хотите использовать этот выбранный интерфейс? ${normal_color}${visual_choice}"
	arr["GREEK",284]="Θέλετε να χρησιμοποιήσετε αυτή την επιλεγμένη διεπαφή; ${normal_color}${visual_choice}"
	arr["ITALIAN",284]="Vuoi usare questa interfaccia già selezionata? ${normal_color}${visual_choice}"
	arr["POLISH",284]="Czy chcesz skorzystać z tego interfejsu? ${normal_color}${visual_choice}"
	arr["GERMAN",284]="Möchten Sie diese ausgewählte Interface verwenden? ${normal_color}${visual_choice}"
	arr["TURKISH",284]="Seçilmiş olan arayüzü kullanmak istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",285]="Selected interface with internet access detected during this session [${normal_color}${internet_interface}${blue_color}]"
	arr["SPANISH",285]="Se ha detectado que ya tiene un interfaz con acceso a internet seleccionada en esta sesión [${normal_color}${internet_interface}${blue_color}]"
	arr["FRENCH",285]="Une interface avec accès à internet a déjà été sélectionné pour cette session [${normal_color}${internet_interface}${blue_color}]"
	arr["CATALAN",285]="S'ha detectat que ja té una interfície amb accés a internet seleccionada en aquesta sessió [${normal_color}${internet_interface}${blue_color}]"
	arr["PORTUGUESE",285]="Verificou-se que há uma interface com acesso à internet selecionada nesta sessão [${normal_color}${internet_interface}${blue_color}]"
	arr["RUSSIAN",285]="Во время этой сессии обнаружен выбранный интерфейс с Интернет подключением [${normal_color}${internet_interface}${blue_color}]"
	arr["GREEK",285]="Η επιλεγμένη διεπαφή με πρόσβαση στο διαδίκτυο εντοπίστηκε κατά τη διάρκεια της συνεδρίας [${normal_color}${internet_interface}${blue_color}]"
	arr["ITALIAN",285]="E' stato riscontrato che ha già un'interfaccia con accesso a internet selezionata in questa sessione [${normal_color}${internet_interface}${blue_color}]"
	arr["POLISH",285]="Wykryto, że w tej sesji masz już wybrany interfejs z dostępem do internetu [${normal_color}${internet_interface}${blue_color}]"
	arr["GERMAN",285]="Es wurde festgestellt, dass Sie bereits eine Interface mit Internetzugang ausgewählt haben [${normal_color}${internet_interface}${blue_color}]"
	arr["TURKISH",285]="Bu oturum sırasında seçilen arayüz internet erişimi ile tespit edildi [${normal_color}${internet_interface}${blue_color}]"

	arr["ENGLISH",286]="If you don't have a captured Handshake file from the target network you can get it now"
	arr["SPANISH",286]="Si no tienes un fichero de Handshake capturado de la red objetivo puedes obtenerlo ahora"
	arr["FRENCH",286]="Si vous n'avez pas un fichier de capture contenant un Handshake du réseau cible vous pouvez l'obtenir maintenant"
	arr["CATALAN",286]="Si no tens un fitxer de Handshake capturat de la xarxa objectiu pots obtenir-ho ara"
	arr["PORTUGUESE",286]="Se você não tem um arquivo de Handshake da rede alvo você pode capturar agora"
	arr["RUSSIAN",286]="Если у вас отсутствует файл с рукопожатием целевой сети, вы можете сейчас захватить его"
	arr["GREEK",286]="Εάν δεν έχετε κάποιο αρχείο Χειραψίας από το δίκτυο-στόχος μπορείτε να το πάρετε τώρα"
	arr["ITALIAN",286]="Se non hai catturato un file di Handshake dalla rete obiettivo puoi ottenerlo ora"
	arr["POLISH",286]="Jeśli nie masz pliku Handshake przechwyconego w sieci docelowej, możesz go teraz zdobyć"
	arr["GERMAN",286]="Wenn Sie keine Handshake-Datei vom Zielnetzwerk erhalten haben, können Sie sie jetzt abrufen"
	arr["TURKISH",286]="Eğer hedef ağ için henüz yakalanmış bir Handshake dosyanız yoksa hemen şimdi yakalayabilirsiniz"

	arr["ENGLISH",287]="The script will check for internet access. Please be patient..."
	arr["SPANISH",287]="El script va a comprobar si tienes acceso a internet. Por favor ten paciencia..."
	arr["FRENCH",287]="Le script va vérifier que vous aillez accès à internet. Soyez patients s'il vous plaît..."
	arr["CATALAN",287]="El script comprovarà si tens accés a internet. Si us plau sigues pacient..."
	arr["PORTUGUESE",287]="O script irá verificar se você tem acesso à internet. Por favor, aguarde..."
	arr["RUSSIAN",287]="Этот скрипт проверит доступ к Интернету. Подождите немного..."
	arr["GREEK",287]="Το script θα ελέγξει αν έχετε πρόσβαση στο διαδίκτυο. Παρακαλώ έχετε λίγη υπομονή..."
	arr["ITALIAN",287]="Lo script controllerà se si ha accesso a internet. Si prega di essere pazienti..."
	arr["POLISH",287]="Skrypt sprawdzi, czy masz dostęp do internetu. Bądź cierpliwy..."
	arr["GERMAN",287]="Das Skript überprüft, ob Sie Internetzugang. Bitte haben Sie etwas Geduld..."
	arr["TURKISH",287]="Yazılım internet erişimin, kontrol edecek. Lütfen sabırlı olun..."

	arr["ENGLISH",288]="It seems you have no internet access. This attack needs an interface with internet access"
	arr["SPANISH",288]="Parece que no tienes conexión a internet. Este ataque necesita una interfaz con acceso a internet"
	arr["FRENCH",288]="Il semble que vous ne pouvez pas vous connecter à internet. Cette attaque a besoin d'une interface avec u accès internet"
	arr["CATALAN",288]="Sembla que no tens connexió a internet. Aquest atac necessita una interfície amb accés a internet"
	arr["PORTUGUESE",288]="Parece que você não tem acesso à internet. Este ataque precisa de uma interface com acesso à internet"
	arr["RUSSIAN",288]="Судя по всему, у вас нет доступа к Интернету. Эта атака требует интерфейс с Интернет доступом"
	arr["GREEK",288]="Φαίνεται πως δεν έχετε πρόσβαση στο διαδίκτυο. Αυτή η επίθεση χρειάζεται μία διεπαφή με πρόσβαση στο διαδίκτυο"
	arr["ITALIAN",288]="Sembra che tu non abbia alcuna connessione a internet. Questo attacco ha bisogno di un'interfaccia con connessione a internet"
	arr["POLISH",288]="Wygląda na to, że nie masz połączenia internetowego. Ten atak wymaga interfejsu z dostępem do internetu"
	arr["GERMAN",288]="Es scheint, dass Sie keine Internetverbindung haben. Dieser Angriff benötigt eine Interface mit Internetzugang"
	arr["TURKISH",288]="İnternet erişiminiz yok gibi görünüyor. Bu saldırı internet erişimi olan bir arayüze ihtiyaç duyuyor"

	arr["ENGLISH",289]="It has been verified successfully you have internet access on selected interface. Script can continue..."
	arr["SPANISH",289]="Se ha verificado correctamente que tienes acceso a internet en la interfaz seleccionada. El script puede continuar..."
	arr["FRENCH",289]="Confirmation de l'accès internet pour l'interface réseaux choisie. Le script peut continuer..."
	arr["CATALAN",289]="S'ha verificat correctament que tens accés a internet a la interfície seleccionada. El script pot continuar..."
	arr["PORTUGUESE",289]="Verificou-se com sucesso que você tem acesso à internet na interface selecionada. O script pode continuar..."
	arr["RUSSIAN",289]="Проверка доступа к Интернету прошла успешно на выбранном интерфейс. Скрипт может продолжать..."
	arr["GREEK",289]="Επαληθεύτηκε επιτυχώς πως έχετε πρόσβαση στο διαδίκτυο με την επιλεγμένη διεπαφή. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",289]="E' stato verificato con successo che si ha accesso a internet sull'interfaccia selezionata. Lo script può continuare ..."
	arr["POLISH",289]="Udało się potwierdzić, że masz dostęp do internet w wybranym interfejsie. Skrypt może kontynuować..."
	arr["GERMAN",289]="Es wurde korrekt überprüft, dass Sie in der ausgewählten Interface Zugriff auf das Internet haben. Das Skript kann fortfahren..."
	arr["TURKISH",289]="Başarılı bir şekilde doğrulandı ve seçilen arayüzde internet erişiminiz var. Yazılım devam edebilir..."

	arr["ENGLISH",290]="It seems you have internet access but not in the selected interface acting as interface with internet access"
	arr["SPANISH",290]="Parece que tienes conexión a internet pero no en la interfaz seleccionada como interfaz con acceso a internet"
	arr["FRENCH",290]="Il semble bien que vous avez accès à internet mais pas avec l'interface sélectionnée à cet effet"
	arr["CATALAN",290]="Sembla que tens connexió a internet però no en la interfície seleccionada com a interfície amb accés a internet"
	arr["PORTUGUESE",290]="Parece que você tem internet, mas não na interface selecionada"
	arr["RUSSIAN",290]="Судя по всему у вас есть доступ к Интернету, но не на выбранном для Интернет доступа интерфейсе"
	arr["GREEK",290]="Φαίνεται πως έχετε πρόσβαση στο διαδίκτυο αλλά όχι στην επιλεγμένη διεπαφή που ενεργεί ως διεπαφή με πρόσβαση στο διαδίκτυο"
	arr["ITALIAN",290]="Sembra che hai connession a internet ma non nell'interfaccia selezionata come interfaccia con accesso ad internet"
	arr["POLISH",290]="Wydaje się, że masz połączenie z internetem ale w innym interfejsie"
	arr["GERMAN",290]="Es scheint, dass Sie eine Internetverbindung haben, aber nicht in der mit Internetzugang gewählten Interface"
	arr["TURKISH",290]="İnternet erişiminiz var gibi görünüyor fakat seçilen arayüz internet erişimi var gibi dvranmıyor"

	arr["ENGLISH",291]="Evil Twin AP attack with sniffing"
	arr["SPANISH",291]="Ataque Evil Twin AP con sniffing"
	arr["FRENCH",291]="Attaque Evil Twin avec capture de données"
	arr["CATALAN",291]="Atac Evil Twin AP amb sniffing"
	arr["PORTUGUESE",291]="Ataque Evil Twin AP com sniffing"
	arr["RUSSIAN",291]="Атака Злой Двойник ТД со сниффингом"
	arr["GREEK",291]="Επίθεση Evil Twin AP με sniffing"
	arr["ITALIAN",291]="Attacco Evil Twin AP con sniffing"
	arr["POLISH",291]="Atak Evil Twin AP ze sniffingiem"
	arr["GERMAN",291]="Evil Twin AP Angriff mit Sniffing"
	arr["TURKISH",291]="Şeytani İkiz AP saldırısı sniffing ile"

	arr["ENGLISH",292]="Evil Twin AP attack with sniffing and sslstrip"
	arr["SPANISH",292]="Ataque Evil Twin AP con sniffing y sslstrip"
	arr["FRENCH",292]="Attaque Evil Twin avec capture de données et sslstrip"
	arr["CATALAN",292]="Atac Evil Twin AP amb sniffing i sslstrip"
	arr["PORTUGUESE",292]="Ataque Evil Twin AP com sniffing e sslstrip"
	arr["RUSSIAN",292]="Атака Злой Двойник ТД со сниффингом и sslstrip"
	arr["GREEK",292]="Επίθεση Evil Twin AP με sniffing και sslstrip"
	arr["ITALIAN",292]="Attacco Evil Twin AP con sniffing e sslstrip"
	arr["POLISH",292]="Atak Evil Twin AP ze sniffingiem i sslstrip"
	arr["GERMAN",292]="Evil Twin AP Angriff mit Sniffing und sslstrip"
	arr["TURKISH",292]="Şeytani İkiz AP saldırısı sniffing ve sslstrip ile"

	arr["ENGLISH",293]="Evil Twin AP attack with captive portal"
	arr["SPANISH",293]="Ataque Evil Twin AP con portal cautivo"
	arr["FRENCH",293]="Attaque Evil Twin avec portail captif"
	arr["CATALAN",293]="Atac Evil Twin AP amb portal captiu"
	arr["PORTUGUESE",293]="Ataque Evil Twin AP com portal cativo"
	arr["RUSSIAN",293]="Атака Злой Двойник ТД с перехватывающим порталом"
	arr["GREEK",293]="Επίθεση Evil Twin AP με captive portal"
	arr["ITALIAN",293]="Attacco Evil Twin AP con captive portal"
	arr["POLISH",293]="Atak Evil Twin AP z portalem captive"
	arr["GERMAN",293]="Evil Twin AP Angriff mit Captive Portal"
	arr["TURKISH",293]="Şeytani İkiz AP saldırısı esaret portalı ile"

	arr["ENGLISH",294]="Detecting resolution... Detected!: ${normal_color}${resolution}"
	arr["SPANISH",294]="Detectando resolución... Detectada!: ${normal_color}${resolution}"
	arr["FRENCH",294]="Détection de la résolution... Détectée!: ${normal_color}${resolution}"
	arr["CATALAN",294]="Detectant resolució... Detectada!: ${normal_color}${resolution}"
	arr["PORTUGUESE",294]="Detectando resolução... Detectada!: ${normal_color}${resolution}"
	arr["RUSSIAN",294]="Определение разрешения... Определено!: ${normal_color}${resolution}"
	arr["GREEK",294]="Εντοπίζεται η ανάλυση... Εντοπίστηκε!: ${normal_color}${resolution}"
	arr["ITALIAN",294]="Rilevamento risoluzione... Rilevata!: ${normal_color}${resolution}"
	arr["POLISH",294]="Wykrywanie rozdzielczości... Wykryto!: ${normal_color}${resolution}"
	arr["GERMAN",294]="Auflösung erkennen... Erkannt!: ${normal_color}${resolution}"
	arr["TURKISH",294]="Çözünürlük tespit ediliyor... Tamamdır!: ${normal_color}${resolution}"

	arr["ENGLISH",295]="Detecting resolution... Can't be detected!, using standard: ${normal_color}${resolution}"
	arr["SPANISH",295]="Detectando resolución... No se ha podido detectar!, usando estándar: ${normal_color}${resolution}"
	arr["FRENCH",295]="Détection de la résolution... Impossible à détecter!, utilisation de la résolution: ${normal_color}${resolution}"
	arr["CATALAN",295]="Detectant resolució... No s'ha pogut detectar!, usant estàndard: ${normal_color}${resolution}"
	arr["PORTUGUESE",295]="Detectando resolução... Não foi possível detectar!, usando o padrão: ${normal_color}${resolution}"
	arr["RUSSIAN",295]="Определение разрешения... Не получается определить!, используется стандартное: ${normal_color}${resolution}"
	arr["GREEK",295]="Εντοπίζεται η ανάλυση... Δεν μπορεί να εντοπιστεί!, χρησιμοποιείται η προεπιλεγμένη: ${normal_color}${resolution}"
	arr["ITALIAN",295]="Rilevamento risoluzione... Non è stato possible rilevarla!, usando quella standard: ${normal_color}${resolution}"
	arr["POLISH",295]="Wykrywanie rozdzielczości... Nie można wykryć! użycie standardu: ${normal_color}${resolution}"
	arr["GERMAN",295]="Erkennung der Auflösung... Die Auflösung konnte nicht erkannt werden!, Standardauflösung: ${normal_color}${resolution}"
	arr["TURKISH",295]="Çözünürlük tespit ediliyor... Başarısız!, standart olarak devam edilecek: ${normal_color}${resolution}"

	arr["ENGLISH",296]="All parameters and requirements are set. The attack is going to start. Multiple windows will be opened, don't close anyone. When you want to stop the attack press [Enter] on this window and the script will automatically close them all"
	arr["SPANISH",296]="Todos los parámetros y requerimientos están listos. Va a comenzar el ataque. Se abrirán múltiples ventanas, no cierres ninguna. Cuando quieras parar el ataque pulsa [Enter] en esta ventana y el script cerrará automáticamente todo"
	arr["FRENCH",296]="Tous les paramètres de l'attaque sont prêts et elle peut comenmcer. Plusieurs consoles vont s'ouvrir, ne les fermez pas. Lorsque vous voulez arrêter l'attaque, appuyez sur [Enter] dans cette console et le script fermera automatiquement les autres"
	arr["CATALAN",296]="Tots els paràmetres i requeriments estan preparats. Començarà l'atac. S'obriran múltiples finestres, no tanquis cap. Quan vulguis parar l'atac prem [Enter] en aquesta finestra i el script tancarà automàticament tot"
	arr["PORTUGUESE",296]="Todos os parâmetros e requisitos estão prontos. Você vai começar o ataque. Várias janelas iram se abrir, não feche nenhuma delas. Quando quiser parar o ataque pressione [Enter] nesta janela e o script irá fechar automaticamente"
	arr["RUSSIAN",296]="Все параметры и требования готовы. Атака может быть начата. Будет открыто много окон, не закрывайте их. Когда вы захотите остановить атаку, нажмите [Enter] в этом окне и скрипт автоматически их все закроет"
	arr["GREEK",296]="Όλοι οι παράμετροι και οι απαιτήσεις έχουν τεθεί. Η επίθεση πρόκειται να ξεκινήσει. Θα ανοίξουν πολλαπλά παράθυρα, μην επιχειρήσετε να κλείσετε κάποιο. Όταν θελήσετε να σταματήσετε την επίθεση πατήστε [Enter] σε αυτό το παράθυρο και το script θα τα κλείσει όλα"
	arr["ITALIAN",296]="Tutti i parametri e i requisiti sono pronti. Si inizierà l'attacco. Si apriranno varie finestre, non chiuderne nessuna. Quando vuoi fermare l'attacco premi [Enter] in questa finestra e lo script chiuderá automaticamente tutto"
	arr["POLISH",296]="Wszystkie parametry i wymagania są gotowe. Atak może się rozpocząć. Otwarte zostanie wiele okien, nie zamykaj żadnego. Aby zatrzymać atak, wciśnij [Enter] w tym oknie, a skrypt automatycznie zamknie wszystkie"
	arr["GERMAN",296]="Alle Parameter und Anforderungen sind bereit. Der Angriff wird beginnen. Mehrere Fenster werden geöffnet, schließen Sie keines. Wenn Sie den Angriff stoppen möchten, drücken Sie [Enter] in diesem Fenster und das Skript wird automatisch alle schließen"
	arr["TURKISH",296]="Tüm parametreler ayarlandı. Saldırı başlayacak. Birden fazla pencere açılacak, bunların hiçbirini kapatmayın. Saldırıyı durdurmak istediğiniz zaman aman pencereden [Enter] tuşlamanız yeterli. Yazılım tüm pencereleri kapatacaktır"

	arr["ENGLISH",297]="Cleaning iptables and routing rules"
	arr["SPANISH",297]="Limpiando iptables y reglas de routing"
	arr["FRENCH",297]="Effacement des règles de routage iptables"
	arr["CATALAN",297]="Netejant iptables i regles de routing"
	arr["PORTUGUESE",297]="Limpando iptables e regras de roteamento"
	arr["RUSSIAN",297]="Очистка iptables и правил маршуртизации"
	arr["GREEK",297]="Γινεται καθαρισμός των iptables και των κανόνων δρομολόγησης"
	arr["ITALIAN",297]="Pulendo iptables e le regole di routing"
	arr["POLISH",297]="Usuwanie iptables i reguł routingu"
	arr["GERMAN",297]="Reinigung von iptables und Routing-Regeln"
	arr["TURKISH",297]="Iptables ve routing rules temizleniyor"

	arr["ENGLISH",298]="Evil Twin attack has been started. Press [Enter] key on this window to stop it"
	arr["SPANISH",298]="El ataque Evil Twin ha comenzado. Pulse la tecla [Enter] en esta ventana para pararlo"
	arr["FRENCH",298]="L'attaque Evil Twin a commencé. Pressez la touche [Enter] dans cette console pour l'arrêter"
	arr["CATALAN",298]="L'atac Evil Twin ha començat. Prem [Enter] a aquesta finestra per aturar-lo"
	arr["PORTUGUESE",298]="Ataque Evil Twin iniciado. Pressione a tecla [Enter] nesta janela para parar"
	arr["RUSSIAN",298]="Атака Злой Двойник начата. Для её остановки клавишу [Enter] в этом окне"
	arr["GREEK",298]="Η επίθεση Evil Twin ξεκίνησε. Πατήστε το κουμπί [Enter] σε αυτό το παράθυρο για να την σταματήσετε"
	arr["ITALIAN",298]="L'attacco Evil Twin è iniziato. Premere il tasto [Enter] in questa finestra per fermarlo"
	arr["POLISH",298]="Rozpoczął się atak Evil Twin. Naciśnij klawisz [Enter] w tym oknie, aby go zatrzymać"
	arr["GERMAN",298]="Der Evil-Twin-Angriff hat begonnen. Drücken Sie die [Enter]-Taste in diesem Fenster, um es zu stoppen"
	arr["TURKISH",298]="Şeytani İkiz saldırısı başlatıldı. Durdurmak için bu pencerede [Enter] tuşlayınız"

	arr["ENGLISH",299]="Restoring interface..."
	arr["SPANISH",299]="Restaurando interfaz..."
	arr["FRENCH",299]="Réinitialisation de l'interface..."
	arr["CATALAN",299]="Restablint interfície..."
	arr["PORTUGUESE",299]="Restaurando interface..."
	arr["RUSSIAN",299]="Восстановление интерфейса..."
	arr["GREEK",299]="Γίνεται επαναφορά διεπαφής..."
	arr["ITALIAN",299]="Ripristinando interfaccia..."
	arr["POLISH",299]="Przywracanie interfejsu..."
	arr["GERMAN",299]="Interface wiederherstellen..."
	arr["TURKISH",299]="Arayüz onarılıyor..."

	arr["ENGLISH",300]="If the xpdyinfo command works, the script will be able to calculate your screen resolution and display the windows in a better way. Depending of the system, the package name containing it could be x11-utils, xdpyinfo, xorg-xdpyinfo, etc."
	arr["SPANISH",300]="Si haces que funcione en tu sistema el comando xdpyinfo, el script podrá calcular tu resolución de pantalla y mostrarte las ventanas de forma más optimizada. Dependiendo del sistema el paquete que lo contiene puede llamarse x11-utils, xdpyinfo, xorg-xdpyinfo, etc."
	arr["FRENCH",300]="Si la commande xdpyinfo est installée dans vôtre système le script pourra calculer votre résolution d'écran et optimiser l'affichage en conséquence. Le paquet à installer pour avoir cette commande s'appelle (selon la distribution) x11-utils, xdpyinfo, xorg-xdpyinfo, etc."
	arr["CATALAN",300]="Si fas que funcioni en el teu sistema l'ordre xdpyinfo, el script podrà calcular la teua resolució de pantalla i mostrar-te les finestres de forma més optimitzada. Depenent del sistema el paquet que el conté pot dir-se x11-utils, xdpyinfo, xorg-xdpyinfo, etc."
	arr["PORTUGUESE",300]="Se o comando xdpyinfo funcionar em seu sistema o script será capaz de calcular a resolução da tela e mostrar-lhe as janelas de uma maneira melhor. Dependendo do sistema, o nome do pacote pode ser: x11-utils, xdpyinfo, xorg-xdpyinfo, etc."
	arr["RUSSIAN",300]="Команда xpdyinfo поможет этому скрипту определить разрешение вашего экрана и выбрать наилучшее отображение окон. В зависимости от системы, имя пакета, в котором содержится эта программа, может быть x11-utils, xdpyinfo, xorg-xdpyinfo, и т.д."
	arr["GREEK",300]="Αν δουλέψει η εντολή xpdyinfo, το script θα μπορέσει να υπολογίσει την ανάλυση της οθόνης και να δείχνει τα παράθυρα καλύτερα. Εξαρτάται από το σύστημα, το όνομα του πακέτου που το περιέχει θα μπορούσε να είναι x11-utils, xdpyinfo, xorg-xdpyinfo, κτλπ."
	arr["ITALIAN",300]="Se funziona il comando xdpyinfo, lo script calcolerà la risoluzione dello schermo e mostrerá le finestre in modo ottimizzato. A seconda del sistema il pacchetto che lo contiene può chiamarsi x11-utils, xdpyinfo, xorg-xdpyinfo, etc."
	arr["POLISH",300]="Jeśli polecenie xdpyinfo działa w systemie, skrypt będzie mógł obliczyć rozdzielczość ekranu i lepiej wyświetlać okna. W zależności od systemu pakiet zawierający go może być nazwany x11-utils, xdpyinfo, xorg-xdpyinfo, itd."
	arr["GERMAN",300]="Wenn Sie den Befehl xdpyinfo in Ihrem System verwenden, kann das Skript Ihre Bildschirmauflösung berechnen und Ihnen die Fenster in einer optimierten Weise zeigen. Je nach System kann das Paket, das es enthält, x11-utils, xdpyinfo, xorg-xdpyinfo usw. genannt werden"
	arr["TURKISH",300]="Eğer xpdyinfo komutu çalışırsa, yazılım ekran çözünürlüğünüzü hesaplayabilecek ve en iyi boyutlardaki pencereler ile çalışacak. Paket isimleri sisteminize göre x11-utils, xdpyinfo, xorg-xdpyinfo, vb... olarak değişiklik gösterebilir"

	arr["ENGLISH",301]="Despite having all essential tools installed, your system uses airmon-zc instead of airmon-ng. In order to work properly you need to install lspci (pciutils) and you don't have it right now. Please, install it and launch the script again"
	arr["SPANISH",301]="A pesar de tener todas las herramientas esenciales instaladas, tu sistema usa airmon-zc en lugar de airmon-ng. Para poder funcionar necesitas tener instalado lspci (pciutils) y tú no lo tienes en este momento. Por favor, instálalo y vuelve a lanzar el script"
	arr["FRENCH",301]="En dépit d'avoir tous les outils essentiels installés votre système utilise airmon-zc au lieu de airmon-ng. Vous devez installer lspci (pciutils) que vous n'avez pas à ce moment. S'il vous plaît, installez-le et relancez le script"
	arr["CATALAN",301]="Tot i tenir totes les eines essencials instal·lades, el teu sistema fa servir airmon-zc en lloc del airmon-ng. Per poder funcionar necessites tenir instal·lat lspci (pciutils) i tu no el tens en aquest moment. Si us plau, instal·la-ho i torna a executar el script"
	arr["PORTUGUESE",301]="Apesar de ter todas as ferramentas essenciais instalado, o sistema utiliza airmon-zc em vez de airmon-ng. Para funcionar você precisa instalar lspci (pciutils) e você não tem neste momento. Por favor, instale e execute o script novamente"
	arr["RUSSIAN",301]="Не смотря на то, что установлены все необходимые основные инструменты, ваша система использует airmon-zc вместо airmon-ng. Чтобы работа проходила должным образом, вам нужно установить lspci (pciutils), которых в данный момент у вас нет. Пожалуйста, установите их и запустите скрипт снова"
	arr["GREEK",301]="Παρά του ότι είναι εγκατεστημένα όλα τα απραίτητα εργαλεία, το σύστημά σας χρησιμοποιεί το airmon-zc αντί το airmon-ng. Για να λειτουργήσει σωστά πρέπει να εγκαταστήσετε το lspci (pciutils) το οποίο δεν το έχετε αυτή τη στιγμή. Παρακαλώ, εγκαταστήστε το και ξανανοίξτε το script"
	arr["ITALIAN",301]="Pur avendo tutti gli strumenti essenziali installati, il sistema utilizza airmon-zc invece di airmon-ng. Per funzionare è necessario installare lspci (pciutils) e tu non lo hai in questo momento. Si prega di installarlo e lanciare nuovamente lo script"
	arr["POLISH",301]="Mimo, że zainstalowano wszystkie niezbędne narzędzia, system zamiast airmon-ng wykorzystuje airmon-zc. Aby pracować musisz mieć zainstalowany lspci (pciutils), którego w tej chwili nie masz. Zainstaluj go i ponownie uruchom skrypt"
	arr["GERMAN",301]="Obwohl alle wesentlichen Tools installiert sind, verwendet Ihr System airmon-zc anstelle von airmon-ng. Um zu arbeiten, müssen Sie lspci (pciutils) installiert haben, und Sie haben es zur Zeit nicht. Bitte installieren Sie es und starten Sie das Skript erneut"
	arr["TURKISH",301]="Tüm gerekli araçlara sahip olmasına rağmen, sisteminiz airmon-ng yerine airmon-zc kullanıyor. Düzgün çalışması için lspci'yi (pciutils) kurmanız gerekiyor ve şu anda buna sahip değilsiniz. Lütfen kurun ve yazılımı tekrar başlatın"

	arr["ENGLISH",302]="Do you want to store in a file the sniffed captured passwords? ${blue_color}If you answer no (\"n\") they will be only shown on screen ${normal_color}${visual_choice}"
	arr["SPANISH",302]="¿Deseas guardar en un fichero las contraseñas obtenidas del sniffing? ${blue_color}Si respondes que no (\"n\") solo se mostrarán por pantalla ${normal_color}${visual_choice}"
	arr["FRENCH",302]="Voulez vous garder les mots de passe capturés dans un fichier? ${blue_color}Si vous répondez non (\"n\") les mots de passe s'afficheront à l'écran ${normal_color}${visual_choice}"
	arr["CATALAN",302]="¿Vols guardar en un fitxer les contrasenyes obtingudes del sniffing? ${blue_color}Si respons que no (\"n\") només es mostraran per pantalla ${normal_color}${visual_choice}"
	arr["PORTUGUESE",302]="Você deseja armazenar em um arquivo as senhas obtidas com o sniffer? ${blue_color}Se você responder não (\"n\") as senhas só serão mostradas na tela ${normal_color}${visual_choice}"
	arr["RUSSIAN",302]="Вы хотите сохранить в файл захваченные сниффингом пароли? ${blue_color}Если ваш ответ нет (\"n\") они будут только показаны на экране ${normal_color}${visual_choice}"
	arr["GREEK",302]="Θέλετε να αποθηκεύσετε σε ένα αρχείο τους sniffed κωδικούς πρόσβασης; ${blue_color}Αν απαντήσετε όχι (\"n\") απλά θα εμφανιστούν στην οθόνη ${normal_color}${visual_choice}"
	arr["ITALIAN",302]="Vuoi salvare in un file le password ottenute con sniffing? ${blue_color}Se si risponde no (\"n\") vengono visualizzate solo sullo schermo ${normal_color}${visual_choice}"
	arr["POLISH",302]="Czy chcesz zapisywać hasła w plikach? ${blue_color}Jeśli odpowiesz nie (\"n\") zostaną tylko wyświetlone na ekranie ${normal_color}${visual_choice}"
	arr["GERMAN",302]="Möchten Sie die aus dem Sniffing erhaltene Passwörter in einer Datei speichern? ${blue_color} Wenn Sie mit Nein antworten (\"n\"), werden sie nur auf dem Bildschirm angezeigt ${normal_color}${visual_choice}"
	arr["TURKISH",302]="Yakalanan şifreler bir dosyada saklamak ister misiniz? ${blue_color}Eğer cevap hayır ise (\"n\") sadece ekranda gösterilecekler ${normal_color}${visual_choice}"

	arr["ENGLISH",303]="Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${default_ettercap_logpath}]"
	arr["SPANISH",303]="Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${default_ettercap_logpath}]"
	arr["FRENCH",303]="Entrez le chemin du fichier ou bien appuyez sur [Enter] pour utiliser le chemin proposé ${normal_color}[${default_ettercap_logpath}]"
	arr["CATALAN",303]="Escriu la ruta on desarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${default_ettercap_logpath}]"
	arr["PORTUGUESE",303]="Digite o caminho onde armazenar o arquivo ou pressione [Enter] para aceitar o padrão ${normal_color}[${default_ettercap_logpath}]"
	arr["RUSSIAN",303]="Напечатайте путь до файла для сохранения или нажмите [Enter] для принятия предложения по умолчанию ${normal_color}[${default_ettercap_logpath}]"
	arr["GREEK",303]="Πληκτρολογήστε το μονοπάτι για να αποθηκεύσετε το αρχείο ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${default_ettercap_logpath}]"
	arr["ITALIAN",303]="Digitare il percorso dove memorizzare il file o premere [Enter] per accettare la proposta di default ${normal_color}[${default_ettercap_logpath}]"
	arr["POLISH",303]="Wpisz ścieżkę, w której będziemy zapisywać plik lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${default_ettercap_logpath}]"
	arr["GERMAN",303]="Schreiben Sie den Pfad, unter dem die Datei gespeichert werden soll, oder drücken Sie die [Enter]-Taste, um den Standardvorschlag zu akzeptieren ${normal_color}[${default_ettercap_logpath}]"
	arr["TURKISH",303]="Dosyayı depolamak için yolu yazın veya varsayılan teklifi kabul etmek için [Enter] tuşuna basın ${normal_color}[${default_ettercap_logpath}]"

	arr["ENGLISH",304]="Parsing sniffer log..."
	arr["SPANISH",304]="Analizando log del sniffer..."
	arr["FRENCH",304]="Analyse du log des captures..."
	arr["CATALAN",304]="Analitzant log del sniffer..."
	arr["PORTUGUESE",304]="Analisando log do Sniffer..."
	arr["RUSSIAN",304]="Разбор журнала сниффера..."
	arr["GREEK",304]="Γίνεται ανάλυση του log του sniffer..."
	arr["ITALIAN",304]="Analizzando log dello sniffer..."
	arr["POLISH",304]="Analiza logu sniffera..."
	arr["GERMAN",304]="Sniffer-Protokoll analyse..."
	arr["TURKISH",304]="Sniffer logu ayrıştırılıyor..."

	arr["ENGLISH",305]="No passwords detected on sniffers's log. File will not be saved"
	arr["SPANISH",305]="No se ha encontrado ninguna contraseña en el log del sniffer. No se guardará el fichero"
	arr["FRENCH",305]="Aucun mot de passe n'a été détecté. Le fichier ne sera pas sauvegardé"
	arr["CATALAN",305]="No s'ha trobat cap contrasenya en el log del sniffer. No es guarda el fitxer"
	arr["PORTUGUESE",305]="Nenhuma senha foi encontrada no log do sniffer. Arquivo não será salvo"
	arr["RUSSIAN",305]="В журнале сниффера паролей не обнаружено. Файл не будет сохранён"
	arr["GREEK",305]="Δεν εντοπίστηκαν κωδικοί πρόσβασης στο log του sniffer. Το αρχείο δεν θα αποθηκευτεί"
	arr["ITALIAN",305]="Nessuna password trovata nel log dello sniffer. Il file non viene salvato"
	arr["POLISH",305]="W logu sniffera nie znaleziono haseł. Plik nie zostanie zapisany"
	arr["GERMAN",305]="Im Sniffer-Protokoll wurde kein Passwort gefunden. Die Datei wird nicht gespeichert"
	arr["TURKISH",305]="Sniffers'ın günlüğünde hiçbir şifre algılanmadı. Dosya kaydedilmeyecek"

	arr["ENGLISH",306]="Passwords captured by sniffer. File saved at ${normal_color}[${ettercap_logpath}]"
	arr["SPANISH",306]="El sniffer ha capturado contraseñas. Fichero salvado en ${normal_color}[${ettercap_logpath}]"
	arr["FRENCH",306]="Des mots de passe ont été capturé et ont été enregistré dans ${normal_color}[${ettercap_logpath}]"
	arr["CATALAN",306]="El sniffer ha capturat contrasenyes. Fitxer desat a ${normal_color}[${ettercap_logpath}]"
	arr["PORTUGUESE",306]="O sniffer capturou senhas. O arquivo foi salvo em ${normal_color}[${ettercap_logpath}]"
	arr["RUSSIAN",306]="Сниффер захватил пароли. Файл сохранён в ${normal_color}[${ettercap_logpath}]"
	arr["GREEK",306]="Καταγράφηκαν κωδικοί πρόσβασης από τον sniffer. Το αρχείο αποθηκεύτηκε στο ${normal_color}[${ettercap_logpath}]"
	arr["ITALIAN",306]="Lo sniffer ha catturato delle password. File salvato in ${normal_color}[${ettercap_logpath}]"
	arr["POLISH",306]="Sniffer przechwycił hasła. Plik zapisany w ${normal_color}[${ettercap_logpath}]"
	arr["GERMAN",306]="Der Sniffer hat Passwörter erfasst. Datei in ${normal_color}[${ettercap_logpath}] ${blue_color}gespeichert"
	arr["TURKISH",306]="Parolalar sniffer tarafından yakalandı. Şu dosyaya kaydedildi ${normal_color}[${ettercap_logpath}]"

	arr["ENGLISH",307]="Language changed to Russian"
	arr["SPANISH",307]="Idioma cambiado a Ruso"
	arr["FRENCH",307]="Le script sera maintenant en Russe"
	arr["CATALAN",307]="Idioma canviat a Rus"
	arr["PORTUGUESE",307]="Idioma alterado para Russo"
	arr["RUSSIAN",307]="Язык изменён на русский"
	arr["GREEK",307]="Η γλώσσα άλλαξε στα Ρωσικά"
	arr["ITALIAN",307]="Lingua cambiata in Russo"
	arr["POLISH",307]="Zmieniono język na Rosyjski"
	arr["GERMAN",307]="Die Sprache wurde auf Russisch geändert"
	arr["TURKISH",307]="Dil Rusça olarak değiştirildi"

	arr["ENGLISH",308]="6.  Russian"
	arr["SPANISH",308]="6.  Ruso"
	arr["FRENCH",308]="6.  Russe"
	arr["CATALAN",308]="6.  Rus"
	arr["PORTUGUESE",308]="6.  Russo"
	arr["RUSSIAN",308]="6.  Русский"
	arr["GREEK",308]="6.  Ρωσικά"
	arr["ITALIAN",308]="6.  Russo"
	arr["POLISH",308]="6.  Rosyjski"
	arr["GERMAN",308]="6.  Russisch"
	arr["TURKISH",308]="6.  Rusça"

	arr["ENGLISH",309]="Sslstrip technique is not infallible. It depends on many factors and not always work. Some browsers such as Mozilla Firefox latest versions are not affected"
	arr["SPANISH",309]="La tecnica sslstrip no es infalible. Depende de muchos factores y no funciona siempre. Algunos navegadores como las últimas versiones de Mozilla Firefox no se ven afectados"
	arr["FRENCH",309]="La technique de sslstrip n'est pas à toute épreuve. Cela dépend de nombreux facteurs et ne fonctionne pas toujours. Certains navigateurs tels que Mozilla Firefox dans leurs versions les plus récentes ne sont pas vulnérables"
	arr["CATALAN",309]="La tècnica sslstrip no és infal·lible. Depèn de molts factors i no funciona sempre. Alguns navegadors com les últimes versions de Mozilla Firefox no es veuen afectats"
	arr["PORTUGUESE",309]="A técnica sslstrip não é infalível. Depende de muitos fatores e nem sempre funciona. Alguns navegadores como o Mozilla Firefox nas versões mais recentes não são afetados"
	arr["RUSSIAN",309]="Техника sslstrip не является надёжной. Эффект программы зависит от многих факторов и иногда она просто не работает. Некоторые браузеры, такие как Mozilla Firefox последних версий, не подвержены атаке"
	arr["GREEK",309]="Η τεχνική sslstrip δεν είναι αλάνθαστη. Εξαρτάται από πολλούς παράγοντες και δεν δουλεύει πάντα. Κάποιοι περιηγητές ιστού όπως οι τελευταίες εκδόσεις του Mozilla Firefox δεν επηρεάζονται"
	arr["ITALIAN",309]="La tecnica sslstrip non è infallibile. Dipende da molti fattori e non sempre funziona. Alcuni browser, come le ultime versioni di Mozilla Firefox non sono vulnerabili"
	arr["POLISH",309]="Technika sslstrip nie jest nieomylna. Zależy od wielu czynników i nie zawsze działa. Nie ma na przykład wpływu na niektóre przeglądarki, takie jak najnowsze wersje Mozilla Firefox"
	arr["GERMAN",309]="Die sslstrip-Technik ist nicht unfehlbar. Es hängt von vielen Faktoren ab und funktioniert nicht immer. Einige Browser wie die neuesten Mozilla Firefox Versionen sind nicht betroffen"
	arr["TURKISH",309]="Sslstrip tekniği yanılmaz değildir. Birçok faktöre bağlıdır ve her zaman işe yaramaz. Mozilla Firefox son sürümleri gibi bazı tarayıcılar etkilenmez"

	arr["ENGLISH",310]="Handshake file selected: ${pink_color}None${normal_color}"
	arr["SPANISH",310]="Fichero de Handshake seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",310]="Fichier Handshake sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",310]="Fitxer de Handshake seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",310]="Arquivo de Handshake selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",310]="Выбранный файл рукопожатия: ${pink_color}Отсутствует${normal_color}"
	arr["GREEK",310]="Επιλεγμένο αρχείο Χειραψίας: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",310]="File di Handshake selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",310]="Wybrany plik Handshake: ${pink_color}Brak${normal_color}"
	arr["GERMAN",310]="Ausgewählte Handshake-Datei: ${pink_color}Keine${normal_color}"
	arr["TURKISH",310]="Handshake dosyası seçildi: ${pink_color}None${normal_color}"

	arr["ENGLISH",311]="Handshake file selected: ${pink_color}${et_handshake}${normal_color}"
	arr["SPANISH",311]="Fichero de Handshake seleccionado: ${pink_color}${et_handshake}${normal_color}"
	arr["FRENCH",311]="Fichier Handshake sélectionnée: ${pink_color}${et_handshake}${normal_color}"
	arr["CATALAN",311]="Fitxer de Handshake seleccionat: ${pink_color}${et_handshake}${normal_color}"
	arr["PORTUGUESE",311]="Arquivo de Handshake selecionado: ${pink_color}${et_handshake}${normal_color}"
	arr["RUSSIAN",311]="Выбранный файл рукопожатия: ${pink_color}${et_handshake}${normal_color}"
	arr["GREEK",311]="Επιλεγμένο αρχείο Χειραψίας: ${pink_color}${et_handshake}${normal_color}"
	arr["ITALIAN",311]="File di Handshake selezionato: ${pink_color}${et_handshake}${normal_color}"
	arr["POLISH",311]="Wybrany plik Handshake: ${pink_color}${et_handshake}${normal_color}"
	arr["GERMAN",311]="Ausgewählte Handshake-Datei: ${pink_color}${et_handshake}${normal_color}"
	arr["TURKISH",311]="Handshake dosyası seçildi: ${pink_color}${et_handshake}${normal_color}"

	arr["ENGLISH",312]="No selected Handshake file detected during this session..."
	arr["SPANISH",312]="No se ha detectado ningún fichero de Handshake seleccionado en esta sesión..."
	arr["FRENCH",312]="Aucun fichier Handshake valable a été sékectionné pour cette session..."
	arr["CATALAN",312]="No s'ha detectat un fitxer de Handshake seleccionat en aquesta sessió..."
	arr["PORTUGUESE",312]="Nenhum arquivo de Handshake foi selecionado nesta sessão..."
	arr["RUSSIAN",312]="Во время этой сессии выбранный файл рукопожатия не обнаружен..."
	arr["GREEK",312]="Δεν εντοπίστηκε κανένα αρχείο Χειραψίας κατά τη διάρκεια της συνεδρίας..."
	arr["ITALIAN",312]="Non è stato rilevato nessun file di Handshake selezionato in questa sessione..."
	arr["POLISH",312]="Nie wybrano pliku Handshake w tej sesji..."
	arr["GERMAN",312]="Keine Handshake-Datei wurde ausgewählt..."
	arr["TURKISH",312]="Bu oturumda hiçbir Handshake dosyası tespit edilmedi..."

	arr["ENGLISH",313]="Handshake selected file detected during this session [${normal_color}${et_handshake}${blue_color}]"
	arr["SPANISH",313]="Se ha detectado un fichero de Handshake seleccionado en esta sesión [${normal_color}${et_handshake}${blue_color}]"
	arr["FRENCH",313]="Le fichier handshake suivant a été détecté comme étant sélectionné pour cette session [${normal_color}${et_handshake}${blue_color}]"
	arr["CATALAN",313]="S'ha detectat un fitxer de Handshake seleccionat en aquesta sessió [${normal_color}${et_handshake}${blue_color}]"
	arr["PORTUGUESE",313]="Um arquivo de Handshake foi capturado nesta sessão [${normal_color}${et_handshake}${blue_color}]"
	arr["RUSSIAN",313]="Обнаружен файл рукопожатия, выбранный в этой сессии [${normal_color}${et_handshake}${blue_color}]"
	arr["GREEK",313]="Εντοπίστηκε επιλεγμένο αρχείο Χειραψίας κατά τη διάρκεια της συνεδρίας [${normal_color}${et_handshake}${blue_color}]"
	arr["ITALIAN",313]="Trovato un file di Handshake selezionato in questa sessione [${normal_color}${et_handshake}${blue_color}]"
	arr["POLISH",313]="Wkryto wybrany plik Handshake w tej sesji [${normal_color}${et_handshake}${blue_color}]"
	arr["GERMAN",313]="In dieser Sitzung wurde eine ausgewählte Handshake-Datei gefunden [${normal_color}${et_handshake}${blue_color}]"
	arr["TURKISH",313]="Bu oturumda handshake dosyyası tespit edildi [${normal_color}${et_handshake}${blue_color}]"

	arr["ENGLISH",314]="Handshake file selected: ${pink_color}${enteredpath}${normal_color}"
	arr["SPANISH",314]="Fichero de Handshake seleccionado: ${pink_color}${enteredpath}${normal_color}"
	arr["FRENCH",314]="Fichier Handshake sélectionné: ${pink_color}${enteredpath}${normal_color}"
	arr["CATALAN",314]="Fitxer de Handshake seleccionat: ${pink_color}${enteredpath}${normal_color}"
	arr["PORTUGUESE",314]="Arquivo de Handshake selecionado: ${pink_color}${enteredpath}${normal_color}"
	arr["RUSSIAN",314]="Выбранный файл рукопожатия: ${pink_color}${enteredpath}${normal_color}"
	arr["GREEK",314]="Επιλεγμένο αρχείο Χειραψίας: ${pink_color}${enteredpath}${normal_color}"
	arr["ITALIAN",314]="File di Handshake selezionato: ${pink_color}${enteredpath}${normal_color}"
	arr["POLISH",314]="Wybrany plik Handshake: ${pink_color}${enteredpath}${normal_color}"
	arr["GERMAN",314]="Ausgewählte Handshake-Datei: ${pink_color}${enteredpath}${normal_color}"
	arr["TURKISH",314]="Handshake dosyası seçildi ${pink_color}${enteredpath}${normal_color}"

	arr["ENGLISH",315]="This attack requires that you have previously a WPA/WPA2 network captured Handshake file"
	arr["SPANISH",315]="Este ataque requiere que tengas capturado previamente un fichero de Handshake de una red WPA/WPA2"
	arr["FRENCH",315]="Vous devez déjà avoir capturé un Handsahke WPA/WPA2 pour pouvoir lancer cette attaque"
	arr["CATALAN",315]="Aquest atac requereix que tinguis capturat prèviament un fitxer de Handshake d'una xarxa WPA/WPA2"
	arr["PORTUGUESE",315]="Este ataque requer que você já tenha capturado um arquivo de Handshake de uma rede WPA/WPA2"
	arr["RUSSIAN",315]="Эта атака требует предварительного захвата файла рукопожатия для WPA/WPA2 сети"
	arr["GREEK",315]="Αυτή η επίθεση απαιτεί να έχετε προηγουμένως κατεγράψει ένα αρχείο Χειραψίας από WPA/WPA2 δίκτο"
	arr["ITALIAN",315]="Questo attacco richiede che tu abbia catturato precedentemente un file di Handshake di una rete WPA/WPA2"
	arr["POLISH",315]="Ten atak wymaga uprzedniego przechwycenia pliku Handshake z sieci WPA/WPA2"
	arr["GERMAN",315]="Dieser Angriff erfordert, dass Sie zuvor eine Handshake-Datei aus einem WPA/WPA2-Netzwerk erfasst haben"
	arr["TURKISH",315]="Bu saldırı, daha önce WPA/WPA2 ağı ele geçirilmiş Handshake dosyasına sahip olmanızı gerektirir"

	arr["ENGLISH",316]="An exploration looking for targets is going to be done..."
	arr["SPANISH",316]="Se va a realizar una exploración en busca de objetivos..."
	arr["FRENCH",316]="Recherche de réseaux cible..."
	arr["CATALAN",316]="Es realitzarà una exploració a la recerca d'objectius..."
	arr["PORTUGUESE",316]="Uma busca por redes wifi será realizada..."
	arr["RUSSIAN",316]="Выполнение сканирования целей..."
	arr["GREEK",316]="Πρόκειται να γίνει μία αναζήτηση για έυρεση στόχων..."
	arr["ITALIAN",316]="Si effettuerà una scansione in cerca di obiettivi..."
	arr["POLISH",316]="Zostanie przeprowadzone poszukiwanie celów..."
	arr["GERMAN",316]="Ein Scan wird auf der Suche nach Zielen durchgeführt..."
	arr["TURKISH",316]="Hedefleri arayan bir keşif yapılacaktır..."

	arr["ENGLISH",317]="If the password for the wifi network is achieved with the captive portal, you must decide where to save it. ${green_color}Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["SPANISH",317]="Si se consigue la contraseña de la red wifi con el portal cautivo, hay que decidir donde guardarla. ${green_color}Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["FRENCH",317]="Si un mot de passe est capté sur le portail captif il faut lui assigner un endroit pour être enregistré. ${green_color}Entrez le chemin du fichier ou bien appuyez sur [Enter] pour utiliser le chemin proposé ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["CATALAN",317]="Si s'aconsegueix la contrasenya de la xarxa wifi amb el portal captiu, cal decidir on guardar-la. ${green_color}Escriu la ruta on desarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["PORTUGUESE",317]="Se a senha da rede wifi for conseguida com o portal cativo, onde deseja salvar? ${green_color}Digite um caminho para salvar o arquivo ou pressione [Enter] para aceitar o padrão ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["RUSSIAN",317]="Вы должны решить, где будет сохранён пароль wifi сети, если он будет получен Перехватывающим порталом. ${green_color}Впишите путь до файла или нажмите [Enter] для принятия значения по умолчанию ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["GREEK",317]="Εάν ο κωδικός πρόσβασης του δικτύου wifi επιτευχθεί με captive portal, θα πρέπει να αποφασίσετε που θα τον αποθηκεύσετε. ${green_color}Πληκτρολογήστε το μονοπάτι για να αποθηκεύσετε το αρχείο ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["ITALIAN",317]="Se si ottiene la passowrd della rete wireless con il captive portal, bisogna decidere dove salvarla. ${green_color}Immettere il percorso dove memorizzare il file o premere [Enter] per accettare quello di default proposto ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["POLISH",317]="Jeśli hasło sieci wifi zostanie uzyskane z portalu captive, musisz zdecydować gdzie je zapisać. ${green_color}Wpisz ścieżkę, w której zapiszemy plik lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["GERMAN",317]="Wenn Sie das WLAN-Passwort mit dem Captive Portal erhalten, müssen Sie entscheiden, wo es gespeichert werden soll. ${green_color} Geben Sie den Pfad ein, unter dem die Datei gespeichert werden soll, oder drücken Sie die [Enter]-Taste, um den Standardvorschlag zu akzeptieren ${normal_color}[${default_et_captive_portal_logpath}]"
	arr["TURKISH",317]="Eğer wifi ağının şifresi esaret portalı ile yakalandıysa, nereye kaydedileceğini belirlemelisiniz. ${green_color}Dosyayı depolamak için yolu yazın veya varsayılan teklifi kabul etmek için [Enter] tuşuna basın. ${normal_color}[${default_et_captive_portal_logpath}]"

	arr["ENGLISH",318]="Choose the language in which network clients will see the captive portal:"
	arr["SPANISH",318]="Elige el idioma en el que los clientes de la red verán el portal cautivo:"
	arr["FRENCH",318]="Choisissez la langue dans laquelle les clients du réseau verront le portail captif:"
	arr["CATALAN",318]="Tria l'idioma en el qual els clients de la xarxa veuran el portal captiu:"
	arr["PORTUGUESE",318]="Escolha o idioma em que os clientes da rede irão ver o portal cativo:"
	arr["RUSSIAN",318]="Выберите язык, на котором клиенты сети будут видеть перехватывающий портал:"
	arr["GREEK",318]="Επιλέξτε τη γλώσσα που θα βλέπουν οι χρήστες του δικτύου στο captive portal:"
	arr["ITALIAN",318]="Scegli la lingua in cui i clienti della rete vedranno il captive portal:"
	arr["POLISH",318]="Wybierz język, w którym klienci sieci zobaczą portal:"
	arr["GERMAN",318]="Wählen Sie die Sprache, in der die Clients des Netzwerks das Captive-Portal sehen:"
	arr["TURKISH",318]="Ağ istemcilerinin Esaret Portalını göreceği dili seçin:"

	arr["ENGLISH",319]="The captive portal language has been established"
	arr["SPANISH",319]="Se ha establecido el idioma del portal cautivo"
	arr["FRENCH",319]="La langue pour le portail captif est activée"
	arr["CATALAN",319]="S'ha establert l'idioma del portal captiu"
	arr["PORTUGUESE",319]="A língua do portal cativo foi selecionada"
	arr["RUSSIAN",319]="Язык перехватывающего портала установлен"
	arr["GREEK",319]="Εγκαταστάθηκε η γλώσσα στο captive portal"
	arr["ITALIAN",319]="La lingua del captive portal è stata stabilita"
	arr["POLISH",319]="Został utworzony język portalu captive"
	arr["GERMAN",319]="Die Sprache des Captive-Portals wurde festgelegt"
	arr["TURKISH",319]="Esaret Portalının dili belirlendi"

	arr["ENGLISH",320]="7.  Greek"
	arr["SPANISH",320]="7.  Griego"
	arr["FRENCH",320]="7.  Grec"
	arr["CATALAN",320]="7.  Grec"
	arr["PORTUGUESE",320]="7.  Grego"
	arr["RUSSIAN",320]="7.  Греческий"
	arr["GREEK",320]="7.  Ελληνικά"
	arr["ITALIAN",320]="7.  Greco"
	arr["POLISH",320]="7.  Grecki"
	arr["GERMAN",320]="7.  Griechisch"
	arr["TURKISH",320]="7.  Yunanca"

	arr["ENGLISH",321]="Do you already have a captured Handshake file? ${blue_color}Answer yes (\"y\") to enter the path or answer no (\"n\") to capture a new one now ${normal_color}${visual_choice}"
	arr["SPANISH",321]="¿Tienes ya un fichero de Handshake capturado? ${blue_color}Responde sí (\"y\") para introducir la ruta o responde no (\"n\") para capturar uno ahora ${normal_color}${visual_choice}"
	arr["FRENCH",321]="Avez-vous déjà un fichier contenant un Handshake capturé? ${blue_color}Répondre oui (\"y\") pour en saisir la route o buien répondre non (\"n\") pour le capturer ${normal_color}${visual_choice}"
	arr["CATALAN",321]="¿Tens ja un fitxer de Handshake capturat? ${blue_color}Respon si (\"y\") per introduir la ruta o respon no (\"n\") per capturar-ne un ara ${normal_color}${visual_choice}"
	arr["PORTUGUESE",321]="Você já tem um arquivo de Handshake capturado? ${blue_color}Responda sim (\"y\") para colocar o caminho do arquivo ou responda não (\"n\") para capturar o arquivo agora ${normal_color}${visual_choice}"
	arr["RUSSIAN",321]="У вас уже есть захваченный файл рукопожатия? ${blue_color}Ответьте Да (\"y\"), для ввода пути или ответьте Нет (\"n\"), для захвата нового рукопожатия ${normal_color}${visual_choice}"
	arr["GREEK",321]="Έχετε ήδη κάποιο αρχείο Χειραψίας; ${blue_color}Απαντήστε ναι (\"y\") για να εισαγάγετε το μονοπάτι ή απαντήστε όχι (\"n\") για να καταγράψετε ένα νέο τώρα ${normal_color}${visual_choice}"
	arr["ITALIAN",321]="Hai già catturato un file di Handshake? ${blue_color}Rispondi sì (\"y\") per introdurre il percorso o rispondi no (\"n\") per catturarne uno ora ${normal_color}${visual_choice}"
	arr["POLISH",321]="Czy masz już przechwycony plik Handshake? ${blue_color}Odpowiedz tak (\"y\") aby wprowadzić ścieżkę lub odpowiedz nie (\"n\"), aby spróbować przechwycić go teraz ${normal_color}${visual_choice}"
	arr["GERMAN",321]="Haben Sie bereits eine erfasste Handshake-Datei? ${blue_color} Ja beantworten (\"y\"), um den Pfad einzugeben oder antworten Sie mit Nein (\"n\"), um jetzt einen zu erfassen ${normal_color}${visual_choice}"
	arr["TURKISH",321]="Yakalanmış bir Handshake dosyası var mı? ${blue_color}Evet ise (\"y\") dizini girin ya da cevap hayır ise (\"n\") yenisini yakalayın ${normal_color}${visual_choice}"

	arr["ENGLISH",322]="It has been checked that there is a Handshake of the chosen target network while checking the selected capture file. Script can continue..."
	arr["SPANISH",322]="Se ha comprobado que existe un Handshake de la red elegida como objetivo durante la exploración en el fichero de captura seleccionado. El script puede continuar..."
	arr["FRENCH",322]="Un Handhsake du réseau cible a bien été retrouvé dans le paquet de capture préalablement choisi. Le script peut donc continuer..."
	arr["CATALAN",322]="S'ha comprovat que hi ha un Handshake de la xarxa triada com a objectiu durant l'exploració en el fitxer de captura seleccionat. El script pot continuar..."
	arr["PORTUGUESE",322]="Verificou-se que no arquivo de captura existe um Handshake da rede da selecionada como o alvo. O script pode continuar..."
	arr["RUSSIAN",322]="Проверка подтвердила, что рукопожатие относится к выбранной целевой сети. Скрипт может продолжать..."
	arr["GREEK",322]="Εντοπίστηκε η παρουσία Χειραψίας για το επιλεγμένο δίκτυο-στόχος καθώς γινόταν έλεγχος του επιλεγμένου αρχείου καταγραφής. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",322]="É stato riscontrato che c'è un Handshake della rete scelta como obiettivo durante la esplorazione del file di cattura selezionato. Lo script può continuare..."
	arr["POLISH",322]="Potwierdzono, że w wybranum pliku przechytywania jest plik Handshake z sieci docelowej. Skrypt może kontynuować..."
	arr["GERMAN",322]="Es wurde überprüft, dass beim Scannen in der ausgewählten Aufnahmedatei ein Handshake des Netzwerks als Ziel ausgewählt wurde. Das Skript kann fortfahren..."
	arr["TURKISH",322]="Seçilen çekim dosyasını kontrol ederken seçilen hedef ağın bir Handshake olduğunu kontrol edilmiştir. Yazılım devam edebilir..."

	arr["ENGLISH",323]="There is no Handshake of the selected network on the capture file"
	arr["SPANISH",323]="No se ha encontrado un Handshake de la red seleccionada en el fichero de captura"
	arr["FRENCH",323]="Aucun Handshake du réseau cible n'a été retrouvé dans le fichier de captures"
	arr["CATALAN",323]="No s'ha trobat un Handshake de la xarxa seleccionada en el fitxer de captura"
	arr["PORTUGUESE",323]="Não foi encontrado nenhum Handshake da rede selecionada no arquivo de captura"
	arr["RUSSIAN",323]="В файле захвата отсутствует рукопожатие выбранной сети"
	arr["GREEK",323]="Δεν υπάρχει Χειραψία του επιλεγμένου δικτύου στο αρχείο καταγραφής"
	arr["ITALIAN",323]="Non è stato trovato una Handshake della rete selezionata nel file di acquisizione"
	arr["POLISH",323]="Nie znaleziono pliku Handshake z wybranej sieci w pliku przechwytywania"
	arr["GERMAN",323]="Ein Handshake des ausgewählten Netzwerks wurde in der Erfassungsdatei nicht gefunden"
	arr["TURKISH",323]="Yakalama dosyasında seçilen ağın bir Handshake'i yok"

	arr["ENGLISH",324]="Handshake file generated successfully at [${normal_color}${et_handshake}${blue_color}]"
	arr["SPANISH",324]="Fichero de Handshake generado con éxito en [${normal_color}${et_handshake}${blue_color}]"
	arr["FRENCH",324]="Fichier Handshake généré avec succès dans [${normal_color}${et_handshake}${blue_color}]"
	arr["CATALAN",324]="Fitxer de Handshake generat amb èxit a [${normal_color}${et_handshake}${blue_color}]"
	arr["PORTUGUESE",324]="Arquivo Handshake gerado com sucesso [${normal_color}${et_handshake}${blue_color}]"
	arr["RUSSIAN",324]="Файл рукопожатия успешно создан в [${normal_color}${et_handshake}${blue_color}]"
	arr["GREEK",324]="Το αρχείο Χειραψίας δημιουργήθηκε επιτυχώς στο [${normal_color}${et_handshake}${blue_color}]"
	arr["ITALIAN",324]="File di Handhake generato con successo in [${normal_color}${et_handshake}${blue_color}]"
	arr["POLISH",324]="Plik Handshake został pomyślnie wygenerowany w [${normal_color}${et_handshake}${blue_color}]"
	arr["GERMAN",324]="Handshake-Datei wurde erfolgreich in generiert [${normal_color}${et_handshake}${blue_color}]"
	arr["TURKISH",324]="Handshake dosyası başarıyla oluşturuldu [${normal_color}${et_handshake}${blue_color}]"

	arr["ENGLISH",325]="Wait. Be patient..."
	arr["SPANISH",325]="Espera. Ten un poco de paciencia..."
	arr["FRENCH",325]="Ayez un peu de patience s'il vous plait..."
	arr["CATALAN",325]="Espera. Tingues una mica de paciència..."
	arr["PORTUGUESE",325]="Aguarde. Por favor, seja paciente..."
	arr["RUSSIAN",325]="Пожалуйста, подождите..."
	arr["GREEK",325]="Περιμένετε. Έχετε λίγη υπομονή..."
	arr["ITALIAN",325]="Aspetta. Devi avere un pò di pazienza..."
	arr["POLISH",325]="Czekaj cierpliwie..."
	arr["GERMAN",325]="Bitte warten. Wir bitten um ein wenig Geduld..."
	arr["TURKISH",325]="Bekleyin. Lütfen sabırlı olun..."

	arr["ENGLISH",326]="Are you going to use the interface with internet access method? ${pink_color}If the answer is no (\"n\"), you'll need ${optional_tools_names[12]} installed to continue. Both will be checked ${normal_color}${visual_choice}"
	arr["SPANISH",326]="¿Vas a utilizar el método de la interfaz con acceso a internet? ${pink_color}Si la respuesta es no (\"n\"), necesitarás tener instalado ${optional_tools_names[12]} para continuar. Ambas cosas se comprobarán ${normal_color}${visual_choice}"
	arr["FRENCH",326]="Allez-vous choisir la méthode qui emploie une interface connectée à internet? ${pink_color}Si la réponse est non (\"n\"), vous m'avez besoin de ${optional_tools_names[12]}. Une vérication se fera à ce niveau avant de lancer l'une ou l'autre méthode${normal_color}${visual_choice}"
	arr["CATALAN",326]="¿Vas a utilitzar el mètode de la interfície amb accés a internet? ${pink_color}Si la resposta és no (\"n\"), necessitaràs tenir instal·lat ${optional_tools_names[12]} per continuar. Totes dues coses es comprovaran ${normal_color}${visual_choice}"
	arr["PORTUGUESE",326]="Você gostaria de utilizar uma interface com acesso à internet para o ataque? ${pink_color}Se a resposta for não (\"n\"), você precisa ter instalado ${optional_tools_names[12]} para continuar. Ambos serão verificados ${normal_color}${visual_choice}"
	arr["RUSSIAN",326]="Собираетесь ли вы использовать этот метод с Интернет-доступом? ${pink_color}Если ответ нет (\"п\"), то для продолжения вам нужно установить ${optional_tools_names[12]}. Будут выполнены проверки обоих условий ${normal_color}${visual_choice}"
	arr["GREEK",326]="Σκοπεύετε να χρησιμοποιήσετε την διεπαφή με την μέθοδο πρόσβασης στο διαδίκτυο; ${pink_color}Αν απαντήσετε όχι (\"n\"), θα πρέπει να έχετε το ${optional_tools_names[12]} εγκατεστημένο για να συνεχίσετε. Και τα δύο ελέγχονται ${normal_color}${visual_choice}"
	arr["ITALIAN",326]="Hai intenzione di utilizzare il metodo dell'interfaccia con accesso ad internet? ${pink_color}Se la risposta è no (\"n\") hai bisogno di tenere installato ${optional_tools_names[12]} per continuare. Entrambi saranno controllati ${normal_color}${visual_choice}"
	arr["POLISH",326]="Czy zamierzasz używać metody interfejsu z dostępem do internetu? ${pink_color}Jeśli odpowiedź brzmi nie (\"n\"), musisz mieć zainstalowane ${optional_tools_names[12]}. Oba narzędzia zostaną sprawdzone ${normal_color}${visual_choice}"
	arr["GERMAN",326]="Verwenden Sie die Interface mit Internetzugang? ${pink_color}Wenn die Antwort nein ist (\"n\"), müssen Sie ${optional_tools_names[12]} installiert haben, um fortzufahren. Beides wird überprüft ${normal_color}${visual_choice}"
	arr["TURKISH",326]="İnternet erişim yöntemiyle arayüzü kullanacak mısınız? ${pink_color}Eğer cevap hayır ise (\"n\"), devam etmek için ${optional_tools_names[12]} aracına ihtiyacınız olacak. İkisi de kontrol edilecek ${normal_color}${visual_choice}"

	arr["ENGLISH",327]="You don't have ${optional_tools_names[12]} installed. The script can't continue. Redirecting to main screen..."
	arr["SPANISH",327]="No tienes instalado ${optional_tools_names[12]}. El script no puede continuar. Redirigiendo a la pantalla principal..."
	arr["FRENCH",327]="${optional_tools_names[12]} n'est pas installé. Le script ne peut pas continuer. Retour au menu principal..."
	arr["CATALAN",327]="No tens instal·lat ${optional_tools_names[12]}. El script no pot continuar. Redirigint a la pantalla principal..."
	arr["PORTUGUESE",327]="Você não tem ${optional_tools_names[12]} instalado. O script não pode continuar. Redirecionando para o menu principal..."
	arr["RUSSIAN",327]="У вас не установлена программа ${optional_tools_names[12]}. Скрипт не может продолжить. Переход на главный экран…"
	arr["GREEK",327]="Το ${optional_tools_names[12]} δεν είναι εγκατεστημένο. Το script δεν μπορεί να συνεχίσει. Θα καθοδηγηθείτε στην κύρια οθόνη..."
	arr["ITALIAN",327]="Non hai installato ${optional_tools_names[12]}. Lo script non può continuare. Reindirizzando alla schermata principale..."
	arr["POLISH",327]="Nie masz zainstalowanych ${optional_tools_names[12]}. Skrypt nie może kontynuować. Przekierowywanie do głównego ekranu..."
	arr["GERMAN",327]="Sie haben ${optional_tools_names[12]} nicht installiert. Das Skript kann nicht fortgesetzt werden. Weiterleitung zum Hauptbildschirm weitergeleitet..."
	arr["TURKISH",327]="${optional_tools_names[12]} aracı bulunamadı. Yazılım devam edemez. Ana ekrana yönlendiriliyorsunuz..."

	arr["ENGLISH",328]="The unique Evil Twin attack in which it's not necessary to have an additional interface with internet access is the captive portal attack. As an alternative, you'll need another additional requirement: ${optional_tools_names[12]}"
	arr["SPANISH",328]="El único ataque de Evil Twin en el que no es necesario tener una interfaz adicional con acceso a internet es el del portal cautivo. Como alternativa necesitarás otro requerimiento adicional: ${optional_tools_names[12]}"
	arr["FRENCH",328]="La seule attaque Evil Twin pour laquelle il n'est pas nécessaire d'avoir une interface supplémentaire connectée à internet est l'attaque du portail captif. Elle implique l'utilisation d'une dépendance supplémentaire: ${optional_tools_names[12]}"
	arr["CATALAN",328]="L'únic atac d'Evil Twin en què no cal tenir una interfície addicional amb accés a internet és el del portal captiu. Com a alternativa et caldrà un altre requeriment addicional: ${optional_tools_names[12]}"
	arr["PORTUGUESE",328]="O único ataque Evil Twin em que não é necessário ter uma interface adicional com acesso à internet é o portal cativo. Porém você vai precisar ter instalado ${optional_tools_names[12]}"
	arr["RUSSIAN",328]="Уникальная атака Злой Двойник, при которой необязательно иметь дополнительный интерфейс с доступом в Интернет для атаки Перехватывающим Порталом. Но для нее вам нужно дополнительно ПО: ${optional_tools_names[12]}"
	arr["GREEK",328]="Η μόνη επίθεση Evil Twin στην οποία δεν είναι απαραίτητο να έχετε επιπλέον διεπαφή με πρόσβαση στο διαδίκτυο είναι η επίθεση με captive portal. Εναλλακτικά, θα χρειαστείτε το: ${optional_tools_names[12]}"
	arr["ITALIAN",328]="L'unico attacco di tipo Evil Twin in cui non è necessario avere un'interfaccia supplementare con accesso a internet è quello con captive portal. In cambo avrai bisogno di un ulteriore requisito: ${optional_tools_names[12]}"
	arr["POLISH",328]="Jedynym atakiem Evil Twin, w którym nie ma konieczności dodatkowego interfejsu z dostępem do internetu, jest atak Captive Portal. Alternatywnie potrzebujesz kolejnego dodatkowego narzędzia: ${optional_tools_names[12]}"
	arr["GERMAN",328]="Der einzige Angriff von Evil Twin, bei dem keine zusätzliche Interface zum Internetzugang benötigt wird, ist die des Captive-Portals. Als Alternative benötigen Sie eine weitere zusätzliche Anforderung: ${optional_tools_names[12]}"
	arr["TURKISH",328]="İnternet erişimi olan ek bir arayüze sahip olmanın gerekli olmadığı benzersiz Şeytani İkiz saldırısı, esaret portalı saldırısıdır. Alternatif olarak, başka bir ek gereksinime ihtiyacınız olacak: ${optional_tools_names[12]}"

	arr["ENGLISH",329]="It seems you have ${optional_tools_names[12]} installed. Script can continue..."
	arr["SPANISH",329]="Se ha comprobado que tienes instalado ${optional_tools_names[12]}. El script puede continuar..."
	arr["FRENCH",329]="${optional_tools_names[12]} correctement detecté. Le script peut continuer..."
	arr["CATALAN",329]="S'ha comprovat que tens instal·lat ${optional_tools_names[12]}. El script pot continuar..."
	arr["PORTUGUESE",329]="${optional_tools_names[12]} está instalado. O script pode continuar..."
	arr["RUSSIAN",329]="Судя по всему, ${optional_tools_names[12]} у вас установлена. Скрипт может продолжить..."
	arr["GREEK",329]="Φαίνεται πως το ${optional_tools_names[12]} είναι εγκατεστημένο. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",329]="Sembra che hai installato ${optional_tools_names[12]}. Lo script può continuare..."
	arr["POLISH",329]="Sprawdzono, że masz zainstalowane ${optional_tools_names[12]}. Skrypt może kontynuować..."
	arr["GERMAN",329]="Es wurde bestätigt, dass Sie ${optional_tools_names[12]} installiert haben. Das Skript kann fortfahren..."
	arr["TURKISH",329]="Görünüşe göre ${optional_tools_names[12]} var. Yazılım devam edebilir..."

	arr["ENGLISH",330]="At this point there are two options to prepare the captive portal. Either having an interface with internet access, or making a fake DNS using ${optional_tools_names[12]}"
	arr["SPANISH",330]="Llegados a este punto hay dos opciones para preparar el portal cautivo. O bien tenemos una interfaz con acceso a internet, o preparamos un falso DNS usando ${optional_tools_names[12]}"
	arr["FRENCH",330]="Le portail captif peut être déployé de deux manières. Soit en utilisant une interface avec accès internet, si il y en a une disponible. Soit avec un faux DNS crée à l'aide de ${optional_tools_names[12]}"
	arr["CATALAN",330]="Arribats a aquest punt hi ha dues opcions per preparar el portal captiu. O bé tenim una interfície amb accés a internet, o vam preparar un fals DNS utilitzant ${optional_tools_names[12]}"
	arr["PORTUGUESE",330]="Neste momento, existem duas opções para o portal cativo. Ou temos uma interface com acesso à internet, ou fazemos um DNS falso usando ${optional_tools_names[12]}"
	arr["RUSSIAN",330]="На данном этапе у вас две опции для подготовки Перехватывающего Портала. Нужно или иметь сетевой интерфейс с Интернет-доступом, или создать фальшивый DNS используя ${optional_tools_names[12]}"
	arr["GREEK",330]="Σε αυτό το σημείο υπάρχουν δύο επιλογές για την προετοιμασία του captive portal. Να έχετε μία διεπαφή με πρόσβαση στο διαδίκτυο, ή να φιάξετε ψευδές DNS χρησιμοποιώντας το ${optional_tools_names[12]}"
	arr["ITALIAN",330]="A questo punto ci sono due opzioni per la preparazione del captive portal. O avere un'interfaccia con accesso a internet, o preparare un DNS falso utilizzando ${optional_tools_names[12]}"
	arr["POLISH",330]="W tym momencie istnieją dwie możliwości przygotowania portalu Captive. Interfejs z dostępem do internet lub przygotowujemy fałszywy DNS przy użyciu ${optional_tools_names[12]}"
	arr["GERMAN",330]="An dieser Stelle gibt es zwei Möglichkeiten, das Captive-Portal vorzubereiten. Entweder haben wir eine Schnittstelle mit Internetzugang, oder wir bereiten einen falschen DNS mit ${optional_tools_names[12]} vor"
	arr["TURKISH",330]="Bu noktada esaret portalını hazırlamak için iki seçenek var. İnternet erişimi olan bir arayüze sahip olmak ya da sahte bir DNS kullanmak ${optional_tools_names[12]}"

	arr["ENGLISH",331]="10. German"
	arr["SPANISH",331]="10. Alemán"
	arr["FRENCH",331]="10. Allemand"
	arr["CATALAN",331]="10. Alemany"
	arr["PORTUGUESE",331]="10. Alemão"
	arr["RUSSIAN",331]="10. Немецкий"
	arr["GREEK",331]="10. Γερμανικά"
	arr["ITALIAN",331]="10. Tedesco"
	arr["POLISH",331]="10. Niemiecki"
	arr["GERMAN",331]="10. Deutsch"
	arr["TURKISH",331]="10. Almanca"

	arr["ENGLISH",332]="Language changed to Greek"
	arr["SPANISH",332]="Idioma cambiado a Griego"
	arr["FRENCH",332]="Le script sera maintenant en Grec"
	arr["CATALAN",332]="Idioma canviat a Grec"
	arr["PORTUGUESE",332]="Idioma alterado para Grego"
	arr["RUSSIAN",332]="Язык изменён на Греческий"
	arr["GREEK",332]="Η γλώσσα άλλαξε στα Ελληνικά"
	arr["ITALIAN",332]="Lingua cambiata in Greco"
	arr["POLISH",332]="Zmieniono język na Grecki"
	arr["GERMAN",332]="Die Sprache wurde in Griechisch geändert"
	arr["TURKISH",332]="Dil Yunanca olarak değiştirildi"

	arr["ENGLISH",333]="8.  WPS attacks menu"
	arr["SPANISH",333]="8.  Menú de ataques WPS"
	arr["FRENCH",333]="8.  Menu d'attaques WPS"
	arr["CATALAN",333]="8.  Menú d'atacs WPS"
	arr["PORTUGUESE",333]="8.  Menu de ataques WPS"
	arr["RUSSIAN",333]="8.  Меню атак на WPS"
	arr["GREEK",333]="8.  Μενού επιθέσεων WPS"
	arr["ITALIAN",333]="8.  Menú degli attacchi WPS"
	arr["POLISH",333]="8.  Menu ataków WPS"
	arr["GERMAN",333]="8.  WPS-Angriffsmenü"
	arr["TURKISH",333]="8.  WPS saldırı menüsü"

	arr["ENGLISH",334]="WPS attacks menu"
	arr["SPANISH",334]="Menú de ataques WPS"
	arr["FRENCH",334]="Menu d'attaques WPS"
	arr["CATALAN",334]="Menú d'atacs WPS"
	arr["PORTUGUESE",334]="Menu de ataques WPS"
	arr["RUSSIAN",334]="Меню атак на WPS"
	arr["GREEK",334]="Μενού επιθέσεων WPS"
	arr["ITALIAN",334]="Menú degli attacchi WPS"
	arr["POLISH",334]="Menu ataków WPS"
	arr["GERMAN",334]="WPS-Angriffsmenü"
	arr["TURKISH",334]="WPS saldırı menüsü"

	arr["ENGLISH",335]="Selected WPS BSSID: ${pink_color}${wps_bssid}${normal_color}"
	arr["SPANISH",335]="BSSID WPS seleccionado: ${pink_color}${wps_bssid}${normal_color}"
	arr["FRENCH",335]="BSSID WPS sélectionné: ${pink_color}${wps_bssid}${normal_color}"
	arr["CATALAN",335]="BSSID WPS seleccionat: ${pink_color}${wps_bssid}${normal_color}"
	arr["PORTUGUESE",335]="BSSID WPS selecionado: ${pink_color}${wps_bssid}${normal_color}"
	arr["RUSSIAN",335]="Выбран WPS BSSID: ${pink_color}${wps_bssid}${normal_color}"
	arr["GREEK",335]="Επιλεγμένο WPS BSSID: ${pink_color}${wps_bssid}${normal_color}"
	arr["ITALIAN",335]="BSSID WPS selezionato: ${pink_color}${wps_bssid}${normal_color}"
	arr["POLISH",335]="Wybrano BSSID WPS: ${pink_color}${wps_bssid}${normal_color}"
	arr["GERMAN",335]="Ausgewählte WPS BSSID: ${pink_color}${wps_bssid}${normal_color}"
	arr["TURKISH",335]="WPS BSSID seçildi: ${pink_color}${wps_bssid}${normal_color}"

	arr["ENGLISH",336]="Selected WPS channel: ${pink_color}${wps_channel}${normal_color}"
	arr["SPANISH",336]="Canal WPS seleccionado: ${pink_color}${wps_channel}${normal_color}"
	arr["FRENCH",336]="Canal WPS sélectionné: ${pink_color}${wps_channel}${normal_color}"
	arr["CATALAN",336]="Canal WPS seleccionat: ${pink_color}${wps_channel}${normal_color}"
	arr["PORTUGUESE",336]="Canal WPS selecionado: ${pink_color}${wps_channel}${normal_color}"
	arr["RUSSIAN",336]="Выбран WPS канал: ${pink_color}${wps_channel}${normal_color}"
	arr["GREEK",336]="Επιλεγμένο WPS κανάλι: ${pink_color}${wps_channel}${normal_color}"
	arr["ITALIAN",336]="Canale WPS selezionato: ${pink_color}${wps_channel}${normal_color}"
	arr["POLISH",336]="Wybrano kanał WPS: ${pink_color}${wps_channel}${normal_color}"
	arr["GERMAN",336]="Ausgewählter WPS-Kanal: ${pink_color}${wps_channel}${normal_color}"
	arr["TURKISH",336]="WPS kanal seçildi: ${pink_color}${wps_channel}${normal_color}"

	arr["ENGLISH",337]="Selected WPS ESSID: ${pink_color}${wps_essid}${blue_color} <- can't be used"
	arr["SPANISH",337]="ESSID WPS seleccionado: ${pink_color}${wps_essid}${blue_color} <- no se puede usar"
	arr["FRENCH",337]="ESSID WPS sélectionné: ${pink_color}${wps_essid}${blue_color} <- ne peut pas être utilisé"
	arr["CATALAN",337]="ESSID WPS seleccionat: ${pink_color}${wps_essid}${blue_color} <- no es pot utilitzar"
	arr["PORTUGUESE",337]="ESSID WPS selecionado: ${pink_color}${wps_essid}${blue_color} <- não pode ser utilizado"
	arr["RUSSIAN",337]="Выбран WPS ESSID: ${pink_color}${wps_essid}${blue_color} <- не может использоваться"
	arr["GREEK",337]="Επιλεγμένο WPS ESSID: ${pink_color}${wps_essid}${blue_color} <- δεν μπορεί να χρησιμοποιηθεί"
	arr["ITALIAN",337]="ESSID WPS selezionato: ${pink_color}${wps_essid}${blue_color} <- non può essere utilizzato"
	arr["POLISH",337]="Wybrano WPS ESSID: ${pink_color}${wps_essid}${blue_color} <- nie można użyć"
	arr["GERMAN",337]="Ausgewähltes ESSID WPS: {pink_color}${wps_essid}${blue_color} <- kann nicht verwendet werden"
	arr["TURKISH",337]="WPS ESSID seçildi: ${pink_color}${wps_essid}${blue_color} <- kullanılamaz"

	arr["ENGLISH",338]="Selected WPS ESSID: ${pink_color}${wps_essid}${normal_color}"
	arr["SPANISH",338]="ESSID WPS seleccionado: ${pink_color}${wps_essid}${normal_color}"
	arr["FRENCH",338]="ESSID WPS sélectionné: ${pink_color}${wps_essid}${normal_color}"
	arr["CATALAN",338]="ESSID WPS seleccionat: ${pink_color}${wps_essid}${normal_color}"
	arr["PORTUGUESE",338]="ESSID WPS selecionado: ${pink_color}${wps_essid}${normal_color}"
	arr["RUSSIAN",338]="Выбран WPS ESSID: ${pink_color}${wps_essid}${normal_color}"
	arr["GREEK",338]="Επιλεγμένο WPS ESSID: ${pink_color}${wps_essid}${normal_color}"
	arr["ITALIAN",338]="ESSID WPS selezionato: ${pink_color}${wps_essid}${normal_color}"
	arr["POLISH",338]="Wybrano WPS ESSID: ${pink_color}${wps_essid}${normal_color}"
	arr["GERMAN",338]="Ausgewähltes ESSID WPS: ${pink_color}${wps_essid}${normal_color}"
	arr["TURKISH",338]="WPS ESSID seçildi: ${pink_color}${wps_essid}${normal_color}"

	arr["ENGLISH",339]="Selected WPS BSSID: ${pink_color}None${normal_color}"
	arr["SPANISH",339]="BSSID WPS seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",339]="BSSID WPS sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",339]="BSSID WPS seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",339]="BSSID WPS selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",339]="Выбран WPS BSSID: ${pink_color}Нет${normal_color}"
	arr["GREEK",339]="Επιλεγμένο WPS BSSID: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",339]="BSSID WPS selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",339]="Wybrano WPS BSSID: ${pink_color}Brak${normal_color}"
	arr["GERMAN",339]="Ausgewähltes BSSID WPS: ${pink_color}Keines${normal_color}"
	arr["TURKISH",339]="WPS BSSID seçildi: ${pink_color}None${normal_color}"

	arr["ENGLISH",340]="Selected WPS channel: ${pink_color}None${normal_color}"
	arr["SPANISH",340]="Canal WPS seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",340]="Canal WPS sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",340]="Canal WPS seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",340]="Canal WPS selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",340]="Выбран WPS канал: ${pink_color}Нет${normal_color}"
	arr["GREEK",340]="Επιλεγμένο WPS κανάλι: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",340]="Canale WPS selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",340]="Wybrano kanał WPS: ${pink_color}Brak${normal_color}"
	arr["GERMAN",340]="Ausgewählter WPS-Kanal: ${pink_color}Keinen${normal_color}"
	arr["TURKISH",340]="WPS kanal seçildi: ${pink_color}None${normal_color}"

	arr["ENGLISH",341]="Selected WPS ESSID: ${pink_color}None${normal_color}"
	arr["SPANISH",341]="ESSID WPS seleccionado: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",341]="ESSID WPS sélectionné: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",341]="ESSID WPS seleccionat: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",341]="ESSID WPS selecionado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",341]="Выбран WPS ESSID: ${pink_color}Нет${normal_color}"
	arr["GREEK",341]="Επιλεγμένο WPS ESSID: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",341]="ESSID WPS selezionato: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",341]="Wybrano WPS ESSID: ${pink_color}Brak${normal_color}"
	arr["GERMAN",341]="Ausgewähltes ESSID WPS: ${pink_color}Keines${normal_color}"
	arr["TURKISH",341]="WPS ESSID seçildi: ${pink_color}None${normal_color}"

	arr["ENGLISH",342]="Pixie Dust attack obtains PIN and password in seconds, but not all access points are affected"
	arr["SPANISH",342]="El ataque Pixie Dust obtiene el PIN y la clave en segundos, pero no todos los puntos de acceso son vulnerables a este ataque"
	arr["FRENCH",342]="L'attaque Pixie Dust permet l'obtention du PIN et du mot de passe en quelques secondes mais les points d'accès ne sont pas tous vulnérables"
	arr["CATALAN",342]="L'atac Pixie Dust obté el PIN i la clau en segons, però no tots els punts d'accés són vulnerables a aquest atac"
	arr["PORTUGUESE",342]="O ataque Pixie Dust recebe o PIN e a senha em segundos, mas nem todos os pontos de acesso são vulneráveis a este ataque"
	arr["RUSSIAN",342]="Pixie Dust получает ПИН и пароль за секунды, но не все точки доступа подвержены этой атаке"
	arr["GREEK",342]="Η επίθεση Pixie Dust αποκτά το PIN και τον κωδικό πρόσβασης σε δευτερόλεπτα, αλλά μερικά σημεία πρόσβασης δεν επηρεάζονται"
	arr["ITALIAN",342]="L'attacco Pixie Dust ottiene il PIN e la password in pochi secondi, ma non tutti i punti di accesso sono vulnerabili a questo attacco"
	arr["POLISH",342]="Atak Pixie Dust pobiera PIN i klucz sieci w kilka sekund, ale nie wszystkie punkty dostępu są na niego podatne"
	arr["GERMAN",342]="Der Pixie Dust Angriff erhält die PIN und den Schlüssel in Sekundenschnelle, aber nicht alle Access Points sind für diesen Angriff anfällig"
	arr["TURKISH",342]="Pixie Dust saldırısı saniyeler içinde PIN ve şifre alır, ancak tüm erişim noktaları etkilenmez"

	arr["ENGLISH",343]="In order to success on any WPS based attack, you need good signal of target network. We might otherwise get false negatives"
	arr["SPANISH",343]="Para realizar cualquier ataque WPS es necesario tener una buena señal de la red objetivo. Si no, podríamos obtener falsos negativos"
	arr["FRENCH",343]="Il faut être dans de bonnes conditions d'émission et de réception pour pouvoir mener à bien une attaque WPS. Sinon l'attaque pourrait se solder par un faux négatif"
	arr["CATALAN",343]="Per realitzar qualsevol atac WPS cal tenir un bon senyal de la xarxa objectiu. Si no, podríem obtenir falsos negatius"
	arr["PORTUGUESE",343]="Para executar qualquer ataque WPS você precisa ter um bom sinal da rede alvo. Caso contrario você pode obter falsos negativos"
	arr["RUSSIAN",343]="Чтобы добиться успеха при любой WPS атаке, вам нужен хорошей сигнал целевой сети. В противном случае мы можем получить ложные срабатывания"
	arr["GREEK",343]="Για να εκτελεστεί επιτυχώς οποιαδήποτε επίθεση WPS, θα πρέπει να υπάρχει ισχυρό σήμα του δικτύου στόχου. Αλλιώς μπορεί να υπάρξουν ψευδώς αρνητικά αποτελέσματα"
	arr["ITALIAN",343]="Per qualsiasi attacco WPS è necessario avere un buon segnale della rete obiettivo. Altrimenti potremmo ottenere falsi negativi"
	arr["POLISH",343]="Aby wykonać dowolny atak WPS, trzeba mieć dobry sygnał z sieci docelowej. Jeśli nie, możemy błędnie stwierdzić ze AP jest odporny"
	arr["GERMAN",343]="Um einen WPS-Angriff auszuführen, ist ein gutes Signal vom Zielnetzwerk erforderlich. Wenn nicht, könnten wir falsche Negative bekommen"
	arr["TURKISH",343]="Herhangi bir WPS tabanlı saldırıda başarılı olmak için, iyi bir hedef ağ sinyaline ihtiyacınız vardır. Aksi halde yanlış negatifler alabiliriz"

	arr["ENGLISH",344]="Some access points can be blocked after failing some PIN connection attempts. It may vary depending on the access point"
	arr["SPANISH",344]="Algunos puntos de acceso se bloquean tras fallar cierto número de intentos de conexión por PIN. Puede variar dependiendo del punto de acceso"
	arr["FRENCH",344]="Certains routeurs bloquent le WPS après un certain nombre de PIN erronés. Ce nombre varie selon les modèle"
	arr["CATALAN",344]="Alguns punts d'accés es bloquejan després de fallar un cert nombre d'intents de connexió per PIN. Pot variar depenent del punt d'accés"
	arr["PORTUGUESE",344]="Alguns pontos de acesso podem estar bloqueados depois de receber uma série de tentativas incorretas de conexão por PIN. Isso pode variar dependendo do ponto de acesso"
	arr["RUSSIAN",344]="Некоторые точки доступа блокируются после нескольких неудачных попыток подключения с ПИНом. Это зависит от конкретной точки доступа"
	arr["GREEK",344]="Μερικά σημεία πρόσβασης μπορεί να μπλοκαριστούν μετά από μερικές αποτυχημένες προσπάθειες σύνδεσης PIN. Μπορεί να διαφέρει ανάλογα με το σημείο πρόσβασης"
	arr["ITALIAN",344]="Alcuni punti di accesso si bloccano dopo un certo numero di tentativi di connessione con PIN. Può variare a seconda del punto di accesso"
	arr["POLISH",344]="Niektóre punkty dostępu są blokowane po pewnej liczbie prób PIN. Liczba ta może się różnić w zależności od punktu dostępu"
	arr["GERMAN",344]="Einige APs sind blockiert, nachdem einige Versuche zur PIN-Verbindung fehlgeschlagen sind. Dies kann abhängig vom Zugriffspunkt variieren"
	arr["TURKISH",344]="Bazı erişim noktaları, bazı PIN bağlantı girişimleri başarısız olduktan sonra engellenebilir. Erişim noktasına bağlı olarak değişebilir"

	arr["ENGLISH",345]="5.  (bully) Custom PIN association"
	arr["SPANISH",345]="5.  (bully) Asociación con PIN personalizado"
	arr["FRENCH",345]="5.  (bully) Association avec PIN personnalisé"
	arr["CATALAN",345]="5.  (bully) Associació amb PIN personalitzat"
	arr["PORTUGUESE",345]="5.  (bully) Associação com um PIN personalizado"
	arr["RUSSIAN",345]="5.  (bully) Подключение с известным ПИНом для раскрытия пароля сети"
	arr["GREEK",345]="5.  (bully) Σύνδεση με εξατομικευμένο PIN"
	arr["ITALIAN",345]="5.  (bully) Associazione con PIN personalizzato"
	arr["POLISH",345]="5.  (bully) Asocjacja z niestandardowym kodem PIN"
	arr["GERMAN",345]="5.  (bully) Assoziation mit personalisierter PIN"
	arr["TURKISH",345]="5.  (bully) Özel PIN ilişkilendirmesi"

	arr["ENGLISH",346]="7.  (bully) Pixie Dust attack"
	arr["SPANISH",346]="7.  (bully) Ataque Pixie Dust"
	arr["FRENCH",346]="7.  (bully) Attaque Pixie Dust"
	arr["CATALAN",346]="7.  (bully) Atac Pixie Dust"
	arr["PORTUGUESE",346]="7.  (bully) Ataque Pixie Dust"
	arr["RUSSIAN",346]="7.  (bully) Атака Pixie Dust"
	arr["GREEK",346]="7.  (bully) Επίθεση Pixie Dust"
	arr["ITALIAN",346]="7.  (bully) Attacco Pixie Dust"
	arr["POLISH",346]="7.  (bully) Atak Pixie Dust"
	arr["GERMAN",346]="7.  (bully) Pixie Dust Angriff"
	arr["TURKISH",346]="7.  (bully) Pixie Dust saldırısı"

	arr["ENGLISH",347]="9.  (bully) Bruteforce PIN attack"
	arr["SPANISH",347]="9.  (bully) Ataque de fuerza bruta por PIN"
	arr["FRENCH",347]="9.  (bully) Attaque brute force PIN"
	arr["CATALAN",347]="9.  (bully) Atac de força bruta per PIN"
	arr["PORTUGUESE",347]="9.  (bully) Ataque de força bruta por PIN"
	arr["RUSSIAN",347]="9.  (bully) Атака полным перебором ПИНа"
	arr["GREEK",347]="9.  (bully) Επίθεση PIN με χρήση ωμής βίας"
	arr["ITALIAN",347]="9.  (bully) Attacco forza bruta con PIN"
	arr["POLISH",347]="9.  (bully) Atak Brute Force za pomocą kodu PIN"
	arr["GERMAN",347]="9.  (bully) Brute-Force-Angriff durch PIN"
	arr["TURKISH",347]="9.  (bully) Bruteforce PIN saldırısı"

	arr["ENGLISH",348]="11. (bully) Known PINs database based attack"
	arr["SPANISH",348]="11. (bully) Ataque basado en base de datos de PINs conocidos"
	arr["FRENCH",348]="11. (bully) Attaque en utilisant un PIN de la base de données"
	arr["CATALAN",348]="11. (bully) Atac basat en base de dades de PINs coneguts"
	arr["PORTUGUESE",348]="11. (bully) Ataque com base em um banco de dados de PINs conhecidos"
	arr["RUSSIAN",348]="11. (bully) Атака на основе базы данных известных и сгенерированных ПИНов"
	arr["GREEK",348]="11. (bully) Επίθεση με χρήση βάσης δεδομένων γνωστών PIN"
	arr["ITALIAN",348]="11. (bully) Attacco che utilizza una base dati di PIN"
	arr["POLISH",348]="11. (bully) Atak oparty o bazę danych znanych PINów"
	arr["GERMAN",348]="11. (bully) Angriff auf Datenbank bekannter PINs basiert"
	arr["TURKISH",348]="11. (bully) Bilinen PIN'ler veritabanı saldırısı"

	arr["ENGLISH",349]="  N.         BSSID      CHANNEL  PWR   LOCKED  ESSID"
	arr["SPANISH",349]="  N.         BSSID        CANAL  PWR   LOCKED  ESSID"
	arr["FRENCH",349]="  N.         BSSID        CANAL  PWR   LOCKED  ESSID"
	arr["CATALAN",349]="  N.         BSSID        CANAL  PWR   LOCKED  ESSID"
	arr["PORTUGUESE",349]="  N.         BSSID        CANAL  PWR   LOCKED  ESSID"
	arr["RUSSIAN",349]="  N.         BSSID      CHANNEL  PWR   LOCKED  ESSID"
	arr["GREEK",349]="  N.         BSSID      CHANNEL  PWR   LOCKED  ESSID"
	arr["ITALIAN",349]="  N.         BSSID       CANALE  PWR   LOCKED  ESSID"
	arr["POLISH",349]="  N.         BSSID        KANAŁ  PWR   LOCKED  ESSID"
	arr["GERMAN",349]="  N.         BSSID        KANAL  PWR   LOCKED  ESSID"
	arr["TURKISH",349]="  N.         BSSID      KANAL  PWR   LOCKED  ESSID"

	arr["ENGLISH",350]="${blue_color}You have selected a locked WPS network ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",350]="${blue_color}Has seleccionado una red WPS bloqueada ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",350]="${blue_color}Vous avez sélectionné un réseau dont le WPS est bloqué ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",350]="${blue_color}Has seleccionat una xarxa WPS bloquejada ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",350]="${blue_color}Você selecionou uma rede com WPS bloqueado ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",350]="${blue_color}Вы выбрали заблокированную WPS сеть ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",350]="${blue_color}Έχετε επιλέξει ένα κλειδωμένο WPS δίκτυο ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",350]="${blue_color}È stata selezionata una rete WPS bloccata ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",350]="${blue_color}Wybrano sieć z zablokowanym WPS ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",350]="${blue_color}Sie haben ein blockiertes WPS-Netzwerk ausgewählt ${green_color}Möchten Sie fortfahren? ${normal_color}${visual_choice}"
	arr["TURKISH",350]="${blue_color}Kilitli bir WPS ağı seçtiniz ${green_color}Devam etmek ister misiniz? ${normal_color}${visual_choice}"

	arr["ENGLISH",351]="WPS locked network: ${pink_color}${wps_locked}${normal_color}"
	arr["SPANISH",351]="Red WPS bloqueada: ${pink_color}${wps_locked}${normal_color}"
	arr["FRENCH",351]="Blocage du WPS: ${pink_color}${wps_locked}${normal_color}"
	arr["CATALAN",351]="Xarxa WPS bloquejada: ${pink_color}${wps_locked}${normal_color}"
	arr["PORTUGUESE",351]="Rede com WPS bloqueado: ${pink_color}${wps_locked}${normal_color}"
	arr["RUSSIAN",351]="Сеть с заблокированным WPS: ${pink_color}${wps_locked}${normal_color}"
	arr["GREEK",351]="Κλειδωμένο WPS δίκτυο: ${pink_color}${wps_locked}${normal_color}"
	arr["ITALIAN",351]="Rete WPS bloccata: ${pink_color}${wps_locked}${normal_color}"
	arr["POLISH",351]="Zablokowana sieć WPS: ${pink_color}${wps_locked}${normal_color}"
	arr["GERMAN",351]="Blockiertes WPS-Netzwerk: ${pink_color}${wps_locked}${normal_color}"
	arr["TURKISH",351]="WPS kilitli ağ: ${pink_color}${wps_locked}${normal_color}"

	arr["ENGLISH",352]="WPS locked network: ${pink_color}None${normal_color}"
	arr["SPANISH",352]="Red WPS bloqueada: ${pink_color}Ninguno${normal_color}"
	arr["FRENCH",352]="Blocage du WPS: ${pink_color}Aucun${normal_color}"
	arr["CATALAN",352]="Xarxa WPS bloquejada: ${pink_color}Ningú${normal_color}"
	arr["PORTUGUESE",352]="Rede com WPS bloqueado: ${pink_color}Nenhum${normal_color}"
	arr["RUSSIAN",352]="Сеть с заблокированным WPS: ${pink_color}Нет${normal_color}"
	arr["GREEK",352]="Κλειδωμένο WPS δίκτυο: ${pink_color}Κανένα${normal_color}"
	arr["ITALIAN",352]="Rete WPS bloccata: ${pink_color}Nessuno${normal_color}"
	arr["POLISH",352]="Zablokowana sieć WPS: ${pink_color}Brak${normal_color}"
	arr["GERMAN",352]="Blockiertes WPS-Netzwerk: ${pink_color}Keins${normal_color}"
	arr["TURKISH",352]="WPS kilitli ağ: ${pink_color}None${normal_color}"

	arr["ENGLISH",353]="Checking to solve possible \"bad FCS\" problem if exists. Parameterizing..."
	arr["SPANISH",353]="Realizando una pequeña prueba para solventar el posible problema de \"bad FCS\" si existiese. Parametrizando..."
	arr["FRENCH",353]="Vérification de routine pour prévenir une éventuelle erreur de type \"bad FCS\""
	arr["CATALAN",353]="Realitzant una petita prova per solucionar el possible problema de \"bad FCS\" si existís. Parametritzant..."
	arr["PORTUGUESE",353]="Fazendo alguns testes para resolver o possível problema \"bad FCS\". Definindo parâmetro..."
	arr["RUSSIAN",353]="Проверка возможного решения проблемы \"bad FCS (контроля последовательности кадров)\" если она существует. Параметризация..."
	arr["GREEK",353]="Γίνεται έλεγχος επίλυσης πιθανού σφάλματος \"bad FCS\" αν υπάρχει. Γίνεται παραμετροποίηση..."
	arr["ITALIAN",353]="Effettuando un piccolo test per risolvere il possibile problema di \"bad FCS\" se presente. Parametrizzando..."
	arr["POLISH",353]="Przeprowadzenie małego testu, aby rozwiązać problem \"bad FCS\" jeśli istniał. Parametryzowanie..."
	arr["GERMAN",353]="Ein Test wird ausgeführt, um das mögliche Problem von \"bad FCS\" zu lösen, falls es existiert. Parametrieren..."
	arr["TURKISH",353]="Varsa olası \"bad FCS\" sorununu çözme kontrol ediliyor. Parametrelendiriliyor..."

	arr["ENGLISH",354]="Done! parameter set"
	arr["SPANISH",354]="Hecho! parámetro fijado"
	arr["FRENCH",354]="Paramètres définis!"
	arr["CATALAN",354]="Fet! paràmetre fixat"
	arr["PORTUGUESE",354]="Feito! parâmetro definido"
	arr["RUSSIAN",354]="Сделано! параметры заданы"
	arr["GREEK",354]="Έγινε! η παράμετρος τέθηκε"
	arr["ITALIAN",354]="Fatto! parametro impostato"
	arr["POLISH",354]="Zrobione! parametry ustawione"
	arr["GERMAN",354]="Fertig! Parameter eingestellt"
	arr["TURKISH",354]="Tamamdır! parametre ayarlandı"

	arr["ENGLISH",355]="It seems this interface was parametrized before. It's not necessary to check again"
	arr["SPANISH",355]="Esta interfaz ya fue parametrizada anteriormente. No es necesario realizar de nuevo el chequeo"
	arr["FRENCH",355]="Cette interface a déjà été configurée: Pas besoin de vérifier de nouevau son état"
	arr["CATALAN",355]="Sembla que aquesta interfície va ser parametritzada abans. No cal verificar-ho de nou"
	arr["PORTUGUESE",355]="Esta interface já foi configurada anteriormente. Não é necessário verificar novamente"
	arr["RUSSIAN",355]="Этот интерфейс был параметризован ранее. Нет необходимости проверять снова"
	arr["GREEK",355]="Φαίνεται πως αυτή η διεπαφή παραμετροποιήθηκε προηγουμένως. Δεν είναι απαραίτητο να γίνει έλεγχος ξανά"
	arr["ITALIAN",355]="Questa interfaccia è stata configurata anteriormente. Non c'è bisogno di controllare di nuovo"
	arr["POLISH",355]="Ten interfejs został wcześniej sparametryzowany. Nie jest konieczne ponownie sprawdzenie"
	arr["GERMAN",355]="Diese Interface wurde zuvor parametriert. Es ist nicht notwendig, die Überprüfung erneut durchzuführen"
	arr["TURKISH",355]="Bu arayüz daha önce parametrize edilmiş gibi görünüyor. Tekrar kontrol etmek gerekli değil"

	arr["ENGLISH",356]="Some combinations don't work well. Such as reaver and Ralink chipset cards. If your card has this chipset is recommended to use bully"
	arr["SPANISH",356]="Algunas combinaciones no funcionan bien. Como por ejemplo reaver y las tarjetas con chipset Ralink. Si tu tarjeta tiene este chipset es mejor utilizar bully"
	arr["FRENCH",356]="Il existe certains problèmes spécifiques de compatibilité. L’exemple le plus marquant est sans aucun doute celui des chipsets Ralink qui ne fonctionnent pas bien avec reaver. Il est donc conseillé d'utiliser bully avec ces chipsets"
	arr["CATALAN",356]="Algunes combinacions no funcionan bé. Com per exemple reaver i les targetes amb chipset Ralink. Si la teva targeta té aquest chipset és millor utilitzar bully"
	arr["PORTUGUESE",356]="Algumas combinações não funcionam bem. Tais como reaver e placas de rede com chipset Ralink. Se o sua placa de rede tem este chipset é melhor usar bully"
	arr["RUSSIAN",356]="Некоторые комбинации не работают нормально. К примеру reaver и карты с чипсетом Ralink. Если ваша карта имеет этот чипсет, то рекомендуется использовать bully"
	arr["GREEK",356]="Μερικοί συνδυασμοί δεν λειτουργούν καλά. Όπως για παράδειγμα το reaver με κάρτες που έχουν Ralink chipset. Αν η κάρτα σας έχει αυτό το chipset είναι προτιμότερο να χρησιμοποιήσετε το bully"
	arr["ITALIAN",356]="Alcune combinazioni non funzionano bene. Come ad esempio reaver e le schede con chipset Ralink. Se la scheda ha questo chipset è meglio usare bully"
	arr["POLISH",356]="Niektóre kombinacje nie działają dobrze. Jak na przykład reaver i karty z chipsetem Ralink. Jeśli Twoja karta ma ten chipset lepiej jest użyć bully"
	arr["GERMAN",356]="Einige Kombinationen funktionieren nicht gut. Zum Beispiel Reaver und Karten mit Ralink-Chipsatz. Wenn Ihre Karte diesen Chipsatz hat, ist es besser, bully zu benutzen"
	arr["TURKISH",356]="Bazı kombinasyonlar iyi çalışmıyor. Reaver ve Ralink chipset kartları gibi. Kartınızın bu yonga seti varsa, bully kullanmanız önerilir"

	arr["ENGLISH",357]="6.  (reaver) Custom PIN association"
	arr["SPANISH",357]="6.  (reaver) Asociación con PIN personalizado"
	arr["FRENCH",357]="6.  (reaver) Association avec le code PIN personnalisé"
	arr["CATALAN",357]="6.  (reaver) Associació amb PIN personalitzat"
	arr["PORTUGUESE",357]="6.  (reaver) Associação com um PIN personalizado"
	arr["RUSSIAN",357]="6.  (reaver) Подключение с известным ПИНом для раскрытия пароля сети"
	arr["GREEK",357]="6.  (reaver) Σύνδεση με εξατομικευμένο PIN"
	arr["ITALIAN",357]="6.  (reaver) Associazione con PIN personalizzato"
	arr["POLISH",357]="6.  (reaver) Asocjacja z niestandardowym kodem PIN"
	arr["GERMAN",357]="6.  (reaver) Assoziation mit Custom PIN"
	arr["TURKISH",357]="6.  (reaver) Özel PIN ilişkilendirmesi"

	arr["ENGLISH",358]="8.  (reaver) Pixie Dust attack"
	arr["SPANISH",358]="8.  (reaver) Ataque Pixie Dust"
	arr["FRENCH",358]="8.  (reaver) Attaque Pixie Dust"
	arr["CATALAN",358]="8.  (reaver) Atac Pixie Dust"
	arr["PORTUGUESE",358]="8.  (reaver) Ataque Pixie Dust"
	arr["RUSSIAN",358]="8.  (reaver) Атака Pixie Dust"
	arr["GREEK",358]="8.  (reaver) Επίθεση Pixie Dust"
	arr["ITALIAN",358]="8.  (reaver) Attacco Pixie Dust"
	arr["POLISH",358]="8.  (reaver) Atak Pixie Dust"
	arr["GERMAN",358]="8.  (reaver) Pixie Dust Angriff"
	arr["TURKISH",358]="8.  (reaver) Pixie Dust saldırısı"

	arr["ENGLISH",359]="10. (reaver) Bruteforce PIN attack"
	arr["SPANISH",359]="10. (reaver) Ataque de fuerza bruta por PIN"
	arr["FRENCH",359]="10. (reaver) Attaque de force brute PIN"
	arr["CATALAN",359]="10. (reaver) Atac de força bruta per PIN"
	arr["PORTUGUESE",359]="10. (reaver) Ataque de força bruta por PIN"
	arr["RUSSIAN",359]="10. (reaver) Атака полным перебором ПИНа"
	arr["GREEK",359]="10. (reaver) Επίθεση PIN με χρήση ωμής βίας"
	arr["ITALIAN",359]="10. (reaver) Attacco forza bruta con PIN"
	arr["POLISH",359]="10. (reaver) Atak Brute Force za pomocą kodu PIN"
	arr["GERMAN",359]="10. (reaver) Brute-Force-Angriff durch PIN"
	arr["TURKISH",359]="10. (reaver) Bruteforce PIN saldırısı"

	arr["ENGLISH",360]="12. (reaver) Known PINs database based attack"
	arr["SPANISH",360]="12. (reaver) Ataque basado en base de datos de PINs conocidos"
	arr["FRENCH",360]="12. (reaver) Attaque en utilisant la base de données de PIN connus"
	arr["CATALAN",360]="12. (reaver) Atac basat en base de dades de PINs coneguts"
	arr["PORTUGUESE",360]="12. (reaver) Ataque com base em um banco de dados de PINs conhecidos"
	arr["RUSSIAN",360]="12. (reaver) Атака на основе базы данных известных и сгенерированных ПИНов"
	arr["GREEK",360]="12. (reaver) Επίθεση με χρήση βάσης δεδομένων γνωστών PIN"
	arr["ITALIAN",360]="12. (reaver) Attacco che utilizza una base dati di PINs conosciuti"
	arr["POLISH",360]="12. (reaver) Atak oparty o bazę danych znanych PINów"
	arr["GERMAN",360]="12. (reaver) Angriff basiert auf Datenbank mit bekannte PINs"
	arr["TURKISH",360]="12. (reaver) Bilinen PIN'ler veritabanı tabanlı saldırı"

	arr["ENGLISH",361]="WPA/WPA2 filter enabled in scan. When started, press [Ctrl+C] to stop..."
	arr["SPANISH",361]="Filtro WPA/WPA2 activado en escaneo. Una vez empezado, pulse [Ctrl+C] para pararlo..."
	arr["FRENCH",361]="Le filtre WPA/WPA2 est activé dans la scan. Une fois l'opération lancée, veuillez presser [Ctrl+C] pour l'arrêter..."
	arr["CATALAN",361]="Filtre WPA/WPA2 activat en escaneig. Una vegada iniciat, polsi [Ctrl+C] per detenir-ho..."
	arr["PORTUGUESE",361]="Filtro WPA/WPA2 ativo na busca de redes wifi. Uma vez iniciado, pressione [Ctrl+C] para pará-lo..."
	arr["RUSSIAN",361]="Для сканирования включен фильтр WPA/WPA2. После запуска, нажмите [Ctrl+C] для остановки..."
	arr["GREEK",361]="Το φίλτρο WPA/WPA2 ενεργοποιήθηκε κατά τη σάρωση. Όταν αρχίσει, μπορείτε να το σταματήσετε πατώντας [Ctrl+C]..."
	arr["ITALIAN",361]="Filtro WPA/WPA2 attivato nella scansione. Una volta avviata, premere [Ctrl+C] per fermarla..."
	arr["POLISH",361]="Filtr WPA/WPA2 aktywowany podczas skanowania. Naciśnij [Ctrl+C] w trakcie trwania, aby zatrzymać..."
	arr["GERMAN",361]="WPA/WPA2-Filter beim Scannen aktiviert. Nach dem Start, drücken Sie [Ctrl+C], um es zu stoppen..."
	arr["TURKISH",361]="WPA/WPA2 filtresi aktifleştirildi. Başladıktan sonra, durdurmak için [Ctrl+C] tuşlayınız..."

	arr["ENGLISH",362]="Custom PIN set to ${normal_color}${custom_pin}"
	arr["SPANISH",362]="PIN personalizado elegido ${normal_color}${custom_pin}"
	arr["FRENCH",362]="PIN personnalisé définit ${normal_color}${custom_pin}"
	arr["CATALAN",362]="PIN personalitzat triat ${normal_color}${custom_pin}"
	arr["PORTUGUESE",362]="PIN personalizado escolhido ${normal_color}${custom_pin}"
	arr["RUSSIAN",362]="Пользовательский PIN установлен на ${normal_color}${custom_pin}"
	arr["GREEK",362]="Το εξατομικευμένο PIN τέθηκε σε ${normal_color}${custom_pin}"
	arr["ITALIAN",362]="PIN personalizzato scelto ${normal_color}${custom_pin}"
	arr["POLISH",362]="Wybrany PIN ${normal_color}${custom_pin}"
	arr["GERMAN",362]="Custom PIN gewählt ${normal_color}${custom_pin}"
	arr["TURKISH",362]="Özel PIN ${normal_color}${custom_pin} olarak ayarlandı"

	arr["ENGLISH",363]="Type custom PIN (8 digits):"
	arr["SPANISH",363]="Escribe el PIN personalizado (8 dígitos):"
	arr["FRENCH",363]="Rentrez PIN personnalisé (8 chiffres):"
	arr["CATALAN",363]="Escriu el PIN personalitzat (8 dígits):"
	arr["PORTUGUESE",363]="Digite o PIN personalizado (8 dígitos):"
	arr["RUSSIAN",363]="Введите пользовательский PIN (8 цифр):"
	arr["GREEK",363]="Πληκτρολογήστε εξατομικευμένο PIN (8 ψηφία):"
	arr["ITALIAN",363]="Inserire il PIN personalizzato (8 cifre):"
	arr["POLISH",363]="Wprowadź niestandardowy kod PIN (8 cyfr):"
	arr["GERMAN",363]="Schreiben Sie die Custom PIN (8-stellig):"
	arr["TURKISH",363]="Özel PIN (8 haneli) yazın:"

	arr["ENGLISH",364]="BSSID set to ${normal_color}${wps_bssid}"
	arr["SPANISH",364]="BSSID elegido ${normal_color}${wps_bssid}"
	arr["FRENCH",364]="Le BSSID choisi est ${normal_color}${wps_bssid}"
	arr["CATALAN",364]="El BSSID escollit ${normal_color}${wps_bssid}"
	arr["PORTUGUESE",364]="BSSID escolhido ${normal_color}${wps_bssid}"
	arr["RUSSIAN",364]="BSSID установлена на ${normal_color}${wps_bssid}"
	arr["GREEK",364]="Το BSSID τέθηκε σε ${normal_color}${wps_bssid}"
	arr["ITALIAN",364]="BSSID selezionato ${normal_color}${wps_bssid}"
	arr["POLISH",364]="Wybrano BSSID ${normal_color}${wps_bssid}"
	arr["GERMAN",364]="Gewähltes BSSID ${normal_color}${wps_bssid}"
	arr["TURKISH",364]="BSSID ${normal_color}${wps_bssid} olarak ayarlandı"

	arr["ENGLISH",365]="Channel set to ${normal_color}${wps_channel}"
	arr["SPANISH",365]="Canal elegido ${normal_color}${wps_channel}"
	arr["FRENCH",365]="Le canal ${normal_color}${wps_channel}${blue_color} a été choisi"
	arr["CATALAN",365]="El canal ${normal_color}${wps_channel}${blue_color} s'ha escollit"
	arr["PORTUGUESE",365]="Canal ${normal_color}${wps_channel}${blue_color} selecionado"
	arr["RUSSIAN",365]="Канал установлен на ${normal_color}${wps_channel}"
	arr["GREEK",365]="Το κανάλι ${normal_color}${wps_channel}${blue_color} έχει επιλεχθεί"
	arr["ITALIAN",365]="Canale selezionato ${normal_color}${wps_channel}"
	arr["POLISH",365]="Wybrany kanał ${normal_color}${wps_channel}"
	arr["GERMAN",365]="Ausgewählter Kanal ${normal_color}${wps_channel}"
	arr["TURKISH",365]="Kanal ${normal_color}${wps_channel} olarak ayarlandı"

	arr["ENGLISH",366]="No filters enabled on scan. When started, press [Ctrl+C] to stop..."
	arr["SPANISH",366]="No hay filtros activados en el escaneo. Una vez empezado, pulse [Ctrl+C] para pararlo..."
	arr["FRENCH",366]="Aucun filtre activé dans le scan. Une fois l'opération lancée, veuillez presser [Ctrl+C] pour l'arrêter..."
	arr["CATALAN",366]="No hi ha filtres activats en l'escaneig. Una vegada iniciat, polsi [Ctrl+C] per detenir-ho..."
	arr["PORTUGUESE",366]="Nenhum filtro ativo na busca de redes wifi. Uma vez iniciado, pressione [Ctrl+C] para pará-lo..."
	arr["RUSSIAN",366]="В сканировании не активированы фильтры. После запуска, нажмите [Ctrl+C] для остановки..."
	arr["GREEK",366]="Δεν έχουν ενεργοποιηθεί φίλτρα στη σάρωση. Όταν αρχίσει, μπορείτε να το σταματήσετε πατώντας [Ctrl+C]..."
	arr["ITALIAN",366]="Nessun filtro attivato nella scansione. Una volta avviata, premere [Ctrl+C] per fermarla..."
	arr["POLISH",366]="W skanowaniu nie zostały włączone żadne filtry. Naciśnij [Ctrl+C] w trakcie trwania, aby zatrzymać..."
	arr["GERMAN",366]="Es sind keine aktivierten Filter im Scan vorhanden. Nach dem Start, drücken Sie [Ctrl+C], um es zu stoppen..."
	arr["TURKISH",366]="Taramada filtre yok. Başladıktan sonra, durdurmak için [Ctrl+C] tuşlayınız..."

	arr["ENGLISH",367]="You have bully installed (v${bully_version}), but not required version. To perform Pixie Dust integrated bully attack you must have at least version v${minimum_bully_pixiewps_version}"
	arr["SPANISH",367]="Tienes bully instalado (v${bully_version}), aunque no la versión requerida. Para realizar el ataque Pixie Dust integrado con bully has de tener al menos la versión v${minimum_bully_pixiewps_version}"
	arr["FRENCH",367]="Bully est installé (v${bully_version}) mais ce n'est pas la bonne version. Vous devez avoir au moins la version v${minimum_bully_pixiewps_version} pour la compatibilité pixie dust"
	arr["CATALAN",367]="Tens bully instal·lat (v${bully_version}), encara que no és la versió requerida. Per realitzar l'atac Pixie Dust integrat amb bully has de tenir almenys la versió v${minimum_bully_pixiewps_version}"
	arr["PORTUGUESE",367]="Você tem o bully instalado (v${bully_version}), mas não a versão necessária. Para fazer o ataque Pixie Dust com bully você precisa ter pelo menos a versão v${minimum_bully_pixiewps_version}"
	arr["RUSSIAN",367]="У вас установлен bully (v${bully_version}), но не та версия, которая требуется. Для выполнения интегрированной в bully атаки Pixie Dust у вас должна быть по крайне мере версия v${minimum_bully_pixiewps_version}"
	arr["GREEK",367]="Έχετε εγκατεστημένο το bully (v${bully_version}), αλλά όχι την απαιτούμενη έκδοση. Για να κάνετε την επίθεση Pixie Dust με ενσωματωμένο bully θα πρέπει να έχετε τουλάχιστον την έκδοση v${minimum_bully_pixiewps_version}"
	arr["ITALIAN",367]="È stato installato bully (v${bully_version}), ma non la versione richiesta. Per realizzare l'attacco Pixie Dust integrato con bully devi avere almeno la versione v${minimum_bully_pixiewps_version}"
	arr["POLISH",367]="Masz zainstalowane bully (v${bully_version}), ale nie wymaganą wersję. Aby atak Pixie Dust był zintegrowany z bully, musisz mieć co najmniej wersję v${minimum_bully_pixiewps_version}"
	arr["GERMAN",367]="Sie haben Bully installiert (v${bully_version}), obwohl nicht die erforderliche Version. Um den Pixie Dust Angriff mit Bully zu integrieren, müssen Sie mindestens die Version v${minimum_bully_pixiewps_version} haben"
	arr["TURKISH",367]="Bully versiyonunuz (v${bully_version}), ama istenilen versiyon değil. Pixie Dust entegreli bully saldırısı yapmak için en az versiyona sahip olmalısınız v${minimum_bully_pixiewps_version}"

	arr["ENGLISH",368]="You have bully installed (v${bully_version}). You meet the version requirement to perform Pixie Dust integrated bully attack (minimum version v${minimum_bully_pixiewps_version}). Script can continue..."
	arr["SPANISH",368]="Tienes bully instalado (v${bully_version}). Cumples con el requisito de versión para realizar el ataque Pixie Dust integrado con bully (versión mínima v${minimum_bully_pixiewps_version}). El script puede continuar..."
	arr["FRENCH",368]="Bully est installé (v${bully_version}). Cette version est compatible avec l'attaque pixie dust (version minimale v${minimum_bully_pixiewps_version}). Le script peut continuer..."
	arr["CATALAN",368]="Tens bully instal·lat (v${bully_version}). Compleixes amb el requisit de versió per realitzar l'atac Pixie Dust integrat amb bully (versió mínima v${minimum_bully_pixiewps_version}). El script pot continuar..."
	arr["PORTUGUESE",368]="Você tem o bully instalado (v${bully_version}). Você cumpre a exigência de versão para o ataque Pixie Dust com bully (versão mínima v${minimum_bully_pixiewps_version}). O script pode continuar..."
	arr["RUSSIAN",368]="У вас установлен bully (v${bully_version}). Версия удовлетворяет требованиям для проведения интегрированной в bully атаки Pixie Dust (минимальная версия v${minimum_bully_pixiewps_version}). Скрипт может продолжить работу..."
	arr["GREEK",368]="Έχετε εγκατεστημένο το bully (v${bully_version}). Έχετε την απαραίτητη έκδοση bully (ελάχιστη έκδοση v${minimum_bully_pixiewps_version}), για την επίθεση Pixie Dust με ενσωματωμένο bully. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",368]="È stato installato bully (v${bully_version}). Soddisfi il requisito della versione per realizzare l'attacco Pixie Dust integrato con bully (versione minima v${minimum_bully_pixiewps_version}). Lo script può continuare..."
	arr["POLISH",368]="Masz zainstalowany bully (v${bully_version}). Spełnia ona wymagania wersji, aby atak Pixie Dust był zintegrowany z bully (wersja minimalna v${minimum_bully_pixiewps_version}). Skrypt może kontynuować..."
	arr["GERMAN",368]="Sie haben bully installiert (v${bully_version}). Du erfüllst die Versionsvoraussetzung, um den mit dem bully integrierten Pixie Dust-Angriff auszuführen (Mindestversion v${minimum_bully_pixiewps_version}). Das Skript kann fortfahren..."
	arr["TURKISH",368]="Bully versiyonunuz (v${bully_version}), İstenilen versiyon karşılanıyor (minimum version v${minimum_bully_pixiewps_version}) ve Pixie Dust entegreli bully saldırısı yapmak için yazılım devam edebilir..."

	arr["ENGLISH",369]="To perform the Pixie Dust integrated attack with reaver or bully, you must have installed at least ${minimum_reaver_pixiewps_version} version for reaver and ${minimum_bully_pixiewps_version} for bully"
	arr["SPANISH",369]="Para realizar el ataque Pixie Dust integrado con reaver o con bully, has de tener instalada como mínimo la versión ${minimum_reaver_pixiewps_version} para reaver y ${minimum_bully_pixiewps_version} para bully"
	arr["FRENCH",369]="Les versions minimales requises de reaver et bully pour l'attaque pixie wps sont reaver ${minimum_reaver_pixiewps_version} et bully ${minimum_bully_pixiewps_version}"
	arr["CATALAN",369]="Per realitzar l'atac Pixie Dust integrat amb reaver o amb bully, has de tenir instal·lada com a mínim la versió ${minimum_reaver_pixiewps_version} per reaver i ${minimum_bully_pixiewps_version} per bully"
	arr["PORTUGUESE",369]="Para executar o ataque Pixie Dust com reaver ou bully, é necessário ter instalado pelo menos a versão ${minimum_reaver_pixiewps_version} para o reaver e ${minimum_bully_pixiewps_version} para o bully"
	arr["RUSSIAN",369]="Для выполнения интегрированной атаки Pixie Dust с reaver или bully, у вас должна быть установлена, по крайней мере, версия ${minimum_reaver_pixiewps_version} для reaver и ${minimum_bully_pixiewps_version} для bully"
	arr["GREEK",369]="Για να κάνετε την επίθεση Pixie Dust με ενσωματωμένο reaver ή bully, θα πρέπει να έχετε εγκαταστημένη τουλάχιστον την έκδοση ${minimum_reaver_pixiewps_version} για reaver και ${minimum_bully_pixiewps_version} για bully"
	arr["ITALIAN",369]="Per realizzare l'attacco Pixie Dust integrato con reaver o bully, deve essere installata almeno la versione ${minimum_reaver_pixiewps_version} per reaver e la versione ${minimum_bully_pixiewps_version} per bully"
	arr["POLISH",369]="Aby przeprowadzić zintegrowany atak Pixie Dust z użyciem reaver lub z bully, musisz mieć zainstalowaną co najmniej wersję ${minimum_reaver_pixiewps_version} reaver i ${minimum_bully_pixiewps_version} bully"
	arr["GERMAN",369]="Um den mit dem reaver oder mit bully integrierten Pixie Dust-Angriff auszuführen, müssen Sie mindestens die Reaver Version ${minimum_reaver_pixiewps_version} und die Bully Version ${minimum_bully_pixiewps_version} installiert haben"
	arr["TURKISH",369]="${pending_of_translation} Reaver veya kabadayı ile Pixie Dust entegre saldırısını gerçekleştirmek için, reaver için en az ${minimum_reaver_pixiewps_version} sürümü ve kabadayılık için ${minimum_bully_pixiewps_version} yüklemiş olmanız gerekir"

	arr["ENGLISH",370]="You have reaver installed (v${reaver_version}). You meet the version requirement to perform Pixie Dust integrated reaver attack (minimum version v${minimum_reaver_pixiewps_version}). Script can continue..."
	arr["SPANISH",370]="Tienes reaver instalado (v${reaver_version}). Cumples con el requisito de versión para realizar el ataque Pixie Dust integrado con reaver (versión minima v${minimum_reaver_pixiewps_version}). El script puede continuar..."
	arr["FRENCH",370]="Reaver est installé (v${reaver_version}). Cette version est compatible avec l'attaque pixie dust (version minimale: ${minimum_reaver_pixiewps_version}). Le script peut continuer..."
	arr["CATALAN",370]="Tens reaver instal·lat (v${reaver_version}). Compleixes amb el requisit de versió per a realitzar l'atac Pixie Dust integrat amb reaver (versió mínima v${minimum_reaver_pixiewps_version}). El script pot continuar..."
	arr["PORTUGUESE",370]="Você tem o reaver instalado (v${reaver_version}). Você cumpre a exigência de versão para o ataque Pixie Dust com reaver (versão mínima v${minimum_reaver_pixiewps_version}). O script pode continuar..."
	arr["RUSSIAN",370]="У вас установлен reaver (v${reaver_version}). Версия удовлетворяет требованиям для выполнения интегрированной в reaver атаки Pixie Dust (минимальная версия v${minimum_reaver_pixiewps_version}). Скрипт может продолжить работу..."
	arr["GREEK",370]="Έχετε εγκατεστημένο το reaver (v${reaver_version}). Έχετε την απαραίτητη έκδοση reaver (ελάχιστη έκδοση v${minimum_reaver_pixiewps_version}), για την επίθεση Pixie Dust με ενσωματωμένο reaver. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",370]="È stato installato reaver (v${reaver_version}). Soddisfi il requisito della versione per realizzare l'attacco Pixie Dust integrato con reaver (versione minima v${minimum_reaver_pixiewps_version}). Lo script può continuare..."
	arr["POLISH",370]="Masz zainstalowany reaver (v${reaver_version}). Spełnia on wymagania dotyczące wersji, aby wykonać atak Pixie Dust (wersja minimalna v${minimum_reaver_pixiewps_version}). Skrypt może kontynuować..."
	arr["GERMAN",370]="Reaver ist installiert (v${reaver_version}). Sie erfüllen die Versionsvoraussetzung, um den Pixie Dust-Angriff auszuführen, der mit Reaver integriert ist (min Version v${minimum_reaver_pixiewps_version}). Das Skript kann fortfahren..."
	arr["TURKISH",370]="${pending_of_translation} Yeniden yüklendiniz (v${reaver_version}). Pixie Dust entegre reaver saldırısını gerçekleştirmek için sürüm gereksinimini karşılıyorsunuz (minimum sürüm v${minimum_reaver_pixiewps_version}). Komut dosyası devam edebilir..."

	arr["ENGLISH",371]="You have reaver installed (v${reaver_version}), but not required version. To perform Pixie Dust integrated reaver attack you must have at least version v${minimum_reaver_pixiewps_version}"
	arr["SPANISH",371]="Tienes reaver instalado (v${reaver_version}), aunque no la versión requerida. Para realizar el ataque Pixie Dust integrado con reaver has de tener al menos la versión v${minimum_reaver_pixiewps_version}"
	arr["FRENCH",371]="Reaver est installé (v${reaver_version}) mais cette version n'est pas compatible avec l'attaque pixie dust. Version minimale requise: v${minimum_reaver_pixiewps_version}"
	arr["CATALAN",371]="Tens reaver instal·lat (v${reaver_version}), encara que no és la versió requerida. Per realitzar l'atac Pixie Dust integrat amb reaver has de tenir almenys la versió v${minimum_reaver_pixiewps_version}"
	arr["PORTUGUESE",371]="Você tem o reaver instalado (v${reaver_version}), mas não a versão necessária. Para fazer o ataque Pixie Dust com reaver integrado você precisa ter pelo menos a versão v${minimum_reaver_pixiewps_version}"
	arr["RUSSIAN",371]="У вас установлен reaver (v${reaver_version}), но не та версия, которая требуется. Для выполнения интегрированной в reaver атаки Pixie Dust у вас должна быть по крайней мере v${minimum_reaver_pixiewps_version}"
	arr["GREEK",371]="Έχετε εγκατεστημένο το reaver (v${reaver_version}), αλλά όχι την απαιτούμενη έκδοση. Για να κάνετε την επίθεση Pixie Dust με ενσωματωμένο reaver θα πρέπει να έχετε τουλάχιστον την έκδοση v${minimum_reaver_pixiewps_version}"
	arr["ITALIAN",371]="È stato installato reaver (v${reaver_version}), ma non la versione richiesta. Per realizzare l'attacco Pixie Dust integrato con reaver devi avere almeno la versione v${minimum_reaver_pixiewps_version}"
	arr["POLISH",371]="Masz zainstalowany reaver (v${reaver_version}), ale nie wymaganą wersję. Aby zrealizować atak Pixie Dust zintegrowany z programem reaver musisz mieć co najmniej wersję v${minimum_reaver_pixiewps_version}"
	arr["GERMAN",371]="Reaver ist installiert (v${reaver_version}), jedoch nicht die erforderliche Version. Um den Pixie Dust-Angriff mit Reaver zu integrieren, müssen Sie mindestens die Version v${minimum_reaver_pixiewps_version} haben"
	arr["TURKISH",371]="${pending_of_translation} Yeniden yüklendiniz (v${reaver_version}), ancak gerekli sürüm değil. Pixie Dust entegre reaver saldırısını gerçekleştirmek için en az sürüm olan ${minimum_reaver_pixiewps_version} olmalıdır"

	arr["ENGLISH",372]="This action can't be performed without known PINs database file"
	arr["SPANISH",372]="Sin fichero de base de datos de PINs conocidos no se puede realizar esta acción"
	arr["FRENCH",372]="Sans la base donées des PINs cette action ne peut pas être exécutée"
	arr["CATALAN",372]="Sense fitxer de base de dades de PINs coneguts no es pot realitzar aquesta acció"
	arr["PORTUGUESE",372]="Esta ação não pode ser executada sem o arquivo com banco de dados de PINs conhecidos"
	arr["RUSSIAN",372]="Это действие не может быть выполнено без файла базы данных известных PIN"
	arr["GREEK",372]="Αυτή η ενέργεια δεν μπορεί να πραγματοποιηθεί χωρίς να υπάρχει το αρχείο με την βάση δεδομένων γνωστών PIN"
	arr["ITALIAN",372]="Senza il file del database dei PIN conosciuti non si puó eseguire questa azione"
	arr["POLISH",372]="Ta czynność nie może zostać zrealizowana bez bazy danych znanych kodów PIN"
	arr["GERMAN",372]="Ohne eine Datenbankdatei mit bekannten PINs kann diese Aktion nicht ausgeführt werden"
	arr["TURKISH",372]="${pending_of_translation} Bu işlem bilinen PIN veritabanı dosyası olmadan gerçekleştirilemez"

	arr["ENGLISH",373]="The known PINs database file exists. Script can continue..."
	arr["SPANISH",373]="Existe el fichero de base de datos de PINs conocidos. El script puede continuar..."
	arr["FRENCH",373]="La base de données PIN est bien présente. Le script peut continuer..."
	arr["CATALAN",373]="S'ha trobat el fitxer de base de dades de PINs coneguts. El script pot continuar..."
	arr["PORTUGUESE",373]="Há um arquivo com banco de dados de PINs conhecidos. O script pode continuar..."
	arr["RUSSIAN",373]="Файл с базой данных известных PIN существует. Скрипт может продолжать..."
	arr["GREEK",373]="Το αρχείο με την βάση δεδομένων γνωστών PIN υπάρχει. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",373]="Esiste il file di base dati dei PINs conosciuti. Lo script può continuare..."
	arr["POLISH",373]="Znaleziono plik bazy danych znanych PIN. Skrypt może kontynuować..."
	arr["GERMAN",373]="Die Datenbankdatei mit bekannte PINs ist vorhanden. Das Skript kann fortfahren..."
	arr["TURKISH",373]="${pending_of_translation} Bilinen PIN'ler veritabanı dosyası mevcut. Komut dosyası devam edebilir..."

	arr["ENGLISH",374]="Local PINs database file (${known_pins_dbfile}) can't be found in the script folder. It will be attempted to download"
	arr["SPANISH",374]="No se ha podido encontrar el fichero local de la base de datos de PINs (${known_pins_dbfile}) en la carpeta del script. Se intentará descargar"
	arr["FRENCH",374]="Base de donnée PIN (${known_pins_dbfile}) absente du dossier contenant le script. Tentative de téléchargement"
	arr["CATALAN",374]="No s'ha pogut trobar el fitxer local de la base de dades de PINs (${known_pins_dbfile}) a la carpeta del script. S'intentarà descarregar"
	arr["PORTUGUESE",374]="Não foi possível localizar o arquivo (${known_pins_dbfile}) com banco de dados local na pasta do script. O script vai tentar realizar o download"
	arr["RUSSIAN",374]="Локальный файл базы данных PIN (${known_pins_dbfile}) не найден в папке скрипта. Будет предпринята попытка загрузить его"
	arr["GREEK",374]="Το αρχείο με την βάση δεδομένων PIN (${known_pins_dbfile}) δεν βρέθηκε στο φάκελο με το script. Θα προσπαθήσει να κατέβει"
	arr["ITALIAN",374]="Impossibile trovare il file di base dati con i PINs conosciuti (${known_pins_dbfile}) nella cartella dello script. Cercheremo di scaricarla"
	arr["POLISH",374]="Nie znaleziono lokalnej bazy danych bazy danych kodów PIN (${known_pins_dbfile}) w folderze skryptu. Spróbuję go pobrać"
	arr["GERMAN",374]="Die lokale Datei der PIN-Datenbank (${known_pins_dbfile}) konnte im Skriptordner nicht gefunden werden. Versuch zum Herunterladen"
	arr["TURKISH",374]="${pending_of_translation} Yerel PIN'ler veritabanı dosyası (${known_pins_dbfile}) komut dosyası klasöründe bulunamadı. İndirilmeye çalışılacak"

	arr["ENGLISH",375]="It seems you have no internet access"
	arr["SPANISH",375]="Parece que no tienes conexión a internet"
	arr["FRENCH",375]="Il semble que vous ne pouvez pas vous connecter à internet"
	arr["CATALAN",375]="Sembla que no tens connexió a internet"
	arr["PORTUGUESE",375]="Parece que você não tem acesso à internet"
	arr["RUSSIAN",375]="Судя по всему, у вас нет Интернет доступа"
	arr["GREEK",375]="Φαίνεται πως δεν έχετε πρόσβαση στο διαδίκτυο"
	arr["ITALIAN",375]="Sembra che tu non abbia connessione a internet"
	arr["POLISH",375]="Wygląda na to, że nie masz połączenia internetowego"
	arr["GERMAN",375]="Es scheint, dass Sie keine Internetverbindung haben"
	arr["TURKISH",375]="Görünüşe göre internet erişiminiz yok"

	arr["ENGLISH",376]="Local PINs database file (${known_pins_dbfile}) was found. Anyway a check for a newer will be performed"
	arr["SPANISH",376]="Se ha encontrado un fichero local de base de datos de PINs (${known_pins_dbfile}). No obstante se va a comprobar si existe uno más actualizado"
	arr["FRENCH",376]="Base de données PIN (${known_pins_dbfile}) présente. Recherche d’éventuelles actualisations"
	arr["CATALAN",376]="S'ha trobat un fitxer local de base de dades de PINs (${known_pins_dbfile}). No obstant, es comprovarà si existeix algun més actualitzat"
	arr["PORTUGUESE",376]="Um banco de dados local de PINs foi encontrado (${known_pins_dbfile}). No entanto, será verificado se existe um mais atualizado"
	arr["RUSSIAN",376]="Локальный файл базы данных PIN (${known_pins_dbfile}) был найден. В любом случае будет выполнена проверка на наличие новой версии"
	arr["GREEK",376]="Το αρχείο με την βάση δεδομένων PIN (${known_pins_dbfile}) βρέθηκε. Παρ'όλα αυτά θα πραγματοποιηθεί έλεγχος για νεότερη έκδοση"
	arr["ITALIAN",376]="Trovato un file locale di base dati dei PINs (${known_pins_dbfile}). Tuttavia sarà verificato se ne esiste uno più aggiornato"
	arr["POLISH",376]="Odnaleziono lokalny plik bazy danych PIN (${known_pins_dbfile}). Sprawdzę jednak, czy jest bardziej aktualna wersja"
	arr["GERMAN",376]="Eine lokale Datenbankdatei mit PINs (${known_pins_dbfile}) wurde gefunden. Es wird jedoch geprüft, ob es eine Aktualisierung gibt"
	arr["TURKISH",376]="${pending_of_translation} Yerel PIN'ler veritabanı dosyası (${known_pins_dbfile}) bulundu. Her neyse yeni bir kontrol yapılacaktır"

	arr["ENGLISH",377]="A more up-to-date PINs database file has been successfully downloaded"
	arr["SPANISH",377]="Se ha descargado con éxito un fichero de base de datos de PINs más actualizado"
	arr["FRENCH",377]="La base de données a été actualisée"
	arr["CATALAN",377]="S'ha descarregat amb èxit un fitxer de base de dades de PINs més actualitzat"
	arr["PORTUGUESE",377]="O banco de dados foi atualizado com sucesso"
	arr["RUSSIAN",377]="Новая версия файла базы данных PIN была успешно загружена"
	arr["GREEK",377]="Ένα ενημερωμένο αρχείο με την βάση δεδομένων PIN έχει κατέβει με επιτυχία"
	arr["ITALIAN",377]="È stato scaricato con successo un file di base dati dei PINs piú aggiornato"
	arr["POLISH",377]="Nowszy plik bazy danych PIN został pomyślnie pobrany"
	arr["GERMAN",377]="Eine aktuellere PIN-Datenbankdatei wurde erfolgreich heruntergeladen"
	arr["TURKISH",377]="${pending_of_translation} Daha güncel bir PIN veritabanı dosyası başarıyla indirildi"

	arr["ENGLISH",378]="An error occurred while trying to download the PINs database file"
	arr["SPANISH",378]="Ocurrió un error al intentar descargar el fichero de base de datos de PINs"
	arr["FRENCH",378]="Erreur lors du téléchargement de l'actualisation de la base de données"
	arr["CATALAN",378]="S'ha produït un error en intentar descarregar el fitxer de base de dades de PINs"
	arr["PORTUGUESE",378]="Ocorreu um erro ao tentar atualizar o banco de dados"
	arr["RUSSIAN",378]="При попытке загрузить файл базы данных PIN произошла ошибка"
	arr["GREEK",378]="Παρουσιάστηκε σφάλμα στην προσπάθεια να κατέβει το αρχείο με την βάση δεδομένων PIN"
	arr["ITALIAN",378]="Si è verificato un errore durante il tentativo di scaricare i file di base dati dei PINs"
	arr["POLISH",378]="Podczas próby pobrania pliku bazy danych kodów PIN wystąpił błąd"
	arr["GERMAN",378]="Beim Versuchdes runterladens der PIN-Datenbankdatei ist ein Fehler aufgetreten"
	arr["TURKISH",378]="${pending_of_translation} PINs veritabanı dosyasını indirmeye çalışırken bir hata oluştu"

	arr["ENGLISH",379]="Check of the PINs database file has already been done. It will not be done again..."
	arr["SPANISH",379]="El chequeo del fichero de base de datos de PINs ya se hizo. No se realizará de nuevo..."
	arr["FRENCH",379]="La vérification de la base de données a été faite et ne sera plus relancée"
	arr["CATALAN",379]="La revisió del fitxer de base de dades de PINs ja es va fer. No es realitzarà de nou..."
	arr["PORTUGUESE",379]="Verificando os PINs do banco de dados. Isso não vai ser feito novamente..."
	arr["RUSSIAN",379]="Уже выполнена проверка файла базы данных PIN. Она не будет делаться ещё раз..."
	arr["GREEK",379]="Έχει γίνει ήδη έλεγχος του αρχείου με την βάση δεδομένων PIN. Δεν θα ξαναελεγχθεί..."
	arr["ITALIAN",379]="Il controllo del file di base dati dei PINs è già stato eseguito. Non sarà più fatto..."
	arr["POLISH",379]="Sprawdzenie pliku bazy danych PIN zostało już wykonane. To się nie powtórzy..."
	arr["GERMAN",379]="Die Überprüfung der PIN-Datenbankdatei wurde bereits durchgeführt. Es wird nicht wieder getan..."
	arr["TURKISH",379]="${pending_of_translation} PIN veritabanı dosyasının kontrolü zaten yapıldı. Bir daha yapılmayacak..."

	arr["ENGLISH",380]="Do you want to try again next time you launch this attack for this session? ${normal_color}${visual_choice}"
	arr["SPANISH",380]="¿Deseas que la próxima vez que lances este ataque en esta sesión se vuelva a intentar? ${normal_color}${visual_choice}"
	arr["FRENCH",380]="La prochaine fois que vous relancez cette attaque pendant cette session, voulez-vous oui ou non ${visual_choice} que l'actualisation soit lancée? ${normal_color}${visual_choice}"
	arr["CATALAN",380]="¿Vols que la propera vegada que llancis aquest atac en aquesta sessió es torni a intentar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",380]="Você quer buscar por atualizações na próxima vez que iniciar este ataque nessa sessão? ${normal_color}${visual_choice}"
	arr["RUSSIAN",380]="Вы хотите снова продолжить эту сессию при запуске этой атаки в следующий раз? ${normal_color}${visual_choice}"
	arr["GREEK",380]="Θέλετε να δοκιμάσετε ξανά την επόμενη φορά που θα ξεκινήσει αυτή η επίθεση για αυτή την συνεδρία; ${normal_color}${visual_choice}"
	arr["ITALIAN",380]="Desideri che la prossima volta che viene lanciato questo attacco in questa sessione si tenti di nuovo? ${normal_color}${visual_choice}"
	arr["POLISH",380]="Czy chcesz spróbować ponownie tego ataku dla tej sesji podczas następnego uruchomienia? ${normal_color}${visual_choice}"
	arr["GERMAN",380]="Möchten Sie beim nächsten Start dieses Angriffs in dieser Sitzung erneut versuchen? ${normal_color}${visual_choice}"
	arr["TURKISH",380]="${pending_of_translation} Bu seans için bu saldırıyı bir daha başlattığınızda tekrar denemek ister misin? ${normal_color}${visual_choice}"

	arr["ENGLISH",381]="An error occurred while trying to access to the checksum file of remote PINs database"
	arr["SPANISH",381]="Ocurrió un error al intentar acceder al fichero de checksum de la base de datos de PINs remota"
	arr["FRENCH",381]="Erreur de checksum avec la base de données PIN en ligne"
	arr["CATALAN",381]="S'ha produït un error en intentar accedir al fitxer de checksum de la base de dades de PINs remota"
	arr["PORTUGUESE",381]="Ocorreu um erro ao tentar acessar o arquivo de checksum do banco de dados remoto"
	arr["RUSSIAN",381]="Произошла ошибка при попытке получить доступ к контрольной сумме файла удаленной базы данных PIN"
	arr["GREEK",381]="Παρουσιάστηκε σφάλμα στην προσπάθεια πρόσβασης στο αρχείο checksum της απομακρυσμένης βάσης δεδομένων PIN"
	arr["ITALIAN",381]="Si è verificato un errore durante il tentativo di accedere al file di checksum della basse dati dei PINs remota"
	arr["POLISH",381]="Podczas próby uzyskania dostępu do pliku kontrolnego zdalnej bazy danych PIN wystąpił błąd"
	arr["GERMAN",381]="Beim Versuch, auf die checksum der Remote-PIN-Datenbank zuzugreifen, ist ein Fehler aufgetreten"
	arr["TURKISH",381]="${pending_of_translation} Uzak PIN'ler veritabanının sağlama dosyasına erişmeye çalışırken bir hata oluştu"

	arr["ENGLISH",382]="Checksums of the local and remote files match. Your PINs database file is up-to-date"
	arr["SPANISH",382]="Los checksum de los ficheros local y remoto coinciden. Tu fichero de base de datos de PINs está actualizado"
	arr["FRENCH",382]="Les checksum des fichiers locaux et distants correspondent. Votre base de données des PINs est à jour"
	arr["CATALAN",382]="Els checksum dels fitxers local i remot coincideixen. El teu fitxer de base de dades de PINs està actualitzat"
	arr["PORTUGUESE",382]="As checksums locais e remotas correspondem. Seu banco de dados local está atualizado"
	arr["RUSSIAN",382]="Контрольные суммы локального и удаленного файлов совпадают. Ваш файл базы данных PIN обновляется"
	arr["GREEK",382]="Τα checksums των τοπικών και των απομακρυσμένων αρχείων ταιριάζουν. Το αρχείο με την βάση δεδομένων PIN είναι ενημερωμένο"
	arr["ITALIAN",382]="I checksum dei file locali e remoti corrispondono. Il file di base dati dei PINs è aggiornato"
	arr["POLISH",382]="Sprawdzono sumy kontrolne pliku lokalnego i zdalnego. Plik bazy danych kodów PIN jest aktualny"
	arr["GERMAN",382]="Die Checksum der lokalen und Remote-Dateien stimmen überein. Ihre PIN-Datenbankdatei ist auf dem neuesten Stand"
	arr["TURKISH",382]="${pending_of_translation} Yerel ve uzak dosyaların sağlama toplamları eşleşir. PIN'leriniz veritabanı dosyanız güncel"

	arr["ENGLISH",383]="It seems there is a more up-to-date PINs database file. It will be downloaded..."
	arr["SPANISH",383]="Parece que hay un fichero de base de datos de PINs más actualizado. Será descargado..."
	arr["FRENCH",383]="Une base de données PIN plus actuelle a été détectée et va être installée"
	arr["CATALAN",383]="Sembla que hi ha un fitxer de base de dades de PINs més actualitzat. Serà descarregat..."
	arr["PORTUGUESE",383]="Parece que há um banco de dados de PINs mais recente. Ele será baixado..."
	arr["RUSSIAN",383]="Есть более новый файл базы данных PIN. Он будет загружен..."
	arr["GREEK",383]="Φαίνεται πως υπάρχει ένα νεότερο αρχείο με την βάση δεδομένων PIN. Θα κατέβει..."
	arr["ITALIAN",383]="Sembra che ci sia un file di base dati dei PINs piú aggiornato. Sarà scaricato..."
	arr["POLISH",383]="Wygląda na to, że istnieje bardziej aktualny plik bazy danych PIN. Zostanie pobrany..."
	arr["GERMAN",383]="Es scheint, dass es eine aktualisierte Datenbank von PINs gibt. Sie wird heruntergeladen..."
	arr["TURKISH",383]="${pending_of_translation} Daha güncel bir PIN veritabanı dosyası var gibi görünüyor. İndirilecek..."

	arr["ENGLISH",384]="Searching in PINs database. Please be patient..."
	arr["SPANISH",384]="Buscando en la base de datos de PINs. Por favor ten paciencia..."
	arr["FRENCH",384]="Recherche dans la base de données PIN. Ayez un peu de patience s'il vous plaît..."
	arr["CATALAN",384]="Buscant a la base de dades de PINs. Si us plau tingues paciència..."
	arr["PORTUGUESE",384]="Pesquisando os PINs no banco de dados. Por favor, seja paciente..."
	arr["RUSSIAN",384]="Поиск в базе данных PIN. Подождите немного..."
	arr["GREEK",384]="Γίνεται αναζήτηση στην βάση δεδομένων PIN. Παρακαλώ έχετε λίγη υπομονή..."
	arr["ITALIAN",384]="Cercando nella base dati dei PINs. Si prega di essere pazienti..."
	arr["POLISH",384]="Wyszukiwanie bazy danych kodu PIN. Cierpliwości..."
	arr["GERMAN",384]="PINs Datenbank wird durchgesucht. Bitte haben Sie etwas Geduld..."
	arr["TURKISH",384]="${pending_of_translation} PIN veritabanında arama. Lütfen sabırlı olun..."

	arr["ENGLISH",385]="Only one match found in the PINs database"
	arr["SPANISH",385]="Se ha encontrado sólo una coincidencia en la base de datos de PINs"
	arr["FRENCH",385]="Un PIN a été trouvé avec la base de données"
	arr["CATALAN",385]="S'ha trobat només una coincidència a la base de dades de PINs"
	arr["PORTUGUESE",385]="Somente um PIN correspondente no banco de dados"
	arr["RUSSIAN",385]="В базе данных PIN найдено только одно совпадение"
	arr["GREEK",385]="Μόνο ένα αντίστοιχο PIN βρέθηκε στην βάση δεδομένων"
	arr["ITALIAN",385]="Solo una corrispondenza trovata nella base dati dei PINs"
	arr["POLISH",385]="Znaleziono tylko jeden pasujący kod PIN w bazie danych"
	arr["GERMAN",385]="In der PIN-Datenbank wurde nur eine Übereinstimmung gefunden"
	arr["TURKISH",385]="${pending_of_translation} PIN veritabanında sadece bir eşleşme bulundu"

	arr["ENGLISH",386]="${counter_pins_found} matching PINs have been found in the PINs database"
	arr["SPANISH",386]="Se han encontrado ${counter_pins_found} PINs coincidentes en la base de datos de PINs"
	arr["FRENCH",386]="${counter_pins_found} PIN possibles selon la base de données"
	arr["CATALAN",386]="S'han trobat ${counter_pins_found} PINs coincidents a la base de dades de PINs"
	arr["PORTUGUESE",386]="Encontrados ${counter_pins_found} PINs correspondentes no banco de dados"
	arr["RUSSIAN",386]="${counter_pins_found} соответствующих ПИНа были найдены в базе данных PIN"
	arr["GREEK",386]="${counter_pins_found} αντίστοιχα PINs βρέθηκαν στην βάση δεδομένων"
	arr["ITALIAN",386]="Trovati ${counter_pins_found} PINs coincidenti nella base dati dei PINs"
	arr["POLISH",386]="Znaleziono ${counter_pins_found} pasujących kodów PIN w bazie danych"
	arr["GERMAN",386]="${counter_pins_found} übereinstimmende PINs wurden in der PIN-Datenbank"
	arr["TURKISH",386]="${pending_of_translation} ${counter_pins_found} PIN'lerde eşleşen PIN'ler bulundu"

	arr["ENGLISH",387]="No matches found in the PINs database"
	arr["SPANISH",387]="No se ha encontrado ninguna coincidencia en la base de datos de PINs"
	arr["FRENCH",387]="Aucun PIN n'a été trouvé dans la base données"
	arr["CATALAN",387]="No s'ha trobat cap coincidència a la base de dades de PINs"
	arr["PORTUGUESE",387]="Nenhuma correspondência encontrada no banco de dados"
	arr["RUSSIAN",387]="В базе данных PIN не найдено совпадений"
	arr["GREEK",387]="Δε βρέθηκε αντίστοιχο PIN στην βάση δεδομένων"
	arr["ITALIAN",387]="Nessuna corrispondenza trovata nella base dati dei PINs"
	arr["POLISH",387]="Brak dopasowania w bazie danych kodów PIN"
	arr["GERMAN",387]="Keine Übereinstimmungen wurden in der PIN-Datenbank gefunden"
	arr["TURKISH",387]="${pending_of_translation} PINs veritabanında eşleşme bulunamadı"

	arr["ENGLISH",388]="Calculating and adding possible PINs using common known algorithms (ComputePIN, EasyBox, etc.) ..."
	arr["SPANISH",388]="Calculando y añadiendo posibles PINs usando algoritmos conocidos comunes (ComputePIN, EasyBox, etc.) ..."
	arr["FRENCH",388]="Générations des PIN en appliquant les algorithmes les plus communs (ComputePIN, EasyBox, etc.) ..."
	arr["CATALAN",388]="Calculant i afegint possibles PINs usant algoritmes coneguts comuns (ComputePIN, EasyBox, etc.) ..."
	arr["PORTUGUESE",388]="Cálculando e adicionando possíveis PINs usando algoritmos comuns conhecidos (ComputePIN, EasyBox, etc.) ..."
	arr["RUSSIAN",388]="Вычисление и добавление возможных PIN с использованием общеизвестных алгоритмов (ComputePIN, EasyBox, etc.) ..."
	arr["GREEK",388]="Γίνεται υπολογισμός πιθανών PINs και πρόσθεση αυτών κάνοντας χρήση κοινών γνωστών αλγορίθμων (ComputePIN, EasyBox, etc.) ..."
	arr["ITALIAN",388]="Calcolando e aggiungendo possibili PINs utilizzando noti algoritmi conosciuti (ComputePIN, EasyBox, etc.) ..."
	arr["POLISH",388]="Obliczanie i dodawanie możliwych kodów PIN przy użyciu powszechnie znanych algorytmów (ComputePIN, EasyBox, itd.) ..."
	arr["GERMAN",388]="Berechnung und Hinzufügen von möglichen PINs mit bekannten Algorithmen (ComputePIN, EasyBox, etc.) ..."
	arr["TURKISH",388]="${pending_of_translation} Bilinen bilinen algoritmaları (ComputePIN, EasyBox, vb.) Kullanarak olası PIN'leri hesaplamak ve eklemek ..."

	arr["ENGLISH",389]="PINs calculated by algorithms have been added. The attack will be launched with a total of ${counter_pins_found} PINs"
	arr["SPANISH",389]="Se han añadido PINs calculados por los algoritmos. El ataque se lanzará con un total de ${counter_pins_found} PINs"
	arr["FRENCH",389]="Ajout des PIN calculées au moyen des algorithmes. L'attaque se fera avec ${counter_pins_found} PIN"
	arr["CATALAN",389]="S'han afegit PINs calculats pels algoritmes. L'atac es llançarà amb un total de ${counter_pins_found} PINs"
	arr["PORTUGUESE",389]="Os PINs calculados com algoritmos foram adicionados. O ataque será iniciado com um total de ${counter_pins_found} PINs"
	arr["RUSSIAN",389]="Добавлены PIN, рассчитанные с помощью алгоритмов. Атака будет произведена в общей сложности по ${counter_pins_found} PIN"
	arr["GREEK",389]="Προστέθηκαν τα PINs που υπολογίστηκαν από τους αλγορίθμους. Η επίθεση θα ξεκινήσει με ${counter_pins_found} PINs συνολικά"
	arr["ITALIAN",389]="Sono stati aggiunti PINs calcolati dagli algoritmi. L'attacco sará lanciato con un totale di ${counter_pins_found} PINs"
	arr["POLISH",389]="Kody PIN obliczone pzez algorytmy zostały dodane. Atak zostanie uruchomiony w sumie dla ${counter_pins_found} kodów PIN"
	arr["GERMAN",389]="Die von den Algorithmen berechneten PINs wurden hinzugefügt. Der Angriff wird mit insgesamt ${counter_pins_found} PINs gestartet"
	arr["TURKISH",389]="${pending_of_translation} Algoritmalar tarafından hesaplanan PIN'ler eklendi. Saldırı toplam ${counter_pins_found} PIN ile başlatılacak"

	arr["ENGLISH",390]="Some access points have only PBC (Push Button Connect) enabled and you can't connect via WPS if you don't press the physical button on the device"
	arr["SPANISH",390]="Algunos puntos de acceso tienen activado solamente PBC (Push Button Connect) y no podrás conectar por WPS si no se pulsa el boton físico del mismo"
	arr["FRENCH",390]="Certains points d'accès n'ont que le WPS PBC (Push Button Connect) activé et vous ne pourrez pas vous connecter par WPS sans presser le bouton du routeur"
	arr["CATALAN",390]="Alguns punts d'accés tenen activat només PBC (Push Button Connect) i no podràs connectar per WPS si no es prem el botó físic d'aquest"
	arr["PORTUGUESE",390]="Alguns pontos de acesso têm ativo somente o PBC (Push Button Connect) em que você não pode se conectar via WPS se o botão físico não for pressionado"
	arr["RUSSIAN",390]="На некоторых точках доступа включено только PBC (Push Button Connect), т.е. подключение по нажатой кнопке, и вы не можете подключиться через WPS, если вы не нажмете на физическую кнопку устройства"
	arr["GREEK",390]="Μερικά σημεία πρόσβασης έχουν PBC (Push Button Connect) και δεν μπορείτε να συνδεθείτε μέσω WPS αν δεν πατήσετε το κουμπί αυτό στη συσκευή"
	arr["ITALIAN",390]="Alcuni punti di accesso hanno solo PBC (Push Button Connect) attivato e non è possibile connettersi tramite WPS se non viene premuto il pulsante fisico"
	arr["POLISH",390]="Niektóre punkty dostępu mają włączoną funkcję PBC (Push Button Connect) i nie można połączyć się za pośrednictwem WPS, jeśli nie naciśniesz fizycznego przycisku"
	arr["GERMAN",390]="Bei einigen Access Points ist nur PBC (Push Button Connect) aktiviert, und Sie können keine Verbindung über WPS herstellen, wenn Sie nicht die physische Taste drücken"
	arr["TURKISH",390]="${pending_of_translation} Bazı erişim noktalarının yalnızca PBC (Push Button Connect) özelliği vardır ve cihazdaki fiziksel tuşa basmazsanız WPS ile bağlanamazsınız"

	arr["ENGLISH",391]="Timeout set to ${normal_color}${timeout}${blue_color} seconds"
	arr["SPANISH",391]="Timeout elegido ${normal_color}${timeout}${blue_color} segundos"
	arr["FRENCH",391]="Paramétrage du timeout ${normal_color}${timeout}${blue_color} secondes"
	arr["CATALAN",391]="Temps d'espera triat ${normal_color}${timeout}${blue_color} segons"
	arr["PORTUGUESE",391]="Timeout definido para ${normal_color}${timeout}${blue_color} segundos"
	arr["RUSSIAN",391]="Тайм-аут установлен на ${normal_color}${timeout}${blue_color} секунд"
	arr["GREEK",391]="Το timeout τέθηκε στα ${normal_color}${timeout}${blue_color} δευτερόλεπτα"
	arr["ITALIAN",391]="Timeout scelto ${normal_color}${timeout}${blue_color} secondi"
	arr["POLISH",391]="Wybrany limit czasu ${normal_color}${timeout}${blue_color} sekund"
	arr["GERMAN",391]="Ausgewähltes Timeout ${normal_color}${timeout}${blue_color} Sekunden"
	arr["TURKISH",391]="${pending_of_translation} Zaman aşımı ${normal_color}${timeout}${blue_color} saniye olarak ayarlandı"

	arr["ENGLISH",392]="In the 5Ghz band there are many channels in which because of the country configuration, you can't operate. There are also other channels in which you can't initiate communication, only communicate with an existing network. This makes starting an access point on a 5Ghz channel very likely to fail if it doesn't match an allowed channel. This is why Evil Twin will start on a channel in the 2.4Ghz band (1-11). But don't worry, it will be transparent for the users because the DoS attack still operate on the real 5Ghz channel against the target"
	arr["SPANISH",392]="En la banda de los 5Ghz hay muchos canales en los que por la configuración del país, no puedes operar. También hay otros canales en los que no puedes iniciar la comunicación, solo comunicarte con una red existente. Esto hace que iniciar un punto de acceso en una canal de 5Ghz tenga muchas probabilidades de fallo si no coincide con un canal permitido. Es por esto que el Evil Twin se iniciará en un canal de la banda 2.4Ghz (1-11). Pero no te preocupes, será transparente para los usuarios ya que el ataque DoS sigue operando en el canal real de 5Ghz contra el objetivo"
	arr["FRENCH",392]="Dans la bande 5Ghz il y a beaucoup de canaux dans lesquels par la configuration du pays, vous ne pouvez pas fonctionner. Il existe également d'autres canaux dans lesquels vous ne pouvez pas initier la communication, communiquez simplement avec un réseau existant. Cela rend le démarrage d'un point d'accès sur un canal 5Ghz très susceptible d'échouer s'il ne correspond pas à un canal autorisé. C'est pourquoi le Evil Twin commencera sur un canal dans la bande 2.4Ghz (1-11). Mais ne vous inquiétez pas, il sera transparent pour les utilisateurs puisque l'attaque DoS continue à fonctionner sur le vrai canal 5Ghz contre la cible"
	arr["CATALAN",392]="En la banda dels 5Ghz hi ha molts canals en els que per la configuració del país, no pots operar. També hi ha altres canals en què no pots iniciar la comunicació, només comunicar-te amb una xarxa existent. Això fa que iniciar un punt d'accés a un canal de 5Ghz tingui moltes probabilitats de fallada si no coincideix amb una cadena permesa. És per això que el Evil Twin s'iniciarà en un canal de la banda 2.4Ghz (1-11). Però no et preocupis, serà transparent per als usuaris ja que l'atac DoS segueix operant al canal real de 5Ghz contra l'objectiu"
	arr["PORTUGUESE",392]="Na banda de 5Ghz existem muitos canais nos quais não se pode operar, dependendo do país. Existem também outros canais nos quais você não pode iniciar a comunicação, apenas se comunicar com redes existentes. Isso faz com que iníciar um ponto de acesso em um canal de 5Ghz seja muito arriscado, pois pode não corresponder a um canal permitido. É por isso que o Evil Twin começará em um canal na banda 2.4Ghz (1-11). Mas não se preocupe, será invisível para os usuários, uma vez que o ataque DoS continua contra o alvo, no canal de 5Ghz"
	arr["RUSSIAN",392]="В диапазоне 5Ghz есть много каналов, в которых вы не можете работать из-за настроек управляющего домена. Существуют также другие каналы, в которых вы не можете инициировать связь, а можете только обмениваться данными с существующей сетью. Это означает, что запуск точки доступа на канале 5Ghz с высокой степенью вероятности закончится неудачей, если выбран неразрешённый канал. Вот почему Evil Twin запускается на канале частот 2.4Ghz (1-11). Но не беспокойтесь, пользователи не заметят разницу, поскольку DoS-атака в отношении цели по-прежнему работает на реальном канале 5Ghz"
	arr["GREEK",392]="Στην 5Ghz ζώνη υπάρχουν πολλά κανάλια τα οποία δεν μπορείτε να χρησιμοποιήσετε λόγω της διαμόρφωσης χώρας. Υπάρχουν επίσης και άλλα κανάλια στα οποία δεν μπορείτε να ξεκινήσετε κάποιου είδους επικοινωνία, αλλά μπορείτε να επικοινωνήσετε μόνο με ένα υπάρχον δίκτυο. Αυτό καθιστά την έναρξη ενός σημείου πρόσβασης σε κανάλι 5Ghz πολύ πιθανό να αποτύχει αν δεν ταιριάζει με κάποιο επιτρεπόμενο κανάλι. Αυτός είναι ο λόγος για τον οποίο το Evil Twin θα ξεκινήσει σε κανάλι στην 2.4Ghz ζώνη (1-11). Αλλά μην ανησυχείτε, θα είναι διαφανής στους χρήστες, επειδή η επίθεση DoS εξακολουθεί να λειτουργεί στο πραγματικό 5Ghz κανάλι έναντι του στόχου"
	arr["ITALIAN",392]="Nella banda 5Ghz ci sono molti canali in cui non è possibile operare a causa della configurazione del paese. Esistono anche altri canali in cui non è possibile avviare la comunicazione, ma solo comunicare con una rete esistente. Ciò rende molto probabile che l'avvio di un punto di accesso su un canale a 5Ghz non riesca se non corrisponde a un canale consentito. Questo è il motivo per cui Evil Twin inizierà su un canale nella banda 2.4Ghz (1-11). Peró non preoccuparti, questo sarà trasparente per gli utenti poiché l'attacco DoS continua a funzionare sul vero canale 5Ghz contro l'obbiettivo selezionato"
	arr["POLISH",392]="W paśmie 5Ghz istnieje wiele kanałów, które nie mogą działać z powodu konfiguracji kraju. Istnieją również inne kanały, w których nie można zainicjować komunikacji, a tylko komunikować się z istniejącą siecią. To sprawia, że uruchomienie punktu dostępu na kanale 5Ghz może się nie udać, jeśli nie pasuje do dozwolonego kanału. Dlatego atak Evil Twin rozpocznie się na kanale w paśmie 2.4Ghz (1-11). Ale nie martw się, będzie to dla użytkowników niewidoczne, ponieważ atak DoS nadal działa przeciwko celowi na prawdziwym kanale 5Ghz"
	arr["GERMAN",392]="Im 5Ghz-Band gibt es viele Kanäle, in denen man nach der Konfiguration des Landes nicht arbeiten kann. Es gibt auch andere Kanäle, in denen Sie keine Kommunikation starten können, sondern nur mit einem bestehenden Netzwerk kommunizieren. Dies führt dazu, dass das Starten eines APs auf einem 5Ghz-Kanal sehr wahrscheinlich fehlschlägt, wenn es nicht mit einem zulässigen Kanal übereinstimmt. Deshalb startet der Evil Twin auf einem Kanal im 2.4Ghz-Band (1-11). Aber keine Sorge, es wird für die Benutzer transparent sein, da die DoS-Attacke weiterhin auf dem echten 5Ghz-Kanal gegen das Ziel arbeitet"
	arr["TURKISH",392]="${pending_of_translation} 5Ghz bandında, ülke konfigürasyonu nedeniyle çalışamayacağınız pek çok kanal var. İletişimi başlatamayacağınız başka kanallar da vardır, sadece mevcut bir ağ ile iletişim kurabilirsiniz. Bu, izin verilen bir kanalla eşleşmezse başarısız olması muhtemel 5 GHz'lik bir kanalda bir erişim noktası başlatılmasını sağlar. Bu yüzden Evil Twin 2.4Ghz bandında (1-11) bir kanalda başlayacaktır. Ama endişelenmeyin, kullanıcılar için şeffaf olacak çünkü DoS saldırısı hala hedefe karşı gerçek 5GHz kanalında çalışıyor"

	arr["ENGLISH",393]="Type value in seconds (${min_max_timeout}) for timeout or press [Enter] to accept the proposal [${normal_color}${timeout_shown}${green_color}]:"
	arr["SPANISH",393]="Escribe un valor en segundos (${min_max_timeout}) para el timeout o pulsa [Enter] para aceptar el valor propuesto [${normal_color}${timeout_shown}${green_color}]:"
	arr["FRENCH",393]="Entrez un intervalle de temps en secondes (${min_max_timeout}) pour le timeout ou appuyez sur [Enter] pour valider la valeur proposée [${normal_color}${timeout_shown}${green_color}]:"
	arr["CATALAN",393]="Escriu un valor en segons (${min_max_timeout}) per al temps d'espera o prem [Enter] per acceptar el valor proposat [${normal_color}${timeout_shown}${green_color}]:"
	arr["PORTUGUESE",393]="Insira um valor em segundos (${min_max_timeout}) para o timeout ou pressione [Enter] para aceitar o valor padrão [${normal_color}${timeout_shown}${green_color}]:"
	arr["RUSSIAN",393]="Введите значение в секундах (${min_max_timeout}) для тайм-аута или нажмите [Enter], чтобы оставить по умолчанию [${normal_color}${timeout_shown}${green_color}]:"
	arr["GREEK",393]="Εισάγετε μια τιμή σε δευτερόλεπτα (${min_max_timeout}) για το timeout ή πατήστε [Enter] για να τεθεί η προεπιλεγμένη τιμή [${normal_color}${timeout_shown}${green_color}]:"
	arr["ITALIAN",393]="Scrivi un valore in secondi (${min_max_timeout}) per il timeout o premi [Enter] per accettare il valore proposto [${normal_color}${timeout_shown}${green_color}]:"
	arr["POLISH",393]="Wprowadź wartość w sekundach (${min_max_timeout}) dla limitu czasu lub naciśnij klawisz [Enter], aby zaakceptować proponowaną wartość [${normal_color}${timeout_shown}${green_color}]:"
	arr["GERMAN",393]="Geben Sie einen Wert in Sekunden (${min_max_timeout}) für die Zeitüberschreitung ein oder drücken Sie [Enter], um den vorgeschlagenen Wert zu übernehmen [${normal_color}${timeout_shown}${green_color}]:"
	arr["TURKISH",393]="${pending_of_translation} Zaman aşımı için saniye cinsinden değeri (${min_max_timeout}) yazın veya teklifi kabul etmek için [Enter] tuşuna basın [${normal_color}${timeout_shown}${green_color}]:"

	arr["ENGLISH",394]="You have selected a 5Ghz target network and the \"DoS pursuit mode\", but the second interface needed to perform the attack doesn't support the 5Ghz band so the attack can't be performed"
	arr["SPANISH",394]="Has seleccionado una red objetivo de 5Ghz y el \"modo persecución DoS\", pero el segundo interfaz necesario para llevar a cabo el ataque no soporta la banda de los 5Ghz por lo que este no se puede realizar"
	arr["FRENCH",394]="Vous avez sélectionné un réseau cible de 5Ghz et le \"mode de poursuite DoS\", mais la deuxième interface nécessaire pour effectuer l'attaque ne supporte pas la bande 5Ghz donc elle ne peut pas être effectuée"
	arr["CATALAN",394]="Has seleccionat una xarxa objectiu de 5Ghz i el \"mode persecució DoS\", però el segon interfície necessari per dur a terme l'atac no suporta la banda dels 5Ghz pel que aquest no es pot realitzar"
	arr["PORTUGUESE",394]="Você selecionou uma rede de 5Ghz e DoS com o \"modo de perseguição\", mas a segunda interface necessária para realizar o ataque não suporta a banda de 5Ghz. O ataque não pode ser realizado"
	arr["RUSSIAN",394]="Вы выбрали целевую сеть на 5Ghz и \"режим преследования DoS\", но второй интерфейс, необходимый для выполнения атаки, не поддерживает полосу 5Ghz, поэтому атака не может быть выполнена"
	arr["GREEK",394]="Έχετε επιλέξει ένα 5Ghz δίκτυο στόχος και το \"DoS pursuit mode\", αλλά η δεύτερη διεπαφή που απαιτείται για να εκτελέσετε την επίθεση δεν υποστηρίζει την 5Ghz ζώνη, ως αποτέλεσμα η επίθεση να μην μπορεί να εκτελεστεί"
	arr["ITALIAN",394]="Hai selezionato come obbiettivo una rete di 5Ghz e la \"DoS pursuit mode\", ma la seconda interfaccia necessaria per eseguire l'attacco non supporta la banda 5Ghz, quindi l'attacco non puó essere eseguito"
	arr["POLISH",394]="Wybrałeś docelową sieć 5Ghz i \"tryb DoS pursuit\", ale drugi interfejs potrzebny do przeprowadzenia ataku nie obsługuje pasma 5Ghz, więc nie można go wykonać"
	arr["GERMAN",394]="Sie haben ein Zielnetzwerk mit 5Ghz und den \"DoS pursuit mode\" gewählt, aber die zweite Schnittstelle, die zur Ausführung des Angriffs benötigt wird, unterstützt das 5Ghz-Band nicht, so dass es nicht ausgeführt werden kann"
	arr["TURKISH",394]="${pending_of_translation} Bir 5Ghz hedef ağı ve \"DoS peşinde koşma modu\" nı seçtiniz, ancak saldırıyı gerçekleştirmek için gereken ikinci arabirim, 5Ghz bandını desteklemiyor, böylece saldırı gerçekleştirilemiyor"

	arr["ENGLISH",395]="Skipping intro, more window size needed"
	arr["SPANISH",395]="Saltando presentación, se necesita más tamaño de ventana"
	arr["FRENCH",395]="Pas de présentation pour manque d'espace en fenêtre"
	arr["CATALAN",395]="Saltant presentació, es necessita més grandària de finestra"
	arr["PORTUGUESE",395]="Saltando intro, uma janela maior é necessária"
	arr["RUSSIAN",395]="Пропуск заставки, требуется окно большего размера"
	arr["GREEK",395]="Το intro παρακάμπτεται, χρειάζεται μεγαλύτερο μέγεθος παραθύρου"
	arr["ITALIAN",395]="Saltando la presentazione, è necessaria una finestra piú grande"
	arr["POLISH",395]="Pomijanie prezentacji, potrzebujesz większego rozmiaru okna"
	arr["GERMAN",395]="Intro wird übersprungen, mehr Fenstergröße ist erforderlich"
	arr["TURKISH",395]="${pending_of_translation} Giriş atlanıyor, daha fazla pencere boyutu gerekiyor"

	arr["ENGLISH",396]="8.  Evil Twin AP attack with sniffing and bettercap-sslstrip2/BeEF"
	arr["SPANISH",396]="8.  Ataque Evil Twin AP con sniffing y bettercap-sslstrip2/BeEF"
	arr["FRENCH",396]="8.  Attaque Evil Twin avec capture des données et bettercap-sslstrip2/BeEF"
	arr["CATALAN",396]="8.  Atac Evil Twin AP amb sniffing i bettercap-sslstrip2/BeEF"
	arr["PORTUGUESE",396]="8.  Ataque Evil Twin AP com sniffing e bettercap-sslstrip2/BeEF"
	arr["RUSSIAN",396]="8.  Атака Злой Двойник ТД со сниффингом и bettercap-sslstrip2/BeEF"
	arr["GREEK",396]="8.  Επίθεση Evil Twin AP με sniffing και bettercap-sslstrip2/BeEF"
	arr["ITALIAN",396]="8.  Attacco Evil Twin AP con sniffing e bettercap-sslstrip2/BeEF"
	arr["POLISH",396]="8.  Atak Evil Twin AP ze sniffingiem i bettercap-sslstrip2/BeEF"
	arr["GERMAN",396]="8.  Evil Twin AP Angriff mit Sniffing und bettercap-sslstrip2/BeEF"
	arr["TURKISH",396]="${pending_of_translation} 8.  Sniffing ve bettercap-sslstrip2/BeEF ile Kötü İkiz AP saldırısı"

	arr["ENGLISH",397]="Evil Twin AP attack with sniffing and bettercap-sslstrip2/BeEF"
	arr["SPANISH",397]="Ataque Evil Twin AP con sniffing y bettercap-sslstrip2/BeEF"
	arr["FRENCH",397]="Attaque Evil Twin avec capture de données et bettercap-sslstrip2/BeEF"
	arr["CATALAN",397]="Atac Evil Twin AP amb sniffing i bettercap-sslstrip2/BeEF"
	arr["PORTUGUESE",397]="Ataque Evil Twin AP com sniffing e bettercap-sslstrip2/BeEF"
	arr["RUSSIAN",397]="Атака Злой Двойник ТД со сниффингом и bettercap-sslstrip2/BeEF"
	arr["GREEK",397]="Επίθεση Evil Twin AP με sniffing και bettercap-sslstrip2/BeEF"
	arr["ITALIAN",397]="Attacco Evil Twin AP con sniffing e bettercap-sslstrip2/BeEF"
	arr["POLISH",397]="Atak Evil Twin AP ze sniffingiem i bettercap-sslstrip2/BeEF"
	arr["GERMAN",397]="Evil Twin AP Angriff mit Sniffing und bettercap-sslstrip2/BeEF"
	arr["TURKISH",397]="${pending_of_translation} Ataque Evil İkiz AP con sniffing y bettercap-sslstrip2/BeEF"

	arr["ENGLISH",398]="Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${default_bettercap_logpath}]"
	arr["SPANISH",398]="Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${default_bettercap_logpath}]"
	arr["FRENCH",398]="Entrez le chemin du fichier ou bien appuyez sur [Enter] pour utiliser le chemin proposé ${normal_color}[${default_bettercap_logpath}]"
	arr["CATALAN",398]="Escriu la ruta on desarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${default_bettercap_logpath}]"
	arr["PORTUGUESE",398]="Digite o caminho onde armazenar o arquivo ou pressione [Enter] para aceitar o padrão ${normal_color}[${default_bettercap_logpath}]"
	arr["RUSSIAN",398]="Напечатайте путь до файла для сохранения или нажмите [Enter] для принятия предложения по умолчанию ${normal_color}[${default_bettercap_logpath}]"
	arr["GREEK",398]="Πληκτρολογήστε το μονοπάτι για να αποθηκεύσετε το αρχείο ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${default_bettercap_logpath}]"
	arr["ITALIAN",398]="Digitare il percorso dove memorizzare il file o premere [Enter] per accettare la proposta di default ${normal_color}[${default_bettercap_logpath}]"
	arr["POLISH",398]="Wpisz ścieżkę, w której będzie zapisany plik lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${default_bettercap_logpath}]"
	arr["GERMAN",398]="Schreiben Sie den Pfad, unter dem die Datei gespeichert werden soll, oder drücken Sie die Enter-Taste, um den Standardvorschlag zu akzeptieren ${normal_color}[${default_bettercap_logpath}]"
	arr["TURKISH",398]="${pending_of_translation} Dosyayı depolamak için yolu yazın veya varsayılan teklifi kabul etmek için [Enter] tuşuna basın ${normal_color}[${default_bettercap_logpath}]"

	arr["ENGLISH",399]="Passwords captured by sniffer. File saved at ${normal_color}[${bettercap_logpath}]"
	arr["SPANISH",399]="El sniffer ha capturado contraseñas. Fichero salvado en ${normal_color}[${bettercap_logpath}]"
	arr["FRENCH",399]="Des mots de passe ont été capturé et ont été enregistré dans ${normal_color}[${bettercap_logpath}]"
	arr["CATALAN",399]="El sniffer ha capturat contrasenyes. Fitxer desat a ${normal_color}[${bettercap_logpath}]"
	arr["PORTUGUESE",399]="O sniffer capturou senhas. O arquivo foi salvo em ${normal_color}[${bettercap_logpath}]"
	arr["RUSSIAN",399]="Сниффер захватил пароли. Файл сохранён в ${normal_color}[${bettercap_logpath}]"
	arr["GREEK",399]="Καταγράφηκαν κωδικοί πρόσβασης από τον sniffer. Το αρχείο αποθηκεύτηκε στο ${normal_color}[${bettercap_logpath}]"
	arr["ITALIAN",399]="Lo sniffer ha catturato passwords. File salvato in ${normal_color}[${bettercap_logpath}]"
	arr["POLISH",399]="Sniffer przechwycił hasła. Plik zapisany w ${normal_color}[${bettercap_logpath}]"
	arr["GERMAN",399]="Der Sniffer hat Passwörter erfasst. Datei in ${normal_color}[${bettercap_logpath}] gespeichert"
	arr["TURKISH",399]="${pending_of_translation} Parolalar sniffer tarafından yakalandı. Dosyada kaydedildi ${normal_color}[${bettercap_logpath}]"

	arr["ENGLISH",400]="On Evil Twin attack with BeEF integrated, in addition to obtaining keys using sniffing techniques, you can try to control the client's browser launching numerous attack vectors. The success of these will depend on many factors such as the kind of client's browser and its version"
	arr["SPANISH",400]="En el ataque Evil Twin con BeEF integrado, además de obtener claves con sniffing, podrás intentar controlar el navegador de los clientes lanzando numerosos vectores de ataque. El éxito de estos dependerá de muchos factores como el tipo de navegador y la versión que utilice el cliente"
	arr["FRENCH",400]="Avec l'attaque Evil Twin plus BeEF il est possible obtenir les clés en sniffant, mais pas seulement. Vous pouvez essayer de prendre le contrôle du navigateur web de la vicitme. Le succès des attaques proposées dépendra, entre autre, de la version du navigateur installé"
	arr["CATALAN",400]="En l'atac Evil Twin amb Beef integrat, a més d'obtenir claus amb sniffing, podràs intentar controlar el navegador dels clients llançant nombrosos vectors d'atac. L'èxit d'aquests dependrà de molts factors com el tipus de navegador i la versió que utilitzi el client"
	arr["PORTUGUESE",400]="No ataque Evil Twin com BeEF integrado, além de obter senhas com sniffing, você pode tentar controlar o navegador do cliente lançando inúmeros vetores de ataque. O sucesso destes dependerá de muitos fatores, como tipo de navegador e versão utilizada pelo cliente"
	arr["RUSSIAN",400]="С атакой Злой Двойник в дополнение к получению паролей сниффингом, вы можете попробовать контролировать клиентский браузер, запуская атаки по ряду векторов. Их успех зависит от многих факторов, в том числе от типа и версии клиентского браузера"
	arr["GREEK",400]="Στην επίθεση Evil Twin με ενσωματωμένο BeEF, εκτός από την απόκτηση κλειδιών με τη χρήση τεχνικών sniffing, μπορείτε να προσπαθήσετε να ελέγξετε τον browser του χρήστη-πελάτη κάνοντας χρήση κάποιων attack vectors. Η επιτυχία αυτών θα εξαρτηθεί από πολλούς παράγοντες όπως το είδος του browser του χρήστη-πελάτη και την έκδοσή του"
	arr["ITALIAN",400]="Nell'attacco Evil Twin con BeEF integrato, oltre ad ottenere le chiavi con sniffing, si può provare a controllare il browser dei clienti lanciando numerosi vettori di attacco. Il successo di questi attacchi dipende da molti fattori, come il tipo di browser e la versione utilizzata dal cliente"
	arr["POLISH",400]="W ataku Evil Twin ze zintegrowanym BeEF, oprócz uzyskiwania kluczy sniffingiem, można spróbować kontrolować przeglądarkę klientów, uruchamiając liczne ataki. Sukces tych działań będzie zależał od wielu czynników, takich jak typ przeglądarki i wersja używana przez klienta"
	arr["GERMAN",400]="Beim Evil-Twin Angriff mit integriertem BeEF können Sie nicht nur Schlüssel mit Sniffing erhalten, sondern auch versuchen, den Browser des Clients zu steuern, indem Sie zahlreiche Angriffsvektoren starten. Der Erfolg hängt von vielen Faktoren ab, beispielsweise vom Browsertyp und der vom Client verwendeten Version"
	arr["TURKISH",400]="${pending_of_translation} BeEF ile Evil Twin saldırısında entegre olarak, koklama tekniklerini kullanarak anahtar elde etmenin yanı sıra, müşterinin tarayıcısını çok sayıda saldırı vektörünü başlatmaya çalışmayı deneyebilirsiniz. Bunların başarısı, müşterinin tarayıcısının türü ve versiyonu gibi birçok faktöre bağlı olacaktır"

	arr["ENGLISH",401]="The beef package you have installed is not BeEF (Browser Exploitation Framework). You have Beef (Flexible Brainfuck interpreter) installed. Both executables have the same name and can lead to confusion. Uninstall it and install what airgeddon needs if you want to use that feature. Installation guide: ${beef_installation_url}"
	arr["SPANISH",401]="El paquete beef que tienes instalado no es BeEF (Browser Exploitation Framework). Tienes instalado Beef (Flexible Brainfuck interpreter). Ambos ejecutables se llaman igual y puede dar lugar a confusión. Desinstálalo e instala el que airgeddon necesita si quieres usar esa característica. Guía de instalación: ${beef_installation_url}"
	arr["FRENCH",401]="Le paquet beef installé n'est pas le bon: Vous avez installé Beef (Flexible Brainfuck interpreter) et vous devez installer BeEF (Browser Exploitation Framework). Les deux ont le même nom et peut induire en erreur. Désinstallez et installez la version dont airgeddon a besoin si vous souhaitez utiliser cette fonctionnalité. Guide d'installation: ${beef_installation_url}"
	arr["CATALAN",401]="El paquet beef que tens instal·lat no és BeEF (Browser Exploitation Framework). Tens instal·lat Beef (Flexible Brainfuck interpreter). Tots dos executables es diuen igual i pot donar lloc a confusió. Desinstalalo i instal·la el que airgeddon necessita si vols utilitzar aquesta característica. Guia d'instal·lació: ${beef_installation_url}"
	arr["PORTUGUESE",401]="O pacote beef instalado não é o BeEF (Browser Exploitation Framework). Você instalou Beef (Flexible Brainfuck interpreter). Ambos possuem o mesmo nome e executável o que pode levar a confusão. Desinstale-o e instale o que o airgeddon precisa se você quiser usar esse recurso. Guia de Instalação: ${beef_installation_url}"
	arr["RUSSIAN",401]="Установленный вами пакет beef не является пакетом BeEF (Browser Exploitation Framework). Вы установили Beef (Flexible Brainfuck interpreter). Оба исполнимых файла имеют одинаковое имя и могут вызвать путаницу. Если вы хотите использовать эту функцию, удалите его и установите тот, который требует airgeddon. Инструкция по установке: ${beef_installation_url}"
	arr["GREEK",401]="Το πακέτο beef που έχετε εγκαταστημένο δεν είναι το BeEF (Browser Exploitation Framework). Έχετε εγκατεστημένο το Beef (Flexible Brainfuck interpreter). Και τα δύο εκτελέσιμα αρχεία έχουν το ίδιο όνομα και μπορεί να γίνει κάποιο μπέρδεμα. Απεγκαταστήστε το και εγκαταστήστε αυτό που χρειάζεται το airgeddon, αν θέλετε να χρησιμοποιήσετε αυτή την επιλογή. Οδηγός εγκατάστασης: ${beef_installation_url}"
	arr["ITALIAN",401]="Il pacchetto beef che hai installato non è BeEF (Browser Exploitation Framework). È stato installato Beef (Flexible Brainfuck interpreter). Entrambi gli eseguibili hanno lo nome e può essere fonte di confusione. Disinstallarlo e installare quello di cui ha bisogno airgeddon se si desidera utilizzare questa funzione. Guida all'installazione: ${beef_installation_url}"
	arr["POLISH",401]="Zainstalowany pakiet beef nie jest BeEF (Browser Exploitation Framework). Masz zainstalowaną Beef (Flexible Brainfuck interpreter). Obydwa pliki wykonywalne są nazywane tak samo i mogą prowadzić do zamieszania. Odinstaluj i zainstaluj system airgeddon, jeśli potrzebujesz tej funkcji. Instrukcja instalacji: ${beef_installation_url}"
	arr["GERMAN",401]="Das von Ihnen installierte beef-Paket ist nicht BeEF (Browser Exploitation Framework). Sie haben Beef (Flexible Brainfuck Interpreter) installiert. Beide ausführbare Dateien werden als gleich bezeichnet und können zu Verwirrung führen. Deinstallieren Sie es und installieren Sie das, das airgeddon benötigt, wenn Sie diese Funktion verwenden möchten. Installationsanleitung: ${beef_installation_url}"
	arr["TURKISH",401]="${pending_of_translation} Yüklediğiniz beef paketi, BeEF (Browser Exploitation Framework) değildir. Beef (Flexible Brainfuck interpreter) kurulu. Her iki yürütücü de aynı ada sahip ve karışıklığa yol açabilir. Bu özelliği kullanmak istiyorsanız kaldırın ve hangi airgeddon'un gereksinimlerini karşılayın. Kurulum kılavuzu: ${beef_installation_url}"

	arr["ENGLISH",402]="Enter the absolute path of the directory where BeEF is installed:"
	arr["SPANISH",402]="Introduce la ruta absoluta del directorio donde está instalado BeEF:"
	arr["FRENCH",402]="Entrez la route absolue vers le dossier où BeEF est installé:"
	arr["CATALAN",402]="Introdueix la ruta absoluta del directori on està instal·lat BeEF:"
	arr["PORTUGUESE",402]="Digite o caminho absoluto do diretório onde BeEF está instalado:"
	arr["RUSSIAN",402]="Введите абсолютный путь к каталогу, в котором установлен BeEF:"
	arr["GREEK",402]="Εισάγετε το απόλυτο μονοπάτι για τον κατάλογο στον όποιο βρίσκεται εγκατεστημένο το BeEF:"
	arr["ITALIAN",402]="Immettere il percorso assoluto della directory in cui è installato BeEF:"
	arr["POLISH",402]="Wprowadż ścieżkę absolutną do instalacji BeEF:"
	arr["GERMAN",402]="Geben Sie den absoluten Pfad des Verzeichnisses ein, in dem BeEF installiert ist:"
	arr["TURKISH",402]="${pending_of_translation} "

	arr["ENGLISH",403]="The directory you entered doesn't exist"
	arr["SPANISH",403]="El directorio introducido no existe"
	arr["FRENCH",403]="Le dossier indiqué n'existe pas"
	arr["CATALAN",403]="El directori introduït no existeix"
	arr["PORTUGUESE",403]="O diretório digitado não existe"
	arr["RUSSIAN",403]="Каталог, который вы ввели, не существует"
	arr["GREEK",403]="Ο κατάλογος που έχετε εισάγει δεν υπάρχει"
	arr["ITALIAN",403]="La cartella indicata non esiste"
	arr["POLISH",403]="Wprowadzony katalog nie istnieje"
	arr["GERMAN",403]="Das eingegebene Verzeichnis existiert nicht"
	arr["TURKISH",403]="${pending_of_translation} Girdiğiniz dizin mevcut değil"

	arr["ENGLISH",404]="The entered path isn't absolute. An absolute path must always begin with \"/\""
	arr["SPANISH",404]="La ruta introducida no es absoluta. Una ruta absoluta siempre debe comenzar por \"/\""
	arr["FRENCH",404]="La route saisie n'est pas absolue. Une route absolue doit toujours commencer par \"/\""
	arr["CATALAN",404]="La ruta introduïda no és absoluta. Una ruta absoluta sempre ha de començar per \"/\""
	arr["PORTUGUESE",404]="O caminho digitado não é absoluto. Um caminho absoluto deve sempre começar com \"/\""
	arr["RUSSIAN",404]="Введенный путь не является абсолютным. Абсолютный путь всегда должен начинаться с \"/\""
	arr["GREEK",404]="Το μονοπάτι που έχετε εισάγει δεν είναι απόλυτο. Ένα απόλυτο μονοπάτι πρέπει πάντα να ξεκινάει με \"/\""
	arr["ITALIAN",404]="Il percorso immesso non è assoluto. Un percorso assoluto deve sempre iniziare con \"/\""
	arr["POLISH",404]="Wprowadzona ścieżka nie jest absolutna. Ścieżka abolutna musi się zawsze zaczynać od \"/\""
	arr["GERMAN",404]="Der eingegebene Pfad ist nicht absolut. Ein absoluter Pfad sollte immer mit \"/\" beginnen"
	arr["TURKISH",404]="${pending_of_translation} Girilen yol mutlak değildir. Mutlak bir yol daima \"/\" ile başlamalıdır"

	arr["ENGLISH",405]="Checking BeEF..."
	arr["SPANISH",405]="Comprobando BeEF..."
	arr["FRENCH",405]="Vérification de BeEF..."
	arr["CATALAN",405]="Comprovant BeEF..."
	arr["PORTUGUESE",405]="Verificando BeEF..."
	arr["RUSSIAN",405]="Проверка BeEF..."
	arr["GREEK",405]="Γίνεται έλεγχος του BeEF..."
	arr["ITALIAN",405]="Controllando BeEF..."
	arr["POLISH",405]="Sprawdzanie BeEF..."
	arr["GERMAN",405]="BeEF wird überprüft..."
	arr["TURKISH",405]="BeEF kontrol ediliyor..."

	arr["ENGLISH",406]="No BeEF executable was detected in given directory"
	arr["SPANISH",406]="No se ha detectado un ejecutable de BeEF en el directorio indicado"
	arr["FRENCH",406]="BeEF n'est pas présent dans le dossier que vous avez indiqué"
	arr["CATALAN",406]="No s'ha detectat un executable de BeEF al directori indicat"
	arr["PORTUGUESE",406]="O executável do BeEF não foi detectado no diretório especificado"
	arr["RUSSIAN",406]="Ни один исполняемый файл BeEF не был обнаружен в заданной директории"
	arr["GREEK",406]="Δεν εντοπίστηκε κάποιο εκτελέσιμο αρχείο BeEF στον κατάλογο που έχετε εισάγει"
	arr["ITALIAN",406]="Non è stato rilevato un eseguibile di BeEF nella directory specificata"
	arr["POLISH",406]="Nie znaleziono pliku wykonywalnego BeEF w danym katalogu"
	arr["GERMAN",406]="Keine BeEF-Programmdatei wurde im angegebenen Verzeichnis nicht gefunden"
	arr["TURKISH",406]="${pending_of_translation} Verilen dizinde BeEF yürütülebilir bulunamadı"

	arr["ENGLISH",407]="BeEF preparation"
	arr["SPANISH",407]="Preparación BeEF"
	arr["FRENCH",407]="Mise en place de BeEF"
	arr["CATALAN",407]="Preparació BeEF"
	arr["PORTUGUESE",407]="Preparando BeEF"
	arr["RUSSIAN",407]="Подготовка BeEF"
	arr["GREEK",407]="Προετοιμασία του BeEF"
	arr["ITALIAN",407]="Preparando BeEF"
	arr["POLISH",407]="Przygotowanie BeEF"
	arr["GERMAN",407]="BeEF wird vorbereitet"
	arr["TURKISH",407]="BeEF hazırlanması"

	arr["ENGLISH",408]="If you installed BeEF manually, airgeddon might not be able to find it and the attack option can appear as restricted. You can try to solve it using the special menu option to fix this. It will work only if BeEF is already correctly installed and your unique problem is the script is not detecting it"
	arr["SPANISH",408]="Si instalaste BeEF manualmente, puede que airgeddon no sea capaz de encontrarlo y la opción del ataque te aparezca restringida. Puedes intentar solucionarlo usando la opción del menú especial para ello. Esto sólo funcionará si BeEF ya está instalado correctamente y el único problema que tienes es que el script no lo detecta"
	arr["FRENCH",408]="Si BeEF a été installé manuellement, il se peut qu'airgeddon ne soit pas en mesure de le trouver. L'option dédiée ne sera pas accessible. Vous pouvez essayer de la réparer en utilisant l'option consacrée à cette tâche depuis le menu spécial. Ça ne marchera que si BeEf est correctement instalé et c'est le script qui n'est pas capable de le détecter"
	arr["CATALAN",408]="Si vas instal·lar BeEF manualment, pot ser que airgeddon no sigui capaç de trobar-lo i l'opció de l'atac t'aparegui restringida. Pots intentar solucionar usant l'opció del menú especial per a això. Això només funcionarà si BeEF ja està instal·lat correctament i l'únic problema que tens és que el script no el detecta"
	arr["PORTUGUESE",408]="Se BeEF foi instalado manualmente, o airgeddon não pode encontrá-lo automaticamente e a opção de ataque aparecerá bloqueada. Você pode tentar corrigi-lo usando a opção de menu especial para isso. Isso só vai funcionar se BeEF já está instalado corretamente e o único problema que você tem é que o script não o detecta"
	arr["RUSSIAN",408]="Если вы установили BeEF вручную, airgeddon может быть не в состоянии найти его, и опция атаки в меню может быть ограничена. Для исправления этого, вы можете попытаться решить эту проблему с помощью специального пункта меню. Это сработает только если BeEF уже правильно установлен, и ваша единственная проблема в том, что скрипт не обнаруживает его"
	arr["GREEK",408]="Εάν έχετε εγκαταστήσει χειροκίνητα το BeEF, το airgeddon μπορεί να μην μπορέσει να το βρεί και η επιλογή της επίθεσης μπορεί να φανεί σαν περιορισμένη. Μπορείτε να προσπαθήσετε να διορθώσετε το πρόβλημα κάνοντας χρήση της ειδικής επιλογής στο μενού. Θα λειτουργήσει μόνο αν το BeEF έχει ήδη εγκατασταθεί σωστά και το μόνο πρόβλημα είναι ότι το script δεν το εντοπίζει"
	arr["ITALIAN",408]="Se BeEF è stato installato manualmente, airgeddon potrebbe non essere in grado di trovarlo e l'opzione di attacco apparirà limitata. Si può cercare di risolvere il problema utilizzando l'opzione del menú specifica per questo. Questo funzionerá solo se BeEF è già installato correttamente e l'unico problema che hai è che lo script non lo rileva"
	arr["POLISH",408]="Jeśli zainstalowałeś BeEF ręcznie, airgeddon może nie być w stanie go znaleźć, a opcja atakowania będzie ograniczona. Możesz spróbować rozwiązać ten problem używając specjalnej opcji menu. To będzie działać tylko wtedy, gdy BeEF jest już poprawnie zainstalowany i jedynym problemem jest to, że skrypt go nie wykrywa"
	arr["GERMAN",408]="Wenn Sie BeEF manuell installiert haben, kann airgeddon es möglicherweise nicht finden und die Angriffsoption scheint eingeschränkt zu sein. Sie können versuchen, es mit hilfe der speziellen Menüoption dafür zu lösen. Dies funktioniert nur, wenn BeEF bereits korrekt installiert ist und das einzige Problem, das Sie haben, ist, dass das Skript es nicht erkennt"
	arr["TURKISH",408]="${pending_of_translation} BeEF'i manuel olarak yüklediyseniz, airgeddon onu bulamayabilir ve saldırı seçeneği kısıtlı olarak görünebilir. Bunu düzeltmek için özel menü seçeneğini kullanarak çözmeyi deneyebilirsiniz. Sadece BeEF zaten doğru bir şekilde kurulmuşsa ve tek sorun, komut dosyasının bunu algılamaması durumunda çalışır"

	arr["ENGLISH",409]="1.  Evil Twin AP attack with sniffing and bettercap-sslstrip2/BeEF"
	arr["SPANISH",409]="1.  Ataque Evil Twin AP con sniffing y bettercap-sslstrip2/BeEF"
	arr["FRENCH",409]="1.  Attaque Evil Twin avec capture des données et bettercap-sslstrip2/BeEF"
	arr["CATALAN",409]="1.  Atac Evil Twin AP amb sniffing i bettercap-sslstrip2/BeEF"
	arr["PORTUGUESE",409]="1.  Ataque Evil Twin AP com sniffing e bettercap-sslstrip2/BeEF"
	arr["RUSSIAN",409]="1.  Атака Злой Двойник ТД со сниффингом и bettercap-sslstrip2/BeEF"
	arr["GREEK",409]="1.  Επίθεση Evil Twin AP με sniffing και bettercap-sslstrip2/BeEF"
	arr["ITALIAN",409]="1.  Attacco Evil Twin AP con sniffing e bettercap-sslstrip2/BeEF"
	arr["POLISH",409]="1.  Atak Evil Twin AP ze sniffingiem i bettercap-sslstrip2/BeEF"
	arr["GERMAN",409]="1.  Evil Twin AP Angriff mit Sniffing und bettercap-sslstrip2/BeEF"
	arr["TURKISH",409]="${pending_of_translation} 1.  Sniffing ve bettercap-sslstrip2/BeEF ile Kötü İkiz AP saldırısı"

	arr["ENGLISH",410]="2.  Try to troubleshoot manually installed BeEF dependency problem"
	arr["SPANISH",410]="2.  Intentar solucionar problema de dependencia BeEF instalado manualmente"
	arr["FRENCH",410]="2.  Essayer de résoudre les problèmes de dépendances avec BeEF installé manuellement"
	arr["CATALAN",410]="2.  Intentar solucionar problema de dependència BeEF instal·lat manualment"
	arr["PORTUGUESE",410]="2.  Tentar resolver o problema de dependência do BeEF instalado manualmente"
	arr["RUSSIAN",410]="2.  Попробуйте устранить проблему вручную установив зависимости BeEF"
	arr["GREEK",410]="2.  Προσπαθήστε να αντιμετωπίσετε το πρόβλημα με τα dependencies του χειροκίνητα εγκατεστημένου BeEF"
	arr["ITALIAN",410]="2.  Cercare di risolvere il problema delle dipende di BeEF installato manualmente"
	arr["POLISH",410]="2.  Próba rozwiązywania problemów z ręcznie zainstalowanym BeEF"
	arr["GERMAN",410]="2.  Versuche manuell installierte BeEF-Abhängigkeitsprobleme zu lösen"
	arr["TURKISH",410]="${pending_of_translation} 2.  El ile yüklenmiş BeEF bağımlılık sorununu gidermeye çalışın"

	arr["ENGLISH",411]="WPS filter enabled in scan. When started, press [Ctrl+C] to stop..."
	arr["SPANISH",411]="Filtro WPS activado en escaneo. Una vez empezado, pulse [Ctrl+C] para pararlo..."
	arr["FRENCH",411]="Le filtre WPS est activé dans la scan. Une fois l'opération lancée, veuillez presser [Ctrl+C] pour l'arrêter..."
	arr["CATALAN",411]="Filtre WPS activat en escaneig. Una vegada iniciat, polsi [Ctrl+C] per detenir-ho..."
	arr["PORTUGUESE",411]="Filtro WPS ativo na busca de redes wifi. Uma vez iniciado, pressione [Ctrl+C] para pará-lo..."
	arr["RUSSIAN",411]="Для сканирования включен фильтр WPS. После запуска, нажмите [Ctrl+C] для остановки..."
	arr["GREEK",411]="Το φίλτρο WPS ενεργοποιήθηκε κατά τη σάρωση. Όταν αρχίσει, μπορείτε να το σταματήσετε πατώντας [Ctrl+C]..."
	arr["ITALIAN",411]="Filtro WPS attivato nella scansione. Una volta avviata, premere [Ctrl+C] per fermarla..."
	arr["POLISH",411]="Filtr WPS aktywowany podczas skanowania. Naciśnij [Ctrl+C] w trakcie trwania, aby zatrzymać..."
	arr["GERMAN",411]="WPS-Filter beim Scannen aktiviert. Nach dem Start, drücken Sie [Ctrl+C], um es zu stoppen..."
	arr["TURKISH",411]="${pending_of_translation} WPS filtresi taramada etkinleştirildi. Başladığınızda, durdurmak için [Ctrl+C] tuşlarına basın..."

	arr["ENGLISH",412]="You don't need to perform this action. Your BeEF is operational"
	arr["SPANISH",412]="No necesitas realizar esta acción. Tu BeEF está operativo"
	arr["FRENCH",412]="Vous n'êtes pas obligé de le faire. BeEF est opérationnel"
	arr["CATALAN",412]="No necessites realitzar aquesta acció. El teu BeEF està operatiu"
	arr["PORTUGUESE",412]="Você não precisa fazer isso. Seu BeEF está operacional"
	arr["RUSSIAN",412]="Вам не нужно выполнять это действие. Ваш BeEF находится в рабочем состоянии"
	arr["GREEK",412]="Δεν χρειάζεται να εκτελέσετε αυτήν την ενέργεια. Το BeEF λειτουργεί κανονικά"
	arr["ITALIAN",412]="Non è necessario fare questo. Il tuo BeEF è operativo"
	arr["POLISH",412]="Nie musisz tego robić. Twoja BeEF działa"
	arr["GERMAN",412]="Sie müssen diese Aktion nicht durchführen. Ihr BeEF ist betriebsbereit"
	arr["TURKISH",412]="${pending_of_translation} Bu eylemi gerçekleştirmeniz gerekmez. BeEF'in operasyonel"

	arr["ENGLISH",413]="airgeddon fixed the problem. Your BeEF is operational"
	arr["SPANISH",413]="airgeddon ha solucionado el problema. Tu BeEF está operativo"
	arr["FRENCH",413]="airgeddon a résolu le problème. BeEF est opérationnel"
	arr["CATALAN",413]="airgeddon ha solucionat el problema. El teu BeEF està operatiu"
	arr["PORTUGUESE",413]="O airgeddon corrigiu o problema. Seu BeEF está operacional"
	arr["RUSSIAN",413]="airgeddon устранил проблему. Ваш BeEF находится в рабочем состоянии"
	arr["GREEK",413]="Το airgeddon διόρθωσε το πρόβλημα. Το BeEF λειτουργεί κανονικά"
	arr["ITALIAN",413]="airgeddon ha risolto il problema. Il tuo BeEF è operativo"
	arr["POLISH",413]="airgeddon rozwiązał problem. Twoja BeEF działa"
	arr["GERMAN",413]="airgeddon hat das Problem gelöst. Ihr BeEF ist betriebsbereit"
	arr["TURKISH",413]="${pending_of_translation} airgeddon sorunu çözdü. BeEF'in operasyonel"

	arr["ENGLISH",414]="You don't have curl installed. Is not possible to download PINs database file"
	arr["SPANISH",414]="No tienes curl instalado. No se puede descargar el fichero de la base de datos de PINs"
	arr["FRENCH",414]="Curl n'est pas installé. Vous ne pouvez pas télécharger le fichier de la base de donées PIN"
	arr["CATALAN",414]="No tens curl instal·lat. No es pot descarregar el fitxer de la base de dades de PINs"
	arr["PORTUGUESE",414]="Você não tem o pacote curl instalado. Você não pode baixar o arquivo com banco de dados de PINs"
	arr["RUSSIAN",414]="У вас не установлен curl. Невозможно загрузить файл базы данных PIN"
	arr["GREEK",414]="Το curl δεν είναι εγκατεστημένο. Είναι αδύνατον να κατέβει το αρχείο με την βάση δεδομένων PIN"
	arr["ITALIAN",414]="Non si dispone di curl installato. Non è possibile scaricare il file della base dati dei PINs"
	arr["POLISH",414]="Nie masz zainstalowanego curl. Nie można pobrać pliku bazy danych kodu PIN"
	arr["GERMAN",414]="Sie haben curl nicht installiert. Die PIN-Datenbank konnte nicht heruntergeladen werden"
	arr["TURKISH",414]="${pending_of_translation} Yüklü curl yok. PIN veritabanı dosyasını indirmek mümkün değil"

	arr["ENGLISH",415]="${blue_color}airgeddon knows you have BeEF installed and you pass the validation, but it was unable to locate the right directory path where you have BeEF installed. Knowing the location gives some advantages for the execution because its configuration file can be customized instead of generic. ${green_color}Do you want to enter it manually? ${normal_color}${visual_choice}"
	arr["SPANISH",415]="${blue_color}airgeddon sabe que tienes BeEF instalado y pasas la validación, pero no ha podido concretar la ruta del directorio exacto donde tienes instalado BeEF. Conocer la localización exacta tiene algunas ventajas a la hora de ejecutarlo ya que la configuración será personalizada en lugar de ser una configuración genérica. ${green_color}¿Quieres introducirla manualmente? ${normal_color}${visual_choice}"
	arr["FRENCH",415]="${blue_color}airgeddon a bien détecté que BeEF est installé mais il n'est malheuruesement pas possible de trouver le dossier le contenant. En l'état actuel des choses il ne sera pas possible de personaliser les parmétres d'éxécution de BeEF. ${green_color}Voulez-vous saisir l'emplacement du dossier? ${normal_color}${visual_choice}"
	arr["CATALAN",415]="${blue_color}airgeddon sap que tens BeEF instal·lat i passes la validació, però no ha pogut concretar la ruta del directori exacte on has instal·lat BeEF. Conèixer la localització exacta té alguns avantatges a l'hora d'executar ja que la configuració serà personalitzada en lloc de ser una configuració genèrica. ${green_color}¿Vols introduir-la manualment? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",415]="${blue_color}O airgeddon sabe que você instalou o BeEF e validou a instalação, mas não pôde encontrar o diretório exato onde você instalou o BeEF. Saber a localização exata tem algumas vantagens quando executá-lo a configuração será personalizada em vez de uma configuração genérica. ${green_color}Você quer inseri-la manualmente? ${normal_color}${visual_choice}"
	arr["RUSSIAN",415]="${blue_color}airgeddon знает, что у вас установлен BeEF и вы успешно прошли проверку, но скрипт оказался не в состоянии найти правильный путь к каталогу, где вы установили BeEF. Знание расположения даёт некоторые преимущества при выполнении, поскольку появляется возможность настроить его конфигурационный файл, а не использовать настройки по умолчанию. ${green_color}Вы хотите ввести расположение вручную? ${normal_color}${visual_choice}"
	arr["GREEK",415]="${blue_color}Το airgeddon γνωρίζει ότι έχετε εγκατεστημένο το BeEF και έχετε περάσει τους απαραίτητους ελέγχους, αλλά δεν μπόρεσε να εντοπίσει το σωστό μονοπάτι για τον κατάλογο όπου έχετε εγκαταστήσει το BeEF. Γνωρίζοντας το μονοπάτι για τον κατάλογο κάνει την διαδικασία της εκτέλεσης πλεονεκτική γιατί το αρχείο παραμέτρων μπορεί να ρυθμιστεί καταλλήλως, αντιθέτως με το προεπιλεγμένο. ${green_color}Θέλετε να το εισάγετε χειροκίνητα; ${normal_color}${visual_choice}"
	arr["ITALIAN",415]="${blue_color}airgeddon sa che hai BeEF installato e passi la validazione, peró non ha potuto trovare il percorso esatto della directory in cui hai installato BeEF. Conoscere l'esatta posizione ha alcuni vantaggi all'ora di eseguiro perchè la configurazione sarà personalizzata, piuttosto che una configurazione generica. ${green_color}Vuoi inserirla manualmente? ${normal_color}${visual_choice}"
	arr["POLISH",415]="${blue_color}airgeddon wie, że masz zainstalowaną wersję BeEF i przejdziesz walidację, ale nie możesz określić dokładnej ścieżki katalogu, w której zainstalowałeś BeEF. Znajomość dokładnej lokalizacji ma pewne zalety w czasie jej wykonywania, ponieważ konfiguracja zostanie dostosowana do indywidualnych potrzeb, a nie jako konfiguracja ogólna. ${green_color}Czy chcesz ją wprowadzić ręcznie? ${normal_color}${visual_choice}"
	arr["GERMAN",415]="${blue_color}airgeddon weiß, dass Sie BeEF installiert haben und Sie die Validierung bestehen, aber airgeddon konnte den genauen Verzeichnispfad, in den BeEF installiert ist, nicht angeben. Die genaue Position zu kennen, hat zum Zeitpunkt der Ausführung einige Vorteile, da die Konfiguration personalisiert wird, anstatt eine generische Konfiguration zu sein. ${green_color} Möchten Sie es manuell eingeben? ${normal_color}${visual_choice}"
	arr["TURKISH",415]="${pending_of_translation} ${blue_color}airgeddon, BeEF'in yüklü olduğunu ve doğrulama işlemini geçtiğinizi biliyor, ancak BeEF'in kurulu olduğu doğru dizin yolunu bulamadı. Konumun bilinmesi, yapılandırma dosyasının jenerik yerine özelleştirilebilmesi nedeniyle yürütme için bazı avantajlar sağlar. ${green_color} El ile girmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",416]="    You can run BeEF, but it is better if you run the second option before"
	arr["SPANISH",416]="    Puedes ejecutar BeEF, pero es recomendable ejecutar la segunda opción antes"
	arr["FRENCH",416]="    Vous pouvez exécuter BeEF mais il est recommandé d'exécuter préalablement la deuxième option"
	arr["CATALAN",416]="    Pots executar BeEF, però és recomanable executar la segona opció del menú abans"
	arr["PORTUGUESE",416]="    Você pode executar BeEF, mas é recomendado executar a segunda opção de menu antes"
	arr["RUSSIAN",416]="    Вы можете запустить BeEF, но лучше, если вы сначала запустите вторую опцию"
	arr["GREEK",416]="    Μπορείτε να εκτελέσετε το BeEF, αλλά είναι καλύτερα να διαλέξετε τη δεύτερη επιλογή από πρίν"
	arr["ITALIAN",416]="    Puoi eseguire BeEF, peró si consiglia di eseguire prima la seconda opzione"
	arr["POLISH",416]="    Możesz uruchomić BeEF, ale zaleca się uruchomienie drugiej opcji najpierw"
	arr["GERMAN",416]="     Sie können BeEF ausführen, es wird jedoch empfohlen, die zweite Option vorher auszuführen"
	arr["TURKISH",416]="${pending_of_translation}     BeEF'i çalıştırabilirsiniz, ancak daha önce ikinci seçeneği çalıştırırsanız daha iyi olur"

	arr["ENGLISH",417]="An unexpected error occurred, redirecting to the menu"
	arr["SPANISH",417]="Ocurrió un error inesperado. Volviendo al menú"
	arr["FRENCH",417]="Une erreur inattendue s'est produite, retour au menu"
	arr["CATALAN",417]="Hi ha hagut un error inesperat, redirigint al menú"
	arr["PORTUGUESE",417]="Ocorreu um erro inesperado, retornando ao menu"
	arr["RUSSIAN",417]="Случилась непредвиденная ошибка, перенаправление в меню"
	arr["GREEK",417]="Παρουσιάστηκε μη αναμενόμενο σφάλμα, γίνεται ανακατεύθυνση στο μενού"
	arr["ITALIAN",417]="Errore imprevisto. Tornando al menú"
	arr["POLISH",417]="Wystąpił nieoczekiwany błąd. Powrót do menu"
	arr["GERMAN",417]="Ein unerwarteter Fehler ist aufgetreten. Zurück zum Menü"
	arr["TURKISH",417]="${pending_of_translation} Menüye yönlendirme beklenmeyen bir hata oluştu"

	arr["ENGLISH",418]="Restoring MAC"
	arr["SPANISH",418]="Restaurando MAC"
	arr["FRENCH",418]="Rétablissement MAC"
	arr["CATALAN",418]="Restaurant MAC"
	arr["PORTUGUESE",418]="Restaurando MAC"
	arr["RUSSIAN",418]="Восстановление MAC-адреса"
	arr["GREEK",418]="Γίνεται αποκατάσταση της διεύθυνσης MAC"
	arr["ITALIAN",418]="Ripristinando MAC"
	arr["POLISH",418]="Przywracanie MAC"
	arr["GERMAN",418]="Wiederherstellen von MAC"
	arr["TURKISH",418]="${pending_of_translation} Geri yükleme MAC"

	arr["ENGLISH",419]="Do you want to spoof your MAC address during this attack? ${normal_color}${visual_choice}"
	arr["SPANISH",419]="¿Deseas falsear la dirección MAC de tu tarjeta durante el ataque? ${normal_color}${visual_choice}"
	arr["FRENCH",419]="Voulez-vous falsifier l'adresse MAC de votre carte pour l'attaque? ${normal_color}${visual_choice}"
	arr["CATALAN",419]="¿Vols falsejar l'adreça MAC de la targeta durant l'atac? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",419]="Você quer modificar o endereço MAC da sua interface durante o ataque? ${normal_color}${visual_choice}"
	arr["RUSSIAN",419]="Вы хотите подменить свой MAC-адрес во время этой атаки? ${normal_color}${visual_choice}"
	arr["GREEK",419]="Θέλετε να κρύψετε την αληθινή διεύθυνση MAC, δημιουργώντας μία ψεύτικη κατά την διάρκεια αυτής της επίθεσης; ${normal_color}${visual_choice}"
	arr["ITALIAN",419]="Vuoi falsificare l'indirizzo MAC della scheda durante l'attacco? ${normal_color}${visual_choice}"
	arr["POLISH",419]="Chcesz spoofować adres MAC karty podczas ataku? ${normal_color}${visual_choice}"
	arr["GERMAN",419]="Möchten Sie die MAC-Adresse Ihrer Karte während des Angriffs verfälschen? ${normal_color}${visual_choice}"
	arr["TURKISH",419]="${pending_of_translation} Bu saldırı sırasında MAC adresinizi taklit etmek ister misiniz? ${normal_color}${visual_choice}"

	arr["ENGLISH",420]="It has been detected that you are running airgeddon inside a Docker container. During this attack hostapd is used to create a fake AP. This component often conflicts with network-manager. From inside the container, airgeddon can't handle it. If you have network-manager installed on your host machine, close it or kill the conflicting processes or you'll get an error. For more information, see the Docker section of the Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["SPANISH",420]="Se ha detectado que estás ejecutando airgeddon en un contenedor de Docker. En este ataque se utiliza hostapd para crear un falso AP. Este componente suele dar conflicto con network-manager. Desde el contenedor, airgeddon no puede gestionarlo. Si tienes network-manager instalado en tu máquina host, ciérralo o mata los procesos en conflicto u obtendrás un error. Para más información consulta la sección Docker del Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["FRENCH",420]="Il a été détecté qu'airgeddon a été lancé depuis un conteneur Docker. Cette attaque à besoin d'hostapd pour créer un Point d'Accès piège. Hostapd a tendance à entrer en conflit avec network-manager et airgeddon ne peut pas le gérer depuis le conteneur. Si network-manager est installé sur votre machine host, arrêtez ou tuez les processus conflictuels. Dans le cas contraire vous obtiendrez une erreur. Pour plus d'informations, consultez la section Docker de notre Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["CATALAN",420]="S'ha detectat que estàs executant airgeddon en un contenidor de Docker. En aquest atac s'utilitza hostapd per crear un fals AP. Aquest component sol donar conflicte amb network-manager. Des del contenidor, airgeddon no pot gestionar-lo. Si tens network-manager instal·lat a la teua màquina host, tanca'l o mata els processos en conflicte u obtindràs un error. Per a més informació consulta la secció Docker del Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["PORTUGUESE",420]="Detectamos que você está executando airgeddon em um contêiner Docker. Neste ataque é usado hostapd para criar um AP falso. Este componente tende a entrar em conflito com network-manager. A partir do contêiner o airgeddon não pode controlá-lo. Se você tem network-manager instalado em sua máquina host feche-o, mate os processos conflitantes ou você irá obter um erro. Para mais informações consulte a seção Docker Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["RUSSIAN",420]="Определено, что вы запускаете airgeddon внутри контейнера Docker. Во время этой атаки для создания поддельной AP используется hostapd. Этот компонент часто конфликтует с network-manager. Изнутри контейнера airgeddon не может справиться с этим. Если на вашем хост-компьютере установлен network-manager, закройте его или уберите конфликтующие процессы, иначе вы получите сообщение об ошибке. Для получения дополнительной информации см. раздел Docker в Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["GREEK",420]="Εντοπίστηκε πως τρέχετε το airgeddon μέσα σε Docker container. Κατά τη διάρκεια αυτής της επίθεσης χρησιμοποιείται το hostapd για να δημιουργήσει ψεύτικο AP. Η δημιουργία αυτού κάνει conflicts με τον network-manager. Το airgeddon δεν μπορεί να το χειριστεί μέσα από το container. Αν υπάρχει ο network-manager εγκατεστημένος στον host-υπολογιστή, κλείστε τον ή διακόψτε τις διεργασίες που κάνουν conflict αλλιώς θα υπάρξουν σφάλματα. Για περισσότερες πληροφορίες, ανατρέξτε στην ενότητα Docker του Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["ITALIAN",420]="È stato rilevato che si sta eseguendo airgeddon in un contenitore Docker. In questo attacco viene utilizzato hostapd per creare un falso AP. Questo componente tende a creare un conflitto con il network-manager. Dal contenitore, airgeddon non può gestirlo. Se si dispone di network-manager installato sul computer host, chiuderlo o uccidere i processi in conflitto o ci sará un errore. Per ulteriori informazioni consultare la sezione Docker della nostra Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["POLISH",420]="Wykryto, że używasz airgeddon w kontenerze Docker. W tym ataku hostapd służy do utworzenia fałszywego AP. Ten komponent często ma konflikt z network-manager. Z kontenera airgeddon nie może sobie z tym poradzić. Jeśli na komputerze hosta zainstalowano network-manager, zamknij lub zabij sprzeczne procesy lub otrzymasz błąd. Aby uzyskać więcej informacji, zobacz sekcję Docker Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["GERMAN",420]="Es wurde festgestellt, dass Sie airgeddon in einem Docker-Container ausführen. Bei diesem Angriff wird mit hostapd ein falscher AP erstellt. Diese Komponente steht normalerweise im Konflikt mit dem network-manager. Aus dem Container kann airgeddon das nicht schaffen. Wenn Sie den network-manager auf Ihrem Host-Computer installiert haben, schließen Sie ihn oder beenden Sie die Prozesse im Konflikt oder Sie erhalten einen Fehler. Weitere Informationen finden Sie im Abschnitt Docker des Wiki: ${normal_color}${urlgithub_wiki}/Docker"
	arr["TURKISH",420]="${pending_of_translation} Bir Docker kabının içinde airgeddon çalıştırdığınız tespit edildi. Bu saldırı sırasında hostapd sahte bir AP oluşturmak için kullanılır. Bu bileşen genellikle ağ yöneticisi ile çakışır. Konteynırın içinden, hava hücresi bunu kaldıramaz. Ana makinenize ağ yöneticisi yüklüyse, kapat veya çakışan işlemleri durdurun veya bir hatayla karşılaşırsınız. Daha fazla bilgi için, Wiki'nin Docker bölümüne bakın: ${normal_color}${urlgithub_wiki}/Docker"

	arr["ENGLISH",421]="Doubts? Visit our Wiki: ${normal_color}${urlgithub_wiki}"
	arr["SPANISH",421]="¿Dudas? Visita nuestro Wiki: ${normal_color}${urlgithub_wiki}"
	arr["FRENCH",421]="Des questions? Visitez notre Wiki: ${normal_color}${urlgithub_wiki}"
	arr["CATALAN",421]="¿Dubtes? Visita el nostre Wiki: ${normal_color}${urlgithub_wiki}"
	arr["PORTUGUESE",421]="Dúvidas? Visite a Wiki: ${normal_color}${urlgithub_wiki}"
	arr["RUSSIAN",421]="Вопросы? Посетите Wiki: ${normal_color}${urlgithub_wiki}"
	arr["GREEK",421]="Απορίες; Επισκεφθείτε το Wiki μας: ${normal_color}${urlgithub_wiki}"
	arr["ITALIAN",421]="Domande? Visita la nostra Wiki: ${normal_color}${urlgithub_wiki}"
	arr["POLISH",421]="Czy masz wątpliwości? Odwiedź nasze Wiki: ${normal_color}${urlgithub_wiki}"
	arr["GERMAN",421]="Zweifel? Besuchen Sie unser Wiki: ${normal_color}${urlgithub_wiki}"
	arr["TURKISH",421]="${pending_of_translation} Şüpheler? Wiki'mizi ziyaret edin: ${normal_color}${urlgithub_wiki}"

	arr["ENGLISH",422]="The automatic update has been disabled when airgeddon is running in a Docker container. If you want to update it, download again the image tagged as \"latest\""
	arr["SPANISH",422]="La actualización automática se ha desactivado cuando airgeddon se ejecuta en un contenedor de Docker. Si deseas actualizarlo descarga de nuevo la imagen con tag \"latest\""
	arr["FRENCH",422]="La mise à jour automatique est désactivée si airgeddon s'exécute depuis un conteneur Docker. Si vous voulez le mettre à jour vous devez télécharger l'image avec le label \"latest\""
	arr["CATALAN",422]="L'actualització automàtica s'ha desactivat quan airgeddon s'executa en un contenidor de Docker. Si vols actualitzar-lo descàrrega de nou la imatge amb tag \"latest\""
	arr["PORTUGUESE",422]="A atualização automática é desativada quando airgeddon é executado em um contêiner Docker. Se você quiser atualizar faça o download novamente da imagem em \"latest\""
	arr["RUSSIAN",422]="Когда airgeddon работает в контейнере Docker, то автоматическое обновление отключено,. Если вы хотите обновить программу, то снова загрузите образ отмеченный как \"latest\""
	arr["GREEK",422]="Η διαδικασία της αυτόματης ενημέρωσης είναι απενεργοποιημένη όταν το airgeddon τρέχει σε Docker container. Εάν θέλετε να το ενημερώσετε, κατεβάστε ξανά το αρχείο με την ετικέτα \"latest\""
	arr["ITALIAN",422]="L'aggiornamento automatico viene disabilitato quando airgeddon viene eseguito in un contenitore Docker. Se vuoi aggiornarlo scaricare di nuovo l'immagine con il tag \"latest\""
	arr["POLISH",422]="Automatyczna aktualizacja została wyłączona, gdy airgeddon jest uruchomiony w kontenerze Docker. Jeśli chcesz go zaktualizować, pobierz ponownie obraz oznaczony jako \"latest\""
	arr["GERMAN",422]="Die automatische Aktualisierung wird deaktiviert, wenn airgeddon in einem Docker-Container ausgeführt wird. Wenn Sie es aktualisieren möchten, laden Sie das Bild erneut mit dem Tag \"latest\""
	arr["TURKISH",422]="${pending_of_translation} Airgeddon bir Docker konteynerinde çalışırken otomatik güncelleme devre dışı bırakıldı. Güncellemek isterseniz, \"latest\" etiketli görüntüyü tekrar indirin"

	arr["ENGLISH",423]="5.  WEP \"All-in-One\" attack"
	arr["SPANISH",423]="5.  Ataque WEP \"Todo-en-Uno\""
	arr["FRENCH",423]="5.  Attaque WEP \"Tout-en-Un\""
	arr["CATALAN",423]="5.  Atac WEP \"Tot-en-Un\""
	arr["PORTUGUESE",423]="5.  Ataque WEP \"Tudo-em-Um\""
	arr["RUSSIAN",423]="5.  Атака на WEP \"Все-в-Одном\""
	arr["GREEK",423]="5.  Επίθεση WEP \"All-in-One\""
	arr["ITALIAN",423]="5.  Attacco WEP \"Tutto-in-Uno\""
	arr["POLISH",423]="5.  Atak WEP \"Wszystko-w-Jednym\""
	arr["GERMAN",423]="5.  WEP-Angriff \"All-in-One\""
	arr["TURKISH",423]="${pending_of_translation} 5.  WEP \"All-in-One\" saldırı"

	arr["ENGLISH",424]="The selected network is invalid. Encryption type of target network must be WEP"
	arr["SPANISH",424]="La red seleccionada no es válida. El tipo de encriptación de la red objetivo debe ser WEP"
	arr["FRENCH",424]="Le réseau sélectionné est invalide . Le réseau cible doit être en WEP"
	arr["CATALAN",424]="La xarxa seleccionada no és vàlida. El tipus d'encriptació de la xarxa objectiu ha de ser WEP"
	arr["PORTUGUESE",424]="A rede selecionada é inválida. O tipo de criptografia da rede deve ser WEP"
	arr["RUSSIAN",424]="Выбранная сеть не подходит. Целевая сеть должна иметь шифрование WEP"
	arr["GREEK",424]="Το επιλεγμένο δίκτυο δεν είναι έγκυρο. Ο τύπος κρυπτογράφησης του δικτύου-στόχος πρέπει να είναι WEP"
	arr["ITALIAN",424]="La rete selezionata non è valida. Il tipo di crittografia della rete obiettivo deve essere WEP"
	arr["POLISH",424]="Wybrana sieć nie jest prawidłowa. Typem szyfrowania sieci docelowej musi być WEP"
	arr["GERMAN",424]="Das ausgewählte Netzwerk ist nicht gültig. Die Art der Verschlüsselung des Zielnetzwerks muss WEP sein"
	arr["TURKISH",424]="${pending_of_translation} Seçilen ağ geçersiz. Hedef ağ şifreleme türü WEP olmalıdır"

	arr["ENGLISH",425]="You have a valid WEP target network selected. Script can continue..."
	arr["SPANISH",425]="Tienes una red objetivo WEP válida seleccionada. El script puede continuar..."
	arr["FRENCH",425]="Choix du réseau cible WEP valide. Le script peut continuer..."
	arr["CATALAN",425]="Tens una xarxa objectiu WEP vàlida seleccionada. El script pot continuar..."
	arr["PORTUGUESE",425]="Você tem uma rede WEP válida selecionada. O script pode continuar..."
	arr["RUSSIAN",425]="У вас есть подходящая целевая сеть WEP. Скрипт может продолжать..."
	arr["GREEK",425]="Έχετε επιλέξει ένα έγκυρο WEP δίκτυο-στόχος. Το script μπορεί να συνεχίσει..."
	arr["ITALIAN",425]="Hai selezionato una rete obiettivo WEP valida. Lo script può continuare..."
	arr["POLISH",425]="Wybrano prawidłową sieć docelową WEP. Skrypt może kontynuować..."
	arr["GERMAN",425]="Sie haben ein gültiges WEP-Zielnetzwerk ausgewählt. Das Skript kann fortfahren..."
	arr["TURKISH",425]="${pending_of_translation} Seçtiğiniz geçerli bir WEP hedef ağınız var. Komut dosyası devam edebilir..."

	arr["ENGLISH",426]="9.  WEP attacks menu"
	arr["SPANISH",426]="9.  Menú de ataques WEP"
	arr["FRENCH",426]="9.  Menu d'attaques WEP"
	arr["CATALAN",426]="9.  Menú d'atacs WEP"
	arr["PORTUGUESE",426]="9.  Menu de ataques WEP"
	arr["RUSSIAN",426]="9.  Меню атак на WEP"
	arr["GREEK",426]="9.  Μενού επιθέσεων WEP"
	arr["ITALIAN",426]="9.  Menú degli attacchi WEP"
	arr["POLISH",426]="9.  Menu ataków WEP"
	arr["GERMAN",426]="9.  WEP-Angriffsmenü"
	arr["TURKISH",426]="9.  WEP saldırı menüsü"

	arr["ENGLISH",427]="WEP attacks menu"
	arr["SPANISH",427]="Menú de ataques WEP"
	arr["FRENCH",427]="Menu d'attaques WEP"
	arr["CATALAN",427]="Menú d'atacs WEP"
	arr["PORTUGUESE",427]="Menu de ataques WEP"
	arr["RUSSIAN",427]="Меню атак на WEP"
	arr["GREEK",427]="Μενού επιθέσεων WEP"
	arr["ITALIAN",427]="Menú degli attacchi WEP"
	arr["POLISH",427]="Menu ataków WEP"
	arr["GERMAN",427]="WEP-Angriffsmenü"
	arr["TURKISH",427]="WEP saldırı menüsü"

	arr["ENGLISH",428]="If real clients exist connected to the WEP encrypted network, the process will be significantly accelerated. Enough IVs (Initialization Vectors) will be catched faster"
	arr["SPANISH",428]="Si existen clientes reales conectados a la red con encriptación WEP, el proceso se acelerará notablemente. Se obtendrán antes suficientes IVs (Vectores de Inicialización)"
	arr["FRENCH",428]="Si des clients légitimes sont connectés à un rseau WEP le processus ira plus vite. Les Ivs requis (vecteurs d'incitiaisation) seront plus vite obtenus"
	arr["CATALAN",428]="Si hi ha clients reals connectats a la xarxa amb encriptació WEP, el procés s'accelerarà notablement. S'obtindran abans suficients IVs (Vectors d'Inicialització)"
	arr["PORTUGUESE",428]="Se clientes reais estiverem conectados à rede com criptografia WEP, o processo será acelerado significativamente. Serão obtidos IVs (Vetores de Inicialização) mais rapidamente"
	arr["RUSSIAN",428]="Если к сети с WEP шифрованием подключены реальные клиенты, то процесс будет значительно ускорен. Будет быстрее накоплено достаточное количество IVs (Векторов Инициализации)"
	arr["GREEK",428]="Εάν υπάρχουν αληθινοί συνδεδεμένοι χρήστες στο κρυπτογραφημένο WEP δίκτυο, η διαδικασία θα επιταχυνθεί σημαντικά. Θα καταγραφθούν αρκετά IVs (Initialization Vectors) γρηγορότερα"
	arr["ITALIAN",428]="Se esistono dei clienti reali connessi alla rete con crittografia WEP il processo sará piú veloce. Si otterrano prima sufficienti IV (Vettori di Inizializzazione)"
	arr["POLISH",428]="Jeśli istnieją prawdziwi klienci podłączeni do sieci z szyfrowaniem WEP, proces przyspiesza zauważalnie. Szybciej uzyskane zostaną wystarczające IVs (Wektory Inicjujące)"
	arr["GERMAN",428]="Wenn echte Clients über die WEP-Verschlüsselung mit dem Netzwerk verbunden sind, beschleunigt sich der Prozess erheblich. Ausreichende IVs werden vorher erhalten (InitialisierungsVektoren)"
	arr["TURKISH",428]="${pending_of_translation} Gerçek istemciler WEP şifreli ağa bağlıysa, süreç önemli ölçüde hızlandırılacaktır. Yeterli İV'ler (Başlatma Vektörleri) daha hızlı yakalanacak"

	arr["ENGLISH",429]="The WEP \"All-in-One\" attack combines different techniques to generate enough traffic to decrypt the key (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentation, Fake association, etc.)"
	arr["SPANISH",429]="El ataque WEP \"Todo-en-Uno\" combina diversas técnicas para generar el tráfico suficiente que hace falta para desencriptar la clave (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentación, Falsa asociación, etc.)"
	arr["FRENCH",429]="L'attaque WEP \"Tout-en-Un\" combine plusieurs techniques pour générer le trafic nécessaire au décryptage de la clef (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentation, Fausse association, etc.)"
	arr["CATALAN",429]="L'atac WEP \"Tot-en-Un\" combina diverses tècniques per generar el trànsit suficient que cal per desxifrar la clau (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentació, Falsa associació, etc.)"
	arr["PORTUGUESE",429]="O ataque WEP \"Tudo-em-Um\" combina várias técnicas para gerar tráfego suficiente que é necessário para desencriptar a chave (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentação, Falsa associação, etc.)"
	arr["RUSSIAN",429]="Атака WEP \"Все-в-Одном\" сочетает в себе различные методы генерации трафика, достаточного для расшифровки ключа (Caffe Latte, Hirte, Replay, Chop-Chop, Дробление, Фальшивые ассоциации и т.д.)"
	arr["GREEK",429]="Η \"All-in-One\" επίθεση WEP συνδυάζει διαφορετικές τεχνικές για να παραχθεί αρκετή κίνηση για να αποκρυπτογραφήσει το κλειδί (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentation, Fake association, κλπ)"
	arr["ITALIAN",429]="L'attacco WEP \"Tutto-in-Uno\" combina diverse tecniche per generare il traffico necessario per decifrare la chiave (Caffe Latte, Hirte, Replay, Chop-Chop, Frammentazione, Falsa associazione, etc.)"
	arr["POLISH",429]="WEP typu \"Wszystko-w-Jednym\" łączy różne techniki, aby uzyskać wystarczająco dużo ruchu, aby odszyfrować klucz (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentation, Fałszywe asocjacja, itd.)"
	arr["GERMAN",429]="Der WEP-Angriff \"All-in-One\" kombiniert verschiedene Techniken, um genug Verkehr zu erzeugen, um den Schlüssel zu entschlüsseln (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentierung, falsche Assoziation, etc.)"
	arr["TURKISH",429]="${pending_of_translation} WEP \"All-in-One\" saldırısı, anahtarın şifresini çözmek için yeterli teknikleri üretmek için farklı teknikleri birleştirir (Caffe Latte, Hirte, Replay, Chop-Chop, Fragmentation, Fake association, vb.)"

	arr["ENGLISH",430]="If the password for the wifi network is obtained with the \"All-in-One\" WEP attack, you should decide where to save it. ${green_color}Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${wep_potpath}]"
	arr["SPANISH",430]="Si se consigue la contraseña de la red wifi con el ataque WEP \"Todo-en-Uno\", hay que decidir donde guardarla. ${green_color}Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${wep_potpath}]"
	arr["FRENCH",430]="Si le mot de passe est obtenu par une attaque WEP \"Tout-en-Un\", il faut ensuite indiquer l'endroit pour la garder. ${green_color}Entrez la route vers l'endroit où vous voulez garder le fichier ou bien appuyez sur [Enter] si la route proposée par défaut vous convient ${normal_color}[${wep_potpath}]"
	arr["CATALAN",430]="Si s'aconsegueix la contrasenya de la xarxa wifi amb l'atac WEP \"Tot-en-Un\", cal decidir on guardar-la. ${green_color}Escriu la ruta on guardarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${wep_potpath}]"
	arr["PORTUGUESE",430]="Se a senha da rede wifi for obtida com o ataque WEP \"Tudo-em-Um\", onde deseja salvá-la?. ${green_color}Digite o caminho onde armazenar o arquivo ou pressione [Enter] para aceitar o padrão ${normal_color}[${wep_potpath}]"
	arr["RUSSIAN",430]="Если во время WEP атаки \"Все-в-Одном\" на Wi-Fi сеть получен пароль, вы должны решить, где его сохранить. ${green_color} Наберите путь для сохранения файла или нажмите [Enter] для принятия значения по умолчанию ${normal_color}[${wep_potpath}]"
	arr["GREEK",430]="Εάν βρεθεί ο κωδικός πρόσβασης για το ασύρματο δίκτυο με την επίθεση WEP \"All-in-One\", θα πρέπει να αποφασίσετε που θα τον αποθηκεύσετε. ${green_color}Πληκτρολογήστε το μονοπάτι για την αποθήκευση του αρχείου ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${wep_potpath}]"
	arr["ITALIAN",430]="Se si ottiene la password della rete wireless con l'attacco WEP \"Tutto-en-Uno\", decidere dove salvarla. ${green_color}Immettere il percorso dove memorizzare il file o premere [Enter] per accettare la proposta di default ${normal_color}[${wep_potpath}]"
	arr["POLISH",430]="Jeśli hasło sieci wifi zostanie zdobyte atakiem WEP \"Wszystko-w-Jednym\", musisz zdecydować, gdzie je zapisać. ${green_color}Wpisz ścieżkę, w której będziemy zapisywać plik lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${wep_potpath}]"
	arr["GERMAN",430]="Wenn Sie das WLAN-Passwort mit dem WEP-Angriff \"All-in-One\" erhalten, müssen Sie entscheiden, wo Sie es speichern möchten. ${green_color} Geben Sie den Pfad ein, unter dem die Datei gespeichert werden soll, oder drücken Sie die [Enter]-Taste, um den Standardvorschlag ${normal_color}[${wep_potpath}] ${blue_color}zu akzeptieren"
	arr["TURKISH",430]="${pending_of_translation} Kablosuz ağın şifresi \"All-in-One\" WEP saldırısıyla elde edilirse, nereye kaydedeceğinize karar vermelisiniz. ${green_color}Dosyayı depolamak için yolu yazın veya varsayılan teklifi kabul etmek için [Enter] tuşuna basın ${normal_color}[${wep_potpath}]"

	arr["ENGLISH",431]="The WEP protocol had a bad design and can be cracked in a few minutes if we have enough generated traffic"
	arr["SPANISH",431]="El protocolo WEP tuvo un diseño erróneo y se puede romper en pocos minutos si se genera tráfico suficiente"
	arr["FRENCH",431]="Le protocole WEP n'est pas sûr et peut se déchiffrer en quelques minutes si suffisamment de trafic est généré"
	arr["CATALAN",431]="El protocol WEP va tindre un disseny erroni i es pot trencar en pocs minuts si es genera trànsit suficient"
	arr["PORTUGUESE",431]="O protocolo WEP é um projeto falho e pode ser quebrado em poucos minutos se tivermos tráfego suficiente"
	arr["RUSSIAN",431]="Протокол WEP сделан неудачно и при достаточном количестве сгенерированного трафика может быть взломан в считанные минуты"
	arr["GREEK",431]="Το πρωτόκολλο WEP είχε κακό σχεδιασμό και μπορεί να σπάσει μέσα σε λίγα λεπτά, αν έχουμε αρκετή κίνηση πακέτων"
	arr["ITALIAN",431]="Il protocollo WEP fú disegnato male e si puó rompere in pochi minuti se si genera abbastanza traffico"
	arr["POLISH",431]="Protokół WEP został nieprawidłowo zaprojektowany i może zostać złamany po kilku minutach, jeśli zostanie wygenerowany wystarczający ruch"
	arr["GERMAN",431]="Das WEP-Protokoll hatte ein falsches Design und kann in wenigen Minuten unterbrochen werden, wenn genügend Datenverkehr generiert wird"
	arr["TURKISH",431]="${pending_of_translation} WEP protokolü kötü bir tasarıma sahipti ve yeterli sayıda trafiğe sahip olmamız durumunda birkaç dakika içinde çatlayabiliriz"

	arr["ENGLISH",432]="Captured IVs (Initialization Vectors) are shown on airodump capture window as \"Data\""
	arr["SPANISH",432]="Los IVs (Vectores de Inicialización) capturados, son representados en la ventana de captura de airodump como \"Data\""
	arr["FRENCH",432]="Les IVs (Vecteurs de Initialisation) capturés sont reportés dans la colomne \"Data\" de la console airodump-ng"
	arr["CATALAN",432]="Els IVs (Vectors d'Inicialització) capturats, són representats en la finestra de captura de airodump com \"Data\""
	arr["PORTUGUESE",432]="Os IVs (Vetores de Inicialização) capturados, são representados na captura de janela airodump como \"Data\""
	arr["RUSSIAN",432]="Захваченные IVs (Векторы Инициализации) показаны в окне захвата airodump как \"Data\""
	arr["GREEK",432]="Τα ληφθέντα IVs (Initialization Vectors) εμφανίζονται στο παράθυρο καταγραφής airodump ως \"Data\""
	arr["ITALIAN",432]="I IV (Vettori di Inizializzazione) catturati, sono rappresentati nella finestra di acquisizione di airodump come \"Data\""
	arr["POLISH",432]="Uchwycone obiekty IV (Wektory Inicjujące) są prezentowane w oknie przechwytywania airodump jako \"Data\""
	arr["GERMAN",432]="Die erfassten IVs (InitialisierungsVektoren) werden im Erfassungsfenster von airodump als \"Data\" dargestellt"
	arr["TURKISH",432]="${pending_of_translation} Yakalanan IV'ler (Başlatma Vektörleri) airodump yakalama penceresinde \"Data\" olarak gösterilir"

	arr["ENGLISH",433]="Some access points are not vulnerable to certain WEP attacks. Like for example the Chop-Chop attack, that only affects some of them"
	arr["SPANISH",433]="Algunos puntos de acceso no son vulnerables a ciertos ataques WEP. Como por ejemplo el ataque Chop-Chop, que solo afecta a algunos"
	arr["FRENCH",433]="Certains points d'accès ne sont pas vulnérables à certaines attaques WEP. Comme par example l'attaque Chop-Chop qui affecte seulement à certains Point d'Accès"
	arr["CATALAN",433]="Alguns punts d'accés no són vulnerables a certs atacs WEP. Com per exemple l'atac Chop-Chop, que només afecta alguns"
	arr["PORTUGUESE",433]="Alguns pontos de acesso não são vulneráveis a certos ataques WEP. Como por exemplo o ataque Chop-Chop, que só afeta alguns"
	arr["RUSSIAN",433]="Некоторые точки доступа не подвержены определенным атакам WEP. Например, атаке Chop-Chop подвержены только некоторые из них"
	arr["GREEK",433]="Ορισμένα σημεία πρόσβασης δεν είναι ευάλωτα σε ορισμένες επιθέσεις WEP. Για παράδειγμα η επίθεση Chop-Chop, επηρεάζει μόνο μερικά από αυτά"
	arr["ITALIAN",433]="Alcuni punti di accesso non sono vulnerabili a certi attacchi WEP. Come ad esempio l'attacco Chop-Chop, che colpisce solo alcuni"
	arr["POLISH",433]="Niektóre punkty dostępu nie są podatne na niektóre ataki WEP. Na przykład atak Chop-Chop, który dotyka tylko niektórych osób"
	arr["GERMAN",433]="Einige Access Points sind nicht anfällig für bestimmte WEP-Angriffe. Zum Beispiel der Chop-Chop-Angriff, der nur einige betrifft"
	arr["TURKISH",433]="${pending_of_translation} Bazı erişim noktaları belirli WEP saldırılarına karşı savunmasız değildir. Örneğin Chop-Chop saldırısı gibi, sadece bazılarını etkiler"

	arr["ENGLISH",434]="WEP \"All-in-One\" attack has been started. Press [Enter] key on this window to stop it"
	arr["SPANISH",434]="El ataque WEP \"Todo-en-Uno\" ha comenzado. Pulse la tecla [Enter] en esta ventana para pararlo"
	arr["FRENCH",434]="L'attaque WEP \"Tout-en-Un\" a commencé. Pressez la touche [Enter] dans cette console pour l'arrêter"
	arr["CATALAN",434]="L'atac WEP \"Tot-en-Un\" ha començat. Prem [Enter] a aquesta finestra per aturar-lo"
	arr["PORTUGUESE",434]="Ataque WEP \"Tudo-em-Um\" iniciado. Pressione a tecla [Enter] nesta janela para parar"
	arr["RUSSIAN",434]="Атака WEP \"Все-в-Одном\" началась. Для её остановки клавишу [Enter] в этом окне"
	arr["GREEK",434]="Η επίθεση WEP \"All-in-One\" έχει αρχίσει. Πατήστε το κουμπί [Enter] σε αυτό το παράθυρο για να την σταματήσετε"
	arr["ITALIAN",434]="L'attacco WEP \"Tutto-in-Uno\" è iniziato. Premere il tasto [Enter] in questa finestra per fermarlo"
	arr["POLISH",434]="Rozpoczął się atak WEP \"Wszystko-w-Jednym\". Naciśnij klawisz [Enter] w tym oknie, aby go zatrzymać"
	arr["GERMAN",434]="Der WEP-Angriff \"All-in-One\" hat begonnen. Drücken Sie die [Enter]-Taste in diesem Fenster, um sie zu stoppen"
	arr["TURKISH",434]="${pending_of_translation} WEP \"All-in-One\" saldırı başlatıldı. Bunu durdurmak için bu pencerede [Enter] tuşuna basın"

	arr["ENGLISH",435]="Error trying to change interface mode. During the process the interface name must be changed, but it looks like you already have an interface occupying the name that would be needed (${normal_color}${desired_interface_name}${red_color})"
	arr["SPANISH",435]="Error al intentar cambiar el modo de la interfaz. En el proceso el nombre de la interfaz cambia, pero parece que ya tienes una interfaz ocupando el nombre que se necesitaría (${normal_color}${desired_interface_name}${red_color})"
	arr["FRENCH",435]="Une erreur est survenue lors de la tentative de changement du mode de l'interface. L'identifiant de l'interface est changé pendant le processus mais il semble que l'identifiant prévu n'est plus disponible car il est déjà utilisé par une autre interface (${normal_color}${desired_interface_name}${red_color})"
	arr["CATALAN",435]="Error en intentar canviar el mode de la interfície. En el procés el nom de la interfície canvia, però sembla que ja tens una interfície ocupant el nom que es necessitaria (${normal_color}${desired_interface_name}${red_color})"
	arr["PORTUGUESE",435]="Erro ao tentar alterar o modo da interface. No processo o nome da interface muda, mas parece que já há uma interface ocupando o mesmo nome (${normal_color}${desired_interface_name}${red_color})"
	arr["RUSSIAN",435]="Ошибка при попытке изменить режим интерфейса. Во время этого процесса имя интерфейса должно быть изменено, но похоже, что у вас уже есть интерфейс, занимающий нужное имя (${normal_color}${desired_interface_name}${red_color})"
	arr["GREEK",435]="Προέκυψε σφάλμα καθώς άλλαζε η κατάσταση της διεπαφής. Κατά τη διάρκεια της διαδικασίας, το όνομα της διεπαφής πρέπει να αλλάξει, αλλά φαίνεται ότι έχετε ήδη μια διεπαφή που έχει το όνομα που θα χρειαζόταν (${normal_color}${desired_interface_name}${red_color})"
	arr["ITALIAN",435]="Errore cercando di cambiare la modalità dell'interfaccia. Nel processo il nome dell'interfaccia cambia, peró sembra che già disponi di un'interfaccia che usa il nome di cui avresti bisogno (${normal_color}${desired_interface_name}${red_color})"
	arr["POLISH",435]="Wystąpił błąd podczas próby zmiany trybu interfejsu. Wymaga to zmiany jego nazwy, ale wygląda jednak na to, że masz już interfejs o nazwie, która będzie potrzebna (${normal_color}${desired_interface_name}${red_color})"
	arr["GERMAN",435]="Fehler beim Versuch, den Modus der Interface zu ändern. Dabei ändert sich der Name der Interface, aber es scheint, dass Sie bereits eine Interface haben, die den Namen belegt, der benötigt ist (${normal_color}${desired_interface_name}${red_color})"
	arr["TURKISH",435]="${pending_of_translation} Arabirim modunu değiştirmeye çalışırken hata oluştu. İşlem sırasında arabirim adı değiştirilmeli, ancak gerekli olan adı taşıyan bir arabirime sahip olduğunuz anlaşılıyor (${normal_color}${desired_interface_name}${red_color})"

	arr["ENGLISH",436]="The hashcat version you have installed (${hashcat_version}) is greater or equal than ${hashcat_hccapx_version} so you need to convert the capture files to \"hccapx\" format, airgeddon will do this automatically. To do this you need a converter that is not present on your system (hashcat-utils package), install it to be able to perform this attack"
	arr["SPANISH",436]="La versión de hashcat que tienes instalada (${hashcat_version}) es igual o superior a la ${hashcat_hccapx_version} por lo que es necesario convertir los ficheros de captura a formato \"hccapx\", airgeddon lo hará automáticamente. Pero para ello hace falta un conversor que no está presente en tu sistema (paquete hashcat-utils), instálalo para poder realizar este ataque"
	arr["FRENCH",436]="La Version d'hashcat installée (${hashcat_version}) est égale ou supérieure à la version ${hashcat_hccapx_version}. Il est nécessaire dans ce cas de convertir les captures au format \"hccapx\", ce que fera automatiquement airgeddon. Il faut pour cela un convertisseur qui n'est pas installé dans votre système (paquet hashcat-utils). Veuilez l'installer pour effectuer cette attaque"
	arr["CATALAN",436]="La versió de hashcat que tens instal·lada (${hashcat_version}) és igual o superior a la ${hashcat_hccapx_version} pel que cal convertir els fitxers de captura a format \"hccapx\", airgeddon ho farà automàticament. Però per a això cal un convertidor que no està present al sistema (paquet hashcat-utils), instal·lal per poder realitzar aquest atac"
	arr["PORTUGUESE",436]="A versão do hashcat instalada (${hashcat_version}) é maior ou igual a ${hashcat_hccapx_version}, portanto é necessário convertermos o arquivo de captura para o formato \"hccapx\", airgeddon fará isso automaticamente. Mas isso requer um conversor que não está instalado no seu sistema (pacote hashcat-utils), instale-o para realizar este ataque"
	arr["RUSSIAN",436]="Установленная версия hashcat (${hashcat_version}) больше или равна ${hashcat_hccapx_version}, поэтому вам нужно конвертировать файлы захвата в формат \"hccapx\", airgeddon сделает это автоматически. Для этого вам нужен конвертер, которого нет в вашей системе (пакет hashcat-utils), установите его, чтобы иметь возможность выполнить эту атаку"
	arr["GREEK",436]="Η έκδοση του hashcat που έχετε εγκαταστήσει (${hashcat_version}) είναι ίδια ή νεότερη από την έκδοση ${hashcat_hccapx_version}, άρα το airgeddon θα μετατρέψει τα αρχεία καταγραφής σε \"hccapx\" για να συνεχιστεί η διαδικασία. Για να επιτευχθεί αυτό χρειάζεστε ένα μετατροπέα που δεν υπάρχει στο σύστημά σας (περιέχεται στο πακέτο hashcat-utils), εγκαταστήστε το για να εκτελέσετε αυτήν την επίθεση"
	arr["ITALIAN",436]="La versione di hashcat installata (${hashcat_version}) è uguale o superiore alla ${hashcat_hccapx_version} quindi è necessario convertire i file di acquisizione al formato \"hccapx\", airgeddon lo fará automaticamente. Peró questo richiede un convertitore che non è presente nel sistema (pacchetto hashcat-utils), installalo per eseguire questo attacco"
	arr["POLISH",436]="Zainstalowana wersja programu hashcat (${hashcat_version}) jest równa lub większa niż ${hashcat_hccapx_version}, dlatego konieczne jest przekonwertowanie plików przechwytywania do formatu \"hccapx\", airgeddon zrobi to automatycznie. Do tego potrzebny jest konwerter, który nie jest obecny w systemie (pakiet hashcat-utils), zainstaluj go, aby móc wykonać ten atak"
	arr["GERMAN",436]="Ihre installierte hashcat-Version (${hashcat_version}) ist gleich oder größer als ${hashcat_hccapx_version}. Daher ist es notwendig, die Capture-Dateien in das Format \"hccapx\" zu konvertieren. airgeddon macht das automatisch. Dafür benötigen Sie einen Konverter, der nicht in Ihrem System vorhanden ist (Paket hashcat-utils), installieren Sie es, um diesen Angriff ausführen zu können"
	arr["TURKISH",436]="${pending_of_translation} Yüklediğiniz hashcat sürümü (${hashcat_version}) ${hashcat_hccapx_version} boyutundan büyük ya da eşittir. Bu nedenle, yakalama dosyalarını \"hccapx\" biçimine dönüştürmeniz gerekir, bu nedenle airgeddon bunu otomatik olarak yapar. Bunu yapmak için sisteminizde mevcut olmayan bir dönüştürücüye ihtiyacınız vardır (hashcat-utils paketi), bu saldırıyı gerçekleştirebilmek için kurun"

	arr["ENGLISH",437]="If you enjoyed the script and found it useful, you can support the project by making a donation. Through PayPal (${normal_color}${mail}${pink_color}) or sending a fraction of cryptocurrency (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Any amount, no matter how small (1, 2, 5 $/€) is welcome. More information and direct links to do it at: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["SPANISH",437]="Si te gustó el script y te pareció útil, puedes apoyar el proyecto haciendo una donación. A través de PayPal (${normal_color}${mail}${pink_color}) o enviando una fracción de criptomoneda (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Cualquier cantidad por pequeña que sea (1, 2, 5 $/€) es bien recibida. Más información y enlaces directos para realizarla en: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["FRENCH",437]="Si le script vous a plus et que vous l'avez trouvé utile, vous pouvez soutenir le projet en faisant un don PayPal (${normal_color}${mail}${pink_color}) ou en envoyant une fraction de crypto-monnaie (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Toute contribution (1, 2, 5 $/€) est bienvenue. Pour faire un don allez à: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["CATALAN",437]="Si et va agradar el script i et va semblar útil, pots donar suport al projecte fent una donació. A través de PayPal (${normal_color}${mail}${pink_color}) o enviant una fracció criptomoneda (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Qualsevol quantitat per petita que sigui (1, 2, 5 $/€) és ben rebuda. Més informació i enllaços directes per a realitzar-la en: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["PORTUGUESE",437]="Se você gostou do script e o achou útil, apoie o projeto fazendo uma doação através: do PayPal (${normal_color}${mail}${pink_color}) ou enviando uma fração de uma criptomoeda (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Qualquer quantidade, mesmo pequena (1, 2, 5 $/€) é bem-vinda. Links diretos e de com realizar em: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["RUSSIAN",437]="Если вам понравилась эта программа и она оказался для вас полезной, вы можете поддержать проект, сделав пожертвование. Доступны переводы через PayPal (${normal_color}${mail}${pink_color}) и криптовалюту (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Приветствуется любая сумма, даже небольшая (1, 2, 5 $/€). Более подробную информацию и прямые ссылки можно получить по адресу: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["GREEK",437]="Εαν μείνατε ευχαριστημένοι από το script και το βρήκατε χρήσιμο, μπορείτε να υποστηρίξετε το project κάνοντας κάποια δωρεά. Μέσω PayPal (${normal_color}${mail}${pink_color}) ή αποστέλλοντας κάποιο κλάσμα κρυπτονομίσματος (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Είναι καλοδεχούμενο οποιοδήποτε ποσό (1, 2, 5 $/€), δεν έχει σημασία το πόσο λίγο μπορεί να είναι. Δίνονται περισσότερες πληροφορίες και links για να κάνετε δωρεά, στη διεύθυνση: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["ITALIAN",437]="Se ti è piaciuto lo script e l'hai trovato utile, puoi sostenere il progetto con una donazione. Attraverso PayPal (${normal_color}${mail}${pink_color}) o inviando una frazione di criptovaluta (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Qualsiasi importo per quanto piccolo (1, 2, 5 $/€) è ben accolto. Piú informazioni e collegamenti diretti per realizzarla in: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["POLISH",437]="Jeśli podobał Ci się ten skrypt i okazał się użyteczny, możesz poprzeć ten projekt, składając donację. Za pośrednictwem usługi PayPal (${normal_color}${mail}${pink_color}) lub wysyłając ułamek kryptowaluty (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Każda kwota, nawet malutka (1, 2, 5 $/€) będzie mile widziana. Więcej informacji i linki do donacji: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["GERMAN",437]="Wenn Ihnen das Skript gefallen hat und Sie es nützlich fanden, können Sie das Projekt mit einer Spende unterstützen. Durch PayPal (${normal_color}${mail}${pink_color}) oder durch Senden eines Bruchteils der Kryptowährung (${normal_color}Bitcoin, Ethereum, Litecoin...${pink_color}). Jeder kleine Betrag (1, 2, 5 $/€) wird gut angenommen. Mehr Informationen und direkte Links, um es zu machen: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["TURKISH",437]="${pending_of_translation} Senaryoyu beğendiyseniz ve yararlı bulduysanız, projeyi bağış yaparak destekleyebilirsiniz. PayPal (${normal_color}${mail}${pink_color}) veya cryptocurrency'ın bir kısmını (${normal_color}Bitcoin, Ethereum, Litecoin... ${pink_color}) göndererek. Ne kadar küçük olursa olsun, ne kadar küçük olursa olsun (1, 2, 5 $/€) kabul edilir. Bunu yapmak için daha fazla bilgi ve doğrudan bağlantı: ${normal_color}${urlgithub_wiki}/Contributing"

	arr["ENGLISH",438]="We are looking for translators to other languages. If you want to see airgeddon in your native language and you also know english, contact us. More information at: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["SPANISH",438]="Buscamos traductores para otros idiomas. Si quieres ver airgeddon en tu lengua materna y además sabes inglés, contáctanos. Más información en: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["FRENCH",438]="Nous recherchons des traducteurs pour d'autres langues. Si vous voulez voir airgeddon dans votre langue maternelle et que vous connaissez l'anglais contactez-nous: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["CATALAN",438]="Busquem traductors per a altres idiomes. Si vols veure airgeddon en la teva llengua materna i més saps anglès, contacta'ns. Més informació a: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["PORTUGUESE",438]="Procuramos tradutores para outros idiomas. Se você quiser ver airgeddon em sua língua nativa e também sabe inglês, por favor contacte-nos. Mais informações: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["RUSSIAN",438]="Мы ищем переводчиков на другие языки. Если вы хотите увидеть airgeddon на своем родном языке, и вы знаете английский язык, пожалуйста, свяжитесь с нами. Дополнительная информация: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["GREEK",438]="Ψάχνουμε μεταφραστές για την υποστήριξη περισσότερων γλωσσών. Αν θέλετε να χρησιμοποιείτε το airgeddon στη μητρική σας γλώσσα, αλλά ξέρετε και αγγλικά, παρακαλούμε επικοινωνήστε μαζί μας. Περισσότερες πληροφορίες: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["ITALIAN",438]="Cerchiamo traduttori per le altre lingue. Se volete vedere airgeddon nella vostra lingua madre e conoscete anche l'inglese, non esitate a contattarci. Per maggiori informazioni: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["POLISH",438]="Szukamy tłumaczy na inne języki. Jeśli chcesz zobaczyć airgeddon w swoim ojczystym języku i znasz angielski, skontaktuj się z nami. Więcej informacji: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["GERMAN",438]="Wir suchen Übersetzer für andere Sprachen. Wenn Sie airgeddon in Ihrer Muttersprache sehen möchten, kontaktieren Sie uns. Weitere Informationen unter: ${normal_color}${urlgithub_wiki}/Contributing"
	arr["TURKISH",438]="${pending_of_translation} Diğer dillere tercümanlar arıyoruz. Eğer kendi dilinizde airgeddon görmek ve ayrıca ingilizce bilmek isterseniz, bize ulaşın. Daha fazla bilgi için: ${normal_color}${urlgithub_wiki}/Contributing"

	arr["ENGLISH",439]="${blue_color}You haven't selected any target, you'll be prompted to input data manually. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",439]="${blue_color}Se ha detectado que no tienes seleccionado ningún objetivo, tendrás que introducir los datos manualmente. ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",439]="${blue_color}Aucun objectif n'a été sélectionnéIl semble que vous avez sélectionné aucun but, vous devez saisir les données manuellement. ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",439]="${blue_color}S'ha detectat que no tens seleccionat cap objectiu, hauràs d'introduir les dades manualment. ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",439]="${blue_color}Nenhum alvo foi selecionado, você será direcionado para inserir os dados manualmente. ${green_color}Deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",439]="${blue_color}Вы не выбрали какую-либо цель, вам будет предложено ввести данные вручную. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",439]="${blue_color}Δεν έχετε επιλέξει κάποιο στόχο, θα σας ζητηθεί να εισάγετε τα δεδομένα χειροκίνητα. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",439]="${blue_color}Abbiamo rilevato che non è stato selezionato alcun obiettivo, è necessario immettere manualmente i dati. ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",439]="${blue_color}Wykryto, że nie wybrano żadnych celów, konieczne będzie ręczne wprowadzanie danych. ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",439]="${blue_color}Es wurde festgestellt, dass Sie kein Ziel ausgewählt haben. Sie müssen die Daten manuell eingeben. ${green_color}Möchten Sie fortfahren? ${normal_color}${visual_choice}"
	arr["TURKISH",439]="${pending_of_translation} ${blue_color}Hiçbir hedef seçmediyseniz, verileri manuel olarak girmeniz istenir. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",440]="Aircrack trophy file generated successfully at [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["SPANISH",440]="Fichero de trofeo aircrack generado con éxito en [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["FRENCH",440]="Le fichier trophée aircrack a bien été crée dans [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["CATALAN",440]="Fitxer de trofeu aircrack generat amb èxit a [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["PORTUGUESE",440]="Arquivo de troféu aircrack gerado com sucesso [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["RUSSIAN",440]="Трофейный файл aircrack был успешно сгенерирован в [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["GREEK",440]="Το aircrack αρχείο τρόπαιο δημιουργήθηκε επιτυχώς [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["ITALIAN",440]="Il file trofeo di aircrack è stato generato con successo in [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["POLISH",440]="Plik trofeum aircrack został pomyślnie wygenerowany w [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["GERMAN",440]="Aircrack-Trophäendatei erfolgreich erstellt in [${normal_color}${aircrackpotenteredpath}${blue_color}]"
	arr["TURKISH",440]="${pending_of_translation} Aircrack kupa dosyası başarıyla oluşturuldu [${normal_color}${aircrackpotenteredpath}${blue_color}]"

	arr["ENGLISH",441]="Type the path to store the file or press [Enter] to accept the default proposal ${normal_color}[${aircrack_potpath}]"
	arr["SPANISH",441]="Escribe la ruta donde guardaremos el fichero o pulsa [Enter] para aceptar la propuesta por defecto ${normal_color}[${aircrack_potpath}]"
	arr["FRENCH",441]="Entrez le chemin où vous voulez enregistrer le fichier ou bien appuyez sur [Enter] pour utiliser le chemin proposé ${normal_color}[${aircrack_potpath}]"
	arr["CATALAN",441]="Escriu la ruta on guardarem el fitxer o prem [Enter] per acceptar la proposta per defecte ${normal_color}[${aircrack_potpath}]"
	arr["PORTUGUESE",441]="Digite o caminho onde armazenar o arquivo ou pressione [Enter] para aceitar o padrão ${normal_color}[${aircrack_potpath}]"
	arr["RUSSIAN",441]="Напечатайте путь к сохранённому файлу или нажмите [Enter] для принятия предложения по умолчанию ${normal_color}[${aircrack_potpath}]"
	arr["GREEK",441]="Πληκτρολογήστε το μονοπάτι για την αποθήκευση του αρχείου ή πατήστε [Enter] για την προεπιλεγμένη επιλογή ${normal_color}[${aircrack_potpath}]"
	arr["ITALIAN",441]="Immettere il percorso dove memorizzare il file o premere [Enter] per accettare quello proposto di default ${normal_color}[${aircrack_potpath}]"
	arr["POLISH",441]="Wpisz ścieżkę, w której będziemy zapisywać plik lub naciśnij [Enter], aby zaakceptować domyślną propozycję ${normal_color}[${aircrack_potpath}]"
	arr["GERMAN",441]="Schreiben Sie den Pfad, unter dem die Datei gespeichert werden soll, oder drücken Sie die [Enter]-Taste, um den Standardvorschlag zu akzeptieren ${normal_color}[${aircrack_potpath}]"
	arr["TURKISH",441]="${pending_of_translation} Dosyayı depolamak için yolu yazın veya varsayılan teklifi kabul etmek için [Enter] tuşuna basın ${normal_color}[${aircrack_potpath}]"

	arr["ENGLISH",442]="If you install ccze you'll see some parts of airgeddon in a colorized way with better aspect. It's not a requirement or a dependency, but it will improve the user experience"
	arr["SPANISH",442]="Si instalas el paquete ccze podrás ver algunas partes de airgeddon colorizadas y con mejor aspecto. No es un requerimiento ni una dependencia, pero mejorará la experiencia de usuario"
	arr["FRENCH",442]="L'installation du paquet ccze améliore le rendu graphique d'airgeddon. Ce n'est pas un prérequis mais un petit plus pour rendre l’utilisation d'airgeddon plus agréable"
	arr["CATALAN",442]="Si instal·les el paquet ccze podràs veure algunes parts de airgeddon coloriçades i amb millor aspecte. No és un requeriment ni una dependència, però millorarà l'experiència d'usuari"
	arr["PORTUGUESE",442]="Se você instalar o pacote ccze poderá ver algumas partes do airgeddon coloridas e mais bonitas. Não é uma exigência nem uma dependência, mas melhora a experiência do usuário"
	arr["RUSSIAN",442]="Если вы установите ccze, то некоторые цветные элементы airgeddon будут выглядеть лучше. Это не требование или зависимость, но это улучшит работу пользователя"
	arr["GREEK",442]="Αν εγκαταστήσετε το ccze θα δείτε μερικά κομμάτια του airgeddon, πολύχρωμα με καλύτερη εμφάνιση. Δεν είναι απαραίτητο dependency, αλλά θα βελτιώσει την εμπειρία του χρήστη"
	arr["ITALIAN",442]="Se installi il pacchetto ccze vedrai alcune parti di airgeddon colorate e più belle. Non è un requisito né una dipendenza, ma migliorerà l'esperienza dell'utente"
	arr["POLISH",442]="Jeśli zainstalujesz pakiet ccze, zobaczysz niektóre części airgeddon kolorowe i lepiej wygladajce. Nie jest to wymóg ani zależność, ale poprawi to komfort użytkowania"
	arr["GERMAN",442]="Wenn Sie das ccze-Paket installieren, sehen Sie einige Teile von airgeddon gefärbt und besser aussehend. Es ist keine Voraussetzung oder eine Abhängigkeit, aber es wird die Benutzererfahrung verbessern"
	arr["TURKISH",442]="${pending_of_translation} Eğer ccze'yi kurarsanız, daha iyi bir yönü olan renkli bir şekilde airgeddon'un bazı kısımlarını göreceksiniz. Bu bir gereksinim veya bağımlılık değil, ancak kullanıcı deneyimini geliştirecek"

	arr["ENGLISH",443]="Options and language menu"
	arr["SPANISH",443]="Menú de opciones e idioma"
	arr["FRENCH",443]="Menu options et langues"
	arr["CATALAN",443]="Menú d'opcions i idioma"
	arr["PORTUGUESE",443]="Opções de menu e idioma"
	arr["RUSSIAN",443]="Настройки и языковое меню"
	arr["GREEK",443]="Μενού επιλογών και γλώσσας"
	arr["ITALIAN",443]="Menú opzioni e lingua"
	arr["POLISH",443]="Opcje i menu językowe"
	arr["GERMAN",443]="Optionen und Sprachmenü"
	arr["TURKISH",443]="Ayarlar ve dil menüsü"

	arr["ENGLISH",444]="11. Options and language menu"
	arr["SPANISH",444]="11. Menú de opciones e idioma"
	arr["FRENCH",444]="11. Menu options et langues"
	arr["CATALAN",444]="11. Menú d'opcions i idioma"
	arr["PORTUGUESE",444]="11. Opções de menu e idioma"
	arr["RUSSIAN",444]="11. Настройки и языковое меню"
	arr["GREEK",444]="11. Μενού επιλογών και γλώσσας"
	arr["ITALIAN",444]="11. Menú opzioni e lingua"
	arr["POLISH",444]="11. Opcje i menu językowe"
	arr["GERMAN",444]="11. Optionen und Sprachmenü"
	arr["TURKISH",444]="11. Ayarlar ve dil menüsü"

	arr["ENGLISH",445]="If you have ccze installed and are experiencing display errors or glitches on some windows, you should disable colorization in the option and language menu"
	arr["SPANISH",445]="Si tienes instalado ccze y experimentas errores de visualización o parpadeos en algunas ventanas, desactiva la colorización en el menú de opciones e idioma"
	arr["FRENCH",445]="Si ccze est installé et que vous avez des erreurs d'affichage et de clignotement avec certaines fenêtres, désactivez la colorisation depuis le menu options et langues"
	arr["CATALAN",445]="Si tens instal·lat ccze i experimentes errors de visualització o pampallugues en algunes finestres, desactiva la coloració al menú d'opcions i idioma"
	arr["PORTUGUESE",445]="Se você tiver ccze instalado e estiver com erros de exibição ou com algumas janelas piscando, desative a colorização em opções de menu e idioma"
	arr["RUSSIAN",445]="Если у вас установлен ccze и возникают ошибки отображения или сбои в некоторых окнах, вы должны отключить цветной вывод в пункте Настройки и языковое меню"
	arr["GREEK",445]="Εάν έχετε εγκαταστήσει το ccze και αντιμετωπίζετε σφάλματα εμφάνισης ή δυσλειτουργίες σε ορισμένα παράθυρα, θα πρέπει να απενεργοποιήσετε τον χρωματισμό στο μενού επιλογών και γλώσσας"
	arr["ITALIAN",445]="Se hai installato ccze e vedi errori o alcune finestre tremolanti, disattiva la colorazione nel menú opzioni e lingua"
	arr["POLISH",445]="Jeśli zainstalowano ccze i wystąpiły błędy wizualizacji lub migotania w niektórych oknach, powinieneś wyłączyć kolory w menu opcji i języka"
	arr["GERMAN",445]="Wenn Sie ccze installiert haben und in einigen Fenstern Anzeigefehler oder Flimmern auftreten, deaktivieren Sie die Einfärbung im Optionen- und Sprachmenü"
	arr["TURKISH",445]="${pending_of_translation} Eğer ccze kuruluysa ve bazı pencerelerde görüntü hataları veya hatalar yaşıyorsanız, seçenek ve dil menüsünde renklendirmeyi devre dışı bırakmalısınız"

	arr["ENGLISH",446]="0.  Return to options menu"
	arr["SPANISH",446]="0.  Volver al menú de opciones"
	arr["FRENCH",446]="0.  Retourner au menu options"
	arr["CATALAN",446]="0.  Tornar al menú d'opcions"
	arr["PORTUGUESE",446]="0.  Voltar ao menu de opções"
	arr["RUSSIAN",446]="0.  Возврат в меню опций"
	arr["GREEK",446]="0.  Επιστροφή στο μενού επιλογών"
	arr["ITALIAN",446]="0.  Tornare al menú delle opzioni"
	arr["POLISH",446]="0.  Wróć do menu opcji"
	arr["GERMAN",446]="0.  Zum Optionsmenü zurückkehren"
	arr["TURKISH",446]="0.  Ayarlar menüsüne geri dön"

	arr["ENGLISH",447]="5.  Set permanently airgeddon's language to the current one"
	arr["SPANISH",447]="5.  Cambiar permanentemente el idioma de airgeddon al actual"
	arr["FRENCH",447]="5.  Etablir comme langue permanente d'airgeddon celle utilisée actuellement"
	arr["CATALAN",447]="5.  Canviar permanentment l'idioma de airgeddon a l'actual"
	arr["PORTUGUESE",447]="5.  Alterar permanentemente o idioma do airgeddon para o atual"
	arr["RUSSIAN",447]="5.  Сделать текущий язык airgeddon постоянным"
	arr["GREEK",447]="5.  Θέστε μόνιμα την τρέχουσα γλώσσα του airgeddon ως προεπιλεγμένη"
	arr["ITALIAN",447]="5.  Modificare in modo permanente la lingua di airgeddon a quella attuale"
	arr["POLISH",447]="5.  Trwale ustaw język airgeddon na aktualny"
	arr["GERMAN",447]="5.  Ändern Sie dauerhaft die Sprache von airgeddon zur aktuellen Sprache"
	arr["TURKISH",447]="${pending_of_translation} 5.  Sürekli olarak airgeddon'un dilini geçerli olana ayarla"

	arr["ENGLISH",448]="If you installed airgeddon from a repository, you should not enable automatic updates. airgeddon will be updated when there is a new version in the repository"
	arr["SPANISH",448]="Si instalaste airgeddon desde un repositorio, no deberías activar la actualización automática. airgeddon se actualizará cuando haya una nueva versión en el repositorio"
	arr["FRENCH",448]="Si vous avez installé airgeddon depuis des dêpots vous devriez ne pas activer les mises à jour automatiques. airgeddon sera mis à jour quand une nouvelle version sera disponible dans vos dépôts"
	arr["CATALAN",448]="Si vas instal·lar airgeddon des d'un repositori, no hauries d'activar l'actualització automàtica. airgeddon s'actualitzarà quan hi hagi una nova versió al repositori"
	arr["PORTUGUESE",448]="Se você instalou airgeddon partir de um repositório, você não deve ativar a atualização automática. airgeddon será atualizado quando houver nova versão no repositório"
	arr["RUSSIAN",448]="Если вы установили airgeddon из репозитория, вам не следует включать автоматические обновления. airgeddon будет обновляться, когда в репозитории будет новая версия"
	arr["GREEK",448]="Αν εγκαταστήσατε το airgeddon από κάποιο επίσημο αποθετήριο, δεν θα πρέπει να ενεργοποιήσετε τις αυτόματες ενημερώσεις. Το airgeddon θα ενημερωθεί όταν υπάρξει κάποια νέα έκδοση στο επίσημο αποθετήριο"
	arr["ITALIAN",448]="Se è stato installato airgeddon da un repository, non si dovrebbe attivare l'aggiornamento automatico. airgeddon sará aggiornato quando ci sará una nuova versione nel repository"
	arr["POLISH",448]="Jeśli zainstalowano airgeddon z repozytorium, nie należy włączać automatycznej aktualizacji. airgeddon zostanie zaktualizowany, gdy w repozytorium znajduje się nowa wersja"
	arr["GERMAN",448]="Wenn Sie airgeddon aus einem Repository installiert haben, sollten Sie das automatische Update nicht aktivieren. airgeddon wird aktualisiert, wenn eine neue Version im Repository vorhanden ist"
	arr["TURKISH",448]="${pending_of_translation} Bir depodan airgeddon'u yüklediyseniz, otomatik güncellemeleri etkinleştirmemelisiniz. depoda yeni bir sürüm olduğunda airgeddon güncellenecektir"

	arr["ENGLISH",449]="2.  Enable automatic updates permanently"
	arr["SPANISH",449]="2.  Habilitar permanentemente la actualización automática"
	arr["FRENCH",449]="2.  Activer de façon permanante la mise à jour automatique"
	arr["CATALAN",449]="2.  Habilita permanentment l'actualització automàtica"
	arr["PORTUGUESE",449]="2.  Ativar permanentemente a atualização automática"
	arr["RUSSIAN",449]="2.  Включение постоянных автоматических обновлений"
	arr["GREEK",449]="2.  Ενεργοποιήστε μόνιμα τις αυτόματες ενημερώσεις"
	arr["ITALIAN",449]="2.  Abilitare permanentemente l'aggiornamento automatico"
	arr["POLISH",449]="2.  Trwale włącz automatyczną aktualizację"
	arr["GERMAN",449]="2.  Aktivieren Sie die automatische Aktualisierung dauerhaft"
	arr["TURKISH",449]="${pending_of_translation} 2.  Otomatik güncellemeleri kalıcı olarak etkinleştir"

	arr["ENGLISH",450]="3.  Enable colorization permanently (on some screen's output)"
	arr["SPANISH",450]="3.  Habilitar permanentemente la colorización (en la salida de algunas pantallas)"
	arr["FRENCH",450]="3.  Activer dé façon permanante la colorisation (en sortie de certains écrans)"
	arr["CATALAN",450]="3.  Habilita permanentment la coloració (a la sortida d'algunes pantalles)"
	arr["PORTUGUESE",450]="3.  Ativar permanentemente a colorização (em algumas telas)"
	arr["RUSSIAN",450]="3.  Включение постоянного цветного вывода (в некоторых окнах программы)"
	arr["GREEK",450]="3.  Ενεργοποιήστε μόνιμα τον χρωματισμό (σε κάποια σημεία)"
	arr["ITALIAN",450]="3.  Abilitare permanentemente la colorazione (in alcuni schermi)"
	arr["POLISH",450]="3.  Trwale włącz kolorowanie (na wyjściu niektórych ekranów)"
	arr["GERMAN",450]="3.  Die Einfärbung dauerhaft aktivieren (in der Ausgabe einiger Bildschirme)"
	arr["TURKISH",450]="${pending_of_translation} 3.  Renklendirmeyi kalıcı olarak etkinleştir (bazı ekranların çıkışında)"

	arr["ENGLISH",451]="Automatic updates: ${pink_color}Enabled${normal_color}"
	arr["SPANISH",451]="Actualizaciones automáticas: ${pink_color}Activadas${normal_color}"
	arr["FRENCH",451]="Mises à jour automatiques: ${pink_color}Activées${normal_color}"
	arr["CATALAN",451]="Actualitzacions automàtiques: ${pink_color}Activades${normal_color}"
	arr["PORTUGUESE",451]="Atualizações automáticas: ${pink_color}Ativa${normal_color}"
	arr["RUSSIAN",451]="Автоматическое обновление: ${pink_color}Включено${normal_color}"
	arr["GREEK",451]="Αυτόματη ενημέρωση: ${pink_color}Ενεργοποιημένο${normal_color}"
	arr["ITALIAN",451]="Aggiornamenti automatici: ${pink_color}Abilitati${normal_color}"
	arr["POLISH",451]="Aktualizacje automatyczne: ${pink_color}Włączone${normal_color}"
	arr["GERMAN",451]="Automatische Updates: ${pink_color}Aktiviert${normal_color}"
	arr["TURKISH",451]="Otomatik güncellemeler: ${pink_color}Etkin${normal_color}"

	arr["ENGLISH",452]="Automatic updates: ${pink_color}Disabled${normal_color}"
	arr["SPANISH",452]="Actualizaciones automáticas: ${pink_color}Desactivadas${normal_color}"
	arr["FRENCH",452]="Mises à jour automatiques: ${pink_color}Désactivées${normal_color}"
	arr["CATALAN",452]="Actualitzacions automàtiques: ${pink_color}Desactivades${normal_color}"
	arr["PORTUGUESE",452]="Atualizações automáticas: ${pink_color}Desativa${normal_color}"
	arr["RUSSIAN",452]="Автоматическое обновление: ${pink_color}Отключено${normal_color}"
	arr["GREEK",452]="Αυτόματη ενημέρωση: ${pink_color}Απενεργοποιημένο${normal_color}"
	arr["ITALIAN",452]="Aggiornamenti automatici: ${pink_color}Disabilitati${normal_color}"
	arr["POLISH",452]="Aktualizacje automatyczne: ${pink_color}Wyłączone${normal_color}"
	arr["GERMAN",452]="Automatische Updates: ${pink_color}Deaktiviert${normal_color}"
	arr["TURKISH",452]="${pending_of_translation} Otomatik güncellemeler: ${pink_color}DevreDışı${normal_color}"

	arr["ENGLISH",453]="Colorization (on some screen's output): ${pink_color}Enabled${normal_color}"
	arr["SPANISH",453]="Colorización (en la salida de algunas pantallas): ${pink_color}Activada${normal_color}"
	arr["FRENCH",453]="Colorisation (sur certains écrans): ${pink_color}Activée${normal_color}"
	arr["CATALAN",453]="Coloració (a la sortida d'algunes pantalles): ${pink_color}Activade${normal_color}"
	arr["PORTUGUESE",453]="Colorização (em algumas telas): ${pink_color}Ativa${normal_color}"
	arr["RUSSIAN",453]="Использование цветов (в некоторых окнах программы): ${pink_color}Включено${normal_color}"
	arr["GREEK",453]="Χρωματισμός (σε κάποια σημεία): ${pink_color}Ενεργοποιημένο${normal_color}"
	arr["ITALIAN",453]="Colorazione (in alcuni schermi): ${pink_color}Abilitata${normal_color}"
	arr["POLISH",453]="Kolorowanie (na wyjściu niektórych ekranów) ${pink_color}Włączone${normal_color}"
	arr["GERMAN",453]="Einfärbung (in der Ausgabe einiger Bildschirme): ${pink_color}Aktiviert${normal_color}"
	arr["TURKISH",453]="${pending_of_translation} Renklendirme (bazı ekranların çıkışında): ${pink_color}Etkin${normal_color}"

	arr["ENGLISH",454]="Colorization (on some screen's output): ${pink_color}Disabled${normal_color}"
	arr["SPANISH",454]="Colorización (en la salida de algunas pantallas): ${pink_color}Desactivada${normal_color}"
	arr["FRENCH",454]="Colorisation (sur certains écrans): ${pink_color}Désactivée${normal_color}"
	arr["CATALAN",454]="Coloració (a la sortida d'algunes pantalles): ${pink_color}Desactivade${normal_color}"
	arr["PORTUGUESE",454]="Colorização (em algumas telas): ${pink_color}Desativa${normal_color}"
	arr["RUSSIAN",454]="Использование цветов (в некоторых окнах программы): ${pink_color}Отключено${normal_color}"
	arr["GREEK",454]="Χρωματισμός (σε κάποια σημεία): ${pink_color}Απενεργοποιημένο${normal_color}"
	arr["ITALIAN",454]="Colorazione (in alcuni schermi): ${pink_color}Disabilitata${normal_color}"
	arr["POLISH",454]="Kolorowanie (na wyjściu niektórych ekranów) ${pink_color}Wyłączone${normal_color}"
	arr["GERMAN",454]="Einfärbung (in der Ausgabe einiger Bildschirme): ${pink_color}Deaktiviert${normal_color}"
	arr["TURKISH",454]="${pending_of_translation} Renklendirme (bazı ekranların çıkışında): ${pink_color}DevreDışı${normal_color}"

	arr["ENGLISH",455]="2.  Disable automatic updates permanently"
	arr["SPANISH",455]="2.  Deshabilitar permanentemente la actualización automática"
	arr["FRENCH",455]="2.  Désactiver de façon permanante les mises à jour automatiques"
	arr["CATALAN",455]="2.  Deshabilita permanentment l'actualització automàtica"
	arr["PORTUGUESE",455]="2.  Desativar permanentemente a atualização automática"
	arr["RUSSIAN",455]="2.  Отключить постоянные автоматические обновления"
	arr["GREEK",455]="2.  Απενεργοποιήστε μόνιμα τις αυτόματες ενημερώσεις"
	arr["ITALIAN",455]="2.  Disattivare permanentemente gli aggiornamenti automatici"
	arr["POLISH",455]="2.  Trwale wyłącz automatyczną aktualizację"
	arr["GERMAN",455]="2.  Automatische Updates dauerhaft deaktivieren"
	arr["TURKISH",455]="${pending_of_translation} 2.  Otomatik güncellemeleri kalıcı olarak devre dışı bırak"

	arr["ENGLISH",456]="3.  Disable colorization permanently (on some screen's output)"
	arr["SPANISH",456]="3.  Deshabilitar permanentemente la colorización (en la salida de algunas pantallas)"
	arr["FRENCH",456]="3.  Désactiver dé façon permanante (sur certains écrans)"
	arr["CATALAN",456]="3.  Deshabilita permanentment la colorización (a la sortida d'algunes pantalles)"
	arr["PORTUGUESE",456]="3.  Desativar permanentemente a colorização (em algumas telas)"
	arr["RUSSIAN",456]="3.  Постоянное отключение использования цветов (в некоторых окнах программы)"
	arr["GREEK",456]="3.  Απενεργοποιήστε μόνιμα τον χρωματισμό (σε κάποια σημεία)"
	arr["ITALIAN",456]="3.  Disattivare permanentemente la colorazione (in alcuni schermi)"
	arr["POLISH",456]="3.  Trwale wyłącz kolorowanie (na wyjściu niektórych ekranów)"
	arr["GERMAN",456]="3.  Die Einfärbung dauerhaft deaktivieren (in der Ausgabe einiger Bildschirme)"
	arr["TURKISH",456]="${pending_of_translation} 3.  Renklendirmeyi kalıcı olarak devre dışı bırak (bazı ekranların çıkışında)"

	arr["ENGLISH",457]="${blue_color}Automatic updates are going to be disabled. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",457]="${blue_color}Se van a desactivar las actualizaciones automáticas. ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",457]="${blue_color}Désactivation des mises à jour automatiques. ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",457]="${blue_color}Es van a desactivar les actualitzacions automàtiques. ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",457]="${blue_color}As atualizações automáticas serão desabilitadas. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",457]="${blue_color}Автоматические обновления будут отключены. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",457]="${blue_color}Οι αυτόματες ενημερώσεις πρόκειται να απενεργοποιηθούν. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",457]="${blue_color}Si stano per disattivare gli aggiornamenti automatici. ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",457]="${blue_color}Aktualizacje automatyczne zostaną wyłączone. ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",457]="${blue_color}Automatische Updates werden deaktiviert. ${green_color}Möchten Sie fortfahren? ${normal_color}${visual_choice}"
	arr["TURKISH",457]="${pending_of_translation} ${blue_color}Otomatik güncellemeler devre dışı bırakılacak. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",458]="${blue_color}Automatic updates are going to be enabled. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",458]="${blue_color}Se van a activar las actualizaciones automáticas. ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",458]="${blue_color}Activation des mises à jour automatiques. ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",458]="${blue_color}Es van a activar les actualitzacions automàtiques. ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",458]="${blue_color}As atualizações automáticas serão ativadas. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",458]="${blue_color}Автоматические обновления будут включены. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",458]="${blue_color}Οι αυτόματες ενημερώσεις πρόκειται να ενεργοποιηθούν. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",458]="${blue_color}Si stanno per attivare gli aggiornamenti automatici. ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",458]="${blue_color}Automatyczne aktualizacje będą włączone. ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",458]="${blue_color}Automatische Updates werden aktiviert. ${green_color} Möchten Sie fortfahren? ${normal_color}${visual_choice}"
	arr["TURKISH",458]="${pending_of_translation} ${blue_color}Otomatik güncellemeler etkinleştirilecek. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",459]="If you installed airgeddon from a repository you shouldn't enable this option. airgeddon will be updated when the repositories do. If you continue, make sure you know what you are doing, or you could cause problems with update flow"
	arr["SPANISH",459]="Si instalaste airgeddon desde un repositorio no deberías activar esta opción. airgeddon se actualizará cuando lo hagan los repositorios. Si continuas, asegúrate de saber bien lo que haces o podrías causar problemas con flujo de actualizaciones"
	arr["FRENCH",459]="Si airgeddon a été installé depuis des dépôts vous devriez ne pas activer cette option. airgeddon sera mis à jour automatiquement en passant par vos dépôts. Si vous décidez de continuer soyez conscient du fait que vous pourriez générer ainsi des conflits lors de futures actualisations système"
	arr["CATALAN",459]="Si vas instal·lar airgeddon des d'un repositori no hauries d'activar aquesta opció. airgeddon s'actualitzarà quan ho facin els repositoris. Si continues, assegura't de saber bé el que fas o podries causar problemes amb flux d'actualitzacions"
	arr["PORTUGUESE",459]="Se você instalou airgeddon a partir de um repositório você não deve ativar essa opção. airgeddon será atualizado quando você estiver disponível nos repositórios. Se você continuar, verifique se você sabe o que está fazendo ou ou você pode causar problemas com o fluxo de atualização"
	arr["RUSSIAN",459]="Если вы установили airgeddon из репозитория, вы не должны включать эту опцию. airgeddon будет обновляться вместе с репозиториями. Если вы продолжите, убедитесь, что знаете, что делаете, или ваши действия могут вызвать проблемы для этой программы"
	arr["GREEK",459]="Εάν εγκαταστήσατε το airgeddon από κάποιο επίσημο αποθετήριο, δεν πρέπει να ενεργοποιήσετε αυτή την επιλογή. Το airgeddon θα ενημερωθεί όταν ενημερωθούν και τα αποθετήρια. Αν συνεχίσετε, βεβαιωθείτε ότι γνωρίζετε τι κάνετε και ότι θα μπορεί να προκαλέσετε προβλήματα με τη ροή ενημέρωσης"
	arr["ITALIAN",459]="Se airgeddon è stato installato da un repository non si dovrebbe attivare questa opzione. airgeddon sará aggiornato quando lo faranno i repository. Se continui, assicurati di sapere bene quello che fai o potrebbe causare problemi al flusso degli aggiornamenti"
	arr["POLISH",459]="Jeśli zainstalowano airgeddon z repozytorium, nie należy włączać tej opcji. airgeddon zostanie zaktualizowany, gdy w repozytorium pojawi się nowa wersja. Jeśli kontynuujesz, upewnij się, że wiesz co robisz, bo to może spowodować problemy z aktualizacją"
	arr["GERMAN",459]="Wenn Sie airgeddon aus einem Repository installiert haben, sollten Sie diese Option nicht aktivieren. airgeddon wird aktualisiert, wenn die Repositories dies tun. Wenn Sie fortfahren, vergewissern Sie sich, dass Sie wissen, was Sie tun. Probleme können erscheinen"
	arr["TURKISH",459]="${pending_of_translation} Bir depodan airgeddon'u yüklediyseniz, bu seçeneği etkinleştirmemelisiniz. Havuzlar yapıldığı zaman airgeddon güncellenecektir. Devam ederseniz, ne yaptığınızı bildiğinizden emin olun, ya da güncelleme akışında sorunlara neden olabilirsiniz"

	arr["ENGLISH",460]="Automatic updates have been enabled"
	arr["SPANISH",460]="Se han activado las actualizaciones automáticas"
	arr["FRENCH",460]="Mises à jour automatiques activées"
	arr["CATALAN",460]="S'han activat les actualitzacions automàtiques"
	arr["PORTUGUESE",460]="As atualizações automáticas foram ativadas"
	arr["RUSSIAN",460]="Автоматические обновления включены"
	arr["GREEK",460]="Οι αυτόματες ενημερώσεις έχουν ενεργοποιηθεί"
	arr["ITALIAN",460]="Sono stati attivati gli aggiornamenti automatici"
	arr["POLISH",460]="Automatyczne aktualizacje zostały włączone"
	arr["GERMAN",460]="Automatische Updates wurden aktiviert"
	arr["TURKISH",460]="Otomatik güncellemeler etkinleştirildi"

	arr["ENGLISH",461]="Automatic updates have been disabled"
	arr["SPANISH",461]="Se han desactivado las actualizaciones automáticas"
	arr["FRENCH",461]="Mises à jour automatiques désactivées"
	arr["CATALAN",461]="S'han desactivat les actualitzacions automàtiques"
	arr["PORTUGUESE",461]="As atualizações automáticas foram desativadas"
	arr["RUSSIAN",461]="Автоматические обновления отключены"
	arr["GREEK",461]="Οι αυτόματες ενημερώσεις έχουν απενεργοποιηθεί"
	arr["ITALIAN",461]="Sono stati disattivati gli aggiornamenti automatici"
	arr["POLISH",461]="Automatyczne aktualizacje zostały wyłączone"
	arr["GERMAN",461]="Automatische Updates wurden deaktiviert"
	arr["TURKISH",461]="Otomatik güncellemeler devre dışı bırakıldı"

	arr["ENGLISH",462]="${blue_color}Colorization (on some screen's output) is going to be disabled. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",462]="${blue_color}Se va a desactivar la colorización (en la salida de algunas pantallas). ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",462]="${blue_color}Désactivation de la colorisation (sur certains écrans). ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",462]="${blue_color}Es va a desactivar le coloració (a la sortida d'algunes pantalles). ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",462]="${blue_color}A coloração (em algumas telas) será desabilitada. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",462]="${blue_color}Использование цветов (в некоторых окнах программы) будет отключено. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",462]="${blue_color}Ο χρωματισμός (σε κάποια σημεία) πρόκειται να απενεργοποιηθεί. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",462]="${blue_color}La colorazione sará disattivata (in alcuni schermi). ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",462]="${blue_color}Koloryzacja zostanie wyłączona (na wyjściu niektórych ekranów). ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",462]="${blue_color}Die Einfärbung wird deaktiviert (in der Ausgabe einiger Bildschirme). ${green_color}Möchten Sie fortfahren? ${normal_color}${visual_choice}"
	arr["TURKISH",462]="${pending_of_translation} ${blue_color}Renklendirme (bazı ekranların çıkışı) devre dışı bırakılacak. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",463]="${blue_color}Colorization (on some screen's output) is going to be enabled. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",463]="${blue_color}Se va a activar la colorización (en la salida de algunas pantallas). ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",463]="${blue_color}Activation colorisation (sur certains écrans). ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",463]="${blue_color}Es va a activar la coloració (a la sortida d'algunes pantalles). ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",463]="${blue_color}A coloração (em algumas telas) será ativada. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",463]="${blue_color}Использование цветов (в некоторых окнах программы) будет включено. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",463]="${blue_color}Ο χρωματισμός (σε κάποια σημεία) πρόκειται να ενεργοποιηθεί. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",463]="${blue_color}La colorazione sará attivata (in alcuni schermi). ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",463]="${blue_color}Koloryzacja zostanie włączona (na wyjściu niektórych ekranów). ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",463]="${blue_color}Die Einfärbung wird aktiviert (in der Ausgabe einiger Bildschirme). ${green_color}Wollen Sie fortfahren? ${normal_color}${visual_choice}"
	arr["TURKISH",463]="${pending_of_translation} ${blue_color}Renklendirme (bazı ekranların çıkışı) etkinleştirilecektir. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",464]="You don't have the ccze package installed so any change on this option will have no effect until you install it"
	arr["SPANISH",464]="No tienes instalado el paquete ccze por lo que cualquier cambio que realices sobre esta opción no tendrá efecto hasta que lo instales"
	arr["FRENCH",464]="Ccze n'est pas installé, les paramétrages effectués avec cette option seront effectifs une fois czze installé"
	arr["CATALAN",464]="No tens instal·lat el paquet ccze pel que qualsevol canvi que facis sobre aquesta opció no tindrà efecte fins que el instal·lis"
	arr["PORTUGUESE",464]="Você não tem o pacote ccze instalado, qualquer alterações feita nesta opção não terá efeito até que você instale-o"
	arr["RUSSIAN",464]="У вас не установлен пакет ccze, поэтому любое изменение этой опции не будет иметь никакого эффекта, пока вы его не установите"
	arr["GREEK",464]="Δεν έχετε εγκατεστημένο το πακέτο ccze, οπότε οποιαδήποτε αλλαγή σε αυτήν την επιλογή δεν θα έχει αποτέλεσμα μέχρι να το εγκαταστήσετε"
	arr["ITALIAN",464]="Non è stato installato il pacchetto ccze per cui tutte le modifiche apportate su questa opzione non avranno alcun effetto finché non si installa"
	arr["POLISH",464]="Nie masz zainstalowanego pakietu ccze, więc wszelkie zmiany wprowadzone w tej opcji nie będą obowiązywać dopóki nie zostanie zainstalowany"
	arr["GERMAN",464]="Sie haben das ccze-Paket nicht installiert, sodass Änderungen, die Sie an dieser Option vornehmen, erst nach der Installation wirksam werden"
	arr["TURKISH",464]="${pending_of_translation} Ccze paketinin yüklü olmaması, bu seçenek üzerinde herhangi bir değişikliğin kuruluncaya kadar hiçbir etkisi olmayacaktır"

	arr["ENGLISH",465]="Colorization has been enabled"
	arr["SPANISH",465]="Se ha activado la colorización"
	arr["FRENCH",465]="Colorisation activée"
	arr["CATALAN",465]="S'ha activat la coloració"
	arr["PORTUGUESE",465]="A colorização foi ativa"
	arr["RUSSIAN",465]="Использование цветов включено"
	arr["GREEK",465]="Ο χρωματισμός ενεργοποιήθηκε"
	arr["ITALIAN",465]="La colorazione è stata abilitata"
	arr["POLISH",465]="Koloryzacja została aktywowana"
	arr["GERMAN",465]="Die Einfärbung wurde aktiviert"
	arr["TURKISH",465]="Renklendirme etkinleştirildi"

	arr["ENGLISH",466]="Colorization has been disabled"
	arr["SPANISH",466]="Se ha desactivado la colorización"
	arr["FRENCH",466]="Colorisation désactivée"
	arr["CATALAN",466]="S'ha desactivat la coloració"
	arr["PORTUGUESE",466]="A colorização foi desativa"
	arr["RUSSIAN",466]="Использование цветов отключено"
	arr["GREEK",466]="Ο χρωματισμός απενεργοποιήθηκε"
	arr["ITALIAN",466]="La colorazione è stata disabilitata"
	arr["POLISH",466]="Koloryzacja została wyłączona"
	arr["GERMAN",466]="Die Einfärbung wurde deaktiviert"
	arr["TURKISH",466]="Renklendirme devre dışı bırakıldı"

	arr["ENGLISH",467]="4.  Enable startup language autodetection permanently"
	arr["SPANISH",467]="4.  Habilitar permanentemente la autodetección de idioma al inicio"
	arr["FRENCH",467]="4.  Activer de façon permanente la détection de langue au lancement"
	arr["CATALAN",467]="4.  Habilitar permanentment l'autodetecció d'idioma a l'inici"
	arr["PORTUGUESE",467]="4.  Ativar permanentemente a detecção do idioma no início"
	arr["RUSSIAN",467]="4.  Автоматическое определение языка постоянно отключено"
	arr["GREEK",467]="4.  Ενεργοποίηση του αυτόματου εντοπισμού γλώσσας κατά την εκκίνηση μόνιμα"
	arr["ITALIAN",467]="4.  Abilitare permanentemente il rilevamento automatico della lingua all'inizio"
	arr["POLISH",467]="4.  Trwale włącz automatyczne wykrywanie języka podczas uruchamiania"
	arr["GERMAN",467]="4.  Automatische Spracherkennung beim Start dauerhaft aktivieren"
	arr["TURKISH",467]="4.  Başlangıç dilini otomatik algılama özelliğini kalıcı olarak etkinleştir"

	arr["ENGLISH",468]="4.  Disable startup language autodetection permanently"
	arr["SPANISH",468]="4.  Deshabilitar permanentemente la autodetección de idioma al inicio"
	arr["FRENCH",468]="4.  Désactiver de façon permanente la détection de langue au lancement"
	arr["CATALAN",468]="4.  Deshabilitar permanentment l'autodetecció d'idioma a l'inici"
	arr["PORTUGUESE",468]="4.  Desativar permanentemente a detecção do idioma no início"
	arr["RUSSIAN",468]="4.  Постоянное отключение автоматического определения языка"
	arr["GREEK",468]="4.  Απενεργοποίηση του αυτόματου εντοπισμού γλώσσας κατά την εκκίνηση μόνιμα"
	arr["ITALIAN",468]="4.  Disattivare permanentemente il rilevamento automatico della lingua all'inizio"
	arr["POLISH",468]="4.  Trwale wyłącz autodetekcję języka podczas uruchamiania"
	arr["GERMAN",468]="4.  Automatische Spracherkennung beim Start dauerhaft deaktivieren"
	arr["TURKISH",468]="4.  Başlangıç dili otomatik algılamayı kalıcı olarak devre dışı bırak"

	arr["ENGLISH",469]="${blue_color}Startup language autodetection will be disabled. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",469]="${blue_color}Se va a deshabilitar la autodetección de idioma al inicio. ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",469]="${blue_color}Désactivation détection langue au lancement. ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",469]="${blue_color}Es va a desactivar la detecció automàtica d'idioma a l'inici. ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",469]="${blue_color}A detecção automática do idioma será desativada. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",469]="${blue_color}Автоопределение языка при запуске будет отключено. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",469]="${blue_color}Ο αυτόματος εντοπισμός γλώσσας κατά την εκκίνηση θα απενεργοποιηθεί. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",469]="${blue_color}Si sta per disabilitare il rilevamento automatico della lingua all'inizio ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",469]="${blue_color}Autodetekcja języka zostanie wyłączona podczas uruchamiania. ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",469]="${blue_color}Die automatische Spracherkennung am Anfang wird deaktiviert. ${green_color}Wollen Sie weitermachen? ${normal_color}${visual_choice}"
	arr["TURKISH",469]="${pending_of_translation} ${blue_color}Başlangıç dili otomatik algılama devre dışı bırakılacak. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",470]="${blue_color}Startup language autodetection will be enabled. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",470]="${blue_color}Se va a habilitar la autodetección de idioma al inicio. ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",470]="${blue_color}Activation détection langue au lancement. ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",470]="${blue_color}Es va a habilitar la detecció automàtica d'idioma a l'inici. ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",470]="${blue_color}A detecção automática do idioma será ativada. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",470]="${blue_color} Автоопределение языка при запуске будет включено. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",470]="${blue_color}Ο αυτόματος εντοπισμός γλώσσας κατά την εκκίνηση θα ενεργοποιηθεί. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",470]="${blue_color}Si sta per abilitare il rilevamento automatico della lingua all'inizio. ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",470]="${blue_color}Autodetekcja języka podczas uruchamiania zostanie włączona. ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",470]="${blue_color}Die automatische Spracherkennung wird zu Beginn aktiviert. ${green_color}Wollen Sie weitermachen? ${normal_color}${visual_choice}"
	arr["TURKISH",470]="${pending_of_translation} ${blue_color}Başlangıç dili otomatik algılama etkinleştirilecek. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",471]="Any permanent change of language you have will be lost on the next start if you enable this option!!"
	arr["SPANISH",471]="Cualquier cambio permanente de idioma que tenga se perderá en el siguiente inicio si activa esta opción!!"
	arr["FRENCH",471]="Les configurations permanentes de langue seront perdues au prochain démarrage si vous choisssez cette option!!"
	arr["CATALAN",471]="Qualsevol canvi permanent d'idioma que tinguis es perdrà en el següent inici si actives aquesta opció!!"
	arr["PORTUGUESE",471]="Qualquer alteração no idioma será perdida no próximo inicio se você habilitar esta opção!!"
	arr["RUSSIAN",471]="При включении этой опции, сделанный выбор по изменению языка будет потерян при следующем запуске!!"
	arr["GREEK",471]="Οποιαδήποτε μόνιμη αλλαγή της γλώσσας θα χαθεί κατά την επόμενη εκκίνηση, αν ενεργοποιήσετε αυτή την επιλογή!!"
	arr["ITALIAN",471]="Qualsiasi cambio permanente di lingua si perderá nel prossimo inizio se si attiva questa opzione!!"
	arr["POLISH",471]="Każda trwała zmiana języka zostanie utracona podczas następnego startu, jeśli aktywujesz tę opcję!!"
	arr["GERMAN",471]="Jeder permanente Sprachwechsel, den Sie haben, wird beim nächsten Start verloren gehen, wenn Sie diese Option aktivieren!!"
	arr["TURKISH",471]="Bu seçeneği etkinleştirirseniz, bir sonraki başlangıçta herhangi bir kalıcı dil değişikliği kaybolur!!"

	arr["ENGLISH",472]="Startup language autodetection has been enabled"
	arr["SPANISH",472]="Se ha activado la autodetección de idioma al inicio"
	arr["FRENCH",472]="Détection automatique du langage au démarrage activée"
	arr["CATALAN",472]="S'ha activat l'autodetecció d'idioma a l'inici"
	arr["PORTUGUESE",472]="A detecção automática do idioma foi ativa na inicialização"
	arr["RUSSIAN",472]="Автоматическое определение языка было включено"
	arr["GREEK",472]="Ο αυτόματος εντοπισμός γλώσσας κατά την εκκίνηση έχει ενεργοποιηθεί"
	arr["ITALIAN",472]="Il rilevamento automatico della lingua all'inizio è abilitato"
	arr["POLISH",472]="Autodetekcja języka podczas uruchamiania została aktywowana"
	arr["GERMAN",472]="Die automatische Spracherkennung am Start wurde aktiviert"
	arr["TURKISH",472]="Başlangıç dili otomatik algılama etkinleştirildi"

	arr["ENGLISH",473]="Startup language autodetection has been disabled"
	arr["SPANISH",473]="Se ha desactivado la autodetección de idioma al inicio"
	arr["FRENCH",473]="Détection automatique du langage au démarrage désactivée"
	arr["CATALAN",473]="S'ha desactivat l'autodetecció d'idioma a l'inici"
	arr["PORTUGUESE",473]="A detecção automática do idioma desativada na inicialização"
	arr["RUSSIAN",473]="Автоматическое определение языка было отключено"
	arr["GREEK",473]="Ο αυτόματος εντοπισμός γλώσσας κατά την εκκίνηση έχει απενεργοποιηθεί"
	arr["ITALIAN",473]="È stato disattivato il rilevamento automatico della lingua all'inizio"
	arr["POLISH",473]="Autodetekcja języka podczas uruchamiania została wyłączona"
	arr["GERMAN",473]="Die automatische Spracherkennung am Start wurde deaktiviert"
	arr["TURKISH",473]="Başlangıç dili otomatik algılama devre dışı bırakıldı"

	arr["ENGLISH",474]="Startup language autodetection: ${pink_color}Enabled${normal_color}"
	arr["SPANISH",474]="Autodetección de idioma al inicio: ${pink_color}Activada${normal_color}"
	arr["FRENCH",474]="Détection automatique du langage au démarrage: ${pink_color}Activée${normal_color}"
	arr["CATALAN",474]="Autodetecció d'idioma a l'inici: ${pink_color}Activade${normal_color}"
	arr["PORTUGUESE",474]="Detecção automática do idioma: ${pink_color}ativa${normal_color}"
	arr["RUSSIAN",474]="Автоопределение языка при запуске: ${pink_color}Включено${normal_color}"
	arr["GREEK",474]="Αυτόματος εντοπισμός γλώσσας κατά την εκκίνηση: ${pink_color}Ενεργοποιημένο${normal_color}"
	arr["ITALIAN",474]="Rilevamento automatico della lingua all'inizio: ${pink_color}Abilitato${normal_color}"
	arr["POLISH",474]="Automatyczne wykrywanie języka podczas uruchamiania: ${pink_color}Aktywowane${normal_color}"
	arr["GERMAN",474]="Automatische Spracherkennung am Start: ${pink_color}Aktiviert${normal_color}"
	arr["TURKISH",474]="Başlangıç dili otomatik algılama: ${pink_color}Etkin${normal_color}"

	arr["ENGLISH",475]="Startup language autodetection: ${pink_color}Disabled${normal_color}"
	arr["SPANISH",475]="Autodetección de idioma al inicio: ${pink_color}Desactivada${normal_color}"
	arr["FRENCH",475]="Détection automatique du langage au démarrage: ${pink_color}Désactivée${normal_color}"
	arr["CATALAN",475]="Autodetecció d'idioma a l'inici: ${pink_color}Desactivade${normal_color}"
	arr["PORTUGUESE",475]="Detecção automática do idioma: ${pink_color}Desativa${normal_color}"
	arr["RUSSIAN",475]="Автоопределение языка при запуске: ${pink_color}Отключено${normal_color}"
	arr["GREEK",475]="Αυτόματος εντοπισμός γλώσσας κατά την εκκίνηση: ${pink_color}Απενεργοποιημένο${normal_color}"
	arr["ITALIAN",475]="Rilevamento automatico della lingua all'inizio: ${pink_color}Disabilitato${normal_color}"
	arr["POLISH",475]="Automatyczne wykrywanie języka podczas uruchamiania: ${pink_color}Niepełnosprawnych${normal_color}"
	arr["GERMAN",475]="Automatische Spracherkennung am Start: ${pink_color}Deaktiviert${normal_color}"
	arr["TURKISH",475]="Başlangıç dili otomatik algılama: ${pink_color}DevreDışı${normal_color}"

	arr["ENGLISH",476]="A graphical X window system has not been detected. If you already have one, check it's working properly. It's essential for airgeddon. The script can't continue"
	arr["SPANISH",476]="No se ha detectado un sistema gráfico de ventanas X. Si lo tienes, comprueba su que esté funcionando correctamente. Es esencial para airgeddon. El script no puede continuar"
	arr["FRENCH",476]="Aucun système graphique X window détecté. Si un tel système est installé vérifiez qu'il fonctionne correctement. Le script ne peut pas continuer sans ça"
	arr["CATALAN",476]="No s'ha detectat un sistema gràfic de finestres X. Si el tens, comprova que estigui funcionant correctament. És essencial per a airgeddon. El script no pot continuar"
	arr["PORTUGUESE",476]="Não foi detectado um sistema X Window (interface gráfica). Se você possui, verifique se está funcionando corretamente. É essencial para airgeddon. O script não pode continuar"
	arr["RUSSIAN",476]="Графическая X система не обнаружена. Если она уже имеется, проверьте её работоспособность. Это важно для airgeddon. Скрипт не может продолжить"
	arr["GREEK",476]="Δεν έχει εντοπιστεί κάποιο γραφικό σύστημα παραθύρων X. Αν έχετε ήδη ένα, ελέγξτε ότι λειτουργεί σωστά. Είναι απαραίτητο για το airgeddon. Το script δεν μπορεί να συνεχίσει"
	arr["ITALIAN",476]="Non è stato rilevato un server X grafico, se è presente controllare il corretto funzionamento. È essenziale per airgeddon. Lo script non può continuare"
	arr["POLISH",476]="Nie wykryto graficznego systemu X Window. Jeśli go masz, sprawdź czy działa poprawnie. Jest niezbędne dla airgeddon. Skrypt nie może kontynuować"
	arr["GERMAN",476]="Kein X Window-Grafiksystem wurde erkannt. Wenn Sie es haben, prüfen Sie, ob es richtig funktioniert. Es ist für airgeddon sehr wichtig. Das Skript kann nicht weiterfahren"
	arr["TURKISH",476]="${pending_of_translation} Bir grafik X pencere sistemi tespit edilmedi. Zaten sahipseniz, düzgün çalıştığını kontrol edin. Airgeddon için şarttır. Komut devam edemiyor"

	arr["ENGLISH",477]="The options in this menu containing the word \"permanently\" modify airgeddon to save the settings for the next time that is to be launched. However, you can always return to this menu to change the value of the option again"
	arr["SPANISH",477]="Las opciones de este menú que contienen la palabra \"permanentemente\", modifican airgeddon para que incluso la siguiente vez que sea iniciado siga guardando la configuración. No obstante, siempre puedes volver a este menú a cambiar de nuevo el valor de la opción"
	arr["FRENCH",477]="Les options contenant le mot \"permanente\" modifiént airgeddon de sorte que les paramétrages persisteront lors des prochains redémarrages. Vous pourrez cependant toujours modifier la configuration permanante depuis ce même menu"
	arr["CATALAN",477]="Les opcions d'aquest menú que contenen la paraula \"permanentment\", modifiquen airgeddon perquè fins i tot la següent vegada que sigui iniciat segueixi guardant la configuració. No obstant això, sempre pots tornar a aquest menú a canviar de nou el valor de l'opció"
	arr["PORTUGUESE",477]="As opções neste menu contendo a palavra \"permanentemente\" serão modificadas de modo que mesmo no próximo início do airgeddon as configurações serão mantidas. No entanto, você pode sempre voltar a este menu e alterar as opções"
	arr["RUSSIAN",477]="Опции в этом меню, содержащие слово \"постоянное\", сохраняются в airgeddon при перезапусках программы. Однако вы всегда можете вернуться в это меню, чтобы снова изменить значение параметра"
	arr["GREEK",477]="Οι επιλογές σε αυτό το μενού που περιέχουν τη λέξη \"μόνιμα\" τροποποιούν το airgeddon ώστε να αποθηκεύει τις ρυθμίσεις για την επόμενη φορά. Ωστόσο, μπορείτε πάντα να επιστρέψετε σε αυτό το μενού για να αλλάξετε ξανά την τιμή της επιλογής"
	arr["ITALIAN",477]="Le opzioni di questo menú che contengono la parola \"permanentemente\" modificano airgeddon in modo che anche la volta successiva che viene avviato continui con la configurazione salvata. Tuttavia, si può sempre tornare a questo menú per cambiare di nuovo il valore dell'opzione"
	arr["POLISH",477]="Opcje w tym menu, które zawierają słowo \"trwale\" zmodyfikują airgeddon tak, że nawet przy następnym uruchomieniu będą zapisane. Jednak zawsze możesz wrócić do tego menu, aby ponownie zmienić ustawienia"
	arr["GERMAN",477]="Die Optionen dieses Menüs, die das Wort \"dauerhaft\" enthalten, modifizieren airgeddon so, dass auch beim nächsten Start die Konfiguration gespeichert wird. Sie können jedoch jederzeit zu diesem Menü zurückkehren, um den Wert der Option erneut zu ändern"
	arr["TURKISH",477]="${pending_of_translation} Bu menüdeki \"kalıcı\" kelimesini içeren seçenekler, başlatılacak bir sonraki seferde ayarları kaydetmek için airgeddon'u değiştirir. Ancak, seçeneğin değerini tekrar değiştirmek için bu menüye her zaman dönebilirsiniz"

	arr["ENGLISH",478]="${blue_color}Language is going to be set permanently to the current one, so on the next start of airgeddon it will be used directly. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",478]="${blue_color}Se va a cambiar permanentemente el idioma al actual para que al siguiente inicio de airgeddon este sea el idioma en el que arranque directamente. ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",478]="${blue_color}La langue actuelle va être activée de façon permanente, c'est à dire que ce sera la langue d'usage lors des prochains démarrages d'airgeddon. ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",478]="${blue_color}Es canviarà permanentment l'idioma a l'actual perquè al següent inici d' airgeddon aquest sigui l'idioma en què arrenqui directament. ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",478]="${blue_color}O idioma será definida permanentemente para o atual, no próximo início do airgeddon este será o idioma usado. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",478]="${blue_color}Текущий язык будет установлен как постоянный, поэтому при следующем запуске airgeddon он будет использоваться без определения языка системы. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",478]="${blue_color}Η τρέχουσα γλώσσα πρόκειται να τεθεί μόνιμα ως προεπιλεγμένη, ώστε κατά την επόμενη εκκίνηση του airgeddon θα χρησιμοποιηθεί κατ' ευθείαν αυτή. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",478]="${blue_color}Sarà modificata in modo permanente la lingua corrente in modo che al prossimo avvio di airgeddon questa sia la lingua di avvio. ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",478]="${blue_color}To na stałe zmieni język na aktualny, tak aby był ustawiony przy następnym uruchomieniu airgeddon. ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",478]="${blue_color}Die aktuelle Sprache wird permanent geändert, so dass der nächste Start von airgeddon in diese Sprache direkt startet. ${green_color}Möchten Sie weitermachen? ${normal_color}${visual_choice}"
	arr["TURKISH",478]="${pending_of_translation} ${blue_color}Dil, geçerli olana kalıcı olarak ayarlanacaktır, böylece bir sonraki hava yolu başlatmada doğrudan kullanılacaktır. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",479]="This change conflicts with the startup language autodetection which is currently enabled. It will be disabled automatically in order to perform the change"
	arr["SPANISH",479]="Este cambio entra en conflicto con la autodetección del idioma al inicio que en este momento está activada. Se desactivará automáticamente para poder realizar el cambio"
	arr["FRENCH",479]="Ce changement entre en conflit avec la détection automatique de la langue au démarrage qui est actuellement activée. Elle va être automatiquement désactivée pour effectuer le changement"
	arr["CATALAN",479]="Aquest canvi entra en conflicte amb la detecció automàtica de l'idioma a l'inici que en aquest moment està activada. Es desactivarà automàticament per a poder realitzar el canvi"
	arr["PORTUGUESE",479]="Esta mudança entra em conflito com a detecção automática do idioma, ativa atualmente. Ela será desativa automaticamente ao fazer essa mudança"
	arr["RUSSIAN",479]="Это изменение конфликтует с автоопределением языка, которое в данный момент включено. Оно будет автоматически отключено для выполнения изменения"
	arr["GREEK",479]="Αυτή η αλλαγή έρχεται σε σύγκρουση με τoν αυτόματo εντοπισμό της γλώσσας εκκίνησης, ο οποίος είναι αυτή τη στιγμή ενεργοποιημένος. Θα απενεργοποιηθεί αυτόματα για να πραγματοποιηθεί η αλλαγή αυτή"
	arr["ITALIAN",479]="Questo cambio è in conflitto con il rilevamento automatico di lingua di inizio che è attualmente attivo. Esso viene disattivato automaticamente per poter fare il cambio"
	arr["POLISH",479]="Ta zmiana jest sprzeczna z automatyczną detekcją języka na początku, która jest aktualnie aktywna. Zostanie ona automatycznie deazktywowana w celu wprowadzenia zmian"
	arr["GERMAN",479]="Diese Änderung steht im Konflikt mit der automatischen Spracherkennung, die zu diesem Zeitpunkt am Anfang aktiviert ist. Es wird automatisch deaktiviert, um die Änderung vorzunehmen"
	arr["TURKISH",479]="${pending_of_translation} Bu değişiklik, şu anda etkin olan başlangıç dili otomatik algılama ile çakışıyor. Değişikliği gerçekleştirmek için otomatik olarak devre dışı bırakılacaktır"

	arr["ENGLISH",480]="Current language is the same of permanent language already set. No changes will be done"
	arr["SPANISH",480]="El idioma actual es el mismo que ya está puesto como permanente. No se realizarán cambios"
	arr["FRENCH",480]="La langue actuelle est la même que celle désignée comme langue permanente. Pas de changements"
	arr["CATALAN",480]="L'idioma actual és el mateix que ja està posat com permanent. No es realitzaran canvis"
	arr["PORTUGUESE",480]="O idioma atual já é o permanente. Nenhuma alteração será feita"
	arr["RUSSIAN",480]="Текущий язык тот же, что и уже установленный постоянный язык. Никаких изменений не будет сделано"
	arr["GREEK",480]="Η τρέχουσα γλώσσα είναι ίδια με τη μόνιμη γλώσσα που έχει οριστεί ήδη. Δεν θα γίνει καμία αλλαγή"
	arr["ITALIAN",480]="La lingua è la stessa che è giá impostata come permanente. Nessuna modifica sará effettuata"
	arr["POLISH",480]="Obecny język jest taki sam jak ten, który został już ustawiony jako stały. Nie zostaną wprowadzone żadne zmiany"
	arr["GERMAN",480]="Die aktuelle Sprache ist dieselbe, die bereits als permanent festgelegt wurde. Es werden keine Änderungen vorgenommen"
	arr["TURKISH",480]="Mevcut dil, zaten ayarlanmış olan kalıcı dil ile aynı. Hiçbir değişiklik yapılmayacak"

	arr["ENGLISH",481]="Language set to the current one permanently"
	arr["SPANISH",481]="Idioma cambiado al actual permanentemente"
	arr["FRENCH",481]="La langue choisie est l'actuelle langue permanente"
	arr["CATALAN",481]="Idioma canviat a l'actual permanentment"
	arr["PORTUGUESE",481]="Idioma definido permanentemente para o atual"
	arr["RUSSIAN",481]="Язык изменён на текущий с сохранением после перезапуска"
	arr["GREEK",481]="Τέθηκε μόνιμα η τρέχουσα γλώσσα"
	arr["ITALIAN",481]="Lingua cambiata a quella attuale permanentemente"
	arr["POLISH",481]="Język trwale zmienił się na aktualny"
	arr["GERMAN",481]="Die Sprache wurde permanent geändert"
	arr["TURKISH",481]="Geçerli dil kalıcı olarak ayarlandı"

	arr["ENGLISH",482]="8.  Italian"
	arr["SPANISH",482]="8.  Italiano"
	arr["FRENCH",482]="8.  Italien"
	arr["CATALAN",482]="8.  Italià"
	arr["PORTUGUESE",482]="8.  Italiano"
	arr["RUSSIAN",482]="8.  Итальянский"
	arr["GREEK",482]="8.  Ιταλικά"
	arr["ITALIAN",482]="8.  Italiano"
	arr["POLISH",482]="8.  Włoski"
	arr["GERMAN",482]="8.  Italienisch"
	arr["TURKISH",482]="8.  İtalyanca"

	arr["ENGLISH",483]="Language changed to Italian"
	arr["SPANISH",483]="Idioma cambiado a Italiano"
	arr["FRENCH",483]="Le script sera maintenant en Italien"
	arr["CATALAN",483]="Idioma canviat a Italià"
	arr["PORTUGUESE",483]="Idioma alterado para Italiano"
	arr["RUSSIAN",483]="Язык изменён на Итальянский"
	arr["GREEK",483]="Η γλώσσα άλλαξε στα Ιταλικά"
	arr["ITALIAN",483]="Lingua cambiata in Italiano"
	arr["POLISH",483]="Zmieniono język na Włoski"
	arr["GERMAN",483]="ie Sprache wurde auf Italienisch geändert"
	arr["TURKISH",483]="Dil İtalyanca olarak değiştirildi"

	arr["ENGLISH",484]="Root permissions successfully detected"
	arr["SPANISH",484]="Permisos de root correctamente detectados"
	arr["FRENCH",484]="Autorisation root detectés"
	arr["CATALAN",484]="Permisos de root correctament detectats"
	arr["PORTUGUESE",484]="Permissões de root detectadas corretamente"
	arr["RUSSIAN",484]="Успешно определены права root"
	arr["GREEK",484]="Τα δικαιώματα root έχουν παραχωρηθεί επιτυχώς"
	arr["ITALIAN",484]="I permessi di root sono stati rilevati correttamente"
	arr["POLISH",484]="Uprawnienia root zostały prawidłowo wykryte"
	arr["GERMAN",484]="Richtig erkannte root-Berechtigungen"
	arr["TURKISH",484]="Root yetkileri başarıyla tespit edildi"

	arr["ENGLISH",485]="${blue_color}Some PINs have been added calculated using the algorithms (ComputePIN, EasyBox, etc.), however you can add one more (Arcadyan). Calculating it requires certain data and a background scan will have to be performed. The process may be very slow. ${green_color}Do you want to proceed with the calculation to add it? ${normal_color}${visual_choice}"
	arr["SPANISH",485]="${blue_color}Se han añadido algunos PINs calculados por algoritmos (ComputePIN, EasyBox, etc.), pero aún se puede añadir uno más (Arcadyan). Calcularlo requiere ciertos datos y habrá que realizar un escaneo en segundo plano. Es posible que el proceso sea muy lento. ${green_color}¿Quieres proceder con el cálculo para añadirlo? ${normal_color}${visual_choice}"
	arr["FRENCH",485]="${blue_color}Certains PINs ajouté ont été calculés par des algorithmes (ComputePIN, EasyBox, etc.), mais vous pouvez encore ajouter un autre (Arcadyan). Le calcul nécessite certaines données et une analyse d'arrière-plan devra être effectuée. Le processus peut être très lent. ${green_color}Voulez-vous procéder au calcul pour l'ajouter? ${normal_color}${visual_choice}"
	arr["CATALAN",485]="${blue_color}S'han afegit alguns PINs calculats per algoritmes (ComputePIN, EasyBox, etc.), però encara es pot afegir un més (Arcadyan). Calcular-lo requereix certes dades i caldrà realitzar un escaneig en segon pla. És possible que el procés sigui molt lent. ${green_color}¿Vols procedir amb el càlcul per afegir-ho? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",485]="${blue_color}Alguns PINs adicionados foram calculados usando algoritmos (ComputePIN, EasyBox, etc.), mas você ainda pode adicionar mais um (Arcadyan). Calculá-lo requer certos dados e uma verificação em segundo plano terá que ser realizada. O processo pode ser muito lento. ${green_color}Deseja continuar com o cálculo para adicioná-lo? ${normal_color}${visual_choice}"
	arr["RUSSIAN",485]="${blue_color}Некоторые добавленные PIN были вычислены алгоритмами (ComputePIN, EasyBox, и т.д.), но вы можете добавить ещё один (Arcadyan). Для его вычисления требуются определенные данные, и необходимо выполнить фоновое сканирование. Процесс может быть очень медленным. ${green_color}Вы хотите добавить PIN, вычисленные этим алгоритмом? ${normal_color}${visual_choice}"
	arr["GREEK",485]="${blue_color}Έχουν προστεθεί ορισμένοι κωδικοί PIN υπολογισμένοι με τους αλγόριθμους (ComputePIN, EasyBox, κτλπ.), μπορείτε όμως να προσθέσετε άλλον έναν κωδικό (Arcadyan). Ο υπολογισμός του απαιτεί ορισμένα δεδομένα και θα πρέπει να πραγματοποιηθεί κάποιο scan στο background. Η διαδικασία αυτή μπορεί να αργοπορήσει. ${green_color}Θέλετε να συνεχίσετε με τον υπολογισμό του και να τον προσθέσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",485]="${blue_color}Sono stati aggiunti alcuni PIN calcolati da algoritmi (ComputePIN, EasyBox, etc.), ma è possibile aggiungerne ancora uno (Arcadyan). Il calcolo richiede alcuni dati e deve essere eseguita una scansione in secondo piano. Il processo può essere molto lento. ${green_color}Vuoi procedere con il calcolo per aggiungerlo? ${normal_color}${visual_choice}"
	arr["POLISH",485]="${blue_color}Niektóre kody PIN zostały dodane obliczone algorytmami (ComputePIN, EasyBox, itd.) ale można jeszcze dodać jeden (Arcadyan). Obliczanie go wymaga pewnych danych oraz będzie musiało zostać wykonane skanowanie w tle. Proces ten może być bardzo powolny. ${green_color}Czy chcesz kontynuować obliczenie, aby go dodać? ${normal_color}${visual_choice}"
	arr["GERMAN",485]="${blue_color}Einige von Algorithmen berechnete PINs (ComputePIN, EasyBox usw.) wurden hinzugefügt, aber es kann noch eine weitere hinzugefügt werden (Arcadyan). Die Berechnung erfordert bestimmte Daten und ein Scan im Hintergrund muss durchgeführt werden. Es ist möglich, dass der Prozess sehr langsam ist. ${green_color}Möchten Sie mit der Berechnung fortfahren, um sie hinzuzufügen? ${normal_color}${visual_choice}"
	arr["TURKISH",485]="${pending_of_translation} ${blue_color}Bazı PIN'ler algoritmalar (ComputePIN, EasyBox, vb.) Kullanılarak hesaplanmıştır, ancak bir tane daha ekleyebilirsiniz (Arcadyan). Bunu hesaplamak belirli veriler gerektirir ve bir arka plan taramasının yapılması gerekir. İşlem çok yavaş olabilir. ${green_color}Eklemek istediğiniz hesaplamaya devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",486]="It's not possible to generate PIN with Arcadyan algorithm. To be able to do it, update \"wash\" (included in reaver package) to a newer version including the necessary \"-j\" option (v${minimum_wash_json_version})"
	arr["SPANISH",486]="No es posible generar el PIN con el algoritmo Arcadyan. Para poder hacerlo actualice \"wash\" (incluido en el paquete reaver) a una versión superior que tenga la necesaria opción \"-j\" (v${minimum_wash_json_version})"
	arr["FRENCH",486]="Il n'est pas possible de générer le PIN avec l'algorithme Arcadyan. Pour ce faire, mettez à jour \"wash\" (inclus dans le paquet reaver) vers une version supérieure qui a l'option \"-j\" (v${minimum_wash_json_version})"
	arr["CATALAN",486]="No és possible fer el PIN amb l'algoritme Arcadyan. Per poder fer-ho actualitzi \"wash\" (inclòs en el paquet reaver) a una versió superior que tingui la necessària opció \"-j\" (v${minimum_wash_json_version})"
	arr["PORTUGUESE",486]="Não foi possível gerar o PIN com o algoritmo Arcadyan. Para isso, atualize \"wash\" (incluso no pacote reaver) para uma versão que tenha a opção necessária \"-j\" (v${minimum_wash_json_version})"
	arr["RUSSIAN",486]="Невозможно создать PIN с алгоритмом Arcadyan. Чтобы это сделать, обновите \"wash\" (включена в пакет reaver) на более новую версию, которая имеет необходимую опцию \"-j\" (v${minimum_wash_json_version})"
	arr["GREEK",486]="Δεν είναι δυνατό να δημιουργηθεί PIN με τον αλγόριθμο Arcadyan. Για να το κάνετε αυτό, ενημερώστε το \"wash\" (περιλαμβάνεται στο πακέτο του reaver) σε νεότερη έκδοση, συμπεριλαμβανομένης της απαραίτητης επιλογής \"-j\" (v${minimum_wash_json_version})"
	arr["ITALIAN",486]="Non è possibile generare il PIN con l'algoritmo Arcadyan. Per effettuare questa operazione, aggiornare \"wash\" (incluso nel pacchetto reaver) a una versione più nuova che disponga dell'opzione necessaria \"-j\" (v${minimum_wash_json_version})"
	arr["POLISH",486]="Nie jest możliwe wygenerowanie kodu PIN za pomocą algorytmu Arcadyan. Aby to zrobić, uaktualnij \"wash\" (zawarty w pakiecie reaver) do wyższej wersji, która wspiera opcję \"-j\" (v${minimum_wash_json_version})"
	arr["GERMAN",486]="Es ist nicht möglich, die PIN mit dem Arcadyan-Algorithmus zu generieren. Aktualisieren Sie dazu \"wash\" (im reaver-Paket enthalten) auf eine höhere Version mit der erforderlichen Option \"-j\" (v${minimum_wash_json_version})"
	arr["TURKISH",486]="${pending_of_translation} Arcadyan algoritması ile PIN üretmek mümkün değil. Bunu yapabilmek için gerekli \"-j\" seçeneği de dahil olmak üzere daha yeni bir sürüme \"wash\" (reaver paketinde yer alan) güncelleştirin (v${minimum_wash_json_version})"

	arr["ENGLISH",487]="PIN generated using Arcadyan algorithm (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["SPANISH",487]="Se ha generado el PIN con el algoritmo Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["FRENCH",487]="Le PIN a été généré avec l'algorithme Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["CATALAN",487]="S'ha generat el PIN amb l'algoritme Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["PORTUGUESE",487]="Foi gerado um PIN com o algoritmo Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["RUSSIAN",487]="PIN-код, созданный с использованием алгоритма Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["GREEK",487]="Το PIN δημιουργήθηκε με τον αλγόριθμο Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["ITALIAN",487]="Il PIN è stato generato con l'algoritmo Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["POLISH",487]="PIN został wygenerowany za pomocą algorytmu Arcadyan (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["GERMAN",487]="Die PIN wurde mit dem Arcadyan-Algorithmus generiert (${normal_color}${arcadyan_pin}${yellow_color})"
	arr["TURKISH",487]="${pending_of_translation} Arcadyan algoritması kullanılarak oluşturulan PIN (${normal_color}${arcadyan_pin}${yellow_color})"

	arr["ENGLISH",488]="PIN can't be generated using Arcadyan algorithm. Failed to collect a complete \"probe\" response from the access point. Probably because of low signal quality"
	arr["SPANISH",488]="No se ha podido generar el PIN con el algoritmo Arcadyan. No se ha podido recoger una respuesta \"probe\" completa del punto de acceso. Probablemente porque la señal no es buena"
	arr["FRENCH",488]="Impossible de générer le PIN avec l'algorithme Arcadyan. Impossible de collecter une réponse complète \"probe\" à partir du point d'accès. Probablement parce que le signal n'est pas de bonne qualite"
	arr["CATALAN",488]="No s'ha pogut generar el PIN amb l'algoritme Arcadyan. No s'ha pogut recollir una resposta \"probe\" completa del punt d'accés. Probablement perquè el senyal no és bona"
	arr["PORTUGUESE",488]="Não foi possível gerar um PIN com o algoritmo Arcadyan. Falha ao coletar a resposta de \"probe\" completa do ponto de acesso. Provavelmente porque o sinal não é bom"
	arr["RUSSIAN",488]="PIN-код не может быть сгенерирован с использованием алгоритма Arcadyan. Не удалось получить полный ответ \"probe\" от точки доступа. Возможно, из-за низкого качества сигнала"
	arr["GREEK",488]="Το PIN δεν μπορεί να δημιουργηθεί χρησιμοποιώντας τον αλγόριθμο Arcadyan. Δεν ήταν δυνατή η συλλογή πλήρους \"probe\" response από το σημείο πρόσβασης. Πιθανόν επειδή το σήμα είναι χαμηλό"
	arr["ITALIAN",488]="Impossibile generare il PIN con l'algoritmo Arcadyan. Impossibile raccogliere una risposta \"probe\" completa dal punto di accesso. Probabilmente perché il segnale non è buono"
	arr["POLISH",488]="Nie można wygenerować kodu PIN za pomocą algorytmu Arcadyan. Nie udało się zebrać kompletnej odpowiedzi \"probe\" z punktu dostępu. Prawdopodobnie dlatego, że pozion sygnału jest słaby"
	arr["GERMAN",488]="Die PIN konnte nicht mit dem Arcadyan-Algorithmus generiert werden. Keine vollständige Antwort \"probe\" vom Zugriffspunkt konnte gesammelt werden. Wahrscheinlich, weil das Signal nicht gut genug ist"
	arr["TURKISH",488]="${pending_of_translation} PIN, Arcadyan algoritması kullanılarak oluşturulamaz. Erişim noktasından eksiksiz bir \"probe\" yanıtı toplanamadı. Muhtemelen düşük sinyal kalitesi nedeniyle"

	arr["ENGLISH",489]="Attempting to collect a complete \"probe\" response from the target access point. This process can take up to 4 minutes..."
	arr["SPANISH",489]="Intentando recoger una respuesta \"probe\" completa del punto de acceso objetivo. Este proceso puede durar hasta 4 minutos..."
	arr["FRENCH",489]="Tentative de collecter une réponse complète de \"probe\" à partir du point d'accès ciblé. Ce processus peut prendre jusqu'à 4 minutes..."
	arr["CATALAN",489]="Intentant recollir una resposta \"probe\" completa del punt d'accés objectiu. Aquest procés pot durar fins a 4 minuts..."
	arr["PORTUGUESE",489]="Tentando coletar uma resposta de \"probe\" completa do ponto do acesso. Este processo pode levar até 4 minutos..."
	arr["RUSSIAN",489]="Попытка собрать полный запрос \"probe\" от целевой точки доступа. Этот процесс может занять до 4 минут..."
	arr["GREEK",489]="Γίνεται προσπάθεια συλλογής πλήρους \"probe\" response από το σημείο πρόσβασης (στόχος). Αυτή η διαδικασία μπορεί να διαρκέσει έως και 4 λεπτά..."
	arr["ITALIAN",489]="Cercando di raccogliere una risposta \"probe\" completa dal punto di accesso obiettivo. Questo processo può richiedere fino a 4 minuti..."
	arr["POLISH",489]="Próba zebrania kompletnej odpowiedzi \"probe\" z docelowego punktu dostępu. Proces ten może potrwać do 4 minut..."
	arr["GERMAN",489]="Versuch, eine vollständige \"probe\"-Antwort vom Zielzugriffspunkt zu sammeln. Dieser Prozess kann bis zu 4 Minuten dauern..."
	arr["TURKISH",489]="${pending_of_translation} Hedef erişim noktasından eksiksiz bir \"probe\" yanıtı toplamaya çalışılıyor. Bu işlem 4 dakika kadar sürebilir..."

	arr["ENGLISH",490]="The Arcadyan algorithm needs a very specific data to calculate the PIN (the serial number of the access point). Getting this data can take a lot of time. You can optionally choose to try to generate it. This generated PIN is very useful in networks of type Orange-XXXX"
	arr["SPANISH",490]="El algoritmo Arcadyan necesita un dato muy concreto para poder calcular el PIN (el número de serie del punto de acceso). Obtener este dato puede llevar bastante tiempo. Podrás elegir opcionalmente intentar generarlo. Este PIN generado es muy útil en redes del tipo Orange-XXXX"
	arr["FRENCH",490]="L'algorithme Arcadyan nécessite des données très spécifiques pour calculer le PIN (le numéro de série du point d'accès). L'obtention de ces données peut prendre un certain temps. Vous pouvez choisir optionnellement d'essayer de le générer. Ce PIN généré est très utile dans les réseaux de type Orange-XXXX"
	arr["CATALAN",490]="L'algoritme Arcadyan necessita una dada molt concret per poder calcular el PIN (el nombre de sèrie del punt d'accés). Obtenir aquesta dada pot portar prou de temps. Podràs triar opcionalment intentar generar-lo. Aquest PIN generat és molt útil en xarxes del tipus Orange-XXXX"
	arr["PORTUGUESE",490]="O algoritmo Arcadyan precisa de dados muito específicos para calcular o PIN (o número de série do ponto de acesso). Obter esses dados pode levar bastante tempo mas você pode optar por tentar gerá-los. O PIN gerado é muito útil nas redes Orange-XXXX"
	arr["RUSSIAN",490]="Алгоритм Arcadyan требует очень специфических данных для расчета PIN-кода (серийный номер точки доступа). Получение этих данных может занять много времени. При желании вы можете сгенерировать PIN, используя этот алгоритм. Этот сгенерированный PIN-код очень полезен в сетях типа Orange-XXXX"
	arr["GREEK",490]="Ο αλγόριθμος Arcadyan χρειάζεται πολύ συγκεκριμένα δεδομένα για τον υπολογισμό του PIN (ο σειριακός αριθμός του σημείου πρόσβασης). Η λήψη αυτών των δεδομένων μπορεί να χρειαστεί αρκετό χρόνο. Μπορείτε να επιλέξετε να προσπαθήσετε να το δημιουργήσετε. Tο PIN που θα δημιουργηθεί είναι πολύ χρήσιμο σε δίκτυα τύπου Orange-XXXX"
	arr["ITALIAN",490]="L'algoritmo Arcadyan richiede dati molto specifici per calcolare il PIN (il numero di serie del punto di accesso). Ottenere questi dati può richiedere molto tempo. Puoi scegliere opzionalmente di provare a generarlo. Questo PIN generato è molto utile nelle reti di tipo Orange-XXXX"
	arr["POLISH",490]="Algorytm Arcadyan potrzebuje bardzo specyficznych danych do obliczania numeru PIN (numeru seryjny punktu dostępu). Uzyskanie tych danych może zająć trochę czasu. Można opcjonalnie zdecydować się na jego wygenerowanie. Ten wygenerowany kod PIN jest bardzo przydatny w sieciach typu Orange-XXXX"
	arr["GERMAN",490]="Der Arcadyan-Algorithmus benötigt sehr spezifische Daten, um die PIN (die Seriennummer des Access Points) berechnen zu können. Die Beschaffung dieser Daten kann sehr lange dauern. Sie können optional auswählen, ob Sie versuchen möchten, es zu generieren. Diese generierte PIN ist sehr nützlich in Netzwerken vom Typ Orange-XXXX"
	arr["TURKISH",490]="${pending_of_translation} Arcadyan algoritmasının PIN'i hesaplamak için çok özel bir veriye ihtiyacı vardır (erişim noktasının seri numarası). Bu verileri almak çok zaman alabilir. İsteğe bağlı olarak onu oluşturmayı deneyebilirsiniz. Bu oluşturulan PIN, Orange-XXXX türündeki ağlarda çok kullanışlıdır"

	arr["ENGLISH",491]="Arcadyan algorithm is not useful for the selected target network, a valid value can't be calculated"
	arr["SPANISH",491]="El algoritmo Arcadyan no sirve para la red objetivo seleccionada, no se puede calcular un valor válido"
	arr["FRENCH",491]="L'algorithme Arcadyan ne correspond pas au réseau sélectionné, une valeur valide ne peut pas être calculée"
	arr["CATALAN",491]="L'algoritme Arcadyan no serveix per a la xarxa objectiu seleccionada, no es pot calcular un valor vàlid"
	arr["PORTUGUESE",491]="O algoritmo Arcadyan não se encaixa na rede selecionada, não foi possível calcular um valor válido"
	arr["RUSSIAN",491]="Алгоритм Arcadyan бесполезен для выбранной целевой сети, действительное значение не может быть рассчитано"
	arr["GREEK",491]="Ο αλγόριθμος Arcadyan δεν είναι χρήσιμος για το επιλεγμένο δίκτυο, δεν μπορεί να υπολογιστεί έγκυρη τιμή"
	arr["ITALIAN",491]="L'algoritmo Arcadyan non è adatto alla rete selezionata come obiettivo, non è possibile calcolare un valore valido"
	arr["POLISH",491]="Algorytm Arcadyan nie pasuje do wybranej sieci docelowej, nie można obliczyć prawidłowej wartości"
	arr["GERMAN",491]="Der Arcadyan-Algorithmus funktioniert nicht für das ausgewählte Zielnetzwerk, ein gültiger Wert kann nicht berechnet werden"
	arr["TURKISH",491]="${pending_of_translation} Arcadyan algoritması seçilen hedef ağ için kullanışlı değildir, geçerli bir değer hesaplanamaz"

	arr["ENGLISH",492]="The Arcadyan algorithm can't be calculated. Although you chose the bully option for the attack, you need to use wash (included in reaver package) to calculate that PIN and you don't have it installed. The script will continue the attack without including it"
	arr["SPANISH",492]="El algoritmo Arcadyan no puede ser calculado. Aunque elegiste la opción de ataque con bully, para calcular ese PIN se necesita utilizar wash (incluido en el paquete reaver) y tú no lo tienes instalado. El script continuará el ataque sin incluirlo"
	arr["FRENCH",492]="L'algorithme Arcadyan ne peut pas être calculé. Bien que vous ayez choisi l'option d'attaque bully, pour calculer ce PIN, vous devez utiliser wash (inclus dans le paquet reaver) et vous ne l'avez pas installé. Le script continuera l'attaque sans l'inclure"
	arr["CATALAN",492]="L'algoritme Arcadyan no pot ser calculat. Encara que vas triar l'opció d'atac amb bully, per calcular aquest PIN es necessita utilitzar wash (inclòs en el paquet reaver) i tu no el tens instal·lat. El script continuarà l'atac sense incloure"
	arr["PORTUGUESE",492]="O algoritmo Arcadyan não pôde efetuar o calculo. Embora você tenha escolhido a opção de ataque com bully, para calcular esse PIN, você precisa usar wash (incluso no pacote reaver) que você não possui. O script continuará o ataque sem calculá-lo"
	arr["RUSSIAN",492]="Алгоритм Arcadyan не может быть рассчитан. Вы выбрали опцию bully для атаки, а для расчета этого PIN-кода вам необходимо использовать wash (включенную в пакет reaver), который у вас не установлен. Скрипт продолжит атаку без этого алгоритма"
	arr["GREEK",492]="Ο αλγόριθμος Arcadyan δεν μπορεί να υπολογιστεί. Παρόλο που επιλέξατε την επιλογή bully για την επίθεση, χρειάζεται να χρησιμοποιήσετε το wash (περιλαμβάνεται στο πακέτο του reaver) για να υπολογίσετε το PIN και δεν το έχετε εγκαταστήσει. Το script θα συνεχίσει την επίθεση χωρίς να το συμπεριλάβει"
	arr["ITALIAN",492]="L'algoritmo Arcadyan non può essere calcolato. Anche se hai scelto l'opzione di attacco con bully, per calcolare quel PIN che devi usare wash (incluso nel pacchetto reaver) e non l'hai installato. Lo script continuerà l'attacco senza includerlo"
	arr["POLISH",492]="Nie można obliczyć algorytmu Arcadyan. Chociaż wybrano opcję ataku za pomocą bully, aby obliczyć ten kod PIN, musisz użyć wash (dołączonego do pakietu reaver) i nie masz go zainstalowanego. Skrypt będzie kontynuował atak bez jego włączania"
	arr["GERMAN",492]="Der Arcadyan-Algorithmus kann nicht berechnet werden. Obwohl Sie den bully-Angriff gewählt haben, müssen Sie zur Berechnung dieser PIN die Funktion wash verwenden (im Paket reaver enthalten), und Sie haben sie nicht installiert. Das Skript setzt den Angriff fort, ohne es einzuschließen"
	arr["TURKISH",492]="${pending_of_translation} Arcadyan algoritması hesaplanamaz. Saldırı için zorlama seçeneğini seçmiş olmanıza rağmen, bu PIN'i hesaplamak için yıkama kullanmanız (reaktif paketine dahil) ve onu yüklememeniz gerekir. Komut dahil etmeden saldırıya devam edecek"

	arr["ENGLISH",493]="The Arcadyan algorithm PIN has already been calculated for this target (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). There is no need to calculate it again"
	arr["SPANISH",493]="El PIN del algoritmo Arcadyan ya fue calculado para este objetivo (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). No hace falta calcularlo de nuevo"
	arr["FRENCH",493]="Le PIN de l'algorithme Arcadyan a était déjà calculé pour cette cible (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Pas besoin de le calculer à nouveau"
	arr["CATALAN",493]="El PIN de l'algoritme Arcadyan ja va ser calculat per a aquest objectiu (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). No cal calcular-lo de nou"
	arr["PORTUGUESE",493]="O PIN com algoritmo Arcadyan já foi calculado para esta rede (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Não é necessário calculá-lo novamente"
	arr["RUSSIAN",493]="PIN с помощью алгоритма Arcadyan уже рассчитан для этой цели (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Нет необходимости вычислять его снова"
	arr["GREEK",493]="Ο αλγόριθμος Arcadyan PIN έχει ήδη υπολογιστεί για αυτό το δίκτυο (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Δεν χρειάζεται να υπολογιστεί ξανά"
	arr["ITALIAN",493]="Il PIN dell'algoritmo Arcadyan è già stato calcolato per questo obiettivo (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Non c'è bisogno di calcolarlo di nuovo"
	arr["POLISH",493]="PIN algorytm Arcadyan został już obliczony dla tego celu (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Nie musisz go ponownie obliczać"
	arr["GERMAN",493]="Die Arcadyan-Algorithmus-PIN wurde bereits für diesen Target berechnet (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Keine Notwendigkeit, es erneut zu berechnen"
	arr["TURKISH",493]="${pending_of_translation} Arcadyan algoritması PIN'i zaten bu hedef için hesaplanmıştır (${normal_color}${wps_data_array[${wps_bssid},'Arcadyan']}${yellow_color}). Tekrar hesaplamaya gerek yok"

	arr["ENGLISH",494]="13. Offline PIN generation using algorithms and database"
	arr["SPANISH",494]="13. Generación offline de PINs con algoritmos y base de datos"
	arr["FRENCH",494]="13. Génération offline de PINs avec les algorithmes et la base de données"
	arr["CATALAN",494]="13. Generació offline de PINs amb algoritmes i base de dades"
	arr["PORTUGUESE",494]="13. Gerar PINs offline com algoritmos e com o banco de dados"
	arr["RUSSIAN",494]="13. Офлайн генерация PIN-кода, используя алгоритмы и базу данных"
	arr["GREEK",494]="13. Offline δημιουργία PIN με χρήση δίαφορων αλγορίθμων και έτοιμης βάσης δεδομένων"
	arr["ITALIAN",494]="13. Generazione offline di PIN con algoritmi e database"
	arr["POLISH",494]="13. Generowanie offline kodów PIN z algorytmami i bazą danych"
	arr["GERMAN",494]="13. Offline Generierung von PINs mit Algorithmen und Datenbank"
	arr["TURKISH",494]="${pending_of_translation} 13. Algoritmaları ve veritabanını kullanarak çevrimdışı PIN üretimi"

	arr["ENGLISH",495]="Offline PIN generation menu"
	arr["SPANISH",495]="Menú de generación offline de PINs"
	arr["FRENCH",495]="Menu de génération de PIN offline"
	arr["CATALAN",495]="Menú de generació offline de PINs"
	arr["PORTUGUESE",495]="Menu de geração offline de PINs"
	arr["RUSSIAN",495]="Меню создания PIN-кода"
	arr["GREEK",495]="Μενού offline δημιουργίας PIN"
	arr["ITALIAN",495]="Menu di generazione offline dei PIN"
	arr["POLISH",495]="Menu generowania PIN offline"
	arr["GERMAN",495]="Menü zur Offline-Generierung von PINs"
	arr["TURKISH",495]="${pending_of_translation} Çevrimdışı PIN oluşturma menüsü"

	arr["ENGLISH",496]="5.  Search in PIN database"
	arr["SPANISH",496]="5.  Consultar en la base de datos de PINs"
	arr["FRENCH",496]="5.  Chercher dans la base de données PIN"
	arr["CATALAN",496]="5.  Consultar a la base de dades de PINs"
	arr["PORTUGUESE",496]="5.  Verificar PINs no banco de dados"
	arr["RUSSIAN",496]="5.  Поиск в базе данных PIN-кода"
	arr["GREEK",496]="5.  Αναζήτηση στη βάση δεδομένων PIN"
	arr["ITALIAN",496]="5.  Controllare il database dei PIN"
	arr["POLISH",496]="5.  Sprawdź bazę danych PIN"
	arr["GERMAN",496]="5.  Suchen Sie in der PIN-Datenbank"
	arr["TURKISH",496]="${pending_of_translation} 5.  PIN veritabanında ara"

	arr["ENGLISH",497]="0.  Return to WPS attacks menu"
	arr["SPANISH",497]="0.  Volver al menú de ataques WPS"
	arr["FRENCH",497]="0.  Retour au menu d'attaques WPS"
	arr["CATALAN",497]="0.  Tornar al menú d'atacs WPS"
	arr["PORTUGUESE",497]="0.  Voltar ao menu de ataques WPS"
	arr["RUSSIAN",497]="0.  Вернуться в меню атак WPS"
	arr["GREEK",497]="0.  Επιστροφή στο μενού επιθέσεων WPS"
	arr["ITALIAN",497]="0.  Tornare al menú attacchi WPS"
	arr["POLISH",497]="0.  Wróć do menu Atak WPS"
	arr["GERMAN",497]="0.  Zum WPS-Angriffsmenü zurückkehren"
	arr["TURKISH",497]="${pending_of_translation} 0.  WPS saldırıları menüsüne dön"

	arr["ENGLISH",498]="choose database or algorithm"
	arr["SPANISH",498]="escoge base de datos o algoritmo"
	arr["FRENCH",498]="choisissez la base de données ou l'algorithme"
	arr["CATALAN",498]="tria base de dades o algoritme"
	arr["PORTUGUESE",498]="escolha um algoritmo ou o banco de dados"
	arr["RUSSIAN",498]="выбрать базу данных или алгоритм"
	arr["GREEK",498]="επιλέξτε βάση δεδομένων ή αλγόριθμο"
	arr["ITALIAN",498]="scegliere database o algoritmo"
	arr["POLISH",498]="wybierz bazę danych lub algorytm"
	arr["GERMAN",498]="Wählen Sie eine Datenbank oder einen Algorithmus"
	arr["TURKISH",498]="${pending_of_translation} veritabanı veya algoritma seç"

	arr["ENGLISH",499]="Showing matches in the PIN database..."
	arr["SPANISH",499]="Mostrando coincidencias de la base de datos de PINs..."
	arr["FRENCH",499]="Afficher les résultats de la base de données PIN..."
	arr["CATALAN",499]="Mostrant coincidències de la base de dades de PINs..."
	arr["PORTUGUESE",499]="Mostrando correspondências de PINs do banco de dados..."
	arr["RUSSIAN",499]="Отображение совпадений в базе данных PIN-кода..."
	arr["GREEK",499]="Εμφάνιση αντιστοιχιών στη βάση δεδομένων PIN..."
	arr["ITALIAN",499]="Mostrando le corrispondenze del database dei PIN..."
	arr["POLISH",499]="Wyświetlanie dopasowań z bazy danych PIN..."
	arr["GERMAN",499]="Übereinstimmungen der PIN-Datenbank werden angezeigt..."
	arr["TURKISH",499]="${pending_of_translation} PIN veritabanında eşleşme gösteriliyor..."

	arr["ENGLISH",500]="Showing calculated PIN using ComputePIN algorithm..."
	arr["SPANISH",500]="Mostrando PIN calculado con el algoritmo ComputePIN..."
	arr["FRENCH",500]="Affichage du PIN calculé avec l'algorithme ComputePIN..."
	arr["CATALAN",500]="Mostrant PIN calculat amb l'algoritme ComputePIN..."
	arr["PORTUGUESE",500]="Mostrando o PIN calculado usando o algoritmo ComputePIN..."
	arr["RUSSIAN",500]="Отображение PIN-кода, рассчитанного с использованием алгоритма ComputePIN..."
	arr["GREEK",500]="Εμφανίζεται το PIN που έχει υπολογιστεί χρησιμοποιώντας τον αλγόριθμο ComputePIN..."
	arr["ITALIAN",500]="Mostrando il PIN calcolato utilizzando l'algoritmo ComputePIN..."
	arr["POLISH",500]="Wyświetlanie kodu PIN obliczonego przy użyciu algorytmu ComputePIN..."
	arr["GERMAN",500]="Berechnete PIN mit dem ComputePIN-Algorithmus anzeigen..."
	arr["TURKISH",500]="${pending_of_translation} ComputePIN algoritması kullanılarak hesaplanan PIN gösteriliyor..."

	arr["ENGLISH",501]="Showing calculated PIN using EasyBox algorithm..."
	arr["SPANISH",501]="Mostrando PIN calculado con el algoritmo EasyBox..."
	arr["FRENCH",501]="Affichage du PIN calculé avec l'algorithme EasyBox..."
	arr["CATALAN",501]="Mostrant PIN calculat amb l'algoritme EasyBox..."
	arr["PORTUGUESE",501]="Mostrando o PIN calculado usando o algoritmo EasyBox..."
	arr["RUSSIAN",501]="Отображение PIN-кода, рассчитанного с использованием алгоритма EasyBox..."
	arr["GREEK",501]="Εμφανίζεται το PIN που έχει υπολογιστεί χρησιμοποιώντας τον αλγόριθμο EasyBox..."
	arr["ITALIAN",501]="Mostrando il PIN calcolato utilizzando l'algoritmo EasyBox..."
	arr["POLISH",501]="Wyświetlanie kodu PIN przy użyciu algorytmu EasyBox..."
	arr["GERMAN",501]="Angezeigte PIN wird mit dem EasyBox-Algorithmus berechnet..."
	arr["TURKISH",501]="${pending_of_translation} EasyBox algoritması kullanılarak hesaplanan PIN gösteriliyor..."

	arr["ENGLISH",502]="Showing calculated PIN using Arcadyan algorithm..."
	arr["SPANISH",502]="Mostrando PIN calculado con el algoritmo Arcadyan..."
	arr["FRENCH",502]="Affichage du PIN calculé avec de l'algorithme Arcadyan..."
	arr["CATALAN",502]="Mostrant PIN calculat amb l'algoritme Arcadyan..."
	arr["PORTUGUESE",502]="Mostrando o PIN calculado usando o algoritmo Arcadyan..."
	arr["RUSSIAN",502]="Отображение PIN-кода, рассчитанного с использованием алгоритма Arcadyan..."
	arr["GREEK",502]="Εμφανίζεται το PIN που έχει υπολογιστεί χρησιμοποιώντας τον αλγόριθμο Arcadyan..."
	arr["ITALIAN",502]="Mostrando il PIN calcolato utilizzando l'algoritmo Arcadyan..."
	arr["POLISH",502]="Wyświetlanie kodu PIN obliczonego przy użyciu algorytmu Arcadyan..."
	arr["GERMAN",502]="Berechnete PIN mit Arcadyan-Algorithmus anzeigen..."
	arr["TURKISH",502]="${pending_of_translation} Arcadyan algoritması kullanılarak hesaplanan PIN gösteriliyor..."

	arr["ENGLISH",503]="It's not necessary to perform the scan again to calculate the Arcadyan algorithm PIN. This has already been done in this session"
	arr["SPANISH",503]="No es necesario realizar de nuevo el escaneo para calcular el PIN del algoritmo Arcadyan. Ya se realizó anteriormente en esta sesión"
	arr["FRENCH",503]="Il n'est pas nécessaire d'effectuer de nouveau un scan pour calculer le PIN de l'algorithme Arcadyan. Déjà fait dans cette session"
	arr["CATALAN",503]="No cal realitzar de nou l'escaneig per calcular el PIN de l'algoritme Arcadyan. Ja es va realitzar anteriorment en aquesta sessió"
	arr["PORTUGUESE",503]="Não é necessário executar uma verificação novamente para calcular o PIN com algoritmo Arcadyan. Isso já foi feito nesta sessão"
	arr["RUSSIAN",503]="Нет необходимости снова выполнять сканирование, чтобы вычислить PIN-код алгоритмом Arcadyan. Это уже сделано ранее в ходе этой сессии"
	arr["GREEK",503]="Δεν είναι απαραίτητο να εκτελέσετε ξανά το scan για να υπολογίσετε το PIN χρησιμοποιώντας τον Arcadyan αλγόριθμο. Έχει ήδη πραγματοποιηθεί σε αυτή τη συνεδρία"
	arr["ITALIAN",503]="Non è necessario eseguire nuovamente la scansione per calcolare il PIN dell'algoritmo Arcadyan. È già stato fatto in precedenza in questa sessione"
	arr["POLISH",503]="Nie jest konieczne przeprowadzanie skanowania aby obliczyć PIN algorytmem Arcadyan. Już zrobiliśmy je wcześniej w tej sesji"
	arr["GERMAN",503]="Es ist nicht erforderlich, den Scan erneut durchzuführen, um die Arcadyan-Algorithmus-PIN zu berechnen. Es wurde zuvor in dieser Sitzung gemacht"
	arr["TURKISH",503]="${pending_of_translation} Arcadyan algoritma PIN'ini hesaplamak için taramayı tekrar yapmak gerekli değildir. Bu zaten bu oturumda yapıldı"

	arr["ENGLISH",504]="${blue_color}This PIN calculation process is not entirely offline. A complete \"probe\" response is required from the target access point to obtain a necessary data. ${green_color}Do you want to continue? ${normal_color}${visual_choice}"
	arr["SPANISH",504]="${blue_color}Este proceso de cálculo de PIN no es puramente offline. Hace falta una respuesta \"probe\" completa del punto de acceso objetivo para obtener un dato necesario. ${green_color}¿Deseas continuar? ${normal_color}${visual_choice}"
	arr["FRENCH",504]="${blue_color}Ce processus de calcul du PIN n'est pas entièrement offline. Une réponse \"probe\" complète est requise part le point d'accès ciblés pour obtenir les données nécessaires. ${green_color}Voulez-vous continuer? ${normal_color}${visual_choice}"
	arr["CATALAN",504]="${blue_color}Aquest procés de càlcul de PIN no és purament offline. Cal una resposta \"probe\" completa del punt d'accés objectiu per obtenir una dada necessaria. ${green_color}¿Vols continuar? ${normal_color}${visual_choice}"
	arr["PORTUGUESE",504]="${blue_color}Este processo de cálculo do PIN não é totalmente offline. É necessária uma resposta de \"probe\" completa do ponto de acesso alvo para obter os dados necessários. ${green_color}Você deseja continuar? ${normal_color}${visual_choice}"
	arr["RUSSIAN",504]="${blue_color}Этот процесс расчета PIN-кода не является чисто офлайн. От целевой точки доступа требуется полный запрос \"probe\" для получения необходимых данных. ${green_color}Вы хотите продолжить? ${normal_color}${visual_choice}"
	arr["GREEK",504]="${blue_color}Αυτή η διαδικασία υπολογισμού PIN δεν είναι καθ' αυτοὺ offline. Απαιτείται ένα ολοκληρωμένο \"probe\" response από το σημείο πρόσβασης για να ληφθούν τα απαραίτητα δεδομένα. ${green_color}Θέλετε να συνεχίσετε; ${normal_color}${visual_choice}"
	arr["ITALIAN",504]="${blue_color}Questo processo di calcolo del PIN non è puramente offline. É richiesta una risposta completa \"probe\" dal punto di accesso obiettivo per ottenere i dati necessari. ${green_color}Vuoi continuare? ${normal_color}${visual_choice}"
	arr["POLISH",504]=" ${blue_color}Ten proces obliczania kodu PIN nie jest wyłącznie offline. Wymagana jest pełna odpowiedź \"probe\" z docelowego punktu dostępu, aby uzyskać niezbędne dane. ${green_color}Czy chcesz kontynuować? ${normal_color}${visual_choice}"
	arr["GERMAN",504]="${blue_color}Dieser PIN-Berechnungsprozess ist nicht rein offline. Eine vollständige \"probe\"-Antwort vom Zielzugriffspunkt wird benötigt, um die erforderlichen Daten zu erhalten. ${green_color} Möchten Sie fortfahren? ${normal_color}${visual_choice}"
	arr["TURKISH",504]="${pending_of_translation} ${blue_color}Bu PIN hesaplama işlemi tamamen çevrimdışı değildir. Gerekli bir veri elde etmek için hedef erişim noktasından eksiksiz bir \"probe\" yanıtı gerekir. ${green_color}Devam etmek istiyor musunuz? ${normal_color}${visual_choice}"

	arr["ENGLISH",505]="Do you want to enable \"DoS pursuit mode\"? ${blue_color}This will launch again the attack if target AP change its channel countering \"channel hopping\" ${normal_color}${visual_choice}"
	arr["SPANISH",505]="¿Deseas activar el \"modo persecución DoS\"? ${blue_color}Esto relanzará el ataque si el AP objetivo cambia de canal contrarrestando el \"channel hopping\" ${normal_color}${visual_choice}"
	arr["FRENCH",505]="Voulez-vous activer le \"mode de poursuite DoS\"? ${blue_color}Cela relancera l'attaque si le AP cible change de canal en contrecarrant le \"channel hopping\" ${normal_color}${visual_choice}"
	arr["CATALAN",505]="¿Vols activar el \"mode persecució DoS\"? ${blue_color}Això rellançarà l'atac si l'AP objectiu canvia de canal contrarestant el \"channel hopping\" ${normal_color}${visual_choice}"
	arr["PORTUGUESE",505]="Você deseja ativar o \"modo de perseguição\"? ${blue_color}Isso irá iniciar o ataque novamente se o alvo mudar de canal, evitando o \"channel hopping\" ${normal_color}${visual_choice}"
	arr["RUSSIAN",505]="Вы хотите включить \"режим преследования DoS\"? ${blue_color}Это мера противодействия \"channel hopping\" (автоматической смены канала ТД); атака будет перезапущена, если ТД изменит свой канал ${normal_color}${visual_choice}"
	arr["GREEK",505]="Θέλετε να ενεργοποιήσετε to \"DoS pursuit mode\"; ${blue_color}Αυτό θα ξεκινήσει πάλι την επίθεση, εάν το σημείο πρόσβασης αλλάξει το κανάλι του \"channel hopping\" ${normal_color}${visual_choice}"
	arr["ITALIAN",505]="Vuoi attivare la modalità \"DoS pursuit mode\"? ${blue_color}Questo riprenderà l'attacco se l'AP obiettivo cambia i canali contrastando il \"channel hopping\" ${normal_color}${visual_choice}"
	arr["POLISH",505]="Czy chcesz uaktywnić \"tryb DoS pursuit\"? ${blue_color}To spowoduje ponowne uruchomienie ataku, jeśli docelowy punkt dostępu AP zmieni kanały \"channel hopping\" ${normal_color}${visual_choice}"
	arr["GERMAN",505]="Möchten Sie den \"DoS pursuit mode\" aktivieren? ${blue_color}Dadurch wird der Angriff erneut gestartet, wenn der Ziel-AP den Kanal ändert, indem er dem \"channel hopping\" entgegenwirkt ${normal_color}${visual_choice}"
	arr["TURKISH",505]="${pending_of_translation} \"DoS takip modu\" özelliğini etkinleştirmek ister misiniz? ${blue_color}Bu, hedef AP'nin kanal sayma \"channel hopping\" ${normal_color}${visual_choice} ${blue_color}kanalını değiştirmesi durumunda saldırıyı yeniden başlatır"

	arr["ENGLISH",506]="DoS attack with the \"DoS pursuit mode\" enabled will start when you press [Enter] on this window. To stop it you must press [Ctrl+C] or close attack window"
	arr["SPANISH",506]="El ataque DoS con el \"modo persecución DoS\" activado comenzará cuando pulse [Enter] en esta ventana. Para detenerlo deberá pulsar [Ctrl+C] o cerrar la ventana del ataque"
	arr["FRENCH",506]="L'attaque DoS avec le \"mode de poursuite DoS\" activation démarrera lorsque vous appuyez sur [Enter] dans cette fenêtre. Pour l'arrêter, vous devez appuyer sur [Ctrl+C] ou fermer la fenêtre d'attaque"
	arr["CATALAN",506]="L'atac DoS amb el \"mode persecució DoS\" activat començarà quan premeu [Enter] en aquesta finestra. Per aturar-lo haurà de prémer [Ctrl+C] o tancar la finestra de l'atac"
	arr["PORTUGUESE",506]="O ataque DoS com o \"modo de perseguição\" foi ativo e será iniciado quando você pressionar [Enter] nesta janela. Para parar, você deve pressionar [Ctrl+C] ou fechar a janela do ataque"
	arr["RUSSIAN",506]="DoS-атака с включенным \"режимом DoS преследования\" будет запущена когда вы в этом окне нажмёте [Enter]. Для её остановки нажмите [Ctrl+C] или закройте окно атаки"
	arr["GREEK",506]="Η επίθεση DoS με το \"DoS pursuit mode\" ενεργοποιημένο θα ξεκινήσει όταν πατήσετε [Enter] σε αυτό το παράθυρο. Για να το σταματήσετε πρέπει να πατήσετε [Ctrl+C] ή να κλείσετε το παράθυρο"
	arr["ITALIAN",506]="L'attacco DoS con la modalità \"DoS pursuit mode\" abilitata inizierá quando si preme [Enter] in questa finestra. Per fermarlo bisogna premere [Ctrl+C] o chiudere la finestra di attacco"
	arr["POLISH",506]="Atak DoS z uruchomionym trybem \"DoS pursuit\" zostanie uruchomiony po naciśnięciu przycisku [Enter] w tym oknie. Aby go zatrzymać, musisz nacisnąć [Ctrl+C] lub zamknąć okno ataku"
	arr["GERMAN",506]="Der DoS-Angriff mit aktiviertem \"DoS pursuit mode\" wird gestartet, wenn Sie in diesen Fenster [Enter] drücken. Um es zu stoppen, müssen Sie [Ctrl+C] drücken oder das Angriffsfenster schließen"
	arr["TURKISH",506]="${pending_of_translation} Bu pencerede [Enter] 'a bastığınızda, \"DoS takip modu\" etkin olan DoS saldırısı başlayacaktır. Durdurmak için [Ctrl+C] tuşuna basmalı veya saldırı penceresini kapatmalısınız"

	arr["ENGLISH",507]="Channel change detected. Relaunching again DoS attack on \"DoS pursuit mode\" now on channel ${normal_color}${channel}"
	arr["SPANISH",507]="Cambio de canal detectado. Relanzando de nuevo ataque DoS en \"modo persecución DoS\" ahora sobre el canal ${normal_color}${channel}"
	arr["FRENCH",507]="Changement de canal détecté. Redémarrage de l'attaque DoS dans le \"mode de poursuite DoS\" maintenant sur le canal ${normal_color}${channel}"
	arr["CATALAN",507]="Canvi de canal detectat. Rellançant de nou l'atac DoS en \"mode persecució DoS\" ara sobre el canal ${normal_color}${channel}"
	arr["PORTUGUESE",507]="Mudança de canal detectada. Iniciando o ataque DoS novamente em \"modo de perseguição\". Agora no canal: ${normal_color}${channel}"
	arr["RUSSIAN",507]="Обнаружено изменение канала. Перезапуск DoS-атаки в \"режиме DoS преследования\" теперь на канале ${normal_color}${channel}"
	arr["GREEK",507]="Εντοπίστηκε αλλαγή καναλιού. Γίνεται πάλι επίθεση DoS \"DoS pursuit mode\" στο κανάλι ${normal_color}${channel}"
	arr["ITALIAN",507]="Cambio di canale rilevato. Riavviare nuovamente l'attacco DoS in modalità \"DoS pursuit mode\" sul canale ${normal_color}${channel}"
	arr["POLISH",507]="Wykryto zmianę kanału. Ponowne uruchomienie ataku DoS w trybie \"DoS pursuit\" na kanale ${normal_color}${channel}"
	arr["GERMAN",507]="Änderung des erkannten Kanals DoS-Angriff erneut im \"DoS pursuit mode\" auf dem Kanal wiederholen ${normal_color}${channel}"
	arr["TURKISH",507]="${pending_of_translation} Kanal değişikliği tespit edildi. Yeniden yeniden başlatılıyor DoS saldırısı şu anda kanalda \"DoS peşinde koşma modu\" ${normal_color}${channel}"

	arr["ENGLISH",508]="\"DoS pursuit mode\" can be unstable for this kind of DoS attack. If you are not obtaining an optimal result just select another kind of attack"
	arr["SPANISH",508]="El \"modo persecución DoS\" puede ser inestable para este tipo de ataque DoS. Si el resultado no es óptimo selecciona otro tipo de ataque"
	arr["FRENCH",508]="Le \"mode de poursuite DoS\" peut être instable pour ce type d'attaque DoS. Si le résultat n'est pas optimal, sélectionnez un autre type d'attaque"
	arr["CATALAN",508]="El \"mode persecució DoS\" pot ser inestable per a aquest tipus d'atac DoS. Si el resultat no és òptim selecciona un altre tipus d'atac"
	arr["PORTUGUESE",508]="O ataque DoS com o \"modo de perseguição\" pode ser instável. Se o resultado não for bom, selecione outro tipo de ataque"
	arr["RUSSIAN",508]="\"Режим DoS преследования\" может быть нестабильной для такой DoS-атаки. Если вы не получаете приемлемого результата, просто выберите другой тип атаки"
	arr["GREEK",508]="Το \"DoS pursuit mode\" μπορεί να είναι ασταθής για αυτό το είδος επίθεσης DoS. Εάν δεν δείτε σωστό αποτέλεσμα, επιλέξτε κάποιο άλλο είδος επίθεσης"
	arr["ITALIAN",508]="La modalitá \"DoS pursuit mode\" può essere instabile per questo tipo di attacco DoS. Se il risultato non è ottimale selezionare un altro tipo di attacco"
	arr["POLISH",508]="\"tryb DoS pursuit\" może być niestabilny dla tego typu ataków DoS. Jeśli wynik nie jest optymalny, wybierz inny rodzaj ataku"
	arr["GERMAN",508]="Der \"DoS pursuit mode\" kann für diese Art von DoS-Angriff instabil sein. Wenn das Ergebnis nicht optimal ist, wählen Sie eine andere Art von Angriff aus"
	arr["TURKISH",508]="${pending_of_translation} \"DoS takip modu\" bu tür DoS saldırısı için kararsız olabilir. Optimal bir sonuç elde edemiyorsanız, başka bir saldırı seçin"

	arr["ENGLISH",509]="If you want to integrate \"DoS pursuit mode\" on an Evil Twin attack, another additional wifi interface in monitor mode will be needed to be able to perform it"
	arr["SPANISH",509]="Si se quiere integrar el \"modo persecución DoS\" en un ataque Evil Twin, será necesario tener otro interfaz wifi adicional en modo monitor para llevarlo a cabo"
	arr["FRENCH",509]="Si vous souhaitez intégrer le \"mode de poursuite DoS\" dans une attaque Evil Twin, il sera nécessaire d'avoir une autre interface wifi supplémentaire en mode moniteur pour l'effectuer"
	arr["CATALAN",509]="Si es vol integrar el \"mode persecució DoS\" en un atac Evil Twin, serà necessari tenir una altra interfície wifi addicional en mode monitor per fer-ho"
	arr["PORTUGUESE",509]="Se você quiser integrar o ataque DoS com o \"modo de perseguição\" em um ataque Evil Twin, será necessário ter uma interface wifi adicional no modo monitor"
	arr["RUSSIAN",509]="Если вы хотите интегрировать \"режим DoS преследования\" на атаку Evil Twin, то для выполнения этого потребуется еще один дополнительный интерфейс wifi в режиме монитора"
	arr["GREEK",509]="Εάν θέλετε να ενσωματώσετε το \"DoS pursuit mode\" σε μια επίθεση Evil Twin, θα χρειαστεί μια επιπλέον διεπαφή wifi σε κατάσταση παρακολούθησης για να εκτελεστεί σωστά"
	arr["ITALIAN",509]="Se si desidera integrare la modalitá \"DoS pursuit mode\" in un attacco Evil Twin, sarà necessario disporre di un'altra interfaccia wifi aggiuntiva in modalità monitor"
	arr["POLISH",509]="Jeśli chcesz zintegrować \"tryb DoS pursuit\" w ataku Evil Twin, konieczne będzie posiadanie innego dodatkowego interfejsu wifi w trybie monitorowania"
	arr["GERMAN",509]="Wenn Sie den \"DoS pursuit mode\" in einen Evil-Twin-Angriff integrieren wollen, müssen Sie im monitor-Modus noch eine zusätzliche WLAN-Interface zur Verfügung haben, um es auszuführen"
	arr["TURKISH",509]="${pending_of_translation} Bir Kötü İkiz saldırısında \"DoS takip modu\" nu entegre etmek isterseniz, bunu gerçekleştirmek için monitör modunda başka bir ek wifi arabirimine ihtiyaç duyulacaktır"

	arr["ENGLISH",510]="On this screen, it's supposed an additional wifi interface is chosen, but you don't have anyone at this moment"
	arr["SPANISH",510]="En esta pantalla, se supone que deberías elegir otro interfaz wifi adicional, pero no dispones de ninguno en este momento"
	arr["FRENCH",510]="Sur cet écran, vous pourriez choisir une interface wifi supplémentaire, mais vous n'en avez pas d'autre en ce moment"
	arr["CATALAN",510]="En aquesta pantalla, se suposa que hauries de triar un altre interfície wifi addicional, però no disposes de cap en aquest moment"
	arr["PORTUGUESE",510]="Nesta tela você deveria escolher uma interface wifi adicional, mas você não tem nenhuma neste momento"
	arr["RUSSIAN",510]="На этом экране предполагается, что будет выбран дополнительный интерфейс wifi, но в данный момент у вас нет других беспроводных интерфейсов"
	arr["GREEK",510]="Σε αυτήν την οθόνη, υποτίθεται ότι έχει επιλεγεί μια πρόσθετη διεπαφή wifi, αλλά δεν έχετε επιλέξει κάποια αυτήν τη στιγμή"
	arr["ITALIAN",510]="In questa schermata, dovresti scegliere un'altra interfaccia wifi addizionale, ma in questo momento non ne hai nessuna"
	arr["POLISH",510]="Na tym ekranie należy wybrać inny dodatkowy interfejs wifi, ale nie masz go w tym momencie"
	arr["GERMAN",510]="Auf diesem Bildschirm sollten Sie eine andere zusätzliche Wi-Fi-Interface auswählen, aber Sie haben keine zu diesem Zeitpunkt"
	arr["TURKISH",510]="${pending_of_translation} Bu ekranda, ek bir wifi arayüzü seçildi, ancak şu anda hiç kimsenin yok"

	arr["ENGLISH",511]="Select another wireless interface:"
	arr["SPANISH",511]="Selecciona otra interfaz inalámbrica:"
	arr["FRENCH",511]="Sélectionnez une autre interface sans fil:"
	arr["CATALAN",511]="Selecciona un altra interfície sense fils:"
	arr["PORTUGUESE",511]="Selecione outra interface sem fio:"
	arr["RUSSIAN",511]="Выберите дополнительный беспроводной интерфейс:"
	arr["GREEK",511]="Επιλέξτε άλλη μία ασύρματη διεπαφή:"
	arr["ITALIAN",511]="Seleziona un'altra interfaccia wireless:"
	arr["POLISH",511]="Wybierz inny interfejs bezprzewodowy:"
	arr["GERMAN",511]="Wählen Sie eine andere drahtlose Interface:"
	arr["TURKISH",511]="Başka bir kablosuz arayüz seçin:"

	arr["ENGLISH",512]="\"DoS pursuit mode\" interface: ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["SPANISH",512]="Interfaz para \"modo persecución DoS\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["FRENCH",512]="Interface pour le \"mode de poursuite DoS\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["CATALAN",512]="Interfície per \"mode persecució DoS\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["PORTUGUESE",512]="Interface para o ataque DoS em \"modo de perseguição\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["RUSSIAN",512]="Интерфейс для \"режима DoS преследования\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["GREEK",512]="Διεπαφή για \"DoS pursuit mode\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["ITALIAN",512]="Interfaccia per la modalitá \"DoS pursuit mode\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["POLISH",512]="Interfejs dla \"tryb DoS pursuit\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["GERMAN",512]="Interface für \"DoS pursuit mode\": ${pink_color}${secondary_wifi_interface}${normal_color}"
	arr["TURKISH",512]="${pending_of_translation} \"DoS takip modu\" arayüzü: ${pink_color}${secondary_wifi_interface}${normal_color}"

	arr["ENGLISH",513]="Interface will be tried to be changed to monitor mode automatically"
	arr["SPANISH",513]="Se intentará cambiar la interfaz a modo monitor automáticamente"
	arr["FRENCH",513]="l'interface va essayer de changer en mode monitor automatiquement"
	arr["CATALAN",513]="S'intentarà canviar la interfície a mode monitor automàticament"
	arr["PORTUGUESE",513]="O script tentará mudar a interface para o modo monitor automaticamente"
	arr["RUSSIAN",513]="Будет сделана автоматическая попытка перевести интерфейс в режим монитора"
	arr["GREEK",513]="Γίνεται απόπειρα αλλαγής κατάστασης διεπαφής σε κατάσταση παρακολούθησης"
	arr["ITALIAN",513]="Si cercherà di cambiare automaticamente l'interfaccia alla modalità monitor"
	arr["POLISH",513]="Spowoduje to automatyczną zmianę interfejsu w tryb monitorowania"
	arr["GERMAN",513]="Es wird versucht, die Interface automatisch in den monitor-Modus zu ändern"
	arr["TURKISH",513]="Arayüz otomatik olarak izleme modunu değiştirmeye çalışılacaktır"

	arr["ENGLISH",514]="Interface ${pink_color}${current_iface_on_messages}${blue_color} selected. Mode: ${pink_color}${ifacemode}${blue_color}. Supported bands: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["SPANISH",514]="Interfaz ${pink_color}${current_iface_on_messages}${blue_color} seleccionada. Modo: ${pink_color}${ifacemode}${blue_color}. Bandas soportadas: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["FRENCH",514]="L'interface ${pink_color}${current_iface_on_messages}${blue_color} sélectionnée. Mode: ${pink_color}${ifacemode}${blue_color}. Bandes supportées: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["CATALAN",514]="Interfície ${pink_color}${current_iface_on_messages}${blue_color} seleccionada. Mode: ${pink_color}${ifacemode}${blue_color}. Bandes suportades: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["PORTUGUESE",514]="Interface ${pink_color}${current_iface_on_messages}${blue_color} selecionada. Modo: ${pink_color}${ifacemode}${blue_color}. Banda(s) suportada(s): ${pink_color}${interface_supported_bands}${normal_color}"
	arr["RUSSIAN",514]="Выбран интерфейс ${pink_color}${current_iface_on_messages}${blue_color}. Режим: ${pink_color}${ifacemode}${blue_color}. Поддерживаемые диапазоны: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["GREEK",514]="Η διεπαφή ${pink_color}${current_iface_on_messages}${blue_color} έχει επιλεχθεί. Κατάσταση: ${pink_color}${ifacemode}${blue_color}. Υποστηριζόμενες ζώνες: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["ITALIAN",514]="Interfaccia ${pink_color}${current_iface_on_messages}${blue_color} selezionata. Modalità: ${pink_color}${ifacemode}${blue_color}. Bande supportate: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["POLISH",514]="Wybrany został interfejs ${pink_color}${current_iface_on_messages}${blue_color}. Tryb: ${pink_color}${ifacemode}${blue_color}. Obsługiwane pasma: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["GERMAN",514]="Interface ${pink_color}${current_iface_on_messages}${blue_color} ausgewählt. Modus: ${pink_color}${ifacemode}${blue_color}. Unterstützte Bänder: ${pink_color}${interface_supported_bands}${normal_color}"
	arr["TURKISH",514]="${pending_of_translation} Arayüz ${pink_color}${current_iface_on_messages}${blue_color}seçildi. Kip: ${pink_color}${ifacemode}${blue_color}. Desteklenen bantlar: ${pink_color}${interface_supported_bands}${normal_color}"

	arr["ENGLISH",515]="You have selected a 5Ghz band channel but your wifi card doesn't support 5Ghz. The operation can't be performed"
	arr["SPANISH",515]="Tienes un canal de la banda de 5Ghz seleccionado pero tu tarjeta wifi no soporta 5Ghz. La operación no se puede llevar a cabo"
	arr["FRENCH",515]="Vous avez sélectionné un canal 5Ghz mais votre carte wifi ne prend pas en charge la 5Ghz. L'opération ne peut pas être effectuée"
	arr["CATALAN",515]="Tens un canal de la banda de 5Ghz seleccionat però la teva targeta wifi no suporta 5Ghz. L'operació no es pot dur a terme"
	arr["PORTUGUESE",515]="Você selecionou um canal da banda de 5Ghz, mas sua interface wifi não suporta 5Ghz. A operação não pode ser realizada"
	arr["RUSSIAN",515]="Вы выбрали канал на частотах 5Ghz, но ваша wifi карта не поддерживает 5Ghz. Операция не может быть выполнена"
	arr["GREEK",515]="Έχετε επιλέξει κανάλι της ζώνης 5Ghz, αλλά η κάρτα wifi σας δεν υποστηρίζει 5Ghz. Η λειτουργία δεν μπορεί να πραγματοποιηθεί"
	arr["ITALIAN",515]="Hai selezionato un canale della banda 5Ghz, ma la tua scheda wifi non supporta 5Ghz. L'operazione non può essere eseguita"
	arr["POLISH",515]="Masz wybrane pasmo 5Ghz, lecz Twoja karta wifi go nie obsługuje. Operacja nie może być wykonana"
	arr["GERMAN",515]="Sie haben einen Kanal des 5Ghz-Bandes ausgewählt, aber Ihre WLAN-Karte unterstützt 5Ghz nicht. Die Operation kann nicht ausgeführt werden"
	arr["TURKISH",515]="5Ghz bant kanalı seçtiniz, ancak wifi kartınız 5Ghz'yi desteklemiyor. İşlem gerçekleştirilemiyor"

	arr["ENGLISH",516]="It is known that the software used in the 5Ghz band still presents some problems sometimes. For example airodump, that when scanning networks can show a value \"-1\" on channel depending of the card chipset and the driver. It is also known that Ralink chipsets sometimes are getting errors on high channels \">=60\""
	arr["SPANISH",516]="Es conocido que el software utilizado en la banda de 5Ghz aún presenta algunos problemas a veces. Como por ejemplo airodump, que al escanear redes puede mostrar un valor \"-1\" en el canal dependiendo del chipset de tu tarjeta y del driver. También es conocido que los chipsets Ralink a veces dan fallos en los canales altos \">=60\""
	arr["FRENCH",516]="Il est connu que les logiciels utilisés dans la bande 5Ghz présente toujours quelques problèmes. Comme par exemple airodump, lors du scan des réseaux, peut montrer une valeur \"-1\" dans le canal en fonction du chipset de votre carte et le pilote. Il est également connu que les chipsets Ralink donnent parfois des échecs dans les canaux élevés \">=60\""
	arr["CATALAN",516]="És conegut que el programari utilitzat en la banda de 5Ghz encara presenta alguns problemes de vegades. Com per exemple airodump, que al escanejar xarxes pot mostrar un valor \"-1\" al canal depenent del chipset de la targeta i del driver. També és conegut que els chipsets Ralink de vegades donen fallades en els canals alts \">=60\""
	arr["PORTUGUESE",516]="O software usado para a banda de 5Ghz ainda apresenta alguns problemas. Como por exemplo airodump, que ao escanear as redes pode mostrar um valor \"-1\" no canal dependendo do chipset da sua interface e do driver. Também se sabe que os chipsets Ralink às vezes apresentaram falhas em canais altos \">=60\""
	arr["RUSSIAN",516]="Известно, что программное обеспечение, используемое на частотах 5Ghz, все еще иногда вызывает некоторые проблемы. Например, airodump при сканировании сетей может отображать \"-1\" вместо значения канала, это зависит от чипсета вашей карты и драйвера. Известно также, что чипсеты Ralink иногда дают сбои в высоких каналах \">=60\""
	arr["GREEK",516]="Είναι γνωστό ότι το λογισμικό που χρησιμοποιείται για την 5Ghz ζώνη εξακολουθεί να παρουσιάζει κάποια προβλήματα κατά καιρούς. Όπως για παράδειγμα το airodump, μπορεί να εμφανίσει την τιμή \"-1\" στη θέση του καναλιού καθώς γίνεται σάρωση, ανάλογα με το chipset της κάρτας σας και του προγράμματος οδήγησης (driver). Είναι επίσης γνωστό ότι τα Ralink chipsets μερικές φορές αποτυγχάνουν σε υψηλά κανάλια \">= 60\""
	arr["ITALIAN",516]="È noto che il software utilizzato dalla banda 5Ghz presenta ancora qualche problema. Come per esempio airodump, che durante la scansione delle reti può mostrare un valore \"-1\" nel canale a seconda del chipset della scheda di rete e del driver. È anche noto che i chipset Ralink a volte danno dei problemi nei canali alti \">=60\""
	arr["POLISH",516]="Powszechnie wiadomo, że oprogramowanie używane w paśmie 5Ghz wciąż ma pewne problemy. Na przykład airodump, który podczas skanowania sieci może pokazywać wartość \"-1\" w kanale w zależności od chipsetu karty i sterownika. Wiadomo również, że chipsety Ralink czasami zawodzą w wysokich kanałach \">=60\""
	arr["GERMAN",516]="Es ist bekannt, dass die Software, die im 5Ghz-Band verwendet wird, immer noch einige Probleme aufweist. Wie zum Beispiel airodump, dass beim Netzwerk-Scannen den Wert \"-1\" in den Kanal zeigt, abhängig von dem Chipset Ihrer Karte und des Treibers. Es ist auch bekannt, dass Ralink-Chipsätze manchmal Fehler in hohen Kanälen \">=60\" ergeben"
	arr["TURKISH",516]="${pending_of_translation} 5Ghz bandında kullanılan yazılımın bazen bazı problemler yaşadığı bilinmektedir. Örneğin airodump, ağları tararken, kart yonga setine ve sürücüye bağlı olarak kanalda \"-1\" değeri gösterebilir. Ralink yonga kümelerinin bazen yüksek kanallarda hatalar aldıkları da bilinir. \">=60\""

	arr["ENGLISH",517]="Set channel (2.4Ghz 1-14) or (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["SPANISH",517]="Selecciona un canal (2.4Ghz 1-14) o (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["FRENCH",517]="Sélectionnez un canal (2.4Ghz 1-14) ou (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["CATALAN",517]="Seleccioni un canal (2.4Ghz 1-14) o (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["PORTUGUESE",517]="Escolha um canal (2.4Ghz 1-14) ou (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["RUSSIAN",517]="Установите канал (2.4Ghz 1-14) или (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["GREEK",517]="Θέστε κανάλι (2.4Ghz 1-14) ή (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["ITALIAN",517]="Seleziona un canale (2.4Ghz 1-14) o (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["POLISH",517]="Wybierz kanał (2.4Ghz 1-14) lub (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["GERMAN",517]="Wählen Sie einen Kanal aus (2.4Ghz 1-14) oder (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"
	arr["TURKISH",517]="Kanal seç (2.4Ghz 1-14) or (5Ghz 36|38|40|44|46|48|52|54|56|60|62|64|100|102|104|108|110|112):"

	arr["ENGLISH",518]="Language changed to Turkish"
	arr["SPANISH",518]="Idioma cambiado a Turco"
	arr["FRENCH",518]="${pending_of_translation} Le script sera maintenant en Turc"
	arr["CATALAN",518]="${pending_of_translation} Idioma canviat a Turc"
	arr["PORTUGUESE",518]="Idioma alterado para Turco"
	arr["RUSSIAN",518]="${pending_of_translation} Язык изменён на Турецкий"
	arr["GREEK",518]="Η γλώσσα άλλαξε στα Τουρκικά"
	arr["ITALIAN",518]="Lingua cambiata a Turco"
	arr["POLISH",518]="${pending_of_translation} Zmieniono język na Turecki"
	arr["GERMAN",518]="${pending_of_translation} Sprache wurde auf Türkisch geändert"
	arr["TURKISH",518]="Dil Türkçe olarak değiştirildi"

	arr["ENGLISH",519]="11. Turkish"
	arr["SPANISH",519]="11. Turco"
	arr["FRENCH",519]="${pending_of_translation} 11. Turc"
	arr["CATALAN",519]="${pending_of_translation} 11. Turc"
	arr["PORTUGUESE",519]="11. Turco"
	arr["RUSSIAN",519]="${pending_of_translation} 11. Турецкий"
	arr["GREEK",519]="11. Τουρκικά"
	arr["ITALIAN",519]="11. Turco"
	arr["POLISH",519]="${pending_of_translation} 11. Turecki"
	arr["GERMAN",519]="${pending_of_translation} 11. Türkisch"
	arr["TURKISH",519]="11. Türkçe"

	case "${3}" in
		"yellow")
			interrupt_checkpoint "${2}" "${3}"
			echo_yellow "${arr[${1},${2}]}"
		;;
		"blue")
			echo_blue "${arr[${1},${2}]}"
		;;
		"red")
			echo_red "${arr[${1},${2}]}"
		;;
		"green")
			if [ "${2}" -ne "${abort_question}" ]; then
				interrupt_checkpoint "${2}" "${3}"
			fi
			echo_green "${arr[${1},${2}]}"
		;;
		"pink")
			echo_pink "${arr[${1},${2}]}"
		;;
		"white")
			echo_white "${arr[${1},${2}]}"
		;;
		"title")
			generate_dynamic_line "${arr[${1},${2}]}" "title"
		;;
		"read")
			interrupt_checkpoint "${2}" "${3}"
			read -p "${arr[${1},${2}]}" -r
		;;
		"multiline")
			echo -ne "${arr[${1},${2}]}"
		;;
		"hint")
			echo_brown "${hintvar} ${pink_color}${arr[${1},${2}]}"
		;;
		"separator")
			generate_dynamic_line "${arr[${1},${2}]}" "separator"
		;;
		"warning")
			echo_yellow "${arr[${1},${2}]}"
		;;
		"under_construction")
			echo_red_slim "${arr[${1},${2}]} (${under_constructionvar})"
		;;
		*)
			if [ -z "${3}" ]; then
				last_echo "${arr[${1},${2}]}" "${normal_color}"
			else
				special_text_missed_optional_tool "${1}" "${2}" "${3}"
			fi
		;;
	esac
}
